@@ -1,30 +1,21 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 #include "StatisticsItemConverter.hxx"
 #include "SchWhichPairs.hxx"
@@ -58,15 +49,15 @@ using namespace ::com::sun::star;
 namespace
 {
 
-uno::Reference< beans::XPropertySet > lcl_GetYErrorBar(
-    const uno::Reference< beans::XPropertySet > & xProp )
+uno::Reference< beans::XPropertySet > lcl_GetErrorBar(
+    const uno::Reference< beans::XPropertySet > & xProp, bool bYError )
 {
     uno::Reference< beans::XPropertySet > xResult;
 
     if( xProp.is())
         try
         {
-            ( xProp->getPropertyValue( C2U( "ErrorBarY" )) >>= xResult );
+        ( xProp->getPropertyValue( bYError ? OUString( "ErrorBarY" ) : OUString("ErrorBarX") ) >>= xResult );
         }
         catch( const uno::Exception & ex )
         {
@@ -115,8 +106,8 @@ void lcl_getErrorValues( const uno::Reference< beans::XPropertySet > & xErrorBar
 
     try
     {
-        xErrorBarProp->getPropertyValue( C2U( "PositiveError" )) >>= rOutPosError;
-        xErrorBarProp->getPropertyValue( C2U( "NegativeError" )) >>= rOutNegError;
+        xErrorBarProp->getPropertyValue( "PositiveError" ) >>= rOutPosError;
+        xErrorBarProp->getPropertyValue( "NegativeError" ) >>= rOutNegError;
     }
     catch( const uno::Exception & ex )
     {
@@ -133,8 +124,8 @@ void lcl_getErrorIndicatorValues(
 
     try
     {
-        xErrorBarProp->getPropertyValue( C2U( "ShowPositiveError" )) >>= rOutShowPosError;
-        xErrorBarProp->getPropertyValue( C2U( "ShowNegativeError" )) >>= rOutShowNegError;
+        xErrorBarProp->getPropertyValue( "ShowPositiveError" ) >>= rOutShowPosError;
+        xErrorBarProp->getPropertyValue( "ShowNegativeError" ) >>= rOutShowNegError;
     }
     catch( const uno::Exception & ex )
     {
@@ -250,8 +241,11 @@ bool StatisticsItemConverter::ApplySpecialItem(
         // SCHATTR_STAT_CONSTMINUS and SCHATTR_STAT_INDICATE
         case SCHATTR_STAT_KIND_ERROR:
         {
+            bool bYError =
+                static_cast<const SfxBoolItem&>(rItemSet.Get(SCHATTR_STAT_ERRORBAR_TYPE)).GetValue();
+
             uno::Reference< beans::XPropertySet > xErrorBarProp(
-                lcl_GetYErrorBar( GetPropertySet() ));
+                lcl_GetErrorBar( GetPropertySet(), bYError ));
 
             SvxChartKindError eErrorKind =
                 static_cast< const SvxChartKindErrorItem & >(
@@ -288,12 +282,11 @@ bool StatisticsItemConverter::ApplySpecialItem(
                 if( !xErrorBarProp.is() )
                 {
                     xErrorBarProp = lcl_GetDefaultErrorBar();
-                    GetPropertySet()->setPropertyValue(
-                        C2U( "ErrorBarY" ), uno::makeAny( xErrorBarProp ));
+                    GetPropertySet()->setPropertyValue( bYError ? OUString( "ErrorBarY" ) : OUString("ErrorBarX"),
+                                                        uno::makeAny( xErrorBarProp ));
                 }
 
-                xErrorBarProp->setPropertyValue( C2U( "ErrorBarStyle" ),
-                                                    uno::makeAny( nStyle ));
+                xErrorBarProp->setPropertyValue( "ErrorBarStyle" , uno::makeAny( nStyle ));
                 bChanged = true;
             }
         }
@@ -302,9 +295,12 @@ bool StatisticsItemConverter::ApplySpecialItem(
         case SCHATTR_STAT_PERCENT:
         case SCHATTR_STAT_BIGERROR:
         {
-            OSL_FAIL( "Deprectaed item" );
+            OSL_FAIL( "Deprecated item" );
+            bool bYError =
+                static_cast<const SfxBoolItem&>(rItemSet.Get(SCHATTR_STAT_ERRORBAR_TYPE)).GetValue();
+
             uno::Reference< beans::XPropertySet > xErrorBarProp(
-                lcl_GetYErrorBar( GetPropertySet()));
+                lcl_GetErrorBar( GetPropertySet(), bYError));
             bool bOldHasErrorBar = xErrorBarProp.is();
 
             double fValue =
@@ -317,10 +313,8 @@ bool StatisticsItemConverter::ApplySpecialItem(
                 ! ( ::rtl::math::approxEqual( fPos, fValue ) &&
                     ::rtl::math::approxEqual( fNeg, fValue )))
             {
-                xErrorBarProp->setPropertyValue( C2U( "PositiveError" ),
-                                                    uno::makeAny( fValue ));
-                xErrorBarProp->setPropertyValue( C2U( "NegativeError" ),
-                                                    uno::makeAny( fValue ));
+                xErrorBarProp->setPropertyValue( "PositiveError" , uno::makeAny( fValue ));
+                xErrorBarProp->setPropertyValue( "NegativeError" , uno::makeAny( fValue ));
                 bChanged = true;
             }
         }
@@ -328,8 +322,11 @@ bool StatisticsItemConverter::ApplySpecialItem(
 
         case SCHATTR_STAT_CONSTPLUS:
         {
+            bool bYError =
+                static_cast<const SfxBoolItem&>(rItemSet.Get(SCHATTR_STAT_ERRORBAR_TYPE)).GetValue();
+
             uno::Reference< beans::XPropertySet > xErrorBarProp(
-                lcl_GetYErrorBar( GetPropertySet()));
+                lcl_GetErrorBar( GetPropertySet(),bYError));
             bool bOldHasErrorBar = xErrorBarProp.is();
 
             double fValue =
@@ -341,7 +338,7 @@ bool StatisticsItemConverter::ApplySpecialItem(
             if( bOldHasErrorBar &&
                 ! ::rtl::math::approxEqual( fPos, fValue ))
             {
-                xErrorBarProp->setPropertyValue( C2U( "PositiveError" ), uno::makeAny( fValue ));
+                xErrorBarProp->setPropertyValue( "PositiveError" , uno::makeAny( fValue ));
                 bChanged = true;
             }
         }
@@ -349,8 +346,10 @@ bool StatisticsItemConverter::ApplySpecialItem(
 
         case SCHATTR_STAT_CONSTMINUS:
         {
+            bool bYError =
+                static_cast<const SfxBoolItem&>(rItemSet.Get(SCHATTR_STAT_ERRORBAR_TYPE)).GetValue();
             uno::Reference< beans::XPropertySet > xErrorBarProp(
-                lcl_GetYErrorBar( GetPropertySet()));
+                lcl_GetErrorBar( GetPropertySet(),bYError));
             bool bOldHasErrorBar = xErrorBarProp.is();
 
             double fValue =
@@ -362,7 +361,7 @@ bool StatisticsItemConverter::ApplySpecialItem(
             if( bOldHasErrorBar &&
                 ! ::rtl::math::approxEqual( fNeg, fValue ))
             {
-                xErrorBarProp->setPropertyValue( C2U( "NegativeError" ), uno::makeAny( fValue ));
+                xErrorBarProp->setPropertyValue( "NegativeError" , uno::makeAny( fValue ));
                 bChanged = true;
             }
         }
@@ -404,12 +403,12 @@ bool StatisticsItemConverter::ApplySpecialItem(
             if( xEqProp.is())
             {
                 bool bShowEq = false;
-                xEqProp->getPropertyValue( C2U("ShowEquation")) >>= bShowEq;
+                xEqProp->getPropertyValue( "ShowEquation" ) >>= bShowEq;
                 bool bNewShowEq =
                     static_cast< const SfxBoolItem & >( rItemSet.Get( nWhichId )).GetValue();
                 if( bShowEq != bNewShowEq )
                 {
-                    xEqProp->setPropertyValue( C2U("ShowEquation"), uno::makeAny( bNewShowEq ));
+                    xEqProp->setPropertyValue( "ShowEquation" , uno::makeAny( bNewShowEq ));
                     bChanged = true;
                 }
             }
@@ -422,12 +421,12 @@ bool StatisticsItemConverter::ApplySpecialItem(
             if( xEqProp.is())
             {
                 bool bShowCoeff = false;
-                xEqProp->getPropertyValue( C2U("ShowCorrelationCoefficient")) >>= bShowCoeff;
+                xEqProp->getPropertyValue( "ShowCorrelationCoefficient" ) >>= bShowCoeff;
                 bool bNewShowCoeff =
                     static_cast< const SfxBoolItem & >( rItemSet.Get( nWhichId )).GetValue();
                 if( bShowCoeff != bNewShowCoeff )
                 {
-                    xEqProp->setPropertyValue( C2U("ShowCorrelationCoefficient"), uno::makeAny( bNewShowCoeff ));
+                    xEqProp->setPropertyValue( "ShowCorrelationCoefficient" , uno::makeAny( bNewShowCoeff ));
                     bChanged = true;
                 }
             }
@@ -436,8 +435,10 @@ bool StatisticsItemConverter::ApplySpecialItem(
 
         case SCHATTR_STAT_INDICATE:
         {
+            bool bYError =
+                static_cast<const SfxBoolItem&>(rItemSet.Get(SCHATTR_STAT_ERRORBAR_TYPE)).GetValue();
             uno::Reference< beans::XPropertySet > xErrorBarProp(
-                lcl_GetYErrorBar( GetPropertySet()));
+                lcl_GetErrorBar( GetPropertySet(),bYError));
             bool bOldHasErrorBar = xErrorBarProp.is();
 
             SvxChartIndicate eIndicate =
@@ -454,8 +455,8 @@ bool StatisticsItemConverter::ApplySpecialItem(
                 ( bShowPos != bNewIndPos ||
                   bShowNeg != bNewIndNeg ))
             {
-                xErrorBarProp->setPropertyValue( C2U( "ShowPositiveError" ), uno::makeAny( bNewIndPos ));
-                xErrorBarProp->setPropertyValue( C2U( "ShowNegativeError" ), uno::makeAny( bNewIndNeg ));
+                xErrorBarProp->setPropertyValue( "ShowPositiveError" , uno::makeAny( bNewIndPos ));
+                xErrorBarProp->setPropertyValue( "ShowNegativeError" , uno::makeAny( bNewIndNeg ));
                 bChanged = true;
             }
         }
@@ -464,9 +465,10 @@ bool StatisticsItemConverter::ApplySpecialItem(
         case SCHATTR_STAT_RANGE_POS:
         case SCHATTR_STAT_RANGE_NEG:
         {
-            // @todo: also be able to deal with x-error bars
-            const bool bYError = true;
-            uno::Reference< chart2::data::XDataSource > xErrorBarSource( lcl_GetYErrorBar( GetPropertySet()), uno::UNO_QUERY );
+            const bool bYError =
+                static_cast<const SfxBoolItem&>(rItemSet.Get(SCHATTR_STAT_ERRORBAR_TYPE)).GetValue();
+            uno::Reference< chart2::data::XDataSource > xErrorBarSource( lcl_GetErrorBar( GetPropertySet(), bYError),
+                                                                         uno::UNO_QUERY );
             uno::Reference< chart2::XChartDocument > xChartDoc( m_xModel, uno::UNO_QUERY );
             uno::Reference< chart2::data::XDataProvider > xDataProvider;
 
@@ -474,13 +476,13 @@ bool StatisticsItemConverter::ApplySpecialItem(
                 xDataProvider.set( xChartDoc->getDataProvider());
             if( xErrorBarSource.is() && xDataProvider.is())
             {
-                ::rtl::OUString aNewRange( static_cast< const SfxStringItem & >( rItemSet.Get( nWhichId )).GetValue());
+                OUString aNewRange( static_cast< const SfxStringItem & >( rItemSet.Get( nWhichId )).GetValue());
                 bool bApplyNewRange = false;
 
                 bool bIsPositiveValue( nWhichId == SCHATTR_STAT_RANGE_POS );
                 if( xChartDoc->hasInternalDataProvider())
                 {
-                    if( aNewRange.getLength())
+                    if( !aNewRange.isEmpty())
                     {
                         uno::Reference< chart2::data::XDataSequence > xSeq(
                             StatisticsHelper::getErrorDataSequenceFromDataSource(
@@ -493,7 +495,7 @@ bool StatisticsItemConverter::ApplySpecialItem(
                             if( xIntDataProvider.is())
                             {
                                 xIntDataProvider->appendSequence();
-                                aNewRange = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("last"));
+                                aNewRange = "last";
                                 bApplyNewRange = true;
                             }
                         }
@@ -505,7 +507,7 @@ bool StatisticsItemConverter::ApplySpecialItem(
                         StatisticsHelper::getErrorDataSequenceFromDataSource(
                             xErrorBarSource, bIsPositiveValue, bYError ));
                     bApplyNewRange =
-                        ! ( xSeq.is() && aNewRange.equals( xSeq->getSourceRangeRepresentation()));
+                        ! ( xSeq.is() && (aNewRange == xSeq->getSourceRangeRepresentation()));
                 }
 
                 if( bApplyNewRange )
@@ -535,13 +537,15 @@ void StatisticsItemConverter::FillSpecialItem(
 
         case SCHATTR_STAT_KIND_ERROR:
         {
+            bool bYError =
+                static_cast<const SfxBoolItem&>(rOutItemSet.Get(SCHATTR_STAT_ERRORBAR_TYPE)).GetValue();
             SvxChartKindError eErrorKind = CHERROR_NONE;
             uno::Reference< beans::XPropertySet > xErrorBarProp(
-                lcl_GetYErrorBar( GetPropertySet()));
+                lcl_GetErrorBar( GetPropertySet(), bYError));
             if( xErrorBarProp.is() )
             {
                 sal_Int32 nStyle = 0;
-                if( xErrorBarProp->getPropertyValue( C2U( "ErrorBarStyle" )) >>= nStyle )
+                if( xErrorBarProp->getPropertyValue( "ErrorBarStyle" ) >>= nStyle )
                 {
                     switch( nStyle )
                     {
@@ -570,7 +574,9 @@ void StatisticsItemConverter::FillSpecialItem(
 
         case SCHATTR_STAT_PERCENT:
         {
-            uno::Reference< beans::XPropertySet > xErrorBarProp( lcl_GetYErrorBar( GetPropertySet()));
+            bool bYError =
+                static_cast<const SfxBoolItem&>(rOutItemSet.Get(SCHATTR_STAT_ERRORBAR_TYPE)).GetValue();
+            uno::Reference< beans::XPropertySet > xErrorBarProp( lcl_GetErrorBar( GetPropertySet(),bYError));
             if( xErrorBarProp.is())
             {
                 double fPos, fNeg;
@@ -582,7 +588,9 @@ void StatisticsItemConverter::FillSpecialItem(
 
         case SCHATTR_STAT_BIGERROR:
         {
-            uno::Reference< beans::XPropertySet > xErrorBarProp( lcl_GetYErrorBar( GetPropertySet()));
+            bool bYError =
+                static_cast<const SfxBoolItem&>(rOutItemSet.Get(SCHATTR_STAT_ERRORBAR_TYPE)).GetValue();
+            uno::Reference< beans::XPropertySet > xErrorBarProp( lcl_GetErrorBar( GetPropertySet(),bYError));
             if( xErrorBarProp.is())
             {
                 double fPos, fNeg;
@@ -594,7 +602,9 @@ void StatisticsItemConverter::FillSpecialItem(
 
         case SCHATTR_STAT_CONSTPLUS:
         {
-            uno::Reference< beans::XPropertySet > xErrorBarProp( lcl_GetYErrorBar( GetPropertySet()));
+            bool bYError =
+                static_cast<const SfxBoolItem&>(rOutItemSet.Get(SCHATTR_STAT_ERRORBAR_TYPE)).GetValue();
+            uno::Reference< beans::XPropertySet > xErrorBarProp( lcl_GetErrorBar( GetPropertySet(),bYError));
             if( xErrorBarProp.is())
             {
                 double fPos, fNeg;
@@ -606,7 +616,9 @@ void StatisticsItemConverter::FillSpecialItem(
 
         case SCHATTR_STAT_CONSTMINUS:
         {
-            uno::Reference< beans::XPropertySet > xErrorBarProp( lcl_GetYErrorBar( GetPropertySet()));
+            bool bYError =
+                static_cast<const SfxBoolItem&>(rOutItemSet.Get(SCHATTR_STAT_ERRORBAR_TYPE)).GetValue();
+            uno::Reference< beans::XPropertySet > xErrorBarProp( lcl_GetErrorBar( GetPropertySet(),bYError));
             if( xErrorBarProp.is())
             {
                 double fPos, fNeg;
@@ -632,7 +644,7 @@ void StatisticsItemConverter::FillSpecialItem(
             bool bShowEq = false;
             uno::Reference< beans::XPropertySet > xEqProp( lcl_getEquationProperties( GetPropertySet(), 0 ));
             if( xEqProp.is())
-                xEqProp->getPropertyValue( C2U("ShowEquation")) >>= bShowEq;
+                xEqProp->getPropertyValue( "ShowEquation" ) >>= bShowEq;
             rOutItemSet.Put( SfxBoolItem( nWhichId, bShowEq ));
         }
         break;
@@ -642,14 +654,16 @@ void StatisticsItemConverter::FillSpecialItem(
             bool bShowCoeff = false;
             uno::Reference< beans::XPropertySet > xEqProp( lcl_getEquationProperties( GetPropertySet(), 0 ));
             if( xEqProp.is())
-                xEqProp->getPropertyValue( C2U("ShowCorrelationCoefficient")) >>= bShowCoeff;
+                xEqProp->getPropertyValue( "ShowCorrelationCoefficient" ) >>= bShowCoeff;
             rOutItemSet.Put( SfxBoolItem( nWhichId, bShowCoeff ));
         }
         break;
 
         case SCHATTR_STAT_INDICATE:
         {
-            uno::Reference< beans::XPropertySet > xErrorBarProp( lcl_GetYErrorBar( GetPropertySet()));
+            bool bYError =
+                static_cast<const SfxBoolItem&>(rOutItemSet.Get(SCHATTR_STAT_ERRORBAR_TYPE)).GetValue();
+            uno::Reference< beans::XPropertySet > xErrorBarProp( lcl_GetErrorBar( GetPropertySet(),bYError));
             SvxChartIndicate eIndicate = CHINDICATE_BOTH;
             if( xErrorBarProp.is())
             {
@@ -678,12 +692,15 @@ void StatisticsItemConverter::FillSpecialItem(
         case SCHATTR_STAT_RANGE_POS:
         case SCHATTR_STAT_RANGE_NEG:
         {
-            uno::Reference< chart2::data::XDataSource > xErrorBarSource( lcl_GetYErrorBar( GetPropertySet()), uno::UNO_QUERY );
+            bool bYError =
+                static_cast<const SfxBoolItem&>(rOutItemSet.Get(SCHATTR_STAT_ERRORBAR_TYPE)).GetValue();
+            uno::Reference< chart2::data::XDataSource > xErrorBarSource( lcl_GetErrorBar( GetPropertySet(),bYError),
+                                                                         uno::UNO_QUERY );
             if( xErrorBarSource.is())
             {
                 uno::Reference< chart2::data::XDataSequence > xSeq(
                     StatisticsHelper::getErrorDataSequenceFromDataSource(
-                        xErrorBarSource, (nWhichId == SCHATTR_STAT_RANGE_POS) /*, true */ /* y */ ));
+                        xErrorBarSource, (nWhichId == SCHATTR_STAT_RANGE_POS), bYError ));
                 if( xSeq.is())
                     rOutItemSet.Put( SfxStringItem( nWhichId, String( xSeq->getSourceRangeRepresentation())));
             }
