@@ -1,30 +1,21 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 #include <com/sun/star/container/XChild.hpp>
 #include <com/sun/star/container/XNameAccess.hpp>
@@ -95,7 +86,7 @@ struct EmbedImpl
     uno::WeakReference < uno::XInterface > m_xModel;
     //EmbeddedObjectContainerNameMap maTempObjectContainer;
     //uno::Reference < embed::XStorage > mxTempStorage;
-    sal_Bool bOwnsStorage;
+    bool bOwnsStorage;
 
     const uno::Reference < embed::XStorage >& GetReplacements();
 };
@@ -109,7 +100,7 @@ const uno::Reference < embed::XStorage >& EmbedImpl::GetReplacements()
             mxImageStorage = mxStorage->openStorageElement(
                 ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ObjectReplacements")), embed::ElementModes::READWRITE );
         }
-        catch ( uno::Exception& )
+        catch (const uno::Exception&)
         {
             mxImageStorage = mxStorage->openStorageElement(
                 ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ObjectReplacements")), embed::ElementModes::READ );
@@ -126,7 +117,7 @@ EmbeddedObjectContainer::EmbeddedObjectContainer()
 {
     pImpl = new EmbedImpl;
     pImpl->mxStorage = ::comphelper::OStorageHelper::GetTemporaryStorage();
-    pImpl->bOwnsStorage = sal_True;
+    pImpl->bOwnsStorage = true;
     pImpl->mpTempObjectContainer = 0;
 }
 
@@ -134,7 +125,7 @@ EmbeddedObjectContainer::EmbeddedObjectContainer( const uno::Reference < embed::
 {
     pImpl = new EmbedImpl;
     pImpl->mxStorage = rStor;
-    pImpl->bOwnsStorage = sal_False;
+    pImpl->bOwnsStorage = false;
     pImpl->mpTempObjectContainer = 0;
 }
 
@@ -142,7 +133,7 @@ EmbeddedObjectContainer::EmbeddedObjectContainer( const uno::Reference < embed::
 {
     pImpl = new EmbedImpl;
     pImpl->mxStorage = rStor;
-    pImpl->bOwnsStorage = sal_False;
+    pImpl->bOwnsStorage = false;
     pImpl->mpTempObjectContainer = 0;
     pImpl->m_xModel = xModel;
 }
@@ -155,7 +146,7 @@ void EmbeddedObjectContainer::SwitchPersistence( const uno::Reference < embed::X
         pImpl->mxStorage->dispose();
 
     pImpl->mxStorage = rStor;
-    pImpl->bOwnsStorage = sal_False;
+    pImpl->bOwnsStorage = false;
 }
 
 sal_Bool EmbeddedObjectContainer::CommitImageSubStorage()
@@ -180,7 +171,7 @@ sal_Bool EmbeddedObjectContainer::CommitImageSubStorage()
                 xTransact->commit();
             }
         }
-        catch( uno::Exception& )
+        catch (const uno::Exception&)
         {
             return sal_False;
         }
@@ -200,7 +191,7 @@ void EmbeddedObjectContainer::ReleaseImageSubStorage()
             pImpl->mxImageStorage->dispose();
             pImpl->mxImageStorage = uno::Reference< embed::XStorage >();
         }
-        catch( uno::Exception& )
+        catch (const uno::Exception&)
         {
             OSL_FAIL( "Problems releasing image substorage!\n" );
         }
@@ -230,12 +221,12 @@ void EmbeddedObjectContainer::CloseEmbeddedObjects()
             {
                 xClose->close( sal_True );
             }
-            catch ( uno::Exception& )
+            catch (const uno::Exception&)
             {
             }
         }
 
-        aIt++;
+        ++aIt;
     }
 }
 
@@ -290,7 +281,7 @@ sal_Bool EmbeddedObjectContainer::HasEmbeddedObject( const uno::Reference < embe
         if ( (*aIt).second == xObj )
             return sal_True;
         else
-            aIt++;
+            ++aIt;
     }
 
     return sal_False;
@@ -313,7 +304,7 @@ sal_Bool EmbeddedObjectContainer::HasInstantiatedEmbeddedObject( const ::rtl::OU
         if ( (*aIt).second == xObj )
             return (*aIt).first;
         else
-            aIt++;
+            ++aIt;
     }
 
     OSL_FAIL( "Unknown object!" );
@@ -324,7 +315,7 @@ uno::Reference < embed::XEmbeddedObject > EmbeddedObjectContainer::GetEmbeddedOb
 {
     RTL_LOGFILE_CONTEXT( aLog, "comphelper (mv76033) comphelper::EmbeddedObjectContainer::GetEmbeddedObject" );
 
-    OSL_ENSURE( rName.getLength(), "Empty object name!");
+    OSL_ENSURE( !rName.isEmpty(), "Empty object name!");
 
     uno::Reference < embed::XEmbeddedObject > xObj;
     EmbeddedObjectContainerNameMap::iterator aIt = pImpl->maObjectContainer.find( rName );
@@ -370,7 +361,7 @@ uno::Reference < embed::XEmbeddedObject > EmbeddedObjectContainer::Get_Impl( con
         // object was not added until now - should happen only by calling this method from "inside"
         //TODO/LATER: it would be good to detect an error when an object should be created already, but isn't (not an "inside" call)
         uno::Reference < embed::XEmbedObjectCreator > xFactory( ::comphelper::getProcessServiceFactory()->createInstance(
-                ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("com.sun.star.embed.EmbeddedObjectCreator")) ), uno::UNO_QUERY );
+                OUString("com.sun.star.embed.EmbeddedObjectCreator") ), uno::UNO_QUERY_THROW );
         uno::Sequence< beans::PropertyValue > aObjDescr( xCopy.is() ? 2 : 1 );
         aObjDescr[0].Name = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Parent" ) );
         aObjDescr[0].Value <<= pImpl->m_xModel.get();
@@ -390,7 +381,7 @@ uno::Reference < embed::XEmbeddedObject > EmbeddedObjectContainer::Get_Impl( con
         // insert object into my list
         AddEmbeddedObject( xObj, rName );
     }
-    catch ( uno::Exception& )
+    catch (const uno::Exception&)
     {
     }
 
@@ -402,7 +393,7 @@ uno::Reference < embed::XEmbeddedObject > EmbeddedObjectContainer::CreateEmbedde
 {
     RTL_LOGFILE_CONTEXT( aLog, "comphelper (mv76033) comphelper::EmbeddedObjectContainer::CreateEmbeddedObject" );
 
-    if ( !rNewName.getLength() )
+    if ( rNewName.isEmpty() )
         rNewName = CreateUniqueObjectName();
 
     OSL_ENSURE( !HasEmbeddedObject(rNewName), "Object to create already exists!");
@@ -427,7 +418,7 @@ uno::Reference < embed::XEmbeddedObject > EmbeddedObjectContainer::CreateEmbedde
         OSL_ENSURE( !xObj.is() || xObj->getCurrentState() != embed::EmbedStates::LOADED,
                     "A freshly create object should be running always!\n" );
     }
-    catch ( uno::Exception& )
+    catch (const uno::Exception&)
     {
     }
 
@@ -444,7 +435,7 @@ void EmbeddedObjectContainer::AddEmbeddedObject( const ::com::sun::star::uno::Re
     RTL_LOGFILE_CONTEXT( aLog, "comphelper (mv76033) comphelper::EmbeddedObjectContainer::AddEmbeddedObject" );
 
 #if OSL_DEBUG_LEVEL > 1
-    OSL_ENSURE( rName.getLength(), "Added object doesn't have a name!");
+    OSL_ENSURE( !rName.isEmpty(), "Added object doesn't have a name!");
     uno::Reference < container::XNameAccess > xAccess( pImpl->mxStorage, uno::UNO_QUERY );
     uno::Reference < embed::XEmbedPersist > xEmb( xObj, uno::UNO_QUERY );
     uno::Reference < embed::XLinkageSupport > xLink( xEmb, uno::UNO_QUERY );
@@ -488,7 +479,7 @@ void EmbeddedObjectContainer::AddEmbeddedObject( const ::com::sun::star::uno::Re
                     {
                         pImpl->mpTempObjectContainer->pImpl->mxStorage->removeElement( aTempName );
                     }
-                    catch ( uno::Exception& )
+                    catch (const uno::Exception&)
                     {
                     }
                 }
@@ -498,7 +489,7 @@ void EmbeddedObjectContainer::AddEmbeddedObject( const ::com::sun::star::uno::Re
                 break;
             }
             else
-                aIt++;
+                ++aIt;
         }
     }
 }
@@ -508,7 +499,7 @@ sal_Bool EmbeddedObjectContainer::StoreEmbeddedObject( const uno::Reference < em
     RTL_LOGFILE_CONTEXT( aLog, "comphelper (mv76033) comphelper::EmbeddedObjectContainer::StoreEmbeddedObject" );
 
     uno::Reference < embed::XEmbedPersist > xPersist( xObj, uno::UNO_QUERY );
-    if ( !rName.getLength() )
+    if ( rName.isEmpty() )
         rName = CreateUniqueObjectName();
 
 #if OSL_DEBUG_LEVEL > 1
@@ -534,7 +525,7 @@ sal_Bool EmbeddedObjectContainer::StoreEmbeddedObject( const uno::Reference < em
             }
         }
     }
-    catch ( uno::Exception& )
+    catch (const uno::Exception&)
     {
         // TODO/LATER: better error recovery should keep storage intact
         return sal_False;
@@ -561,7 +552,7 @@ uno::Reference < embed::XEmbeddedObject > EmbeddedObjectContainer::InsertEmbedde
 {
     RTL_LOGFILE_CONTEXT( aLog, "comphelper (mv76033) comphelper::EmbeddedObjectContainer::InsertEmbeddedObject( InputStream )" );
 
-    if ( !rNewName.getLength() )
+    if ( rNewName.isEmpty() )
         rNewName = CreateUniqueObjectName();
 
     // store it into the container storage
@@ -577,7 +568,7 @@ uno::Reference < embed::XEmbeddedObject > EmbeddedObjectContainer::InsertEmbedde
         uno::Reference < embed::XStorage > xNewStore = pImpl->mxStorage->openStorageElement( rNewName, embed::ElementModes::READWRITE );
         xStore->copyToStorage( xNewStore );
     }
-    catch ( uno::Exception& )
+    catch (const uno::Exception&)
     {
         if ( bIsStorage )
             // it is storage persistence, but opening of new substorage or copying to it failed
@@ -597,7 +588,7 @@ uno::Reference < embed::XEmbeddedObject > EmbeddedObjectContainer::InsertEmbedde
                     ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "MediaType" ) ),
                     uno::makeAny( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "application/vnd.sun.star.oleobject" ) ) ) );
         }
-        catch ( uno::Exception& )
+        catch (const uno::Exception&)
         {
             // complete disaster!
             return uno::Reference < embed::XEmbeddedObject >();
@@ -612,7 +603,7 @@ uno::Reference < embed::XEmbeddedObject > EmbeddedObjectContainer::InsertEmbedde
             // no object could be created, so withdraw insertion
             pImpl->mxStorage->removeElement( rNewName );
     }
-    catch ( uno::Exception& )
+    catch (const uno::Exception&)
     {
     }
 
@@ -623,7 +614,7 @@ uno::Reference < embed::XEmbeddedObject > EmbeddedObjectContainer::InsertEmbedde
 {
     RTL_LOGFILE_CONTEXT( aLog, "comphelper (mv76033) comphelper::EmbeddedObjectContainer::InsertEmbeddedObject( MediaDescriptor )" );
 
-    if ( !rNewName.getLength() )
+    if ( rNewName.isEmpty() )
         rNewName = CreateUniqueObjectName();
 
     uno::Reference < embed::XEmbeddedObject > xObj;
@@ -647,7 +638,7 @@ uno::Reference < embed::XEmbeddedObject > EmbeddedObjectContainer::InsertEmbedde
 
         AddEmbeddedObject( xObj, rNewName );
     }
-    catch ( uno::Exception& )
+    catch (const uno::Exception&)
     {
     }
 
@@ -658,7 +649,7 @@ uno::Reference < embed::XEmbeddedObject > EmbeddedObjectContainer::InsertEmbedde
 {
     RTL_LOGFILE_CONTEXT( aLog, "comphelper (mv76033) comphelper::EmbeddedObjectContainer::InsertEmbeddedLink" );
 
-    if ( !rNewName.getLength() )
+    if ( rNewName.isEmpty() )
         rNewName = CreateUniqueObjectName();
 
     uno::Reference < embed::XEmbeddedObject > xObj;
@@ -683,7 +674,7 @@ uno::Reference < embed::XEmbeddedObject > EmbeddedObjectContainer::InsertEmbedde
 
         AddEmbeddedObject( xObj, rNewName );
     }
-    catch ( uno::Exception& )
+    catch (const uno::Exception&)
     {
     }
 
@@ -698,7 +689,7 @@ sal_Bool EmbeddedObjectContainer::TryToCopyGraphReplacement( EmbeddedObjectConta
 
     sal_Bool bResult = sal_False;
 
-    if ( ( &rSrc != this || !aOrigName.equals( aTargetName ) ) && aOrigName.getLength() && aTargetName.getLength() )
+    if ( ( &rSrc != this || !aOrigName.equals( aTargetName ) ) && !aOrigName.isEmpty() && !aTargetName.isEmpty() )
     {
         ::rtl::OUString aMediaType;
         uno::Reference < io::XInputStream > xGrStream = rSrc.GetGraphicStream( aOrigName, &aMediaType );
@@ -723,10 +714,11 @@ uno::Reference < embed::XEmbeddedObject > EmbeddedObjectContainer::CopyAndGetEmb
         uno::Reference < embed::XEmbedPersist > xPersist( xObj, uno::UNO_QUERY_THROW );
         aOrigName = xPersist->getEntryName();
     }
-    catch( uno::Exception& )
-    {}
+    catch (const uno::Exception&)
+    {
+    }
 
-    if ( !rName.getLength() )
+    if ( rName.isEmpty() )
         rName = CreateUniqueObjectName();
 
     // objects without persistance are not really stored by the method
@@ -744,7 +736,7 @@ uno::Reference < embed::XEmbeddedObject > EmbeddedObjectContainer::CopyAndGetEmb
                 {
                     // this is a OOo link, it has no persistence
                     ::rtl::OUString aURL = xOrigLinkage->getLinkURL();
-                    if ( !aURL.getLength() )
+                    if ( aURL.isEmpty() )
                         throw uno::RuntimeException();
 
                     // create new linked object from the URL the link is based on
@@ -813,7 +805,7 @@ uno::Reference < embed::XEmbeddedObject > EmbeddedObjectContainer::CopyAndGetEmb
                                 aPropertiesList[nInd].Name,
                                 xOrigProps->getPropertyValue( aPropertiesList[nInd].Name ) );
                         }
-                        catch( beans::PropertyVetoException& )
+                        catch (const beans::PropertyVetoException&)
                         {
                             // impossibility to copy readonly property is not treated as an error for now
                             // but the assertion is helpful to detect such scenarios and review them
@@ -825,7 +817,7 @@ uno::Reference < embed::XEmbeddedObject > EmbeddedObjectContainer::CopyAndGetEmb
                    if ( xResult.is() )
                     AddEmbeddedObject( xResult, rName );
             }
-            catch( uno::Exception& )
+            catch (const uno::Exception&)
             {
                 if ( xResult.is() )
                 {
@@ -833,8 +825,9 @@ uno::Reference < embed::XEmbeddedObject > EmbeddedObjectContainer::CopyAndGetEmb
                     {
                         xResult->close( sal_True );
                     }
-                    catch( uno::Exception& )
-                    {}
+                    catch (const uno::Exception&)
+                    {
+                    }
                     xResult = uno::Reference< embed::XEmbeddedObject >();
                 }
             }
@@ -846,7 +839,7 @@ uno::Reference < embed::XEmbeddedObject > EmbeddedObjectContainer::CopyAndGetEmb
     if ( xResult.is() )
     {
         // the object is successfully copied, try to copy graphical replacement
-        if ( aOrigName.getLength() )
+        if ( !aOrigName.isEmpty() )
             TryToCopyGraphReplacement( rSrc, aOrigName, rName );
 
         // the object might need the size to be set
@@ -856,8 +849,9 @@ uno::Reference < embed::XEmbeddedObject > EmbeddedObjectContainer::CopyAndGetEmb
                 xResult->setVisualAreaSize( embed::Aspects::MSOLE_CONTENT,
                                             xObj->getVisualAreaSize( embed::Aspects::MSOLE_CONTENT ) );
         }
-        catch( uno::Exception& )
-        {}
+        catch (const uno::Exception&)
+        {
+        }
     }
 
     return xResult;
@@ -882,9 +876,8 @@ sal_Bool EmbeddedObjectContainer::MoveEmbeddedObject( EmbeddedObjectContainer& r
         if ( bRet )
             TryToCopyGraphReplacement( rSrc, aName, rName );
     }
-    catch ( uno::Exception& e )
+    catch (const uno::Exception&)
     {
-        (void)e;
         OSL_FAIL( "Failed to insert embedded object into storage!" );
         bRet = sal_False;
     }
@@ -903,7 +896,7 @@ sal_Bool EmbeddedObjectContainer::MoveEmbeddedObject( EmbeddedObjectContainer& r
                 break;
             }
 
-            aIt++;
+            ++aIt;
         }
 
         OSL_ENSURE( bRet, "Object not found for removal!" );
@@ -915,7 +908,7 @@ sal_Bool EmbeddedObjectContainer::MoveEmbeddedObject( EmbeddedObjectContainer& r
                 if ( xPersist.is() )
                     rSrc.pImpl->mxStorage->removeElement( aName );
             }
-            catch ( uno::Exception& )
+            catch (const uno::Exception&)
             {
                 OSL_FAIL( "Failed to remove object from storage!" );
                 bRet = sal_False;
@@ -980,7 +973,7 @@ sal_Bool EmbeddedObjectContainer::MoveEmbeddedObject( const ::rtl::OUString& rNa
 
             return sal_True;
         }
-        catch ( uno::Exception& )
+        catch (const uno::Exception&)
         {
             OSL_FAIL("Could not move object!");
             return sal_False;
@@ -1018,7 +1011,7 @@ sal_Bool EmbeddedObjectContainer::RemoveEmbeddedObject( const uno::Reference < e
         {
             xClose->close( sal_True );
         }
-        catch ( util::CloseVetoException& )
+        catch (const util::CloseVetoException&)
         {
             bClose = sal_False;
         }
@@ -1058,14 +1051,14 @@ sal_Bool EmbeddedObjectContainer::RemoveEmbeddedObject( const uno::Reference < e
                         static const ::rtl::OUString s_sMediaType(RTL_CONSTASCII_USTRINGPARAM("MediaType"));
                         xStorProps->getPropertyValue( s_sMediaType ) >>= aOrigStorMediaType;
 
-                        OSL_ENSURE( aOrigStorMediaType.getLength(), "No valuable media type in the storage!\n" );
+                        OSL_ENSURE( !aOrigStorMediaType.isEmpty(), "No valuable media type in the storage!\n" );
 
                         uno::Reference< beans::XPropertySet > xTargetStorProps(
                                                                     pImpl->mpTempObjectContainer->pImpl->mxStorage,
                                                                     uno::UNO_QUERY_THROW );
                         xTargetStorProps->setPropertyValue( s_sMediaType,uno::makeAny( aOrigStorMediaType ) );
                     }
-                    catch( uno::Exception& )
+                    catch (const uno::Exception&)
                     {
                         OSL_FAIL( "Can not set the new media type to a storage!\n" );
                     }
@@ -1085,7 +1078,7 @@ sal_Bool EmbeddedObjectContainer::RemoveEmbeddedObject( const uno::Reference < e
                 // objects without persistence need to stay in running state if they shall not be closed
                 xObj->changeState( embed::EmbedStates::RUNNING );
         }
-        catch ( uno::Exception& )
+        catch (const uno::Exception&)
         {
             return sal_False;
         }
@@ -1105,7 +1098,7 @@ sal_Bool EmbeddedObjectContainer::RemoveEmbeddedObject( const uno::Reference < e
             break;
         }
 
-        aIt++;
+        ++aIt;
     }
 
     OSL_ENSURE( bFound, "Object not found for removal!" );
@@ -1125,7 +1118,7 @@ sal_Bool EmbeddedObjectContainer::RemoveEmbeddedObject( const uno::Reference < e
             if ( xPersist.is() && pImpl->mxStorage->hasByName( aName ) )
                 pImpl->mxStorage->removeElement( aName );
         }
-        catch ( uno::Exception& )
+        catch (const uno::Exception&)
         {
             OSL_FAIL( "Failed to remove object from storage!" );
             return sal_False;
@@ -1152,7 +1145,7 @@ sal_Bool EmbeddedObjectContainer::CloseEmbeddedObject( const uno::Reference < em
             break;
         }
 
-        aIt++;
+        ++aIt;
     }
 
     if ( bFound )
@@ -1162,7 +1155,7 @@ sal_Bool EmbeddedObjectContainer::CloseEmbeddedObject( const uno::Reference < em
         {
             xClose->close( sal_True );
         }
-        catch ( uno::Exception& )
+        catch (const uno::Exception&)
         {
             // it is no problem if the object is already closed
             // TODO/LATER: what if the object can not be closed?
@@ -1178,8 +1171,8 @@ uno::Reference < io::XInputStream > EmbeddedObjectContainer::GetGraphicStream( c
 
     uno::Reference < io::XInputStream > xStream;
 
-    OSL_ENSURE( aName.getLength(), "Retrieving graphic for unknown object!" );
-    if ( aName.getLength() )
+    OSL_ENSURE( !aName.isEmpty(), "Retrieving graphic for unknown object!" );
+    if ( !aName.isEmpty() )
     {
         try
         {
@@ -1196,7 +1189,7 @@ uno::Reference < io::XInputStream > EmbeddedObjectContainer::GetGraphicStream( c
                 }
             }
         }
-        catch ( uno::Exception& )
+        catch (const uno::Exception&)
         {
         }
     }
@@ -1219,7 +1212,7 @@ uno::Reference < io::XInputStream > EmbeddedObjectContainer::GetGraphicStream( c
             break;
         }
 
-        aIt++;
+        ++aIt;
     }
 
     // try to load it from the container storage
@@ -1255,7 +1248,7 @@ sal_Bool EmbeddedObjectContainer::InsertGraphicStream( const com::sun::star::uno
         xPropSet->setPropertyValue( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Compressed")),
                                     uno::makeAny( (sal_Bool)sal_True ) );
     }
-    catch( uno::Exception& )
+    catch (const uno::Exception&)
     {
         return sal_False;
     }
@@ -1286,7 +1279,7 @@ sal_Bool EmbeddedObjectContainer::InsertGraphicStreamDirectly( const com::sun::s
 
         xOptRepl->insertStreamElementDirect( rObjectName, rStream, aProps );
     }
-    catch( uno::Exception& )
+    catch (const uno::Exception&)
     {
         return sal_False;
     }
@@ -1304,7 +1297,7 @@ sal_Bool EmbeddedObjectContainer::RemoveGraphicStream( const ::rtl::OUString& rO
         uno::Reference < embed::XStorage > xReplacements = pImpl->GetReplacements();
         xReplacements->removeElement( rObjectName );
     }
-    catch( uno::Exception& )
+    catch (const uno::Exception&)
     {
         return sal_False;
     }
@@ -1316,7 +1309,7 @@ namespace {
                                             const uno::Reference< io::XInputStream >& xInStream,
                                             const ::rtl::OUString& aStreamName )
     {
-        OSL_ENSURE( aStreamName.getLength() && xInStream.is() && xDocStor.is(), "Misuse of the method!\n" );
+        OSL_ENSURE( !aStreamName.isEmpty() && xInStream.is() && xDocStor.is(), "Misuse of the method!\n" );
 
         try
         {
@@ -1336,7 +1329,7 @@ namespace {
             if ( xTransact.is() )
                 xTransact->commit();
         }
-        catch( uno::Exception& )
+        catch (const uno::Exception&)
         {
             OSL_FAIL( "The pictures storage is not available!\n" );
         }
@@ -1437,7 +1430,7 @@ sal_Bool EmbeddedObjectContainer::StoreAsChildren(sal_Bool _bOasisFormat,sal_Boo
         bResult = aCnt.CommitImageSubStorage();
 
     }
-    catch ( uno::Exception& )
+    catch (const uno::Exception&)
     {
         // TODO/LATER: error handling
         bResult = sal_False;
@@ -1453,7 +1446,7 @@ sal_Bool EmbeddedObjectContainer::StoreAsChildren(sal_Bool _bOasisFormat,sal_Boo
             if ( _xStorage->hasByName( aObjReplElement ) && _xStorage->isStorageElement( aObjReplElement ) )
                 _xStorage->removeElement( aObjReplElement );
         }
-        catch ( uno::Exception& )
+        catch (const uno::Exception&)
         {
             // TODO/LATER: error handling;
             bResult = sal_False;
@@ -1510,7 +1503,7 @@ sal_Bool EmbeddedObjectContainer::StoreChildren(sal_Bool _bOasisFormat,sal_Bool
                     //TODO/LATER: only storing if changed!
                     xPersist->storeOwn();
                 }
-                catch( uno::Exception& )
+                catch (const uno::Exception&)
                 {
                     // TODO/LATER: error handling
                     bResult = sal_False;
@@ -1532,7 +1525,7 @@ sal_Bool EmbeddedObjectContainer::StoreChildren(sal_Bool _bOasisFormat,sal_Bool
                             InsertStreamIntoPicturesStorage_Impl( pImpl->mxStorage, xInStream, *pIter );
                     }
                 }
-                catch( uno::Exception& )
+                catch (const uno::Exception&)
                 {
                 }
             }
@@ -1551,7 +1544,7 @@ sal_Bool EmbeddedObjectContainer::StoreChildren(sal_Bool _bOasisFormat,sal_Bool
             if ( !_bOasisFormat && pImpl->mxStorage->hasByName( aObjReplElement ) && pImpl->mxStorage->isStorageElement( aObjReplElement ) )
                 pImpl->mxStorage->removeElement( aObjReplElement );
         }
-        catch( uno::Exception& )
+        catch (const uno::Exception&)
         {
             // TODO/LATER: error handling
             bResult = sal_False;
@@ -1579,7 +1572,7 @@ uno::Reference< io::XInputStream > EmbeddedObjectContainer::GetGraphicReplacemen
             aRep.Data >>= aSeq;
             xInStream = new ::comphelper::SequenceInputStream( aSeq );
         }
-        catch ( uno::Exception& )
+        catch (const uno::Exception&)
         {
         }
     }
@@ -1611,7 +1604,7 @@ sal_Bool EmbeddedObjectContainer::SetPersistentEntries(const uno::Reference< emb
                                                 uno::Sequence< beans::PropertyValue >() );
 
                 }
-                catch( uno::Exception& )
+                catch (const uno::Exception&)
                 {
                     // TODO/LATER: error handling
                     bError = sal_True;
@@ -1627,7 +1620,7 @@ sal_Bool EmbeddedObjectContainer::SetPersistentEntries(const uno::Reference< emb
                     if ( xModif->isModified() )
                         xModif->setModified( sal_False );
                 }
-                catch( uno::Exception& )
+                catch (const uno::Exception&)
                 {
                 }
             }
