@@ -1,30 +1,21 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 #include "file/FColumns.hxx"
 #include "connectivity/sdbcx/VColumn.hxx"
@@ -44,13 +35,14 @@ using namespace ::com::sun::star::sdbc;
 using namespace ::com::sun::star::container;
 using namespace ::com::sun::star::lang;
 
-typedef connectivity::sdbcx::OCollection OCollection_TYPE;
-
 sdbcx::ObjectType OColumns::createObject(const ::rtl::OUString& _rName)
 {
-
+    const Any aCatalog;
+    const ::rtl::OUString sCatalogName;
+    const ::rtl::OUString sSchemaName(m_pTable->getSchema());
+    const ::rtl::OUString sTableName(m_pTable->getName());
     Reference< XResultSet > xResult = m_pTable->getConnection()->getMetaData()->getColumns(Any(),
-    m_pTable->getSchema(),m_pTable->getName(),_rName);
+    sSchemaName, sTableName, _rName);
 
     sdbcx::ObjectType xRet = NULL;
     if(xResult.is())
@@ -71,7 +63,10 @@ sdbcx::ObjectType OColumns::createObject(const ::rtl::OUString& _rName)
                                             sal_False,
                                             sal_False,
                                             sal_False,
-                                            m_pTable->getConnection()->getMetaData()->supportsMixedCaseQuotedIdentifiers());
+                                            m_pTable->getConnection()->getMetaData()->supportsMixedCaseQuotedIdentifiers(),
+                                            sCatalogName,
+                                            sSchemaName,
+                                            sTableName);
                 xRet = pRet;
                 break;
             }
