@@ -1,32 +1,21 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
-
-
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 #include <comphelper/processfactory.hxx>
 #include <com/sun/star/awt/PosSize.hpp>
@@ -67,7 +56,7 @@ using namespace ::rtl;
 #define C2S(cChar) String::CreateFromAscii(cChar)
 #define DISTANCE_CONTROL_TO_FIXEDTEXT 5
 
-::Point lcl_MovePoint(const FixedText& rFixedText)
+static ::Point lcl_MovePoint(const FixedText& rFixedText)
 {
     ::Point aRet(rFixedText.GetPosPixel());
     aRet.X() += rFixedText.GetSizePixel().Width();
@@ -76,7 +65,7 @@ using namespace ::rtl;
 }
 
 //-----------------------------------------------------------------------------
-OUString lcl_GetColumnName( const Mapping* pMapping, sal_uInt16 nIndexPos )
+static OUString lcl_GetColumnName( const Mapping* pMapping, sal_uInt16 nIndexPos )
 {
     BibConfig* pBibConfig = BibModul::GetConfig();
     OUString sRet = pBibConfig->GetDefColumnName(nIndexPos);
@@ -155,7 +144,7 @@ void BibPosListener::cursorMoved(const lang::EventObject& /*aEvent*/) throw( uno
                 uno::Any aVal = xValueAcc->getByName(uTypeMapping);
                 uno::Reference< uno::XInterface >  xInt = *(uno::Reference< uno::XInterface > *)aVal.getValue();
                 uno::Reference< sdb::XColumn >  xCol(xInt, UNO_QUERY);
-                DBG_ASSERT(xCol.is(), "BibPosListener::positioned : invalid column (no sdb::XColumn) !");
+                DBG_ASSERT(xCol.is(), "BibPosListener::cursorMoved : invalid column (no sdb::XColumn) !");
                 if (xCol.is())
                 {
                     nTempVal = xCol->getShort();
@@ -179,10 +168,9 @@ void BibPosListener::cursorMoved(const lang::EventObject& /*aEvent*/) throw( uno
             }
         }
     }
-    catch(Exception& rEx)
+    catch(const Exception&)
     {
-        (void) rEx; // make compiler happy
-        OSL_FAIL("BibPosListener::positioned: something went wrong !");
+        OSL_FAIL("BibPosListener::cursorMoved: something went wrong !");
     }
 }
 
@@ -511,8 +499,8 @@ uno::Reference< awt::XControlModel >  BibGeneralPage::AddXControl(
                     uno::Sequence<rtl::OUString> aListSource(TYPE_COUNT);
                     rtl::OUString* pListSourceArr = aListSource.getArray();
                     //pListSourceArr[0] = C2U("select TypeName, TypeIndex from TypeNms");
-                    for(sal_uInt16 i = 0; i < TYPE_COUNT; i++)
-                        pListSourceArr[i] = String::CreateFromInt32(i);
+                    for(sal_Int32 i = 0; i < TYPE_COUNT; ++i)
+                        pListSourceArr[i] = rtl::OUString::valueOf(i);
                     aAny.setValue(&aListSource, ::getCppuType((uno::Sequence<rtl::OUString>*)0));
 
                     xPropSet->setPropertyValue(C2U("ListSource"), aAny);
@@ -721,7 +709,7 @@ IMPL_LINK(BibGeneralPage, ScrollHdl, ScrollBar*, pScroll)
         nCurrentOffset = aFixedTexts[0]->GetPosPixel().Y() - aBasePos.Y();
     else
         nCurrentOffset = aFixedTexts[0]->GetPosPixel().X() - aBasePos.X();
-    nOffset = pScroll->IsVisible() ? pScroll->GetThumbPos() + nCurrentOffset : nCurrentOffset;;
+    nOffset = pScroll->IsVisible() ? pScroll->GetThumbPos() + nCurrentOffset : nCurrentOffset;
 
     for(sal_uInt16 i = 0; i < FIELD_COUNT; i++)
     {
@@ -813,7 +801,7 @@ sal_Bool BibGeneralPage::HandleShortCutKey( const KeyEvent& rKeyEvent )
     DBG_ASSERT( KEY_MOD2 == rKeyEvent.GetKeyCode().GetModifier(), "+BibGeneralPage::HandleShortCutKey(): this is not for me!" );
 
     const vcl::I18nHelper&      rI18nHelper = Application::GetSettings().GetUILocaleI18nHelper();
-    const xub_Unicode           c = rKeyEvent.GetCharCode();
+    const sal_Unicode           c = rKeyEvent.GetCharCode();
     sal_Bool                        bHandled = sal_False;
 
     sal_Int16                   i;
