@@ -1,34 +1,22 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
-
-//----------------------------------------------------------------------------
-#include <vcl/sound.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/scrbar.hxx>
 
@@ -98,7 +86,7 @@ void ValWnd::SetValue( const String& rStrVal )
 //----------------------------------------------------------------------------
 
 ArgEdit::ArgEdit( Window* pParent, const ResId& rResId )
-    :   RefEdit( pParent, rResId ),
+    :   RefEdit( pParent, NULL, rResId ),
         pEdPrev ( NULL ),
         pEdNext ( NULL ),
         pSlider ( NULL ),
@@ -190,11 +178,7 @@ void ArgEdit::KeyInput( const KeyEvent& rKEvt )
             {
                 pEd->GrabFocus();
             }
-            else
-                Sound::Beep();
         }
-        else
-            Sound::Beep();
     }
     else
         RefEdit::KeyInput( rKEvt );
@@ -307,7 +291,6 @@ String ArgInput::GetArgName()
     return aPrivArgName;
 }
 
-
 /*************************************************************************
 #*  Member:     SetArgName                                  Date:13.01.97
 #*------------------------------------------------------------------------
@@ -344,45 +327,6 @@ void ArgInput::SetArgSelection  (const Selection& rSel )
     if(pEdArg !=NULL) pEdArg ->SetSelection(rSel );
 }
 
-/*************************************************************************
-#*  Member:     SetArgSelection                             Date:13.01.97
-#*------------------------------------------------------------------------
-#*
-#*  Class:      ArgInput
-#*
-#*  Function:   Returns the Selection for the EditBox.
-#*
-#*  Input:      String
-#*
-#*  Output:     ---
-#*
-#************************************************************************/
-Selection ArgInput::GetArgSelection ()
-{
-    Selection   aSel;
-    if(pEdArg !=NULL) aSel=pEdArg ->GetSelection();
-    return aSel;
-}
-
-/*************************************************************************
-#*  Member:     SetArgSelection                             Date:13.01.97
-#*------------------------------------------------------------------------
-#*
-#*  Class:      ArgInput
-#*
-#*  Function:   Replaces the Selection in the EditBox.
-#*
-#*  Input:      String
-#*
-#*  Output:     ---
-#*
-#************************************************************************/
-void ArgInput::ReplaceSelOfArg(const String& rStr )
-{
-    if(pEdArg !=NULL) pEdArg ->ReplaceSelected(rStr );
-}
-
-
 
 /*************************************************************************
 #*  Member:     SetArgVal                                   Date:13.01.97
@@ -704,29 +648,6 @@ IMPL_LINK( ArgInput, EdModifyHdl,ArgEdit*, pEd )
     return 0;
 }
 
-/*************************************************************************
-#*  Member:     EditBox                                 Date:20.01.97
-#*------------------------------------------------------------------------
-#*
-#*  Class:      EditBox
-#*
-#*  Function:   Constructor from Class ArgInput
-#*
-#*  Input:      Parent, Window-Style
-#*
-#*  Output:     ---
-#*
-#************************************************************************/
-EditBox::EditBox(   Window* pParent,WinBits nWinStyle)
-        :Control(pParent,nWinStyle|WB_DIALOGCONTROL)
-{
-    pMEdit=new MultiLineEdit(this,WB_LEFT | WB_VSCROLL | (nWinStyle & WB_TABSTOP) |
-                    WB_NOBORDER | WB_NOHIDESELECTION | WB_IGNORETAB);
-
-    pMEdit->Show();
-    aOldSel=pMEdit->GetSelection();
-}
-
 /*************************************************************************
 #*  Member:     EditBox                                 Date:20.01.97
 #*------------------------------------------------------------------------
@@ -894,7 +815,7 @@ long EditBox::PreNotify( NotifyEvent& rNEvt )
 #*  Output:     ---
 #*
 #************************************************************************/
-IMPL_LINK( EditBox, ChangedHdl, EditBox*, EMPTYARG )
+IMPL_LINK_NOARG(EditBox, ChangedHdl)
 {
     if(pMEdit!=NULL)
     {
@@ -933,12 +854,6 @@ RefEdit::RefEdit( Window* _pParent,IControlReferenceHandler* pParent, const ResI
     aTimer.SetTimeout( SC_ENABLE_TIME );
 }
 
-RefEdit::RefEdit( Window* pParent, const ResId& rResId ) :
-    Edit( pParent, rResId ),
-    pAnyRefDlg( NULL )
-{
-}
-
 RefEdit::~RefEdit()
 {
     aTimer.SetTimeoutHdl( Link() );
@@ -1020,7 +935,7 @@ void RefEdit::LoseFocus()
         pAnyRefDlg->HideReference();
 }
 
-IMPL_LINK( RefEdit, UpdateHdl, Timer*, EMPTYARG )
+IMPL_LINK_NOARG(RefEdit, UpdateHdl)
 {
     if( pAnyRefDlg )
         pAnyRefDlg->ShowReference( GetText() );
