@@ -1,36 +1,26 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+/*
+ * This file is part of the LibreOffice project.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * OpenOffice.org - a multi-platform office productivity suite
+ * This file incorporates work covered by the following license notice:
  *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 
 #include "framework/undomanagerhelper.hxx"
 
-/** === begin UNO includes === **/
 #include <com/sun/star/lang/XComponent.hpp>
-/** === end UNO includes === **/
 
 #include <cppuhelper/interfacecontainer.hxx>
 #include <cppuhelper/exc_hlp.hxx>
@@ -88,7 +78,7 @@ namespace framework
                             );
         virtual             ~UndoActionWrapper();
 
-        virtual String      GetComment() const;
+        virtual rtl::OUString GetComment() const;
         virtual void        Undo();
         virtual void        Redo();
         virtual sal_Bool    CanRepeat(SfxRepeatTarget&) const;
@@ -121,9 +111,9 @@ namespace framework
     }
 
     //------------------------------------------------------------------------------------------------------------------
-    String UndoActionWrapper::GetComment() const
+    rtl::OUString UndoActionWrapper::GetComment() const
     {
-        String sComment;
+        rtl::OUString sComment;
         try
         {
             sComment = m_xUndoAction->getTitle();
@@ -220,10 +210,10 @@ namespace framework
         bool                                m_disposed;
         bool                                m_bAPIActionRunning;
         bool                                m_bProcessingEvents;
+        sal_Int32                           m_nLockCount;
         ::cppu::OInterfaceContainerHelper   m_aUndoListeners;
         ::cppu::OInterfaceContainerHelper   m_aModifyListeners;
         IUndoManagerImplementation&         m_rUndoManagerImplementation;
-        UndoManagerHelper&                  m_rAntiImpl;
         ::std::stack< bool >                m_aContextVisibilities;
 #if OSL_DEBUG_LEVEL > 0
         ::std::stack< bool >                m_aContextAPIFlags;
@@ -235,16 +225,16 @@ namespace framework
         ::osl::Mutex&   getMutex() { return m_aMutex; }
 
     public:
-        UndoManagerHelper_Impl( UndoManagerHelper& i_antiImpl, IUndoManagerImplementation& i_undoManagerImpl )
+        UndoManagerHelper_Impl( IUndoManagerImplementation& i_undoManagerImpl )
             :m_aMutex()
             ,m_aQueueMutex()
             ,m_disposed( false )
             ,m_bAPIActionRunning( false )
             ,m_bProcessingEvents( false )
+            ,m_nLockCount( 0 )
             ,m_aUndoListeners( m_aMutex )
             ,m_aModifyListeners( m_aMutex )
             ,m_rUndoManagerImplementation( i_undoManagerImpl )
-            ,m_rAntiImpl( i_antiImpl )
         {
             getUndoManager().AddUndoListener( *this );
         }
@@ -290,6 +280,9 @@ namespace framework
         void clearRedo( IMutexGuard& i_instanceLock );
         void reset( IMutexGuard& i_instanceLock );
 
+        void lock();
+        void unlock();
+
         void addUndoManagerListener( const Reference< XUndoManagerListener >& i_listener )
         {
             m_aUndoListeners.addInterface( i_listener );
@@ -479,6 +472,37 @@ namespace framework
         );
     }
 
+    //------------------------------------------------------------------------------------------------------------------
+    void UndoManagerHelper_Impl::lock()
+    {
+        // SYNCHRONIZED --->
+        ::osl::MutexGuard aGuard( getMutex() );
+
+        if ( ++m_nLockCount == 1 )
+        {
+            IUndoManager& rUndoManager = getUndoManager();
+            rUndoManager.EnableUndo( false );
+        }
+        // <--- SYNCHRONIZED
+    }
+
+    //------------------------------------------------------------------------------------------------------------------
+    void UndoManagerHelper_Impl::unlock()
+    {
+        // SYNCHRONIZED --->
+        ::osl::MutexGuard aGuard( getMutex() );
+
+        if ( m_nLockCount == 0 )
+            throw NotLockedException( "Undo manager is not locked", getXUndoManager() );
+
+        if ( --m_nLockCount == 0 )
+        {
+            IUndoManager& rUndoManager = getUndoManager();
+            rUndoManager.EnableUndo( true );
+        }
+        // <--- SYNCHRONIZED
+    }
+
     //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::impl_processRequest( ::boost::function0< void > const& i_request, IMutexGuard& i_instanceLock )
     {
@@ -904,7 +928,7 @@ namespace framework
     //==================================================================================================================
     //------------------------------------------------------------------------------------------------------------------
     UndoManagerHelper::UndoManagerHelper( IUndoManagerImplementation& i_undoManagerImpl )
-        :m_pImpl( new UndoManagerHelper_Impl( *this, i_undoManagerImpl ) )
+        :m_pImpl( new UndoManagerHelper_Impl( i_undoManagerImpl ) )
     {
     }
 
@@ -1100,25 +1124,13 @@ namespace framework
     //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper::lock()
     {
-        // SYNCHRONIZED --->
-        ::osl::MutexGuard aGuard( m_pImpl->getMutex() );
-
-        IUndoManager& rUndoManager = m_pImpl->getUndoManager();
-        rUndoManager.EnableUndo( false );
-        // <--- SYNCHRONIZED
+        m_pImpl->lock();
     }
 
     //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper::unlock()
     {
-        // SYNCHRONIZED --->
-        ::osl::MutexGuard aGuard( m_pImpl->getMutex() );
-
-        IUndoManager& rUndoManager = m_pImpl->getUndoManager();
-        if ( rUndoManager.IsUndoEnabled() )
-            throw NotLockedException( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "Undo manager is not locked" )), m_pImpl->getXUndoManager() );
-        rUndoManager.EnableUndo( true );
-        // <--- SYNCHRONIZED
+        m_pImpl->unlock();
     }
 
     //------------------------------------------------------------------------------------------------------------------
