@@ -1,30 +1,21 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 
 #include <sal/macros.h>
@@ -75,14 +66,14 @@ LinguOptions::LinguOptions()
         aLinguCfg.GetOptions( *pData );
     }
 
-    osl_incrementInterlockedCount( &nRefCount );
+    osl_atomic_increment( &nRefCount );
 }
 
 
 LinguOptions::LinguOptions(const LinguOptions & /*rOpt*/)
 {
     DBG_ASSERT( pData, "lng : data missing" );
-    osl_incrementInterlockedCount( &nRefCount );
+    osl_atomic_increment( &nRefCount );
 }
 
 
@@ -90,7 +81,7 @@ LinguOptions::~LinguOptions()
 {
     MutexGuard  aGuard( GetLinguMutex() );
 
-    if ( osl_decrementInterlockedCount( &nRefCount ) == 0 )
+    if ( osl_atomic_decrement( &nRefCount ) == 0 )
     {
         delete pData;   pData  = NULL;
     }
@@ -139,7 +130,7 @@ OUString LinguOptions::GetName( sal_Int32 nWID )
 
     OUString aRes;
 
-    sal_Int32 nLen = SAL_N_ELEMENTS( aWID_Name );
+    sal_Int32 nLen = sizeof (aWID_Name) / sizeof (aWID_Name[0]);
     if (0 <= nWID && nWID < nLen && aWID_Name[ nWID ].nWID == nWID)
         aRes = OUString::createFromAscii(aWID_Name[nWID].pPropertyName);
     else
@@ -151,7 +142,7 @@ OUString LinguOptions::GetName( sal_Int32 nWID )
 
 
 //! map must be sorted by first entry in alphabetical increasing order.
-const SfxItemPropertyMapEntry* lcl_GetLinguProps()
+static const SfxItemPropertyMapEntry* lcl_GetLinguProps()
 {
     static const SfxItemPropertyMapEntry aLinguProps[] =
     {
@@ -237,7 +228,7 @@ Reference< XPropertySetInfo > SAL_CALL LinguProps::getPropertySetInfo()
     MutexGuard  aGuard( GetLinguMutex() );
 
     static Reference< XPropertySetInfo > aRef =
-            new SfxItemPropertySetInfo( &aPropertyMap );
+            new SfxItemPropertySetInfo( aPropertyMap );
     return aRef;
 }
 
@@ -259,12 +250,6 @@ void SAL_CALL LinguProps::setPropertyValue(
             launchEvent( aChgEvt );
         }
     }
-#ifdef LINGU_EXCEPTIONS
-    else
-    {
-        throw UnknownPropertyException();
-    }
-#endif
 }
 
 Any SAL_CALL LinguProps::getPropertyValue( const OUString& rPropertyName )
@@ -279,12 +264,6 @@ Any SAL_CALL LinguProps::getPropertyValue( const OUString& rPropertyName )
     {
         aRet = aConfig.GetProperty( pCur->nWID );
     }
-#ifdef LINGU_EXCEPTIONS
-    else
-    {
-        throw UnknownPropertyException();
-    }
-#endif
 
     return aRet;
 }
@@ -301,12 +280,6 @@ void SAL_CALL LinguProps::addPropertyChangeListener(
         const SfxItemPropertySimpleEntry* pCur = aPropertyMap.getByName( rPropertyName );
         if(pCur)
             aPropListeners.addInterface( pCur->nWID, rxListener );
-#ifdef LINGU_EXCEPTIONS
-        else
-        {
-            throw UnknownPropertyException();
-        }
-#endif
     }
 }
 
@@ -322,12 +295,6 @@ void SAL_CALL LinguProps::removePropertyChangeListener(
         const SfxItemPropertySimpleEntry* pCur = aPropertyMap.getByName( rPropertyName );
         if(pCur)
             aPropListeners.removeInterface( pCur->nWID, rxListener );
-#ifdef LINGU_EXCEPTIONS
-        else
-        {
-            throw UnknownPropertyException();
-        }
-#endif
     }
 }
 
