@@ -1,30 +1,21 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 #include <boost/scoped_ptr.hpp>
 
@@ -453,16 +444,16 @@ void FastSaxParser::parseStream( const InputSource& maStructSource) throw (SAXEx
     entity.maStructSource = maStructSource;
 
     if( !entity.maStructSource.aInputStream.is() )
-        throw SAXException( OUString( RTL_CONSTASCII_USTRINGPARAM( "No input source" ) ), Reference< XInterface >(), Any() );
+        throw SAXException( OUString(  "No input source" ), Reference< XInterface >(), Any() );
 
     entity.maConverter.setInputStream( entity.maStructSource.aInputStream );
-    if( entity.maStructSource.sEncoding.getLength() )
+    if( !entity.maStructSource.sEncoding.isEmpty() )
         entity.maConverter.setEncoding( OUStringToOString( entity.maStructSource.sEncoding, RTL_TEXTENCODING_ASCII_US ) );
 
     // create parser with proper encoding
     entity.mpParser = XML_ParserCreate( 0 );
     if( !entity.mpParser )
-        throw SAXException( OUString( RTL_CONSTASCII_USTRINGPARAM( "Couldn't create parser" ) ), Reference< XInterface >(), Any() );
+        throw SAXException( OUString( "Couldn't create parser" ), Reference< XInterface >(), Any() );
 
     // set all necessary C-Callbacks
     XML_SetUserData( entity.mpParser, this );
@@ -566,14 +557,14 @@ void FastSaxParser::setLocale( const Locale & Locale ) throw (RuntimeException)
 Sequence< OUString > FastSaxParser::getSupportedServiceNames_Static(void)
 {
     Sequence<OUString> aRet(1);
-    aRet.getArray()[0] = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(PARSER_SERVICE_NAME) );
+    aRet.getArray()[0] = ::rtl::OUString( PARSER_SERVICE_NAME );
     return aRet;
 }
 
 // XServiceInfo
 OUString FastSaxParser::getImplementationName() throw (RuntimeException)
 {
-    return OUString(RTL_CONSTASCII_USTRINGPARAM( PARSER_IMPLEMENTATION_NAME ));
+    return OUString( PARSER_IMPLEMENTATION_NAME );
 }
 
 // XServiceInfo
@@ -594,7 +585,7 @@ Sequence< OUString > FastSaxParser::getSupportedServiceNames(void) throw (Runtim
 {
 
     Sequence<OUString> seq(1);
-    seq.getArray()[0] = OUString(RTL_CONSTASCII_USTRINGPARAM( PARSER_SERVICE_NAME ));
+    seq.getArray()[0] = OUString( PARSER_SERVICE_NAME );
     return seq;
 }
 
@@ -667,7 +658,8 @@ void FastSaxParser::parse()
             break;
         }
 
-        bool bContinue = XML_Parse( rEntity.mpParser, (const char*) seqOut.getConstArray(), nRead, 0 ) != 0;
+        bool const bContinue = XML_STATUS_ERROR != XML_Parse(rEntity.mpParser,
+            reinterpret_cast<const char*>(seqOut.getConstArray()), nRead, 0);
         // callbacks used inside XML_Parse may have caught an exception
         if( !bContinue || rEntity.maSavedException.hasValue() )
         {
@@ -787,7 +779,7 @@ void FastSaxParser::callbackStartElement( const XML_Char* pwName, const XML_Char
         // #158414# second: fill attribute list with other attributes
         for( ::std::vector< AttributeData >::const_iterator aIt = aAttribs.begin(), aEnd = aAttribs.end(); aIt != aEnd; ++aIt )
         {
-            if( aIt->maPrefix.getLength() > 0 )
+            if( !aIt->maPrefix.isEmpty() )
             {
                 sal_Int32 nAttributeToken = GetTokenWithPrefix( aIt->maPrefix, aIt->maName );
                 if( nAttributeToken != FastToken::DONTKNOW )
@@ -809,7 +801,7 @@ void FastSaxParser::callbackStartElement( const XML_Char* pwName, const XML_Char
         splitName( pwName, pPrefix, nPrefixLen, pName, nNameLen );
         if( nPrefixLen > 0 )
             nElementToken = GetTokenWithPrefix( pPrefix, nPrefixLen, pName, nNameLen );
-        else if( rEntity.maContextStack.top()->maNamespace.getLength() > 0 )
+        else if( !rEntity.maContextStack.top()->maNamespace.isEmpty() )
             nElementToken = GetTokenWithNamespaceURL( rEntity.maContextStack.top()->maNamespace, pName, nNameLen );
         else
             nElementToken = GetToken( pName );
@@ -858,7 +850,7 @@ void FastSaxParser::callbackStartElement( const XML_Char* pwName, const XML_Char
     }
 }
 
-void FastSaxParser::callbackEndElement( const XML_Char* )
+void FastSaxParser::callbackEndElement( SAL_UNUSED_PARAMETER const XML_Char* )
 {
     Entity& rEntity = getEntity();
     OSL_ENSURE( !rEntity.maContextStack.empty(), "FastSaxParser::callbackEndElement - no context" );
@@ -899,20 +891,20 @@ void FastSaxParser::callbackCharacters( const XML_Char* s, int nLen )
 }
 
 void FastSaxParser::callbackEntityDecl(
-    const XML_Char * /*entityName*/,
-    int /*is_parameter_entity*/,
-    const XML_Char *value, int /*value_length*/,
-    const XML_Char * /*base*/,
-    const XML_Char * /*systemId*/,
-    const XML_Char * /*publicId*/,
-    const XML_Char * /*notationName*/)
+    SAL_UNUSED_PARAMETER const XML_Char * /*entityName*/,
+    SAL_UNUSED_PARAMETER int /*is_parameter_entity*/,
+    const XML_Char *value, SAL_UNUSED_PARAMETER int /*value_length*/,
+    SAL_UNUSED_PARAMETER const XML_Char * /*base*/,
+    SAL_UNUSED_PARAMETER const XML_Char * /*systemId*/,
+    SAL_UNUSED_PARAMETER const XML_Char * /*publicId*/,
+    SAL_UNUSED_PARAMETER const XML_Char * /*notationName*/)
 {
     if (value) { // value != 0 means internal entity
         OSL_TRACE("FastSaxParser: internal entity declaration, stopping");
         XML_StopParser(getEntity().mpParser, XML_FALSE);
         getEntity().maSavedException <<= SAXParseException(
-            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
-                    "FastSaxParser: internal entity declaration, stopping")),
+            ::rtl::OUString(
+                    "FastSaxParser: internal entity declaration, stopping"),
             static_cast<OWeakObject*>(this), Any(),
             mxDocumentLocator->getPublicId(),
             mxDocumentLocator->getSystemId(),
@@ -923,8 +915,10 @@ void FastSaxParser::callbackEntityDecl(
     }
 }
 
-int FastSaxParser::callbackExternalEntityRef( XML_Parser parser,
-        const XML_Char *context, const XML_Char * /*base*/, const XML_Char *systemId, const XML_Char *publicId )
+int FastSaxParser::callbackExternalEntityRef(
+    XML_Parser parser, const XML_Char *context,
+    SAL_UNUSED_PARAMETER const XML_Char * /*base*/, const XML_Char *systemId,
+    const XML_Char *publicId )
 {
     bool bOK = true;
     InputSource source;
