@@ -1,47 +1,31 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
-
-
-
-
-// INCLUDE --------------------------------------------------------------
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 #include <svl/zforlist.hxx>
 
 #include "dpshttab.hxx"
 #include "dptabres.hxx"
 #include "document.hxx"
-#include "collect.hxx"
 #include "cell.hxx"
-#include "dpcachetable.hxx"
+#include "dpfilteredcache.hxx"
 #include "dpobject.hxx"
 #include "globstr.hrc"
-#include "dpglobal.hxx"
 #include "rangenam.hxx"
 #include "queryentry.hxx"
 
@@ -58,13 +42,12 @@ using ::std::vector;
 
 // -----------------------------------------------------------------------
 
-ScSheetDPData::ScSheetDPData(ScDocument* pD, const ScSheetSourceDesc& rDesc, const ScDPCache* pCache) :
+ScSheetDPData::ScSheetDPData(ScDocument* pD, const ScSheetSourceDesc& rDesc, const ScDPCache& rCache) :
     ScDPTableData(pD),
     aQuery ( rDesc.GetQueryParam() ),
     bIgnoreEmptyRows( false ),
     bRepeatIfEmpty(false),
-    mrDesc(rDesc),
-    aCacheTable(pCache)
+    aCacheTable(rCache)
 {
     SCSIZE nEntryCount( aQuery.GetEntryCount());
     for (SCSIZE j = 0; j < nEntryCount; ++j)
@@ -99,7 +82,7 @@ long ScSheetDPData::GetColumnCount()
     return aCacheTable.getColSize();
 }
 
-String ScSheetDPData::getDimensionName(long nColumn)
+rtl::OUString ScSheetDPData::getDimensionName(long nColumn)
 {
     CreateCacheTable();
     if (getIsDataLayoutDimension(nColumn))
@@ -111,11 +94,11 @@ String ScSheetDPData::getDimensionName(long nColumn)
     else if (nColumn >= aCacheTable.getColSize())
     {
         OSL_FAIL("getDimensionName: invalid dimension");
-        return String();
+        return rtl::OUString();
     }
     else
     {
-        return  aCacheTable.getFieldName((SCCOL)nColumn);
+        return aCacheTable.getFieldName(static_cast<SCCOL>(nColumn));
     }
 }
 
@@ -190,25 +173,17 @@ void ScSheetDPData::CreateCacheTable()
         // already cached.
         return;
 
-    if (!aCacheTable.hasCache())
-    {
-        OSL_FAIL("Cache table should be created with a live data cache instance at all times.");
-        // This better not happen!!  The cache table should be created with a
-        // live data cache at all times.
-        return;
-    }
-
     aCacheTable.fillTable(aQuery, bIgnoreEmptyRows, bRepeatIfEmpty);
 }
 
-void ScSheetDPData::FilterCacheTable(const vector<ScDPCacheTable::Criterion>& rCriteria, const boost::unordered_set<sal_Int32>& rCatDims)
+void ScSheetDPData::FilterCacheTable(const vector<ScDPFilteredCache::Criterion>& rCriteria, const boost::unordered_set<sal_Int32>& rCatDims)
 {
     CreateCacheTable();
     aCacheTable.filterByPageDimension(
         rCriteria, (IsRepeatIfEmpty() ? rCatDims : boost::unordered_set<sal_Int32>()));
 }
 
-void ScSheetDPData::GetDrillDownData(const vector<ScDPCacheTable::Criterion>& rCriteria, const boost::unordered_set<sal_Int32>& rCatDims, Sequence< Sequence<Any> >& rData)
+void ScSheetDPData::GetDrillDownData(const vector<ScDPFilteredCache::Criterion>& rCriteria, const boost::unordered_set<sal_Int32>& rCatDims, Sequence< Sequence<Any> >& rData)
 {
     CreateCacheTable();
     sal_Int32 nRowSize = aCacheTable.getRowSize();
@@ -225,11 +200,17 @@ void ScSheetDPData::CalcResults(CalcInfo& rInfo, bool bAutoShow)
     CalcResultsFromCacheTable(aCacheTable, rInfo, bAutoShow);
 }
 
-const ScDPCacheTable& ScSheetDPData::GetCacheTable() const
+const ScDPFilteredCache& ScSheetDPData::GetCacheTable() const
 {
     return aCacheTable;
 }
 
+void ScSheetDPData::ReloadCacheTable()
+{
+    aCacheTable.clear();
+    CreateCacheTable();
+}
+
 ScSheetSourceDesc::ScSheetSourceDesc(ScDocument* pDoc) :
     mpDoc(pDoc) {}
 
@@ -241,7 +222,7 @@ void ScSheetSourceDesc::SetSourceRange(const ScRange& rRange)
 
 const ScRange& ScSheetSourceDesc::GetSourceRange() const
 {
-    if (maRangeName.getLength())
+    if (!maRangeName.isEmpty())
     {
         // Obtain the source range from the range name first.
         maSourceRange = ScRange();
@@ -251,7 +232,7 @@ const ScRange& ScSheetSourceDesc::GetSourceRange() const
             if (!pRangeName)
                 break;
 
-            OUString aUpper = ScGlobal::pCharClass->upper(maRangeName);
+            OUString aUpper = ScGlobal::pCharClass->uppercase(maRangeName);
             const ScRangeData* pData = pRangeName->findByUpperName(aUpper);
             if (!pData)
                 break;
@@ -281,7 +262,7 @@ const OUString& ScSheetSourceDesc::GetRangeName() const
 
 bool ScSheetSourceDesc::HasRangeName() const
 {
-    return maRangeName.getLength() > 0;
+    return !maRangeName.isEmpty();
 }
 
 void ScSheetSourceDesc::SetQueryParam(const ScQueryParam& rParam)
@@ -301,7 +282,7 @@ bool ScSheetSourceDesc::operator== (const ScSheetSourceDesc& rOther) const
         maQueryParam  == rOther.maQueryParam;
 }
 
-const ScDPCache* ScSheetSourceDesc::CreateCache() const
+const ScDPCache* ScSheetSourceDesc::CreateCache(const ScDPDimensionSaveData* pDimData) const
 {
     if (!mpDoc)
         return NULL;
@@ -319,16 +300,11 @@ const ScDPCache* ScSheetSourceDesc::CreateCache() const
     {
         // Name-based data source.
         ScDPCollection::NameCaches& rCaches = pDPs->GetNameCaches();
-        return rCaches.getCache(GetRangeName(), GetSourceRange());
+        return rCaches.getCache(GetRangeName(), GetSourceRange(), pDimData);
     }
 
     ScDPCollection::SheetCaches& rCaches = pDPs->GetSheetCaches();
-    return rCaches.getCache(GetSourceRange());
-}
-
-long ScSheetSourceDesc::GetCacheId() const
-{
-    return -1;
+    return rCaches.getCache(GetSourceRange(), pDimData);
 }
 
 sal_uLong ScSheetSourceDesc::CheckSourceRange() const
@@ -336,6 +312,14 @@ sal_uLong ScSheetSourceDesc::CheckSourceRange() const
     if (!mpDoc)
         return STR_ERR_DATAPILOTSOURCE;
 
+    // Make sure the range is valid and sane.
+    const ScRange& rSrcRange = GetSourceRange();
+    if (!rSrcRange.IsValid())
+        return STR_ERR_DATAPILOTSOURCE;
+
+    if (rSrcRange.aStart.Col() > rSrcRange.aEnd.Col() || rSrcRange.aStart.Row() > rSrcRange.aEnd.Row())
+        return STR_ERR_DATAPILOTSOURCE;
+
     return 0;
 }
 
