@@ -1,33 +1,21 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
-
-
-
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 #include <vcl/svapp.hxx>
 
@@ -35,6 +23,7 @@
 #include "brdcst.hxx"
 #include "document.hxx"
 #include "reftokenhelper.hxx"
+#include "stlalgorithm.hxx"
 
 using namespace com::sun::star;
 using ::std::vector;
@@ -118,29 +107,14 @@ boost::unordered_set<sal_uInt16>& ScChartListener::ExternalRefListener::getAllFi
 
 // ----------------------------------------------------------------------------
 
-ScChartListener::ScChartListener( const String& rName, ScDocument* pDocP,
-        const ScRange& rRange ) :
-    StrData( rName ),
-    SvtListener(),
-    mpExtRefListener(NULL),
-    mpTokens(new vector<ScTokenRef>),
-    pUnoData( NULL ),
-    pDoc( pDocP ),
-    bUsed( false ),
-    bDirty( false ),
-    bSeriesRangesScheduled( false )
-{
-    SetRangeList( rRange );
-}
-
-ScChartListener::ScChartListener( const String& rName, ScDocument* pDocP,
+ScChartListener::ScChartListener( const rtl::OUString& rName, ScDocument* pDocP,
         const ScRangeListRef& rRangeList ) :
-    StrData( rName ),
     SvtListener(),
     mpExtRefListener(NULL),
     mpTokens(new vector<ScTokenRef>),
+    maName(rName),
     pUnoData( NULL ),
-    pDoc( pDocP ),
+    mpDoc( pDocP ),
     bUsed( false ),
     bDirty( false ),
     bSeriesRangesScheduled( false )
@@ -148,13 +122,13 @@ ScChartListener::ScChartListener( const String& rName, ScDocument* pDocP,
     ScRefTokenHelper::getTokensFromRangeList(*mpTokens, *rRangeList);
 }
 
-ScChartListener::ScChartListener( const String& rName, ScDocument* pDocP, vector<ScTokenRef>* pTokens ) :
-    StrData( rName ),
+ScChartListener::ScChartListener( const rtl::OUString& rName, ScDocument* pDocP, vector<ScTokenRef>* pTokens ) :
     SvtListener(),
     mpExtRefListener(NULL),
     mpTokens(pTokens),
+    maName(rName),
     pUnoData( NULL ),
-    pDoc( pDocP ),
+    mpDoc( pDocP ),
     bUsed( false ),
     bDirty( false ),
     bSeriesRangesScheduled( false )
@@ -162,12 +136,12 @@ ScChartListener::ScChartListener( const String& rName, ScDocument* pDocP, vector
 }
 
 ScChartListener::ScChartListener( const ScChartListener& r ) :
-    StrData( r ),
     SvtListener(),
     mpExtRefListener(NULL),
     mpTokens(new vector<ScTokenRef>(*r.mpTokens)),
+    maName(r.maName),
     pUnoData( NULL ),
-    pDoc( r.pDoc ),
+    mpDoc( r.mpDoc ),
     bUsed( false ),
     bDirty( r.bDirty ),
     bSeriesRangesScheduled( r.bSeriesRangesScheduled )
@@ -180,9 +154,9 @@ ScChartListener::ScChartListener( const ScChartListener& r ) :
         // Re-register this new listener for the files that the old listener
         // was listening to.
 
-        ScExternalRefManager* pRefMgr = pDoc->GetExternalRefManager();
+        ScExternalRefManager* pRefMgr = mpDoc->GetExternalRefManager();
         const boost::unordered_set<sal_uInt16>& rFileIds = r.mpExtRefListener->getAllFileIds();
-        mpExtRefListener.reset(new ExternalRefListener(*this, pDoc));
+        mpExtRefListener.reset(new ExternalRefListener(*this, mpDoc));
         boost::unordered_set<sal_uInt16>::const_iterator itr = rFileIds.begin(), itrEnd = rFileIds.end();
         for (; itr != itrEnd; ++itr)
         {
@@ -201,7 +175,7 @@ ScChartListener::~ScChartListener()
     if (mpExtRefListener.get())
     {
         // Stop listening to all external files.
-        ScExternalRefManager* pRefMgr = pDoc->GetExternalRefManager();
+        ScExternalRefManager* pRefMgr = mpDoc->GetExternalRefManager();
         const boost::unordered_set<sal_uInt16>& rFileIds = mpExtRefListener->getAllFileIds();
         boost::unordered_set<sal_uInt16>::const_iterator itr = rFileIds.begin(), itrEnd = rFileIds.end();
         for (; itr != itrEnd; ++itr)
@@ -209,9 +183,9 @@ ScChartListener::~ScChartListener()
     }
 }
 
-ScDataObject* ScChartListener::Clone() const
+const rtl::OUString& ScChartListener::GetName() const
 {
-    return new ScChartListener( *this );
+    return maName;
 }
 
 void ScChartListener::SetUno(
@@ -245,26 +219,26 @@ void ScChartListener::Notify( SvtBroadcaster&, const SfxHint& rHint )
 
 void ScChartListener::Update()
 {
-    if ( pDoc->IsInInterpreter() )
+    if ( mpDoc->IsInInterpreter() )
     {   // If interpreting do nothing and restart timer so we don't
         // interfere with interpreter and don't produce an Err522 or similar.
         // This may happen if we are rescheduled via Basic function.
-        pDoc->GetChartListenerCollection()->StartTimer();
+        mpDoc->GetChartListenerCollection()->StartTimer();
         return ;
     }
     if ( pUnoData )
     {
         bDirty = false;
-        //! irgendwann mal erkennen, was sich innerhalb des Charts geaendert hat
+        // recognize some day what has changed inside the Chart
         chart::ChartDataChangeEvent aEvent( pUnoData->GetSource(),
                                         chart::ChartDataChangeType_ALL,
                                         0, 0, 0, 0 );
         pUnoData->GetListener()->chartDataChanged( aEvent );
     }
-    else if ( pDoc->GetAutoCalc() )
+    else if ( mpDoc->GetAutoCalc() )
     {
         bDirty = false;
-        pDoc->UpdateChart( GetString());
+        mpDoc->UpdateChart(GetName());
     }
 }
 
@@ -282,13 +256,6 @@ void ScChartListener::SetRangeList( const ScRangeListRef& rNew )
     mpTokens->swap(aTokens);
 }
 
-void ScChartListener::SetRangeList( const ScRange& rRange )
-{
-    ScTokenRef pToken;
-    ScRefTokenHelper::getTokenFromRange(pToken, rRange);
-    mpTokens->push_back(pToken);
-}
-
 namespace {
 
 class StartEndListening : public unary_function<ScTokenRef, void>
@@ -359,7 +326,7 @@ void ScChartListener::StartListeningTo()
         // no references to listen to.
         return;
 
-    for_each(mpTokens->begin(), mpTokens->end(), StartEndListening(pDoc, *this, true));
+    for_each(mpTokens->begin(), mpTokens->end(), StartEndListening(mpDoc, *this, true));
 }
 
 void ScChartListener::EndListeningTo()
@@ -368,7 +335,7 @@ void ScChartListener::EndListeningTo()
         // no references to listen to.
         return;
 
-    for_each(mpTokens->begin(), mpTokens->end(), StartEndListening(pDoc, *this, false));
+    for_each(mpTokens->begin(), mpTokens->end(), StartEndListening(mpDoc, *this, false));
 }
 
 
@@ -401,7 +368,7 @@ void ScChartListener::UpdateChartIntersecting( const ScRange& rRange )
     if (ScRefTokenHelper::intersects(*mpTokens, pToken))
     {
         // force update (chart has to be loaded), don't use ScChartListener::Update
-        pDoc->UpdateChart( GetString());
+        mpDoc->UpdateChart(GetName());
     }
 }
 
@@ -410,13 +377,13 @@ void ScChartListener::UpdateSeriesRanges()
 {
     ScRangeListRef pRangeList(new ScRangeList);
     ScRefTokenHelper::getRangeListFromTokens(*pRangeList, *mpTokens);
-    pDoc->SetChartRangeList(GetString(), pRangeList);
+    mpDoc->SetChartRangeList(GetName(), pRangeList);
 }
 
 ScChartListener::ExternalRefListener* ScChartListener::GetExtRefListener()
 {
     if (!mpExtRefListener.get())
-        mpExtRefListener.reset(new ExternalRefListener(*this, pDoc));
+        mpExtRefListener.reset(new ExternalRefListener(*this, mpDoc));
 
     return mpExtRefListener.get();
 }
@@ -424,17 +391,17 @@ ScChartListener::ExternalRefListener* ScChartListener::GetExtRefListener()
 void ScChartListener::SetUpdateQueue()
 {
     bDirty = true;
-    pDoc->GetChartListenerCollection()->StartTimer();
+    mpDoc->GetChartListenerCollection()->StartTimer();
 }
 
-bool ScChartListener::operator==( const ScChartListener& r )
+bool ScChartListener::operator==( const ScChartListener& r ) const
 {
     bool b1 = (mpTokens.get() && !mpTokens->empty());
     bool b2 = (r.mpTokens.get() && !r.mpTokens->empty());
 
-    if (pDoc != r.pDoc || bUsed != r.bUsed || bDirty != r.bDirty ||
+    if (mpDoc != r.mpDoc || bUsed != r.bUsed || bDirty != r.bDirty ||
         bSeriesRangesScheduled != r.bSeriesRangesScheduled ||
-        GetString() != r.GetString() || b1 != b2)
+        GetName() != r.GetName() || b1 != b2)
         return false;
 
     if (!b1 && !b2)
@@ -444,6 +411,11 @@ bool ScChartListener::operator==( const ScChartListener& r )
     return *mpTokens == *r.mpTokens;
 }
 
+bool ScChartListener::operator!=( const ScChartListener& r ) const
+{
+    return !operator==(r);
+}
+
 // ============================================================================
 
 ScChartHiddenRangeListener::ScChartHiddenRangeListener()
@@ -463,7 +435,6 @@ ScChartListenerCollection::RangeListenerItem::RangeListenerItem(const ScRange& r
 }
 
 ScChartListenerCollection::ScChartListenerCollection( ScDocument* pDocP ) :
-    ScStrCollection( 4, 4, false ),
     pDoc( pDocP )
 {
     aTimer.SetTimeoutHdl( LINK( this, ScChartListenerCollection, TimerHdl ) );
@@ -471,7 +442,6 @@ ScChartListenerCollection::ScChartListenerCollection( ScDocument* pDocP ) :
 
 ScChartListenerCollection::ScChartListenerCollection(
         const ScChartListenerCollection& rColl ) :
-    ScStrCollection( rColl ),
     pDoc( rColl.pDoc )
 {
     aTimer.SetTimeoutHdl( LINK( this, ScChartListenerCollection, TimerHdl ) );
@@ -483,78 +453,167 @@ ScChartListenerCollection::~ScChartListenerCollection()
     //  ScChartListener::EndListeningTo may cause ScChartListenerCollection::StartTimer
     //  to be called if an empty ScNoteCell is deleted
 
-    if (GetCount())
-        FreeAll();
-}
-
-ScDataObject*   ScChartListenerCollection::Clone() const
-{
-    return new ScChartListenerCollection( *this );
+    maListeners.clear();
 }
 
 void ScChartListenerCollection::StartAllListeners()
 {
-    for ( sal_uInt16 nIndex = 0; nIndex < nCount; nIndex++ )
+    ListenersType::iterator it = maListeners.begin(), itEnd = maListeners.end();
+    for (; it != itEnd; ++it)
+        it->second->StartListeningTo();
+}
+
+void ScChartListenerCollection::insert(ScChartListener* pListener)
+{
+    rtl::OUString aName = pListener->GetName();
+    maListeners.insert(aName, pListener);
+}
+
+ScChartListener* ScChartListenerCollection::findByName(const rtl::OUString& rName)
+{
+    ListenersType::iterator it = maListeners.find(rName);
+    return it == maListeners.end() ? NULL : it->second;
+}
+
+const ScChartListener* ScChartListenerCollection::findByName(const rtl::OUString& rName) const
+{
+    ListenersType::const_iterator it = maListeners.find(rName);
+    return it == maListeners.end() ? NULL : it->second;
+}
+
+bool ScChartListenerCollection::hasListeners() const
+{
+    return !maListeners.empty();
+}
+
+const ScChartListenerCollection::ListenersType& ScChartListenerCollection::getListeners() const
+{
+    return maListeners;
+}
+
+ScChartListenerCollection::ListenersType& ScChartListenerCollection::getListeners()
+{
+    return maListeners;
+}
+
+ScChartListenerCollection::StringSetType& ScChartListenerCollection::getNonOleObjectNames()
+{
+    return maNonOleObjectNames;
+}
+
+rtl::OUString ScChartListenerCollection::getUniqueName(const rtl::OUString& rPrefix) const
+{
+    for (sal_Int32 nNum = 1; nNum < 10000; ++nNum) // arbitrary limit to prevent infinite loop.
     {
-        ((ScChartListener*) pItems[ nIndex ])->StartListeningTo();
+        rtl::OUStringBuffer aBuf(rPrefix);
+        aBuf.append(nNum);
+        rtl::OUString aTestName = aBuf.makeStringAndClear();
+        if (maListeners.find(aTestName) == maListeners.end())
+            return aTestName;
     }
+    return rtl::OUString();
 }
 
 void ScChartListenerCollection::ChangeListening( const String& rName,
         const ScRangeListRef& rRangeListRef, bool bDirty )
 {
-    ScChartListener aCLSearcher( rName, pDoc, rRangeListRef );
-    ScChartListener* pCL;
-    sal_uInt16 nIndex;
-    if ( Search( &aCLSearcher, nIndex ) )
+    ScChartListener* pCL = findByName(rName);
+    if (pCL)
     {
-        pCL = (ScChartListener*) pItems[ nIndex ];
         pCL->EndListeningTo();
         pCL->SetRangeList( rRangeListRef );
     }
     else
     {
-        pCL = new ScChartListener( aCLSearcher );
-        Insert( pCL );
+        pCL = new ScChartListener(rName, pDoc, rRangeListRef);
+        insert(pCL);
     }
     pCL->StartListeningTo();
     if ( bDirty )
         pCL->SetDirty( true );
 }
 
+namespace {
+
+class InsertChartListener : public std::unary_function<ScChartListener*, void>
+{
+    ScChartListenerCollection::ListenersType& mrListeners;
+public:
+    InsertChartListener(ScChartListenerCollection::ListenersType& rListeners) :
+        mrListeners(rListeners) {}
+
+    void operator() (ScChartListener* p)
+    {
+        rtl::OUString aName = p->GetName();
+        mrListeners.insert(aName, p);
+    }
+};
+
+}
+
 void ScChartListenerCollection::FreeUnused()
 {
-    // rueckwaerts wg. Pointer-Aufrueckerei im Array
-    for ( sal_uInt16 nIndex = nCount; nIndex-- >0; )
+    std::vector<ScChartListener*> aUsed, aUnused;
+
+    // First, filter each listener into 'used' and 'unused' categories.
     {
-        ScChartListener* pCL = (ScChartListener*) pItems[ nIndex ];
-        //  Uno-Charts nicht rauskicken
-        //  (werden per FreeUno von aussen geloescht)
-        if ( !pCL->IsUno() )
+        ListenersType::iterator it = maListeners.begin(), itEnd = maListeners.end();
+        for (; it != itEnd; ++it)
         {
-            if ( pCL->IsUsed() )
-                pCL->SetUsed( false );
+            ScChartListener* p = it->second;
+            if (p->IsUno())
+            {
+                // We don't delete UNO charts; they are to be deleted separately via FreeUno().
+                aUsed.push_back(p);
+                continue;
+            }
+
+            if (p->IsUsed())
+            {
+                p->SetUsed(false);
+                aUsed.push_back(p);
+            }
             else
-                Free( pCL );
+                aUnused.push_back(p);
         }
     }
+
+    // Release all pointers currently managed by the ptr_map container.
+    maListeners.release().release();
+
+    // Re-insert the listeners we need to keep.
+    std::for_each(aUsed.begin(), aUsed.end(), InsertChartListener(maListeners));
+
+    // Now, delete the ones no longer needed.
+    std::for_each(aUnused.begin(), aUnused.end(), ScDeleteObjectByPtr<ScChartListener>());
 }
 
 void ScChartListenerCollection::FreeUno( const uno::Reference< chart::XChartDataChangeEventListener >& rListener,
                                          const uno::Reference< chart::XChartData >& rSource )
 {
-    // rueckwaerts wg. Pointer-Aufrueckerei im Array
-    for ( sal_uInt16 nIndex = nCount; nIndex-- >0; )
+    std::vector<ScChartListener*> aUsed, aUnused;
+
+    // First, filter each listener into 'used' and 'unused' categories.
     {
-        ScChartListener* pCL = (ScChartListener*) pItems[ nIndex ];
-        if ( pCL->IsUno() &&
-             pCL->GetUnoListener() == rListener &&
-             pCL->GetUnoSource() == rSource )
+        ListenersType::iterator it = maListeners.begin(), itEnd = maListeners.end();
+        for (; it != itEnd; ++it)
         {
-            Free( pCL );
+            ScChartListener* p = it->second;
+            if (p->IsUno() && p->GetUnoListener() == rListener && p->GetUnoSource() == rSource)
+                aUnused.push_back(p);
+            else
+                aUsed.push_back(p);
         }
-        //! sollte nur einmal vorkommen?
     }
+
+    // Release all pointers currently managed by the ptr_map container.
+    maListeners.release().release();
+
+    // Re-insert the listeners we need to keep.
+    std::for_each(aUsed.begin(), aUsed.end(), InsertChartListener(maListeners));
+
+    // Now, delete the ones no longer needed.
+    std::for_each(aUnused.begin(), aUnused.end(), ScDeleteObjectByPtr<ScChartListener>());
 }
 
 void ScChartListenerCollection::StartTimer()
@@ -563,7 +622,7 @@ void ScChartListenerCollection::StartTimer()
     aTimer.Start();
 }
 
-IMPL_LINK( ScChartListenerCollection, TimerHdl, Timer*, EMPTYARG )
+IMPL_LINK_NOARG(ScChartListenerCollection, TimerHdl)
 {
     if ( Application::AnyInput( VCL_INPUT_KEYBOARD ) )
     {
@@ -576,24 +635,25 @@ IMPL_LINK( ScChartListenerCollection, TimerHdl, Timer*, EMPTYARG )
 
 void ScChartListenerCollection::UpdateDirtyCharts()
 {
-    for ( sal_uInt16 nIndex = 0; nIndex < nCount; nIndex++ )
+    ListenersType::iterator it = maListeners.begin(), itEnd = maListeners.end();
+    for (; it != itEnd; ++it)
     {
-        ScChartListener* pCL = (ScChartListener*) pItems[ nIndex ];
-        if ( pCL->IsDirty() )
-            pCL->Update();
-        if ( aTimer.IsActive() && !pDoc->IsImportingXML())
-            break;                      // da kam einer dazwischen
+        ScChartListener* p = it->second;
+        if (p->IsDirty())
+            p->Update();
+
+        if (aTimer.IsActive() && !pDoc->IsImportingXML())
+            break;                      // one interfered
     }
 }
 
 
 void ScChartListenerCollection::SetDirty()
 {
-    for ( sal_uInt16 nIndex = 0; nIndex < nCount; nIndex++ )
-    {
-        ScChartListener* pCL = (ScChartListener*) pItems[ nIndex ];
-        pCL->SetDirty( true );
-    }
+    ListenersType::iterator it = maListeners.begin(), itEnd = maListeners.end();
+    for (; it != itEnd; ++it)
+        it->second->SetDirty(true);
+
     StartTimer();
 }
 
@@ -602,27 +662,27 @@ void ScChartListenerCollection::SetDiffDirty(
             const ScChartListenerCollection& rCmp, bool bSetChartRangeLists )
 {
     bool bDirty = false;
-    for ( sal_uInt16 nIndex = 0; nIndex < nCount; nIndex++ )
+    ListenersType::iterator it = maListeners.begin(), itEnd = maListeners.end();
+    for (; it != itEnd; ++it)
     {
-        ScChartListener* pCL = (ScChartListener*) pItems[ nIndex ];
-        sal_uInt16 nFound;
-        bool bFound = rCmp.Search( pCL, nFound );
-        if ( !bFound || (*pCL != *((const ScChartListener*) rCmp.pItems[ nFound ])) )
+        ScChartListener* pCL = it->second;
+        OSL_ASSERT(pCL);
+        const ScChartListener* pCLCmp = rCmp.findByName(pCL->GetName());
+        if (!pCLCmp || *pCL != *pCLCmp)
         {
             if ( bSetChartRangeLists )
             {
-                if ( bFound )
+                if (pCLCmp)
                 {
                     const ScRangeListRef& rList1 = pCL->GetRangeList();
-                    const ScRangeListRef& rList2 =
-                        ((const ScChartListener*) rCmp.pItems[ nFound ])->GetRangeList();
+                    const ScRangeListRef& rList2 = pCLCmp->GetRangeList();
                     bool b1 = rList1.Is();
                     bool b2 = rList2.Is();
                     if ( b1 != b2 || (b1 && b2 && (*rList1 != *rList2)) )
-                        pDoc->SetChartRangeList( pCL->GetString(), rList1 );
+                        pDoc->SetChartRangeList( pCL->GetName(), rList1 );
                 }
                 else
-                    pDoc->SetChartRangeList( pCL->GetString(), pCL->GetRangeList() );
+                    pDoc->SetChartRangeList( pCL->GetName(), pCL->GetRangeList() );
             }
             bDirty = true;
             pCL->SetDirty( true );
@@ -636,9 +696,10 @@ void ScChartListenerCollection::SetDiffDirty(
 void ScChartListenerCollection::SetRangeDirty( const ScRange& rRange )
 {
     bool bDirty = false;
-    for ( sal_uInt16 nIndex = 0; nIndex < nCount; nIndex++ )
+    ListenersType::iterator it = maListeners.begin(), itEnd = maListeners.end();
+    for (; it != itEnd; ++it)
     {
-        ScChartListener* pCL = (ScChartListener*) pItems[ nIndex ];
+        ScChartListener* pCL = it->second;
         const ScRangeListRef& rList = pCL->GetRangeList();
         if ( rList.Is() && rList->Intersects( rRange ) )
         {
@@ -661,40 +722,43 @@ void ScChartListenerCollection::SetRangeDirty( const ScRange& rRange )
 
 void ScChartListenerCollection::UpdateScheduledSeriesRanges()
 {
-    for ( sal_uInt16 nIndex = 0; nIndex < nCount; nIndex++ )
-    {
-        ScChartListener* pCL = (ScChartListener*) pItems[ nIndex ];
-        pCL->UpdateScheduledSeriesRanges();
-    }
+    ListenersType::iterator it = maListeners.begin(), itEnd = maListeners.end();
+    for (; it != itEnd; ++it)
+        it->second->UpdateScheduledSeriesRanges();
 }
 
 
 void ScChartListenerCollection::UpdateChartsContainingTab( SCTAB nTab )
 {
     ScRange aRange( 0, 0, nTab, MAXCOL, MAXROW, nTab );
-    for ( sal_uInt16 nIndex = 0; nIndex < nCount; nIndex++ )
-    {
-        ScChartListener* pCL = (ScChartListener*) pItems[ nIndex ];
-        pCL->UpdateChartIntersecting( aRange );
-    }
+    ListenersType::iterator it = maListeners.begin(), itEnd = maListeners.end();
+    for (; it != itEnd; ++it)
+        it->second->UpdateChartIntersecting(aRange);
 }
 
 
-bool ScChartListenerCollection::operator==( const ScChartListenerCollection& r )
+bool ScChartListenerCollection::operator==( const ScChartListenerCollection& r ) const
 {
-    // hier nicht ScStrCollection::operator==() verwenden, der umstaendlich via
-    // IsEqual und Compare laeuft, stattdessen ScChartListener::operator==()
-    if ( pDoc != r.pDoc || nCount != r.nCount )
+    // Do not use ScStrCollection::operator==() here that uses IsEqual und Compare.
+    // Use ScChartListener::operator==() instead.
+    if (pDoc != r.pDoc || maListeners.size() != r.maListeners.size())
         return false;
-    for ( sal_uInt16 nIndex = 0; nIndex < nCount; nIndex++ )
+
+    ListenersType::const_iterator it = maListeners.begin(), itEnd = maListeners.end();
+    ListenersType::const_iterator it2 = r.maListeners.begin();
+    for (; it != itEnd; ++it, ++it2)
     {
-        if ( *((ScChartListener*) pItems[ nIndex ]) !=
-                *((ScChartListener*) r.pItems[ nIndex ]) )
+        if (*it != *it2)
             return false;
     }
     return true;
 }
 
+bool ScChartListenerCollection::operator!=( const ScChartListenerCollection& r ) const
+{
+    return !operator==(r);
+}
+
 void ScChartListenerCollection::StartListeningHiddenRange( const ScRange& rRange, ScChartHiddenRangeListener* pListener )
 {
     RangeListenerItem aItem(rRange, pListener);
