@@ -1,30 +1,21 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 #include "xetable.hxx"
 
@@ -41,6 +32,7 @@
 #include "xehelper.hxx"
 #include "xecontent.hxx"
 #include "xeescher.hxx"
+#include "xeextlst.hxx"
 
 using namespace ::oox;
 
@@ -570,7 +562,7 @@ void XclExpSingleCellBase::WriteBody( XclExpStream& rStrm )
 
 // ----------------------------------------------------------------------------
 
-IMPL_FIXEDMEMPOOL_NEWDEL( XclExpNumberCell, 256, 256 )
+IMPL_FIXEDMEMPOOL_NEWDEL( XclExpNumberCell )
 
 XclExpNumberCell::XclExpNumberCell(
         const XclExpRoot& rRoot, const XclAddress& rXclPos,
@@ -616,7 +608,7 @@ void XclExpNumberCell::WriteContents( XclExpStream& rStrm )
 
 // ----------------------------------------------------------------------------
 
-IMPL_FIXEDMEMPOOL_NEWDEL( XclExpBooleanCell, 256, 256 )
+IMPL_FIXEDMEMPOOL_NEWDEL( XclExpBooleanCell )
 
 XclExpBooleanCell::XclExpBooleanCell(
         const XclExpRoot rRoot, const XclAddress& rXclPos,
@@ -647,7 +639,7 @@ void XclExpBooleanCell::WriteContents( XclExpStream& rStrm )
     rStrm << sal_uInt16( mbValue ? 1 : 0 ) << EXC_BOOLERR_BOOL;
 }
 
-IMPL_FIXEDMEMPOOL_NEWDEL( XclExpLabelCell, 256, 256 )
+IMPL_FIXEDMEMPOOL_NEWDEL( XclExpLabelCell )
 
 XclExpLabelCell::XclExpLabelCell(
         const XclExpRoot& rRoot, const XclAddress& rXclPos,
@@ -757,7 +749,7 @@ void XclExpLabelCell::WriteContents( XclExpStream& rStrm )
 
 // ----------------------------------------------------------------------------
 
-IMPL_FIXEDMEMPOOL_NEWDEL( XclExpFormulaCell, 256, 256 )
+IMPL_FIXEDMEMPOOL_NEWDEL( XclExpFormulaCell )
 
 XclExpFormulaCell::XclExpFormulaCell(
         const XclExpRoot& rRoot, const XclAddress& rXclPos,
@@ -803,8 +795,7 @@ XclExpFormulaCell::XclExpFormulaCell(
         bool bForceLineBreak = false;
         if( nFormatType == NUMBERFORMAT_TEXT )
         {
-            String aResult;
-            mrScFmlaCell.GetString( aResult );
+            String aResult = mrScFmlaCell.GetString();
             bForceLineBreak = mrScFmlaCell.IsMultilineResult();
             nScript = XclExpStringHelper::GetLeadingScriptType( rRoot, aResult );
         }
@@ -909,7 +900,8 @@ void XclExpFormulaCell::SaveXml( XclExpXmlStream& rStrm )
             // OOXTODO: XML_si,     uint
             // OOXTODO: XML_bx      bool
             FSEND );
-    rWorksheet->writeEscaped( XclXmlUtils::ToOUString( *mrScFmlaCell.GetDocument(), mrScFmlaCell.aPos, mrScFmlaCell.GetCode() ) );
+    rWorksheet->writeEscaped( XclXmlUtils::ToOUString( *mrScFmlaCell.GetDocument(), mrScFmlaCell.aPos,
+                mrScFmlaCell.GetCode(), rStrm.GetRoot().GetOpCodeMap() ) );
     rWorksheet->endElement( XML_f );
     if( strcmp( sType, "inlineStr" ) == 0 )
     {
@@ -949,8 +941,7 @@ void XclExpFormulaCell::WriteContents( XclExpStream& rStrm )
 
         case NUMBERFORMAT_TEXT:
         {
-            String aResult;
-            mrScFmlaCell.GetString( aResult );
+            String aResult = mrScFmlaCell.GetString();
             if( aResult.Len() || (rStrm.GetRoot().GetBiff() <= EXC_BIFF5) )
             {
                 rStrm << EXC_FORMULA_RES_STRING;
@@ -1194,7 +1185,7 @@ void XclExpMultiCellBase::RemoveUnusedXFIndexes( const ScfUInt16Vec& rXFIndexes
 
 // ----------------------------------------------------------------------------
 
-IMPL_FIXEDMEMPOOL_NEWDEL( XclExpBlankCell, 256, 256 )
+IMPL_FIXEDMEMPOOL_NEWDEL( XclExpBlankCell )
 
 XclExpBlankCell::XclExpBlankCell( const XclAddress& rXclPos, const XclExpMultiXFId& rXFId ) :
     XclExpMultiCellBase( EXC_ID3_BLANK, EXC_ID_MULBLANK, 0, rXclPos )
@@ -1244,7 +1235,7 @@ void XclExpBlankCell::WriteXmlContents( XclExpXmlStream& rStrm, const XclAddress
 
 // ----------------------------------------------------------------------------
 
-IMPL_FIXEDMEMPOOL_NEWDEL( XclExpRkCell, 256, 256 )
+IMPL_FIXEDMEMPOOL_NEWDEL( XclExpRkCell )
 
 XclExpRkCell::XclExpRkCell(
         const XclExpRoot& rRoot, const XclAddress& rXclPos,
@@ -1302,8 +1293,8 @@ XclExpOutlineBuffer::XclExpOutlineBuffer( const XclExpRoot& rRoot, bool bRows )
         mpScOLArray = bRows ? pOutlineTable->GetRowArray() : pOutlineTable->GetColArray();
 
     if( mpScOLArray )
-        for( sal_uInt16 nLevel = 0; nLevel < SC_OL_MAXDEPTH; ++nLevel )
-            if( ScOutlineEntry* pEntry = mpScOLArray->GetEntryByPos( nLevel, 0 ) )
+        for( size_t nLevel = 0; nLevel < SC_OL_MAXDEPTH; ++nLevel )
+            if( const ScOutlineEntry* pEntry = mpScOLArray->GetEntryByPos( nLevel, 0 ) )
                 maLevelInfos[ nLevel ].mnScEndPos = pEntry->GetEnd();
 }
 
@@ -1312,7 +1303,7 @@ void XclExpOutlineBuffer::UpdateColRow( SCCOLROW nScPos )
     if( mpScOLArray )
     {
         // find open level index for passed position
-        sal_uInt16 nNewOpenScLevel = 0; // new open level (0-based Calc index)
+        size_t nNewOpenScLevel = 0; // new open level (0-based Calc index)
         sal_uInt8 nNewLevel = 0;    // new open level (1-based Excel index)
 
         if( mpScOLArray->FindTouchedLevel( nScPos, nScPos, nNewOpenScLevel ) )
@@ -1329,7 +1320,7 @@ void XclExpOutlineBuffer::UpdateColRow( SCCOLROW nScPos )
                     neighbored groups without gap - therefore check ALL levels). */
                 if( maLevelInfos[ nScLevel ].mnScEndPos < nScPos )
                 {
-                    if( ScOutlineEntry* pEntry = mpScOLArray->GetEntryByPos( nScLevel, nScPos ) )
+                    if( const ScOutlineEntry* pEntry = mpScOLArray->GetEntryByPos( nScLevel, nScPos ) )
                     {
                         maLevelInfos[ nScLevel ].mnScEndPos = pEntry->GetEnd();
                         maLevelInfos[ nScLevel ].mbHidden = pEntry->IsHidden();
@@ -1485,6 +1476,7 @@ XclExpColinfo::XclExpColinfo( const XclExpRoot& rRoot,
     XclExpRecord( EXC_ID_COLINFO, 12 ),
     XclExpRoot( rRoot ),
     mnWidth( 0 ),
+    mnScWidth( 0 ),
     mnFlags( 0 ),
     mnFirstXclCol( static_cast< sal_uInt16 >( nScCol ) ),
     mnLastXclCol( static_cast< sal_uInt16 >( nScCol ) )
@@ -1499,7 +1491,7 @@ XclExpColinfo::XclExpColinfo( const XclExpRoot& rRoot,
     // column width
     sal_uInt16 nScWidth = rDoc.GetColWidth( nScCol, nScTab );
     mnWidth = XclTools::GetXclColumnWidth( nScWidth, GetCharWidth() );
-
+    mnScWidth =  sc::TwipsToHMM( nScWidth );
     // column flags
     ::set_flag( mnFlags, EXC_COLINFO_HIDDEN, rDoc.ColHidden(nScCol, nScTab) );
 
@@ -1565,7 +1557,7 @@ void XclExpColinfo::SaveXml( XclExpXmlStream& rStrm )
             // OOXTODO: XML_outlineLevel,
             // OOXTODO: XML_phonetic,
             XML_style,          lcl_GetStyleId( rStrm, maXFId.mnXFIndex ).getStr(),
-            XML_width,          OString::valueOf( (double) (mnWidth / 255.0) ).getStr(),
+            XML_width,          OString::valueOf( (double) (mnScWidth / (double)sc::TwipsToHMM( GetCharWidth() )) ).getStr(),
             FSEND );
 }
 
@@ -2031,41 +2023,22 @@ void XclExpRowBuffer::Finalize( XclExpDefaultRowData& rDefRowData, const ScfUInt
     XclExpDefaultRowData aMaxDefData;
     size_t nMaxDefCount = 0;
     // only look for default format in existing rows, if there are more than unused
-    bool bSearchExisting = ( maRowMap.size() >= (  GetMaxPos().Row() - maRowMap.size() ) );
-    if ( bSearchExisting )
+    for (itr = itrBeg; itr != itrEnd; ++itr)
     {
-        for (itr = itrBeg; itr != itrEnd; ++itr)
+        const RowRef& rRow = itr->second;
+        if (rRow->IsDefaultable())
         {
-            const RowRef& rRow = itr->second;
-            if (rRow->IsDefaultable())
+            XclExpDefaultRowData aDefData( *rRow );
+            size_t& rnDefCount = aDefRowMap[ aDefData ];
+            ++rnDefCount;
+            if( rnDefCount > nMaxDefCount )
             {
-                XclExpDefaultRowData aDefData( *rRow );
-                size_t& rnDefCount = aDefRowMap[ aDefData ];
-                ++rnDefCount;
-                if( rnDefCount > nMaxDefCount )
-                {
-                    nMaxDefCount = rnDefCount;
-                    aMaxDefData = aDefData;
-                }
-            }
-        }
-    }
-    else
-    {
-        // find a suitable unused row to get the default height from,
-        // searching backwards from max row
-        for ( SCROW nRow = GetMaxPos().Row(); nRow >= 0; --nRow )
-        {
-            if ( maRowMap.find( nRow ) == maRowMap.end() )
-            {
-                // use first encountered unused row height as default
-                // I wonder should we do this always ( and abandon the search
-                // of exising rows )
-                aMaxDefData.mnHeight = GetDoc().GetRowHeight(nRow, GetCurrScTab(), false);
-                break;
+                nMaxDefCount = rnDefCount;
+                aMaxDefData = aDefData;
             }
         }
     }
+
     // return the default row format to caller
     rDefRowData = aMaxDefData;
 
@@ -2168,17 +2141,25 @@ XclExpDimensions* XclExpRowBuffer::GetDimensions()
 XclExpRow& XclExpRowBuffer::GetOrCreateRow( sal_uInt32 nXclRow, bool bRowAlwaysEmpty )
 {
     RowMap::iterator itr = maRowMap.begin();
+    ScDocument& rDoc = GetRoot().GetDoc();
+    SCTAB nScTab = GetRoot().GetCurrScTab();
     for ( size_t nFrom = maRowMap.size(); nFrom <= nXclRow; ++nFrom )
     {
         itr = maRowMap.find(nFrom);
         if ( itr == maRowMap.end() )
         {
-            RowRef p(new XclExpRow(GetRoot(), nFrom, maOutlineBfr, bRowAlwaysEmpty));
-            maRowMap.insert(RowMap::value_type(nFrom, p));
+            // only create RowMap entries for rows that differ from previous,
+            // or if it is the desired row
+            if ( !nFrom || ( nFrom == nXclRow ) || ( nFrom && ( rDoc.GetRowHeight(nFrom, nScTab, false) != rDoc.GetRowHeight(nFrom-1, nScTab, false) ) ) )
+            {
+                RowRef p(new XclExpRow(GetRoot(), nFrom, maOutlineBfr, bRowAlwaysEmpty));
+                maRowMap.insert(RowMap::value_type(nFrom, p));
+            }
         }
     }
     itr = maRowMap.find(nXclRow);
     return *itr->second;
+
 }
 
 // ============================================================================
@@ -2197,7 +2178,8 @@ XclExpCellTable::XclExpCellTable( const XclExpRoot& rRoot ) :
     mxNoteList( new XclExpNoteList ),
     mxMergedcells( new XclExpMergedcells( rRoot ) ),
     mxHyperlinkList( new XclExpHyperlinkList ),
-    mxDval( new XclExpDval( rRoot ) )
+    mxDval( new XclExpDval( rRoot ) ),
+    mxExtLst( new XclExtLst( rRoot ) )
 {
     ScDocument& rDoc = GetDoc();
     SCTAB nScTab = GetCurrScTab();
@@ -2212,6 +2194,12 @@ XclExpCellTable::XclExpCellTable( const XclExpRoot& rRoot ) :
     SCROW nLastUsedScRow;
     rDoc.GetTableArea( nScTab, nLastUsedScCol, nLastUsedScRow );
 
+    if(nLastUsedScCol > nMaxScCol)
+        nLastUsedScCol = nMaxScCol;
+
+    if(nLastUsedScRow > nMaxScRow)
+        nLastUsedScRow = nMaxScRow;
+
     ScRange aUsedRange( 0, 0, nScTab, nLastUsedScCol, nLastUsedScRow, nScTab );
     GetAddressConverter().ValidateRange( aUsedRange, true );
     nLastUsedScCol = aUsedRange.aEnd.Col();
@@ -2333,7 +2321,7 @@ XclExpCellTable::XclExpCellTable( const XclExpRoot& rRoot ) :
                     mxHyperlinkList->AppendRecord( aLinkHelper.GetLinkRecord() );
                 // add list of multiple URLs to the additional cell note text
                 if( aLinkHelper.HasMultipleUrls() )
-                    ScGlobal::AddToken( aAddNoteText, aLinkHelper.GetUrlList(), '\n', 2 );
+                    aAddNoteText = ScGlobal::addToken( aAddNoteText, aLinkHelper.GetUrlList(), '\n', 2 );
             }
             break;
 
@@ -2362,10 +2350,8 @@ XclExpCellTable::XclExpCellTable( const XclExpRoot& rRoot ) :
         if( xCell )
             maRowBfr.AppendCell( xCell, bIsMergedBase );
 
-        // notes
-        const ScPostIt* pScNote = pScCell ? pScCell->GetNote() : 0;
-        if( pScNote || (aAddNoteText.Len() > 0) )
-            mxNoteList->AppendNewRecord( new XclExpNote( GetRoot(), aScPos, pScNote, aAddNoteText ) );
+        if ( aAddNoteText.Len()  )
+            mxNoteList->AppendNewRecord( new XclExpNote( GetRoot(), aScPos, NULL, aAddNoteText ) );
 
         // other sheet contents
         if( pPattern )
@@ -2440,6 +2426,7 @@ XclExpRecordRef XclExpCellTable::CreateRecord( sal_uInt16 nRecId ) const
         case EXC_ID_MERGEDCELLS:    xRec = mxMergedcells;   break;
         case EXC_ID_HLINK:          xRec = mxHyperlinkList; break;
         case EXC_ID_DVAL:           xRec = mxDval;          break;
+        case EXC_ID_EXTLST:         xRec = mxExtLst;        break;
         default:    OSL_FAIL( "XclExpCellTable::CreateRecord - unknown record id" );
     }
     return xRec;
@@ -2455,8 +2442,16 @@ void XclExpCellTable::Save( XclExpStream& rStrm )
 
 void XclExpCellTable::SaveXml( XclExpXmlStream& rStrm )
 {
+    // DEFAULT row height
+    XclExpDefaultRowData& rDefData = mxDefrowheight->GetDefaultData();
+    sax_fastparser::FSHelperPtr& rWorksheet = rStrm.GetCurrentStream();
+    rWorksheet->startElement( XML_sheetFormatPr,
+        XML_defaultRowHeight, OString::valueOf( (double) rDefData.mnHeight / 20.0 ).getStr(), FSEND );
+    rWorksheet->endElement( XML_sheetFormatPr );
+
     maColInfoBfr.SaveXml( rStrm );
     maRowBfr.SaveXml( rStrm );
+    mxExtLst->SaveXml( rStrm );
 }
 
 // ============================================================================
