@@ -1,35 +1,22 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
-
-
-
-// INCLUDE ---------------------------------------------------------------
 #include "XMLStylesImportHelper.hxx"
 #include "xmlimprt.hxx"
 #include <com/sun/star/util/NumberFormat.hpp>
@@ -148,35 +135,6 @@ void ScMyStyleRanges::AddCurrencyRange(const ScRange& rRange,
         aItr->mpRanges->addRange(rRange);
 }
 
-void ScMyStyleRanges::InsertRow(const sal_Int32 nRow, const sal_Int32 nTab, ScDocument* /*pDoc*/)
-{
-    if (mpTextList)
-        mpTextList->insertRow(static_cast<SCROW>(nRow), static_cast<SCTAB>(nTab));
-    if (mpNumberList)
-        mpNumberList->insertRow(static_cast<SCROW>(nRow), static_cast<SCTAB>(nTab));
-    if (mpTimeList)
-        mpTimeList->insertRow(static_cast<SCROW>(nRow), static_cast<SCTAB>(nTab));
-    if (mpDateTimeList)
-        mpDateTimeList->insertRow(static_cast<SCROW>(nRow), static_cast<SCTAB>(nTab));
-    if (mpPercentList)
-        mpPercentList->insertRow(static_cast<SCROW>(nRow), static_cast<SCTAB>(nTab));
-    if (mpLogicalList)
-        mpLogicalList->insertRow(static_cast<SCROW>(nRow), static_cast<SCTAB>(nTab));
-    if (mpUndefinedList)
-        mpUndefinedList->insertRow(static_cast<SCROW>(nRow), static_cast<SCTAB>(nTab));
-
-    if (pCurrencyList)
-    {
-        ScMyCurrencyStylesSet::iterator aItr(pCurrencyList->begin());
-        ScMyCurrencyStylesSet::iterator aEndItr(pCurrencyList->end());
-        while (aItr != aEndItr)
-        {
-            aItr->mpRanges->insertRow(static_cast<SCROW>(nRow), static_cast<SCTAB>(nTab));
-            ++aItr;
-        }
-    }
-}
-
 void ScMyStyleRanges::InsertCol(const sal_Int32 nCol, const sal_Int32 nTab, ScDocument* /*pDoc*/)
 {
     if (mpTextList)
@@ -215,22 +173,6 @@ void ScMyStyleRanges::SetStylesToRanges(const list<ScRange>& rRanges,
         rImport.SetStyleToRange(*itr, pStyleName, nCellType, pCurrency);
 }
 
-void ScMyStyleRanges::SetStylesToRanges(ScRangeList* pList,
-    const rtl::OUString* pStyleName, const sal_Int16 nCellType,
-    const rtl::OUString* pCurrency, ScXMLImport& rImport)
-{
-    for ( size_t i = 0, nCount = pList->size(); i < nCount; ++i)
-        rImport.SetStyleToRange( *(*pList)[i], pStyleName, nCellType, pCurrency );
-}
-
-void ScMyStyleRanges::SetStylesToRanges(ScRangeListRef xList,
-    const rtl::OUString* pStyleName, const sal_Int16 nCellType,
-    const rtl::OUString* pCurrency, ScXMLImport& rImport)
-{
-    for (size_t i = 0, nCount = xList->size(); i < nCount; ++i)
-        rImport.SetStyleToRange( *(*xList)[i], pStyleName, nCellType, pCurrency );
-}
-
 void ScMyStyleRanges::SetStylesToRanges(const rtl::OUString* pStyleName, ScXMLImport& rImport)
 {
     if (mpNumberList)
@@ -313,22 +255,16 @@ ScMyStylesImportHelper::ScMyStylesImportHelper(ScXMLImport& rTempImport)
 
 ScMyStylesImportHelper::~ScMyStylesImportHelper()
 {
-    if (pPrevStyleName)
-        delete pPrevStyleName;
-    if (pPrevCurrency)
-        delete pPrevCurrency;
-    if (pStyleName)
-        delete pStyleName;
-    if (pCurrency)
-        delete pCurrency;
+    delete pPrevStyleName;
+    delete pPrevCurrency;
+    delete pStyleName;
+    delete pCurrency;
 }
 
 void ScMyStylesImportHelper::ResetAttributes()
 {
-    if (pPrevStyleName)
-        delete pPrevStyleName;
-    if (pPrevCurrency)
-        delete pPrevCurrency;
+    delete pPrevStyleName;
+    delete pPrevCurrency;
     pPrevStyleName = pStyleName;
     pPrevCurrency = pCurrency;
     nPrevCellType = nCellType;
@@ -364,7 +300,7 @@ ScMyStylesSet::iterator ScMyStylesImportHelper::GetIterator(const rtl::OUString*
 void ScMyStylesImportHelper::AddDefaultRange(const ScRange& rRange)
 {
     OSL_ENSURE(aRowDefaultStyle != aCellStyles.end(), "no row default style");
-    if (!aRowDefaultStyle->sStyleName.getLength())
+    if (aRowDefaultStyle->sStyleName.isEmpty())
     {
         SCCOL nStartCol(rRange.aStart.Col());
         SCCOL nEndCol(rRange.aEnd.Col());
@@ -380,8 +316,7 @@ void ScMyStylesImportHelper::AddDefaultRange(const ScRange& rRange)
                     ScRange aRange(rRange);
                     aRange.aStart.SetCol(nStartCol);
                     aRange.aEnd.SetCol(i - 1);
-                    if (pPrevStyleName)
-                        delete pPrevStyleName;
+                    delete pPrevStyleName;
                     pPrevStyleName = new rtl::OUString(aPrevItr->sStyleName);
                     AddSingleRange(aRange);
                     nStartCol = i;
@@ -392,8 +327,7 @@ void ScMyStylesImportHelper::AddDefaultRange(const ScRange& rRange)
             {
                 ScRange aRange(rRange);
                 aRange.aStart.SetCol(nStartCol);
-                if (pPrevStyleName)
-                    delete pPrevStyleName;
+                delete pPrevStyleName;
                 pPrevStyleName = new rtl::OUString(aPrevItr->sStyleName);
                 AddSingleRange(aRange);
             }
@@ -404,13 +338,12 @@ void ScMyStylesImportHelper::AddDefaultRange(const ScRange& rRange)
         }
         else
         {
-            OSL_FAIL("to much columns");
+            OSL_FAIL("too much columns");
         }
     }
     else
     {
-        if (pPrevStyleName)
-            delete pPrevStyleName;
+        delete pPrevStyleName;
         pPrevStyleName = new rtl::OUString(aRowDefaultStyle->sStyleName);
         AddSingleRange(rRange);
     }
@@ -434,7 +367,7 @@ void ScMyStylesImportHelper::AddSingleRange(const ScRange& rRange)
 
 void ScMyStylesImportHelper::AddRange()
 {
-    if (pPrevStyleName && pPrevStyleName->getLength())
+    if (pPrevStyleName && !pPrevStyleName->isEmpty())
         AddSingleRange(aPrevRange);
     else
         AddDefaultRange(aPrevRange);
@@ -460,10 +393,8 @@ void ScMyStylesImportHelper::SetRowStyle(const rtl::OUString& sStyleName)
 void ScMyStylesImportHelper::SetAttributes(rtl::OUString* pStyleNameP,
     rtl::OUString* pCurrencyP, const sal_Int16 nCellTypeP)
 {
-    if (this->pStyleName)
-        delete this->pStyleName;
-    if (this->pCurrency)
-        delete this->pCurrency;
+    delete this->pStyleName;
+    delete this->pCurrency;
     this->pStyleName = pStyleNameP;
     this->pCurrency = pCurrencyP;
     this->nCellType = nCellTypeP;
@@ -516,25 +447,12 @@ void ScMyStylesImportHelper::AddRange(const ScRange& rRange)
     }
 }
 
-void ScMyStylesImportHelper::AddCell(const com::sun::star::table::CellAddress& rAddress)
+void ScMyStylesImportHelper::AddCell(const ScAddress& rAddress)
 {
-    ScAddress aScAddress( static_cast<SCCOL>(rAddress.Column), static_cast<SCROW>(rAddress.Row), rAddress.Sheet );
-    ScRange aScRange( aScAddress, aScAddress );
+    ScRange aScRange( rAddress, rAddress );
     AddRange(aScRange);
 }
 
-void ScMyStylesImportHelper::InsertRow(const sal_Int32 nRow, const sal_Int32 nTab, ScDocument* pDoc)
-{
-    ScXMLImport::MutexGuard aGuard(rImport);
-    ScMyStylesSet::iterator aItr(aCellStyles.begin());
-    ScMyStylesSet::iterator aEndItr(aCellStyles.end());
-    while (aItr != aEndItr)
-    {
-        aItr->xRanges->InsertRow(nRow, nTab, pDoc);
-        ++aItr;
-    }
-}
-
 void ScMyStylesImportHelper::InsertCol(const sal_Int32 nCol, const sal_Int32 nTab, ScDocument* pDoc)
 {
     ScXMLImport::MutexGuard aGuard(rImport);
