@@ -1,33 +1,21 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
-
-
-//------------------------------------------------------------------
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 #include <rangelst.hxx>
 #include <sfx2/app.hxx>
@@ -38,7 +26,6 @@
 #include <sfx2/navigat.hxx>
 #include <svl/stritem.hxx>
 #include <svl/urlbmk.hxx>
-#include <vcl/sound.hxx>
 #include <unotools/charclass.hxx>
 #include <stdlib.h>
 
@@ -172,7 +159,7 @@ void ColumnEdit::Down()
 void ColumnEdit::First()
 {
     nCol = 1;
-    SetText( 'A' );
+    SetText(rtl::OUString('A'));
 }
 
 //------------------------------------------------------------------------
@@ -454,7 +441,7 @@ void CommandToolBox::Click()
 
 //------------------------------------------------------------------------
 
-IMPL_LINK( CommandToolBox, ToolBoxDropdownClickHdl, ToolBox*, EMPTYARG )
+IMPL_LINK_NOARG(CommandToolBox, ToolBoxDropdownClickHdl)
 {
     //  Das Popupmenue fuer den Dropmodus muss im Click (Button Down)
     //  statt im Select (Button Up) aufgerufen werden.
@@ -553,8 +540,6 @@ ScNavigatorSettings::ScNavigatorSettings() :
 
 SFX_IMPL_CHILDWINDOWCONTEXT( ScNavigatorDialogWrapper, SID_NAVIGATOR )
 
-#define IS_MODE(bit)(((nFlags)&(bit))==(bit))
-
 ScNavigatorDialogWrapper::ScNavigatorDialogWrapper(
                                     Window*          pParent,
                                     sal_uInt16           nId,
@@ -662,7 +647,7 @@ ScNavigatorDlg::ScNavigatorDlg( SfxBindings* pB, SfxChildWindowContext* pCW, Win
     //  eListMode wird von aussen gesetzt, Root weiter unten
 
     aLbDocuments.SetDropDownLineCount(9);
-    String aOpen = String::CreateFromAscii(RTL_CONSTASCII_STRINGPARAM( " (" ));
+    rtl::OUString aOpen(" (");
     aStrActive = aOpen;
     aStrActive += String( ScResId( STR_ACTIVE ) );
     aStrActive += ')';                                      // " (aktiv)"
@@ -675,8 +660,10 @@ ScNavigatorDlg::ScNavigatorDlg( SfxBindings* pB, SfxChildWindowContext* pCW, Win
 
     aTitleBase = GetText();
 
-    long nListboxYPos = aTbxCmd.GetPosPixel().Y() + aTbxCmd.GetSizePixel().Height() + 4;
-    aLbEntries.SetPosSizePixel( 0, nListboxYPos, 0, 0, WINDOW_POSSIZE_Y);
+    long nListboxYPos =
+        Max( aTbxCmd.GetPosPixel().Y() + aTbxCmd.GetSizePixel().Height(),
+             aEdRow.GetPosPixel().Y() + aEdRow.GetSizePixel().Height() ) + 4;
+    aLbEntries.setPosSizePixel( 0, nListboxYPos, 0, 0, WINDOW_POSSIZE_Y);
 
     nBorderOffset = aLbEntries.GetPosPixel().X();
 
@@ -1037,8 +1024,6 @@ void ScNavigatorDlg::SetCurrentTableStr( const rtl::OUString& rName )
             return;
         }
     }
-
-    Sound::Beep();                  // Tabelle nicht gefunden
 }
 
 //------------------------------------------------------------------------
