@@ -1,33 +1,22 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
-
-// INCLUDE ---------------------------------------------------------------
 #include "scitems.hxx"
 #include <editeng/eeitem.hxx>
 
@@ -77,7 +66,7 @@
 
 //------------------------------------------------------------------------
 
-void lcl_LimitRect( Rectangle& rRect, const Rectangle& rVisible )
+static void lcl_LimitRect( Rectangle& rRect, const Rectangle& rVisible )
 {
     if ( rRect.Top()    < rVisible.Top()-1 )    rRect.Top()    = rVisible.Top()-1;
     if ( rRect.Bottom() > rVisible.Bottom()+1 ) rRect.Bottom() = rVisible.Bottom()+1;
@@ -87,7 +76,7 @@ void lcl_LimitRect( Rectangle& rRect, const Rectangle& rVisible )
     // Wenn's weit daneben liegt, wird lcl_DrawOneFrame erst gar nicht gerufen.
 }
 
-void lcl_DrawOneFrame( OutputDevice* pDev, const Rectangle& rInnerPixel,
+static void lcl_DrawOneFrame( OutputDevice* pDev, const Rectangle& rInnerPixel,
                         const String& rTitle, const Color& rColor, sal_Bool bTextBelow,
                         double nPPTX, double nPPTY, const Fraction& rZoomY,
                         ScDocument* pDoc, ScViewData* pButtonViewData, sal_Bool bLayoutRTL )
@@ -187,7 +176,7 @@ void lcl_DrawOneFrame( OutputDevice* pDev, const Rectangle& rInnerPixel,
     pDev->DrawRect( aOuter );
 }
 
-void lcl_DrawScenarioFrames( OutputDevice* pDev, ScViewData* pViewData, ScSplitPos eWhich,
+static void lcl_DrawScenarioFrames( OutputDevice* pDev, ScViewData* pViewData, ScSplitPos eWhich,
                             SCCOL nX1, SCROW nY1, SCCOL nX2, SCROW nY2 )
 {
     ScDocument* pDoc = pViewData->GetDocument();
@@ -264,7 +253,7 @@ void lcl_DrawScenarioFrames( OutputDevice* pDev, ScViewData* pViewData, ScSplitP
 
 //------------------------------------------------------------------------
 
-void lcl_DrawHighlight( ScOutputData& rOutputData, ScViewData* pViewData,
+static void lcl_DrawHighlight( ScOutputData& rOutputData, ScViewData* pViewData,
                         const std::vector<ScHighlightEntry>& rHighlightRanges )
 {
     SCTAB nTab = pViewData->GetTabNo();
@@ -730,7 +719,7 @@ void ScGridWindow::Draw( SCCOL nX1, SCROW nY1, SCCOL nX2, SCROW nY2, ScUpdateMod
 
         // Autofilter- und Pivot-Buttons
 
-    DrawButtons( nX1, nY1, nX2, nY2, aTabInfo, pContentDev );          // Pixel
+    DrawButtons( nX1, nX2, aTabInfo, pContentDev );          // Pixel
 
         // Notiz-Anzeiger
 
@@ -1121,7 +1110,7 @@ void ScGridWindow::DrawPagePreview( SCCOL nX1, SCROW nY1, SCCOL nX2, SCROW nY2,
     }
 }
 
-void ScGridWindow::DrawButtons( SCCOL nX1, SCROW /*nY1*/, SCCOL nX2, SCROW /*nY2*/, ScTableInfo& rTabInfo, OutputDevice* pContentDev )
+void ScGridWindow::DrawButtons( SCCOL nX1, SCCOL nX2, ScTableInfo& rTabInfo, OutputDevice* pContentDev)
 {
     aComboButton.SetOutputDevice( pContentDev );
 
@@ -1222,33 +1211,33 @@ void ScGridWindow::DrawButtons( SCCOL nX1, SCROW /*nY1*/, SCCOL nX2, SCROW /*nY2
             }
         }
 
-        if ( pRowInfo[nArrY].bPushButton && pRowInfo[nArrY].bChanged )
+        if ( pRowInfo[nArrY].bPivotButton && pRowInfo[nArrY].bChanged )
         {
             RowInfo* pThisRowInfo = &pRowInfo[nArrY];
             nRow = pThisRowInfo->nRowNo;
             for (nCol=nX1; nCol<=nX2; nCol++)
             {
                 CellInfo* pInfo = &pThisRowInfo->pCellInfo[nCol+1];
-                if ( pInfo->bPushButton && !pInfo->bHOverlapped && !pInfo->bVOverlapped )
-                {
-                    Point aScrPos = pViewData->GetScrPos( nCol, nRow, eWhich );
-                    long nSizeX;
-                    long nSizeY;
-                    pViewData->GetMergeSizePixel( nCol, nRow, nSizeX, nSizeY );
-                    long nPosX = aScrPos.X();
-                    long nPosY = aScrPos.Y();
-                    // bLayoutRTL is handled in setBoundingBox
+                if (pInfo->bHOverlapped || pInfo->bVOverlapped)
+                    continue;
 
-                    String aStr;
-                    pDoc->GetString(nCol, nRow, nTab, aStr);
-                    aCellBtn.setText(aStr);
-                    aCellBtn.setBoundingBox(Point(nPosX, nPosY), Size(nSizeX-1, nSizeY-1), bLayoutRTL);
-                    aCellBtn.setPopupLeft(false);   // DataPilot popup is always right-aligned for now
-                    aCellBtn.setDrawBaseButton(true);
-                    aCellBtn.setDrawPopupButton(pInfo->bPopupButton);
-                    aCellBtn.setHasHiddenMember(pInfo->bFilterActive);
-                    aCellBtn.draw();
-                }
+                Point aScrPos = pViewData->GetScrPos( nCol, nRow, eWhich );
+                long nSizeX;
+                long nSizeY;
+                pViewData->GetMergeSizePixel( nCol, nRow, nSizeX, nSizeY );
+                long nPosX = aScrPos.X();
+                long nPosY = aScrPos.Y();
+                // bLayoutRTL is handled in setBoundingBox
+
+                String aStr;
+                pDoc->GetString(nCol, nRow, nTab, aStr);
+                aCellBtn.setText(aStr);
+                aCellBtn.setBoundingBox(Point(nPosX, nPosY), Size(nSizeX-1, nSizeY-1), bLayoutRTL);
+                aCellBtn.setPopupLeft(false);   // DataPilot popup is always right-aligned for now
+                aCellBtn.setDrawBaseButton(pInfo->bPivotButton);
+                aCellBtn.setDrawPopupButton(pInfo->bPivotPopupButton);
+                aCellBtn.setHasHiddenMember(pInfo->bFilterActive);
+                aCellBtn.draw();
             }
         }
 
@@ -1382,7 +1371,7 @@ void ScGridWindow::GetSelectionRects( ::std::vector< Rectangle >& rPixelRects )
     PutInOrder( nY1, nY2 );
 
     sal_Bool bTestMerge = sal_True;
-    sal_Bool bRepeat = sal_True;
+    bool bRepeat = true;
 
     SCCOL nTestX2 = nX2;
     SCROW nTestY2 = nY2;
