@@ -1,30 +1,21 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 #include <svtools/libcall.hxx>
 #include <vcl/msgbox.hxx>
@@ -1534,7 +1525,7 @@ void lcl_Pivot( FixedText& aTimeText )  // 30
     }
 }
 
-IMPL_LINK(MyWindow, CountHdl, PushButton*, EMPTYARG)
+IMPL_LINK_NOARG(MyWindow, CountHdl)
 {
 
     long nCount = aCountField.GetValue();
@@ -1645,7 +1636,7 @@ IMPL_LINK(MyWindow, CountHdl, PushButton*, EMPTYARG)
 
 //-----------------------------------------------------------------------
 
-IMPL_LINK(MyWindow, TextHdl, PushButton*, EMPTYARG)
+IMPL_LINK_NOARG(MyWindow, TextHdl)
 {
     sal_uInt16 nCol = (sal_uInt16)aColField.GetValue();
     sal_uInt16 nRow = (sal_uInt16)aRowField.GetValue();
@@ -1694,7 +1685,7 @@ IMPL_LINK(MyWindow, TextHdl, PushButton*, EMPTYARG)
 
 //-----------------------------------------------------------------------
 
-IMPL_LINK(MyWindow, BlaHdl, PushButton*, EMPTYARG)
+IMPL_LINK_NOARG(MyWindow, BlaHdl)
 {
     aTimeText.SetText("...");
 
@@ -1768,7 +1759,7 @@ IMPL_LINK(MyWindow, BlaHdl, PushButton*, EMPTYARG)
 
 //-----------------------------------------------------------------------
 
-IMPL_LINK(MyWindow, TabHdl, PushButton*, EMPTYARG)
+IMPL_LINK_NOARG(MyWindow, TabHdl)
 {
     String aResult;
 
@@ -1861,7 +1852,7 @@ void lcl_FillCells(XCellCollectionRef xColl)
     }
 }
 
-IMPL_LINK(MyWindow, ViewHdl, PushButton*, EMPTYARG)
+IMPL_LINK_NOARG(MyWindow, ViewHdl)
 {
     XSpreadsheetDocumentRef xDoc = lcl_GetDocument();           // Calc-Model
     XInterfaceRef xInt = lcl_GetView();
