@@ -1,30 +1,21 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 #include <com/sun/star/i18n/TextConversionOption.hpp>
 
@@ -52,7 +43,6 @@
 
 class SfxRequest;
 
-#define C2U(cChar)  rtl::OUString::createFromAscii(cChar)
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::beans;
@@ -227,8 +217,7 @@ void FuHangulHanjaConversion::StartChineseConversion()
         if(xMCF.is())
         {
             Reference< ui::dialogs::XExecutableDialog > xDialog(
-                    xMCF->createInstanceWithContext(
-                        rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.linguistic2.ChineseTranslationDialog"))
+                    xMCF->createInstanceWithContext("com.sun.star.linguistic2.ChineseTranslationDialog"
                         , xContext), UNO_QUERY);
             Reference< lang::XInitialization > xInit( xDialog, UNO_QUERY );
             if( xInit.is() )
@@ -238,7 +227,7 @@ void FuHangulHanjaConversion::StartChineseConversion()
                 Sequence<Any> aSeq(1);
                 Any* pArray = aSeq.getArray();
                 PropertyValue aParam;
-                aParam.Name = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ParentWindow"));
+                aParam.Name = "ParentWindow";
                 aParam.Value <<= makeAny(xDialogParentWindow);
                 pArray[0] <<= makeAny(aParam);
                 xInit->initialize( aSeq );
@@ -256,9 +245,9 @@ void FuHangulHanjaConversion::StartChineseConversion()
                     {
                         try
                         {
-                            xProp->getPropertyValue( C2U("IsDirectionToSimplified") ) >>= bToSimplified;
-                            xProp->getPropertyValue( C2U("IsUseCharacterVariants") ) >>= bUseVariants;
-                            xProp->getPropertyValue( C2U("IsTranslateCommonTerms") ) >>= bCommonTerms;
+                            xProp->getPropertyValue( "IsDirectionToSimplified" ) >>= bToSimplified;
+                            xProp->getPropertyValue( "IsUseCharacterVariants" ) >>= bUseVariants;
+                            xProp->getPropertyValue( "IsTranslateCommonTerms" ) >>= bCommonTerms;
                         }
                         catch( Exception& )
                         {
