@@ -1,30 +1,21 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 
 #include "pdfiprocessor.hxx"
@@ -83,7 +74,6 @@ namespace pdfi
     m_eTextDirection( LrTb ),
     m_nPages(0),
     m_nNextZOrder( 1 ),
-    m_fWordSpace(0.0),
     m_bIsWhiteSpaceInLine( false ),
     m_xStatusIndicator( xStat ),
     m_bHaveTextOnDocLevel(false),
@@ -220,7 +210,7 @@ sal_Int32 PDFIProcessor::getFontId( const FontAttributes& rAttr ) const
 // line diagnose block - start
 void PDFIProcessor::processGlyphLine()
 {
-    if( m_GlyphsList.empty() )
+    if( m_GlyphsList.size()<1 )
         return;
 
     double fPreAvarageSpaceValue= 0.0;
@@ -322,15 +312,11 @@ void PDFIProcessor::processGlyphLine()
         pFrame->ZOrder = m_nNextZOrder++;
         pPara = m_pElFactory->createParagraphElement( pFrame );
 
-
-
         processGlyph( 0,
                   m_GlyphsList[0],
                   pPara,
                   pFrame,
                   m_bIsWhiteSpaceInLine );
-
-
     }
 
 
@@ -423,9 +409,7 @@ void PDFIProcessor::processGlyph( double       fPreAvarageSpaceValue,
 
         drawCharGlyphs(  aGlyph.getGlyph(),
                          aGlyph.getRect(),
-                         aGlyph.getFontMatrix(),
                          aGlyph.getGC(),
-                         aGlyph.getCurElement(),
                          pPara,
                          pFrame,
                          flag);
@@ -434,9 +418,7 @@ void PDFIProcessor::processGlyph( double       fPreAvarageSpaceValue,
     {
         drawCharGlyphs( aGlyph.getGlyph(),
                         aGlyph.getRect(),
-                        aGlyph.getFontMatrix(),
                         aGlyph.getGC(),
-                        aGlyph.getCurElement(),
                         pPara,
                         pFrame,
                         false );
@@ -493,7 +475,6 @@ GraphicsContext& PDFIProcessor::getTransformGlyphContext( CharGlyph& rGlyph )
     geometry::Matrix2D          rFontMatrix = rGlyph.getFontMatrix();
 
     rtl::OUString tempStr( 32 );
-    geometry::RealRectangle2D aRect(rRect);
 
     basegfx::B2DHomMatrix aFontMatrix;
     basegfx::unotools::homMatrixFromMatrix(
@@ -515,9 +496,7 @@ GraphicsContext& PDFIProcessor::getTransformGlyphContext( CharGlyph& rGlyph )
 }
 void PDFIProcessor::drawCharGlyphs( rtl::OUString&             rGlyphs,
                                     geometry::RealRectangle2D& rRect,
-                                    geometry::Matrix2D&         ,
                                     GraphicsContext aGC,
-                                    Element*  ,
                                     ParagraphElement* pPara,
                                     FrameElement* pFrame,
                                     bool bSpaceFlag )
@@ -743,7 +722,7 @@ void PDFIProcessor::intersectEoClip(const uno::Reference< rendering::XPolyPolygo
 void PDFIProcessor::hyperLink( const geometry::RealRectangle2D& rBounds,
                                const ::rtl::OUString&           rURI )
 {
-    if( rURI.getLength() )
+    if( !rURI.isEmpty() )
     {
         HyperlinkElement* pLink = m_pElFactory->createHyperlinkElement(
             &m_pCurPage->Hyperlinks,
@@ -832,7 +811,7 @@ void PDFIProcessor::emit( XmlEmitter&               rEmitter,
         rVisitorFactory.createOptimizingVisitor(*this));
     // FIXME: localization
     startIndicator( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( " " ) ) );
-    m_pDocument->visitedBy( *optimizingVisitor, std::list<Element*>::iterator());
+    m_pDocument->visitedBy( *optimizingVisitor, std::list<Element*>::const_iterator());
 
 #if OSL_DEBUG_LEVEL > 1
     m_pDocument->emitStructure( 0 );
@@ -844,7 +823,7 @@ void PDFIProcessor::emit( XmlEmitter&               rEmitter,
         rVisitorFactory.createStyleCollectingVisitor(aStyles,*this));
     // FIXME: localization
 
-    m_pDocument->visitedBy( *finalizingVisitor, std::list<Element*>::iterator() );
+    m_pDocument->visitedBy( *finalizingVisitor, std::list<Element*>::const_iterator() );
 
     EmitContext aContext( rEmitter, aStyles, m_aImages, *this, m_xStatusIndicator, m_xContext );
     ElementTreeVisitorSharedPtr aEmittingVisitor(
@@ -879,7 +858,7 @@ void PDFIProcessor::emit( XmlEmitter&               rEmitter,
     // emit style list
     aStyles.emit( aContext, *aEmittingVisitor );
 
-    m_pDocument->visitedBy( *aEmittingVisitor, std::list<Element*>::iterator() );
+    m_pDocument->visitedBy( *aEmittingVisitor, std::list<Element*>::const_iterator() );
     aContext.rEmitter.endTag( "office:document" );
     endIndicator();
 }
@@ -916,16 +895,6 @@ void PDFIProcessor::endIndicator()
         m_xStatusIndicator->end();
 }
 
-void PDFIProcessor::sortDocument( bool bDeep )
-{
-    for( std::list< Element* >::iterator it = m_pDocument->Children.begin();
-         it != m_pDocument->Children.end(); ++it )
-    {
-        if( dynamic_cast<PageElement*>(*it) != NULL )
-            sortElements( *it, bDeep );
-    }
-}
-
 static bool lr_tb_sort( Element* pLeft, Element* pRight )
 {
     // first: top-bottom sorting
