@@ -1,30 +1,21 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 
 #include "fltfnc.hxx"
@@ -40,7 +31,6 @@
 #include <comphelper/sequenceashashmap.hxx>
 
 #include <sot/exchange.hxx>
-#include <tools/config.hxx>
 #include <basic/sbmeth.hxx>
 #include <basic/basmgr.hxx>
 #include <basic/sbstar.hxx>
@@ -76,14 +66,11 @@
 #include <com/sun/star/frame/XLoadEventListener.hpp>
 #include <com/sun/star/frame/XFilterDetect.hpp>
 #include <com/sun/star/loader/XImplementationLoader.hpp>
-#include <com/sun/star/loader/CannotActivateFactoryException.hpp>
 #include <comphelper/processfactory.hxx>
-#include <com/sun/star/beans/PropertyValue.hpp>
 
 #include <sal/types.h>
 #include <com/sun/star/uno/Reference.hxx>
 #include <com/sun/star/ucb/XContent.hpp>
-#include <rtl/ustring.hxx>
 #include <unotools/pathoptions.hxx>
 #include <unotools/moduleoptions.hxx>
 #include <comphelper/mediadescriptor.hxx>
@@ -119,7 +106,6 @@ using namespace ::com::sun::star::beans;
 #include <sfx2/request.hxx>
 #include "arrdecl.hxx"
 #include <sfx2/appuno.hxx>
-#include <sfx2/viewfrm.hxx>
 
 #include <boost/ptr_container/ptr_vector.hpp>
 #include <functional>
@@ -141,7 +127,7 @@ static void CreateFilterArr()
 //----------------------------------------------------------------
 inline String ToUpper_Impl( const String &rStr )
 {
-    return SvtSysLocale().GetCharClass().upper( rStr );
+    return SvtSysLocale().GetCharClass().uppercase( rStr );
 }
 
 //----------------------------------------------------------------
@@ -222,8 +208,8 @@ const SfxFilter* SfxFilterContainer::GetDefaultFilter_Impl( const String& rName
     const SfxFilter* pFilter = aMatcher.GetFilter4FilterName(sDefaultFilter);
 
     if (
-        (pFilter) &&
-        (pFilter->GetServiceName().CompareIgnoreCaseToAscii( sServiceName ) != COMPARE_EQUAL)
+        pFilter &&
+        !pFilter->GetServiceName().equalsIgnoreAsciiCase(sServiceName)
        )
     {
         pFilter = 0;
@@ -239,7 +225,7 @@ const SfxFilter* SfxFilterContainer::GetDefaultFilter_Impl( const String& rName
         for ( size_t i = 0, n = pFilterArr->size(); i < n; ++i )
         {
             const SfxFilter* pCheckFilter = pFilterArr->at( i );
-            if ( pCheckFilter->GetServiceName().CompareIgnoreCaseToAscii( sServiceName ) == COMPARE_EQUAL )
+            if ( pCheckFilter->GetServiceName().equalsIgnoreAsciiCase(sServiceName) )
             {
                 pFilter = pCheckFilter;
                 break;
@@ -292,7 +278,7 @@ namespace
     {
         rtl::OUString aName;
 
-        if (rName.getLength())
+        if (!rName.isEmpty())
             aName = SfxObjectShell::GetServiceNameFromFactory(rName);
 
         // find the impl-Data of any comparable FilterMatcher that was created
@@ -340,7 +326,7 @@ void SfxFilterMatcher_Impl::Update()
         for ( size_t i = 0, n = pFilterArr->size(); i < n; ++i )
         {
             SfxFilter* pFilter = pFilterArr->at( i );
-            if ( pFilter->GetServiceName() == String(aName) )
+            if ( pFilter->GetServiceName() == aName )
                 pList->push_back( pFilter );
         }
     }
@@ -355,7 +341,7 @@ void SfxFilterMatcher_Impl::InitForIterating() const
         // global filter array has not been created yet
         SfxFilterContainer::ReadFilters_Impl();
 
-    if ( aName.getLength() )
+    if ( !aName.isEmpty() )
     {
         // matcher of factory: use only filters of that document type
         ((SfxFilterMatcher_Impl*)this)->pList = new SfxFilterList_Impl;
@@ -390,7 +376,7 @@ sal_uInt32  SfxFilterMatcher::GuessFilterIgnoringContent(
     SfxFilterFlags nMust,
     SfxFilterFlags nDont ) const
 {
-    Reference< XTypeDetection > xDetection( ::comphelper::getProcessServiceFactory()->createInstance(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.document.TypeDetection"))), UNO_QUERY );
+    Reference< XTypeDetection > xDetection( ::comphelper::getProcessServiceFactory()->createInstance(::rtl::OUString("com.sun.star.document.TypeDetection")), UNO_QUERY );
     ::rtl::OUString sTypeName;
     try
     {
@@ -401,7 +387,7 @@ sal_uInt32  SfxFilterMatcher::GuessFilterIgnoringContent(
     }
 
     *ppFilter = NULL;
-    if ( sTypeName.getLength() )
+    if ( !sTypeName.isEmpty() )
     {
         // make sure filter list is initialized
         m_rImpl.InitForIterating();
@@ -425,7 +411,7 @@ sal_uInt32  SfxFilterMatcher::GuessFilterControlDefaultUI( SfxMedium& rMedium, c
     const SfxFilter* pOldFilter = *ppFilter;
 
     // no detection service -> nothing to do !
-    Reference< XTypeDetection > xDetection( ::comphelper::getProcessServiceFactory()->createInstance(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.document.TypeDetection"))), UNO_QUERY );
+    Reference< XTypeDetection > xDetection( ::comphelper::getProcessServiceFactory()->createInstance(::rtl::OUString("com.sun.star.document.TypeDetection")), UNO_QUERY );
     if (!xDetection.is())
         return ERRCODE_ABORT;
 
@@ -437,6 +423,7 @@ sal_uInt32  SfxFilterMatcher::GuessFilterControlDefaultUI( SfxMedium& rMedium, c
 
         ::rtl::OUString sURL( rMedium.GetURLObject().GetMainURL( INetURLObject::NO_DECODE ) );
         ::com::sun::star::uno::Reference< ::com::sun::star::io::XInputStream > xInStream = rMedium.GetInputStream();
+        rtl::OUString aFilterName;
 
         // stream exists => deep detection (with preselection ... if possible)
         if (xInStream.is())
@@ -447,7 +434,7 @@ sal_uInt32  SfxFilterMatcher::GuessFilterControlDefaultUI( SfxMedium& rMedium, c
             aDescriptor[::comphelper::MediaDescriptor::PROP_INPUTSTREAM()       ] <<= xInStream;
             aDescriptor[::comphelper::MediaDescriptor::PROP_INTERACTIONHANDLER()] <<= rMedium.GetInteractionHandler();
 
-            if ( m_rImpl.aName.getLength() )
+            if ( !m_rImpl.aName.isEmpty() )
                 aDescriptor[::comphelper::MediaDescriptor::PROP_DOCUMENTSERVICE()] <<= m_rImpl.aName;
 
             if ( pOldFilter )
@@ -458,23 +445,39 @@ sal_uInt32  SfxFilterMatcher::GuessFilterControlDefaultUI( SfxMedium& rMedium, c
 
             ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue > lDescriptor = aDescriptor.getAsConstPropertyValueList();
             sTypeName = xDetection->queryTypeByDescriptor(lDescriptor, sal_True); // lDescriptor is used as In/Out param ... dont use aDescriptor.getAsConstPropertyValueList() directly!
+
+            for (sal_Int32 i = 0; i < lDescriptor.getLength(); ++i)
+            {
+                if (lDescriptor[i].Name == "FilterName")
+                    // Type detection picked a preferred filter for this format.
+                    aFilterName = lDescriptor[i].Value.get<rtl::OUString>();
+            }
         }
         // no stream exists => try flat detection without preselection as fallback
         else
             sTypeName = xDetection->queryTypeByURL(sURL);
 
-        if (sTypeName.getLength())
+        if (!sTypeName.isEmpty())
         {
-            // detect filter by given type
-            // In case of this matcher is bound to a particular document type:
-            // If there is no acceptable type for this document at all, the type detection has possibly returned something else.
-            // The DocumentService property is only a preselection, and all preselections are considered as optional!
-            // This "wrong" type will be sorted out now because we match only allowed filters to the detected type
-            ::com::sun::star::uno::Sequence< ::com::sun::star::beans::NamedValue > lQuery(1);
-            lQuery[0].Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Name"));
-            lQuery[0].Value <<= sTypeName;
+            const SfxFilter* pFilter = NULL;
+            if (!aFilterName.isEmpty())
+                // Type detection returned a suitable filter for this.  Use it.
+                pFilter = SfxFilter::GetFilterByName(aFilterName);
+
+            if (!pFilter)
+            {
+                // detect filter by given type
+                // In case of this matcher is bound to a particular document type:
+                // If there is no acceptable type for this document at all, the type detection has possibly returned something else.
+                // The DocumentService property is only a preselection, and all preselections are considered as optional!
+                // This "wrong" type will be sorted out now because we match only allowed filters to the detected type
+                ::com::sun::star::uno::Sequence< ::com::sun::star::beans::NamedValue > lQuery(1);
+                lQuery[0].Name = ::rtl::OUString("Name");
+                lQuery[0].Value <<= sTypeName;
+
+                pFilter = GetFilterForProps(lQuery, nMust, nDont);
+            }
 
-            const SfxFilter* pFilter = GetFilterForProps(lQuery, nMust, nDont);
             if (pFilter)
             {
                 *ppFilter = pFilter;
@@ -494,7 +497,7 @@ sal_Bool SfxFilterMatcher::IsFilterInstalled_Impl( const SfxFilter* pFilter )
     if ( pFilter->GetFilterFlags() & SFX_FILTER_MUSTINSTALL )
     {
         // Here could a  re-installation be offered
-        String aText( SfxResId( STR_FILTER_NOT_INSTALLED ) );
+        String aText( SfxResId(STR_FILTER_NOT_INSTALLED).toString() );
         aText.SearchAndReplaceAscii( "$(FILTER)", pFilter->GetUIName() );
         QueryBox aQuery( NULL, WB_YES_NO | WB_DEF_YES, aText );
         short nRet = aQuery.Execute();
@@ -512,7 +515,7 @@ sal_Bool SfxFilterMatcher::IsFilterInstalled_Impl( const SfxFilter* pFilter )
     }
     else if ( pFilter->GetFilterFlags() & SFX_FILTER_CONSULTSERVICE )
     {
-        String aText( SfxResId( STR_FILTER_CONSULT_SERVICE ) );
+        String aText( SfxResId(STR_FILTER_CONSULT_SERVICE).toString() );
         aText.SearchAndReplaceAscii( "$(FILTER)", pFilter->GetUIName() );
         InfoBox ( NULL, aText ).Execute();
         return sal_False;
@@ -614,7 +617,7 @@ const SfxFilter* SfxFilterMatcher::GetFilterForProps( const com::sun::star::uno:
             ::rtl::OUString aValue;
 
             // try to get the preferred filter (works without loading all filters!)
-            if ( (aProps[::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("PreferredFilter"))] >>= aValue) && aValue.getLength() )
+            if ( (aProps[::rtl::OUString("PreferredFilter")] >>= aValue) && !aValue.isEmpty() )
             {
                 const SfxFilter* pFilter = SfxFilter::GetFilterByName( aValue );
                 if ( !pFilter || (pFilter->GetFilterFlags() & nMust) != nMust || (pFilter->GetFilterFlags() & nDont ) )
@@ -622,15 +625,14 @@ const SfxFilter* SfxFilterMatcher::GetFilterForProps( const com::sun::star::uno:
                     // pFilter == 0: if preferred filter is a Writer filter, but Writer module is not installed
                     continue;
 
-                if ( m_rImpl.aName.getLength() )
+                if ( !m_rImpl.aName.isEmpty() )
                 {
                     // if this is not the global FilterMatcher: check if filter matches the document type
-                    ::rtl::OUString aService;
-                    if ( pFilter->GetServiceName() != String(m_rImpl.aName) )
+                    if ( pFilter->GetServiceName() != m_rImpl.aName )
                     {
                         // preferred filter belongs to another document type; now we must search the filter
                         m_rImpl.InitForIterating();
-                        aProps[::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Name"))] >>= aValue;
+                        aProps[::rtl::OUString("Name")] >>= aValue;
                         pFilter = GetFilter4EA( aValue, nMust, nDont );
                         if ( pFilter )
                             return pFilter;
@@ -663,7 +665,7 @@ const SfxFilter* SfxFilterMatcher::GetFilter4Mime( const ::rtl::OUString& rMedia
     }
 
     com::sun::star::uno::Sequence < com::sun::star::beans::NamedValue > aSeq(1);
-    aSeq[0].Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("MediaType"));
+    aSeq[0].Name = ::rtl::OUString("MediaType");
     aSeq[0].Value <<= rMediaType;
     return GetFilterForProps( aSeq, nMust, nDont );
 }
@@ -692,7 +694,7 @@ const SfxFilter* SfxFilterMatcher::GetFilter4EA( const String& rType,SfxFilterFl
     }
 
     com::sun::star::uno::Sequence < com::sun::star::beans::NamedValue > aSeq(1);
-    aSeq[0].Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Name"));
+    aSeq[0].Name = ::rtl::OUString("Name");
     aSeq[0].Value <<= ::rtl::OUString( rType );
     return GetFilterForProps( aSeq, nMust, nDont );
 }
@@ -731,7 +733,7 @@ const SfxFilter* SfxFilterMatcher::GetFilter4Extension( const String& rExt, SfxF
         sExt.Erase(0,1);
 
     com::sun::star::uno::Sequence < com::sun::star::beans::NamedValue > aSeq(1);
-    aSeq[0].Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Extensions"));
+    aSeq[0].Name = ::rtl::OUString("Extensions");
     ::com::sun::star::uno::Sequence < ::rtl::OUString > aExts(1);
     aExts[0] = sExt;
     aSeq[0].Value <<= aExts;
@@ -745,7 +747,7 @@ const SfxFilter* SfxFilterMatcher::GetFilter4ClipBoardId( sal_uInt32 nId, SfxFil
 
     com::sun::star::uno::Sequence < com::sun::star::beans::NamedValue > aSeq(1);
     ::rtl::OUString aName = SotExchange::GetFormatName( nId );
-    aSeq[0].Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ClipboardFormat"));
+    aSeq[0].Name = ::rtl::OUString("ClipboardFormat");
     aSeq[0].Value <<= aName;
     return GetFilterForProps( aSeq, nMust, nDont );
 }
@@ -830,7 +832,7 @@ IMPL_STATIC_LINK( SfxFilterMatcher, MaybeFileHdl_Impl, String*, pString )
     const SfxFilter* pFilter = pThis->GetFilter4Extension( *pString, SFX_FILTER_IMPORT );
     if (pFilter && !pFilter->GetWildcard().Matches( String() ) &&
         !pFilter->GetWildcard().Matches(DEFINE_CONST_UNICODE("*.*")) &&
-        !pFilter->GetWildcard().Matches('*')
+        !pFilter->GetWildcard().Matches(rtl::OUString('*'))
        )
     {
         return sal_True;
@@ -894,7 +896,7 @@ const SfxFilter* SfxFilterMatcherIter::Next()
     sal_Int32               nItem   = 0                ;
     for( nItem=0; nItem<nCount; ++nItem )
     {
-        if( sPrefix.getLength() > 0 )
+        if( !sPrefix.isEmpty() )
         {
             sString.append( sPrefix );
         }
@@ -951,33 +953,40 @@ void SfxFilterContainer::ReadSingleFilter_Impl(
         sal_Int32 nFilterProperty      = 0                            ;
         for( nFilterProperty=0; nFilterProperty<nFilterPropertyCount; ++nFilterProperty )
         {
-            if( lFilterProperties[nFilterProperty].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("FileFormatVersion")) )
+            if ( lFilterProperties[nFilterProperty].Name == "FileFormatVersion" )
             {
                 lFilterProperties[nFilterProperty].Value >>= nFormatVersion;
             }
-            else if( lFilterProperties[nFilterProperty].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("TemplateName")) )
+            else if ( lFilterProperties[nFilterProperty].Name == "TemplateName" )
             {
                 lFilterProperties[nFilterProperty].Value >>= sDefaultTemplate;
             }
-            else if( lFilterProperties[nFilterProperty].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("Flags")) )
+            else if ( lFilterProperties[nFilterProperty].Name == "Flags" )
             {
                 lFilterProperties[nFilterProperty].Value >>= nFlags;
             }
-            else if( lFilterProperties[nFilterProperty].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("UIName")) )
+            else if ( lFilterProperties[nFilterProperty].Name == "UIName" )
             {
                 lFilterProperties[nFilterProperty].Value >>= sUIName;
             }
-            else if( lFilterProperties[nFilterProperty].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("UserData")) )
+            else if ( lFilterProperties[nFilterProperty].Name == "UserData" )
             {
                 ::com::sun::star::uno::Sequence< ::rtl::OUString > lUserData;
                 lFilterProperties[nFilterProperty].Value >>= lUserData;
                 sUserData = implc_convertStringlistToString( lUserData, ',', ::rtl::OUString() );
             }
-            else if( lFilterProperties[nFilterProperty].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("DocumentService")) )
+            else if ( lFilterProperties[nFilterProperty].Name == "DocumentService" )
             {
                 lFilterProperties[nFilterProperty].Value >>= sServiceName;
             }
-            else if( lFilterProperties[nFilterProperty].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("Type")) )
+            else if (lFilterProperties[nFilterProperty].Name == "ExportExtension")
+            {
+                // Extension preferred by the filter.  This takes precedence
+                // over those that are given in the file format type.
+                lFilterProperties[nFilterProperty].Value >>= sExtension;
+                sExtension = OUString("*.") + sExtension;
+            }
+            else if ( lFilterProperties[nFilterProperty].Name == "Type" )
             {
                 lFilterProperties[nFilterProperty].Value >>= sType;
                 // Try to get filter .. but look for any exceptions!
@@ -999,25 +1008,28 @@ void SfxFilterContainer::ReadSingleFilter_Impl(
                     sal_Int32 nTypeProperty      = 0                          ;
                     for( nTypeProperty=0; nTypeProperty<nTypePropertyCount; ++nTypeProperty )
                     {
-                        if( lTypeProperties[nTypeProperty].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("ClipboardFormat")) )
+                        if ( lTypeProperties[nTypeProperty].Name == "ClipboardFormat" )
                         {
                             lTypeProperties[nTypeProperty].Value >>= sHumanName;
                         }
-                        else if( lTypeProperties[nTypeProperty].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("DocumentIconID")) )
+                        else if ( lTypeProperties[nTypeProperty].Name == "DocumentIconID" )
                         {
                             lTypeProperties[nTypeProperty].Value >>= nDocumentIconId;
                         }
-                        else if( lTypeProperties[nTypeProperty].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("MediaType")) )
+                        else if ( lTypeProperties[nTypeProperty].Name == "MediaType" )
                         {
                             lTypeProperties[nTypeProperty].Value >>= sMimeType;
                         }
-                        else if( lTypeProperties[nTypeProperty].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("Extensions")) )
+                        else if ( lTypeProperties[nTypeProperty].Name == "Extensions" )
                         {
-                            ::com::sun::star::uno::Sequence< ::rtl::OUString > lExtensions;
-                            lTypeProperties[nTypeProperty].Value >>= lExtensions;
-                            sExtension = implc_convertStringlistToString( lExtensions, ';', DEFINE_CONST_UNICODE("*.") );
+                            if (sExtension.isEmpty())
+                            {
+                                ::com::sun::star::uno::Sequence< ::rtl::OUString > lExtensions;
+                                lTypeProperties[nTypeProperty].Value >>= lExtensions;
+                                sExtension = implc_convertStringlistToString( lExtensions, ';', DEFINE_CONST_UNICODE("*.") );
+                            }
                         }
-                        else if( lTypeProperties[nTypeProperty].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("URLPattern")) )
+                        else if ( lTypeProperties[nTypeProperty].Name == "URLPattern" )
                         {
                                 ::com::sun::star::uno::Sequence< ::rtl::OUString > lPattern;
                                 lTypeProperties[nTypeProperty].Value >>= lPattern;
@@ -1028,11 +1040,11 @@ void SfxFilterContainer::ReadSingleFilter_Impl(
             }
         }
 
-        if ( !sServiceName.getLength() )
+        if ( sServiceName.isEmpty() )
             return;
 
         // old formats are found ... using HumanPresentableName!
-        if( sHumanName.getLength() )
+        if( !sHumanName.isEmpty() )
         {
             nClipboardId = SotExchange::RegisterFormatName( sHumanName );
 
@@ -1135,7 +1147,6 @@ void SfxFilterContainer::ReadFilters_Impl( sal_Bool bUpdate )
                     SfxFilter* pFilter;
                     for ( size_t i = 0, n = rList.size(); i < n; ++i )
                     {
-                        pFilter = NULL;
                         pFilter = rList[ i ];
                         pFilter->nFormatType |= SFX_FILTER_NOTINSTALLED;
                     }
