@@ -1,30 +1,21 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 
 #include "arrdecl.hxx"
@@ -40,8 +31,7 @@
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/frame/XTitle.hpp>
 #include <osl/mutex.hxx>
-
-#include <tools/resary.hxx>
+#include <rtl/instance.hxx>
 #include <vcl/msgbox.hxx>
 #include <vcl/wrkwin.hxx>
 #include <vcl/svapp.hxx>
@@ -120,12 +110,13 @@ using ::basic::BasicManagerRepository;
 
 DBG_NAME(SfxObjectShell)
 
-#define DocumentInfo
 #include "sfxslots.hxx"
 
 namespace {
 
-static WeakReference< XInterface > s_xCurrentComponent;
+class theCurrentComponent : public rtl::Static< WeakReference< XInterface >, theCurrentComponent > {};
+
+#ifndef DISABLE_SCRIPTING
 
 // remember all registered components for VBA compatibility, to be able to remove them on disposing the model
 typedef ::std::map< XInterface*, ::rtl::OString > VBAConstantNameMap;
@@ -143,15 +134,17 @@ static VBAConstantNameMap s_aRegisteredVBAConstants;
     if( xProps.is() ) try
     {
         ::rtl::OUString aConstName;
-        xProps->getPropertyValue( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(  "ThisVBADocObj"  ) ) ) >>= aConstName;
+        xProps->getPropertyValue( ::rtl::OUString( "ThisVBADocObj"  ) ) >>= aConstName;
         return ::rtl::OUStringToOString( aConstName, RTL_TEXTENCODING_ASCII_US );
     }
-    catch( uno::Exception& ) // not supported
+    catch (const uno::Exception&) // not supported
     {
     }
     return ::rtl::OString();
 }
 
+#endif
+
 } // namespace
 
 //=========================================================================
@@ -189,6 +182,7 @@ void SAL_CALL SfxModelListener_Impl::disposing( const com::sun::star::lang::Even
         SfxObjectShell::SetCurrentComponent( Reference< XInterface >() );
     }
 
+#ifndef DISABLE_SCRIPTING
     /*  Remove VBA component from AppBasic. As every application registers its
         own current component, the disposed component may not be the "current
         component" of the SfxObjectShell. */
@@ -202,13 +196,9 @@ void SAL_CALL SfxModelListener_Impl::disposing( const com::sun::star::lang::Even
             s_aRegisteredVBAConstants.erase( aIt );
         }
     }
+#endif
 
-    if ( mpDoc->Get_Impl()->bHiddenLockedByAPI )
-    {
-        mpDoc->Get_Impl()->bHiddenLockedByAPI = sal_False;
-        mpDoc->OwnerLock(sal_False);
-    }
-    else if ( !mpDoc->Get_Impl()->bClosing )
+    if ( !mpDoc->Get_Impl()->bClosing )
         // GCC crashes when already in the destructor, so first query the Flag
         mpDoc->DoClose();
 }
@@ -237,7 +227,6 @@ SfxObjectShell_Impl::SfxObjectShell_Impl( SfxObjectShell& _rDocShell )
     ,bImportDone ( sal_False)
     ,bInPrepareClose( sal_False )
     ,bPreparedForClose( sal_False )
-    ,bWaitingForPicklist( sal_True )
     ,bForbidReload( sal_False )
     ,bBasicInitialized( sal_False )
     ,bIsPrintJobCancelable( sal_True )
@@ -270,7 +259,6 @@ SfxObjectShell_Impl::SfxObjectShell_Impl( SfxObjectShell& _rDocShell )
     ,pModule( 0 )
     ,eFlags( SFXOBJECTSHELL_UNDEFINED )
     ,bReadOnlyUI( sal_False )
-    ,bHiddenLockedByAPI( sal_False )
     ,nStyleFilter( 0 )
     ,bDisposing( sal_False )
     ,m_bEnableSetModified( sal_True )
@@ -284,7 +272,7 @@ SfxObjectShell_Impl::SfxObjectShell_Impl( SfxObjectShell& _rDocShell )
 {
     SfxObjectShell* pDoc = &_rDocShell;
     SfxObjectShellArr_Impl &rArr = SFX_APP()->GetObjectShells_Impl();
-    rArr.C40_INSERT( SfxObjectShell, pDoc, rArr.Count() );
+    rArr.push_back( pDoc );
     bInList = sal_True;
 }
 
@@ -410,7 +398,7 @@ SfxObjectShell::~SfxObjectShell()
     // The removing of the temporary file must be done as the latest step in the document destruction
     if ( pImp->aTempName.Len() )
     {
-        String aTmp;
+        rtl::OUString aTmp;
         ::utl::LocalFileHelper::ConvertPhysicalNameToURL( pImp->aTempName, aTmp );
         ::utl::UCBContentHelper::Kill( aTmp );
     }
@@ -466,7 +454,7 @@ sal_Bool SfxObjectShell::Close()
             {
                 xCloseable->close( sal_True );
             }
-            catch( Exception& )
+            catch (const Exception&)
             {
                 pImp->bClosing = sal_False;
             }
@@ -477,10 +465,9 @@ sal_Bool SfxObjectShell::Close()
             // remove from Document list
             SfxApplication *pSfxApp = SFX_APP();
             SfxObjectShellArr_Impl &rDocs = pSfxApp->GetObjectShells_Impl();
-            const SfxObjectShell *pThis = this;
-            sal_uInt16 nPos = rDocs.GetPos(pThis);
-            if ( nPos < rDocs.Count() )
-                rDocs.Remove( nPos );
+            SfxObjectShellArr_Impl::iterator it = std::find( rDocs.begin(), rDocs.end(), this );
+            if ( it != rDocs.end() )
+                rDocs.erase( it );
             pImp->bInList = sal_False;
         }
     }
@@ -501,9 +488,9 @@ SfxObjectShell* SfxObjectShell::GetFirst
     SfxObjectShellArr_Impl &rDocs = SFX_APP()->GetObjectShells_Impl();
 
     // seach for a SfxDocument of the specified type
-    for ( sal_uInt16 nPos = 0; nPos < rDocs.Count(); ++nPos )
+    for ( sal_uInt16 nPos = 0; nPos < rDocs.size(); ++nPos )
     {
-        SfxObjectShell* pSh = rDocs.GetObject( nPos );
+        SfxObjectShell* pSh = rDocs[ nPos ];
         if ( bOnlyVisible && pSh->IsPreview() && pSh->IsReadOnly() )
             continue;
 
@@ -529,14 +516,14 @@ SfxObjectShell* SfxObjectShell::GetNext
 
     // refind the specified predecessor
     sal_uInt16 nPos;
-    for ( nPos = 0; nPos < rDocs.Count(); ++nPos )
-        if ( rDocs.GetObject(nPos) == &rPrev )
+    for ( nPos = 0; nPos < rDocs.size(); ++nPos )
+        if ( rDocs[nPos] == &rPrev )
             break;
 
     // search for the next SfxDocument of the specified type
-    for ( ++nPos; nPos < rDocs.Count(); ++nPos )
+    for ( ++nPos; nPos < rDocs.size(); ++nPos )
     {
-        SfxObjectShell* pSh = rDocs.GetObject( nPos );
+        SfxObjectShell* pSh = rDocs[ nPos ];
         if ( bOnlyVisible && pSh->IsPreview() && pSh->IsReadOnly() )
             continue;
 
@@ -648,7 +635,7 @@ sal_uInt16 SfxObjectShell::PrepareClose
             const SfxPoolItem *pPoolItem;
             if ( IsSaveVersionOnClose() )
             {
-                SfxStringItem aItem( SID_DOCINFO_COMMENTS, String( SfxResId( STR_AUTOMATICVERSION ) ) );
+                SfxStringItem aItem( SID_DOCINFO_COMMENTS, SfxResId(STR_AUTOMATICVERSION).toString() );
                 SfxBoolItem aWarnItem( SID_FAIL_ON_WARNING, bUI );
                 const SfxPoolItem* ppArgs[] = { &aItem, &aWarnItem, 0 };
                 pPoolItem = pFrame->GetBindings().ExecuteSynchron( SID_SAVEDOC, ppArgs );
@@ -657,7 +644,7 @@ sal_uInt16 SfxObjectShell::PrepareClose
             {
                 SfxBoolItem aWarnItem( SID_FAIL_ON_WARNING, bUI );
                 const SfxPoolItem* ppArgs[] = { &aWarnItem, 0 };
-                pPoolItem = pFrame->GetBindings().ExecuteSynchron( SID_SAVEDOC, ppArgs );
+                pPoolItem = pFrame->GetBindings().ExecuteSynchron( IsReadOnlyMedium() ? SID_SAVEASDOC : SID_SAVEDOC, ppArgs );
             }
 
             if ( !pPoolItem || pPoolItem->ISA(SfxVoidItem) || ( pPoolItem->ISA(SfxBoolItem) && !( (const SfxBoolItem*) pPoolItem )->GetValue() ) )
@@ -677,6 +664,7 @@ sal_uInt16 SfxObjectShell::PrepareClose
 }
 
 //--------------------------------------------------------------------
+#ifndef DISABLE_SCRIPTING
 namespace
 {
     static BasicManager* lcl_getBasicManagerForDocument( const SfxObjectShell& _rDocument )
@@ -710,15 +698,20 @@ namespace
         return pBasMgr;
     }
 }
+#endif
 
 //--------------------------------------------------------------------
 
 BasicManager* SfxObjectShell::GetBasicManager() const
 {
+#ifdef DISABLE_SCRIPTING
+    return NULL;
+#else
     BasicManager* pBasMgr = lcl_getBasicManagerForDocument( *this );
     if ( !pBasMgr )
         pBasMgr = SFX_APP()->GetBasicManager();
     return pBasMgr;
+#endif
 }
 
 //--------------------------------------------------------------------
@@ -732,6 +725,9 @@ void SfxObjectShell::SetHasNoBasic()
 
 sal_Bool SfxObjectShell::HasBasic() const
 {
+#ifdef DISABLE_SCRIPTING
+    return sal_False;
+#else
     if ( pImp->m_bNoBasicCapabilities )
         return sal_False;
 
@@ -739,9 +735,11 @@ sal_Bool SfxObjectShell::HasBasic() const
         const_cast< SfxObjectShell* >( this )->InitBasicManager_Impl();
 
     return pImp->pBasicManager->isValid();
+#endif
 }
 
 //--------------------------------------------------------------------
+#ifndef DISABLE_SCRIPTING
 namespace
 {
     const Reference< XLibraryContainer >&
@@ -762,7 +760,7 @@ namespace
                                         xContext, xStorageDoc )
                                 ,   UNO_QUERY_THROW );
             }
-            catch( const Exception& )
+            catch (const Exception&)
             {
                 DBG_UNHANDLED_EXCEPTION();
             }
@@ -770,11 +768,12 @@ namespace
         return _rxContainer;
     }
 }
-
+#endif
 //--------------------------------------------------------------------
 
 Reference< XLibraryContainer > SfxObjectShell::GetDialogContainer()
 {
+#ifndef DISABLE_SCRIPTING
     if ( !pImp->m_bNoBasicCapabilities )
         return lcl_getOrCreateLibraryContainer( false, pImp->xDialogLibraries, GetModel() );
 
@@ -783,6 +782,7 @@ Reference< XLibraryContainer > SfxObjectShell::GetDialogContainer()
         return pBasMgr->GetDialogLibraryContainer().get();
 
     OSL_FAIL( "SfxObjectShell::GetDialogContainer: falling back to the application - is this really expected here?" );
+#endif
     return SFX_APP()->GetDialogContainer();
 }
 
@@ -790,6 +790,7 @@ Reference< XLibraryContainer > SfxObjectShell::GetDialogContainer()
 
 Reference< XLibraryContainer > SfxObjectShell::GetBasicContainer()
 {
+#ifndef DISABLE_SCRIPTING
     if ( !pImp->m_bNoBasicCapabilities )
         return lcl_getOrCreateLibraryContainer( true, pImp->xBasicLibraries, GetModel() );
 
@@ -798,6 +799,7 @@ Reference< XLibraryContainer > SfxObjectShell::GetBasicContainer()
         return pBasMgr->GetScriptLibraryContainer().get();
 
     OSL_FAIL( "SfxObjectShell::GetBasicContainer: falling back to the application - is this really expected here?" );
+#endif
     return SFX_APP()->GetBasicContainer();
 }
 
@@ -805,7 +807,11 @@ Reference< XLibraryContainer > SfxObjectShell::GetBasicContainer()
 
 StarBASIC* SfxObjectShell::GetBasic() const
 {
+#ifdef DISABLE_SCRIPTING
+    return NULL;
+#else
     return GetBasicManager()->GetLib(0);
+#endif
 }
 
 //--------------------------------------------------------------------
@@ -847,10 +853,12 @@ void SfxObjectShell::InitBasicManager_Impl()
         does not take ownership but stores only the raw pointer. Owner of all
         Basic managers is the global BasicManagerRepository instance.
      */
+#ifndef DISABLE_SCRIPTING
     DBG_ASSERT( !pImp->bBasicInitialized && !pImp->pBasicManager->isValid(), "Lokaler BasicManager bereits vorhanden");
     pImp->pBasicManager->reset( BasicManagerRepository::getDocumentBasicManager( GetModel() ) );
     DBG_ASSERT( pImp->pBasicManager->isValid(), "SfxObjectShell::InitBasicManager_Impl: did not get a BasicManager!" );
     pImp->bBasicInitialized = sal_True;
+#endif
 }
 
 //--------------------------------------------------------------------
@@ -923,7 +931,9 @@ sal_uInt16 SfxObjectShell::GetAutoStyleFilterIndex()
 
 void SfxObjectShell::SetCurrentComponent( const Reference< XInterface >& _rxComponent )
 {
-    Reference< XInterface > xOldCurrentComp(s_xCurrentComponent);
+    WeakReference< XInterface >& rTheCurrentComponent = theCurrentComponent::get();
+
+    Reference< XInterface > xOldCurrentComp(rTheCurrentComponent);
     if ( _rxComponent == xOldCurrentComp )
         // nothing to do
         return;
@@ -932,8 +942,9 @@ void SfxObjectShell::SetCurrentComponent( const Reference< XInterface >& _rxComp
     // In other words, it's still possible that we here do something which is not necessary,
     // but we should have filtered quite some unnecessary calls already.
 
+#ifndef DISABLE_SCRIPTING
     BasicManager* pAppMgr = SFX_APP()->GetBasicManager();
-    s_xCurrentComponent = _rxComponent;
+    rTheCurrentComponent = _rxComponent;
     if ( pAppMgr )
     {
         // set "ThisComponent" for Basic
@@ -943,7 +954,7 @@ void SfxObjectShell::SetCurrentComponent( const Reference< XInterface >& _rxComp
         if ( _rxComponent.is() )
         {
             ::rtl::OString aVBAConstName = lclGetVBAGlobalConstName( _rxComponent );
-            if ( aVBAConstName.getLength() > 0 )
+            if ( !aVBAConstName.isEmpty() )
             {
                 pAppMgr->SetGlobalUNOConstant( aVBAConstName.getStr(), Any( _rxComponent ) );
                 s_aRegisteredVBAConstants[ _rxComponent.get() ] = aVBAConstName;
@@ -953,18 +964,19 @@ void SfxObjectShell::SetCurrentComponent( const Reference< XInterface >& _rxComp
         else if ( xOldCurrentComp.is() )
         {
             ::rtl::OString aVBAConstName = lclGetVBAGlobalConstName( xOldCurrentComp );
-            if ( aVBAConstName.getLength() > 0 )
+            if ( !aVBAConstName.isEmpty() )
             {
                 pAppMgr->SetGlobalUNOConstant( aVBAConstName.getStr(), Any( Reference< XInterface >() ) );
                 s_aRegisteredVBAConstants.erase( xOldCurrentComp.get() );
             }
         }
     }
+#endif
 }
 
 Reference< XInterface > SfxObjectShell::GetCurrentComponent()
 {
-    return s_xCurrentComponent;
+    return theCurrentComponent::get();
 }
 
 
@@ -972,7 +984,7 @@ String SfxObjectShell::GetServiceNameFromFactory( const String& rFact )
 {
     //! Remove everything behind name!
     String aFact( rFact );
-    String aPrefix = String::CreateFromAscii( "private:factory/" );
+    String aPrefix = rtl::OUString("private:factory/");
     if ( aPrefix.Len() == aFact.Match( aPrefix ) )
         aFact.Erase( 0, aPrefix.Len() );
     sal_uInt16 nPos = aFact.Search( '?' );
@@ -994,44 +1006,48 @@ String SfxObjectShell::GetServiceNameFromFactory( const String& rFact )
 
     if ( aFact.EqualsAscii("swriter") )
     {
-        aServiceName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.text.TextDocument"));
+        aServiceName = ::rtl::OUString("com.sun.star.text.TextDocument");
     }
     else if ( aFact.EqualsAscii("sweb") || aFact.EqualsAscii("swriter/web") )
     {
-        aServiceName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.text.WebDocument"));
+        aServiceName = ::rtl::OUString("com.sun.star.text.WebDocument");
     }
     else if ( aFact.EqualsAscii("sglobal") || aFact.EqualsAscii("swriter/globaldocument") )
     {
-        aServiceName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.text.GlobalDocument"));
+        aServiceName = ::rtl::OUString("com.sun.star.text.GlobalDocument");
     }
     else if ( aFact.EqualsAscii("scalc") )
     {
-        aServiceName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.sheet.SpreadsheetDocument"));
+        aServiceName = ::rtl::OUString("com.sun.star.sheet.SpreadsheetDocument");
     }
     else if ( aFact.EqualsAscii("sdraw") )
     {
-        aServiceName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.drawing.DrawingDocument"));
+        aServiceName = ::rtl::OUString("com.sun.star.drawing.DrawingDocument");
     }
     else if ( aFact.EqualsAscii("simpress") )
     {
-        aServiceName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.presentation.PresentationDocument"));
+        aServiceName = ::rtl::OUString("com.sun.star.presentation.PresentationDocument");
     }
     else if ( aFact.EqualsAscii("schart") )
     {
-        aServiceName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.chart.ChartDocument"));
+        aServiceName = ::rtl::OUString("com.sun.star.chart.ChartDocument");
     }
     else if ( aFact.EqualsAscii("smath") )
     {
-        aServiceName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.formula.FormulaProperties"));
+        aServiceName = ::rtl::OUString("com.sun.star.formula.FormulaProperties");
     }
+#ifndef DISABLE_SCRIPTING
     else if ( aFact.EqualsAscii("sbasic") )
     {
-        aServiceName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.script.BasicIDE"));
+        aServiceName = ::rtl::OUString("com.sun.star.script.BasicIDE");
     }
+#endif
+#ifndef DISABLE_DBCONNECTIVITY
     else if ( aFact.EqualsAscii("sdatabase") )
     {
-        aServiceName = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.sdb.OfficeDatabaseDocument"));
+        aServiceName = ::rtl::OUString("com.sun.star.sdb.OfficeDatabaseDocument");
     }
+#endif
 
     return aServiceName;
 }
@@ -1072,7 +1088,7 @@ Reference<lang::XComponent> SfxObjectShell::CreateAndLoadComponent( const SfxIte
     SFX_ITEMSET_ARG(&rSet, pFileNameItem, SfxStringItem, SID_FILE_NAME, sal_False);
     SFX_ITEMSET_ARG(&rSet, pTargetItem, SfxStringItem, SID_TARGETNAME, sal_False);
     ::rtl::OUString aURL;
-    ::rtl::OUString aTarget(RTL_CONSTASCII_USTRINGPARAM("_blank"));
+    ::rtl::OUString aTarget("_blank");
     if ( pFileNameItem )
         aURL = pFileNameItem->GetValue();
     if ( pTargetItem )
@@ -1085,15 +1101,16 @@ Reference<lang::XComponent> SfxObjectShell::CreateAndLoadComponent( const SfxIte
     }
     else
         xLoader = uno::Reference < frame::XComponentLoader >( comphelper::getProcessServiceFactory()->createInstance(
-            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.frame.Desktop")) ), uno::UNO_QUERY );
+            ::rtl::OUString("com.sun.star.frame.Desktop") ), uno::UNO_QUERY );
 
     Reference <lang::XComponent> xComp;
     try
     {
         xComp = xLoader->loadComponentFromURL(aURL, aTarget, 0, aProps);
     }
-    catch( uno::Exception& )
-    {}
+    catch (const uno::Exception&)
+    {
+    }
 
     return xComp;
 }
