@@ -1,35 +1,22 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
-
-// include ---------------------------------------------------------------
-
-#define _DATETIMEITEM_CXX
 #include <svl/dateitem.hxx>
 #include <svl/svl.hrc>
 
@@ -54,15 +41,6 @@ TYPEINIT1(SfxDateTimeItem, SfxPoolItem);
 
 // -----------------------------------------------------------------------
 
-SfxDateTimeItem::SfxDateTimeItem( sal_uInt16 which ) :
-    SfxPoolItem( which ),
-    aDateTime( DateTime::SYSTEM )
-{
-    DBG_CTOR(SfxDateTimeItem, 0);
-}
-
-// -----------------------------------------------------------------------
-
 SfxDateTimeItem::SfxDateTimeItem( sal_uInt16 which, const DateTime& rDT ) :
     SfxPoolItem( which ),
     aDateTime( rDT )
@@ -160,8 +138,7 @@ SfxItemPresentation SfxDateTimeItem::GetPresentation
         {
             DBG_WARNING("SfxDateTimeItem::GetPresentation():"
                          " Using default en_US IntlWrapper");
-            const IntlWrapper aIntlWrapper(
-                ::comphelper::getProcessServiceFactory(), LANGUAGE_ENGLISH_US );
+            const IntlWrapper aIntlWrapper( LanguageTag( LANGUAGE_ENGLISH_US) );
             rText = aIntlWrapper.getLocaleData()->getDate(aDateTime);
             rText.AppendAscii(RTL_CONSTASCII_STRINGPARAM(", "));
             rText += aIntlWrapper.getLocaleData()->getTime(aDateTime);
