@@ -1,30 +1,21 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 
 #include "datwin.hxx"
@@ -69,7 +60,7 @@ void ButtonFrame::Draw( OutputDevice& rDev )
 
     if ( aText.Len() )
     {
-        String aVal = rDev.GetEllipsisString(aText,aInnerRect.GetWidth() - 2*MIN_COLUMNWIDTH);
+        OUString aVal = rDev.GetEllipsisString(aText,aInnerRect.GetWidth() - 2*MIN_COLUMNWIDTH);
 
         Font aFont( rDev.GetFont() );
         sal_Bool bOldTransp = aFont.IsTransparent();
@@ -112,14 +103,12 @@ void ButtonFrame::Draw( OutputDevice& rDev )
 //-------------------------------------------------------------------
 
 BrowserColumn::BrowserColumn( sal_uInt16 nItemId, const class Image &rImage,
-                              const String& rTitle, sal_uLong nWidthPixel, const Fraction& rCurrentZoom,
-                              HeaderBarItemBits nFlags )
+                              const String& rTitle, sal_uLong nWidthPixel, const Fraction& rCurrentZoom )
 :   _nId( nItemId ),
     _nWidth( nWidthPixel ),
     _aImage( rImage ),
     _aTitle( rTitle ),
-    _bFrozen( sal_False ),
-    _nFlags( nFlags )
+    _bFrozen( sal_False )
 {
     double n = (double)_nWidth;
     n *= (double)rCurrentZoom.GetDenominator();
@@ -150,8 +139,7 @@ void BrowserColumn::Draw( BrowseBox& rBox, OutputDevice& rDev, const Point& rPos
     {
         // paint handle column
         ButtonFrame( rPos, Size( Width()-1, rBox.GetDataRowHeight()-1 ),
-                     String(), sal_False, bCurs,
-                     0 != (BROWSER_COLUMN_TITLEABBREVATION&_nFlags) ).Draw( rDev );
+                     String(), sal_False, bCurs, false ).Draw( rDev );
         Color aOldLineColor = rDev.GetLineColor();
         rDev.SetLineColor( Color( COL_BLACK ) );
         rDev.DrawLine(
@@ -407,7 +395,7 @@ void BrowserDataWin::StartDrag( sal_Int8 _nAction, const Point& _rPosPixel )
 //-------------------------------------------------------------------
 void BrowserDataWin::Command( const CommandEvent& rEvt )
 {
-    // Scrollmaus-Event?
+    // scroll mouse event?
     BrowseBox *pBox = GetParent();
     if ( ( (rEvt.GetCommand() == COMMAND_WHEEL) ||
            (rEvt.GetCommand() == COMMAND_STARTAUTOSCROLL) ||
@@ -459,7 +447,7 @@ sal_Bool BrowserDataWin::ImplRowDividerHitTest( const BrowserMouseEvent& _rEvent
     if ( ! (  GetParent()->IsInteractiveRowHeightEnabled()
            && ( _rEvent.GetRow() >= 0 )
            && ( _rEvent.GetRow() < GetParent()->GetRowCount() )
-           && ( _rEvent.GetColumnId() == 0 )
+           && ( _rEvent.GetColumnId() == BrowseBox::HandleColumnId )
            )
        )
        return sal_False;
@@ -488,7 +476,7 @@ void BrowserDataWin::MouseButtonDown( const MouseEvent& rEvt )
 
 void BrowserDataWin::MouseMove( const MouseEvent& rEvt )
 {
-    // Pseudo MouseMoves verhindern
+    // avoid pseudo MouseMoves
     Point aNewPos = OutputToScreenPixel( rEvt.GetPosPixel() );
     if ( ( aNewPos == aLastMousePos ) )
         return;
@@ -521,25 +509,25 @@ void BrowserDataWin::MouseMove( const MouseEvent& rEvt )
 
 //-------------------------------------------------------------------
 
-IMPL_LINK_INLINE_START( BrowserDataWin, RepeatedMouseMove, void *, EMPTYARG )
+IMPL_LINK_NOARG_INLINE_START(BrowserDataWin, RepeatedMouseMove)
 {
     GetParent()->MouseMove( BrowserMouseEvent( this, aRepeatEvt ) );
     return 0;
 }
-IMPL_LINK_INLINE_END( BrowserDataWin, RepeatedMouseMove, void *, EMPTYARG )
+IMPL_LINK_NOARG_INLINE_END(BrowserDataWin, RepeatedMouseMove)
 
 //-------------------------------------------------------------------
 
 void BrowserDataWin::MouseButtonUp( const MouseEvent& rEvt )
 {
-    // Pseudo MouseMoves verhindern
+    // avoid pseudo MouseMoves
     Point aNewPos = OutputToScreenPixel( rEvt.GetPosPixel() );
     aLastMousePos = aNewPos;
 
-    // Move an die aktuelle Position simulieren
+    // simulate a move to the current position
     MouseMove( rEvt );
 
-    // eigentliches Up-Handling
+    // actual button up handling
     ReleaseMouse();
     if ( aMouseTimer.IsActive() )
         aMouseTimer.Stop();
@@ -738,12 +726,12 @@ void BrowserScrollBar::Tracking( const TrackingEvent& rTEvt )
     sal_uLong nPos = GetThumbPos();
     if ( nPos != _nLastPos )
     {
-        String aTip( String::CreateFromInt32(nPos) );
+        String aTip( rtl::OUString::valueOf(static_cast<sal_Int32>(nPos)) );
         aTip += '/';
         if ( _pDataWin->GetRealRowCount().Len() )
             aTip += _pDataWin->GetRealRowCount();
         else
-            aTip += String::CreateFromInt32(GetRangeMax());
+            aTip += rtl::OUString::valueOf(static_cast<sal_Int32>(GetRangeMax()));
 
         Rectangle aRect( GetPointerPosPixel(), Size( GetTextHeight(), GetTextWidth( aTip ) ) );
         if ( _nTip )
