@@ -1,35 +1,26 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 #include <vcl/wrkwin.hxx>
 #include <sot/factory.hxx>
 #include <tools/shl.hxx>
-#include <vcl/salbtype.hxx>     // FRound
+#include <tools/helpers.hxx>
 #include <vcl/msgbox.hxx>
 #include <svl/eitem.hxx>
 #include <sfx2/dispatch.hxx>
@@ -38,16 +29,6 @@
 #include <unotools/localedatawrapper.hxx>
 #include <comphelper/processfactory.hxx>
 
-#define _SDR_NOITEMS
-#define _SDR_NOTOUCH
-#define _SDR_NOTRANSFORM
-#define _SDR_NOOBJECTS
-#define _SDR_NOVIEWMARKER
-#define _SDR_NODRAGMETHODS
-#define _SDR_NOUNDO
-#define _SDR_NOXOUTDEV
-#define _XOUTBMP_STATICS_ONLY
-
 #include <svx/dialmgr.hxx>
 #include "svx/xoutbmp.hxx"
 #include <svx/dialogs.hrc>
@@ -60,9 +41,10 @@
 #include <svx/svdopath.hxx>
 #include "svx/dlgutil.hxx"
 #include <vcl/svapp.hxx>
+#include <vcl/virdev.hxx>
 #include "dlgunit.hxx"
 
-SFX_IMPL_FLOATINGWINDOW( SvxContourDlgChildWindow, SID_CONTOUR_DLG );
+SFX_IMPL_FLOATINGWINDOW_WITHID( SvxContourDlgChildWindow, SID_CONTOUR_DLG );
 
 
 /******************************************************************************/
@@ -195,64 +177,9 @@ PolyPolygon SvxContourDlg::CreateAutoContour( const Graphic& rGraphic,
     return PolyPolygon( XOutBitmap::GetCountour( aBmp, nContourFlags, 128, pRect ) );
 }
 
-void SvxContourDlg::ScaleContour( PolyPolygon& rContour, const Graphic& rGraphic,
-                                  const MapUnit eUnit, const Size& rDisplaySize )
-{
-    DBG_ASSERT( rGraphic.GetType() != GRAPHIC_NONE, "Graphic is not valid!" );
-
-    OutputDevice*   pOutDev = Application::GetDefaultDevice();
-    const MapMode   aDispMap( eUnit );
-    const MapMode   aGrfMap( rGraphic.GetPrefMapMode() );
-    const Size      aGrfSize( rGraphic.GetPrefSize() );
-    Size            aOrgSize;
-    Point           aNewPoint;
-    sal_Bool            bPixelMap = aGrfMap.GetMapUnit() == MAP_PIXEL;
-
-    if ( bPixelMap )
-        aOrgSize = pOutDev->PixelToLogic( aGrfSize, aDispMap );
-    else
-        aOrgSize = pOutDev->LogicToLogic( aGrfSize, aGrfMap, aDispMap );
-
-    if ( aOrgSize.Width() && aOrgSize.Height() )
-    {
-        double fScaleX = (double) rDisplaySize.Width() / aOrgSize.Width();
-        double fScaleY = (double) rDisplaySize.Height() / aOrgSize.Height();
-
-        for ( sal_uInt16 j = 0, nPolyCount = rContour.Count(); j < nPolyCount; j++ )
-        {
-            Polygon& rPoly = rContour[ j ];
-
-            for ( sal_uInt16 i = 0, nCount = rPoly.GetSize(); i < nCount; i++ )
-            {
-                if ( bPixelMap )
-                    aNewPoint = pOutDev->PixelToLogic( rPoly[ i ], aDispMap  );
-                else
-                    aNewPoint = pOutDev->LogicToLogic( rPoly[ i ], aGrfMap, aDispMap  );
-
-                rPoly[ i ] = Point( FRound( aNewPoint.X() * fScaleX ), FRound( aNewPoint.Y() * fScaleY ) );
-            }
-        }
-    }
-}
-
 // Loop through to super class, no virtual Methods to not become incompatible
 // due to IF changes
 
-void SvxContourDlg::SetExecState( sal_Bool bEnable )
-{
-    pSuperClass->SetExecState( bEnable );
-}
-
-void SvxContourDlg::SetGraphic( const Graphic& rGraphic )
-{
-    pSuperClass->SetGraphic( rGraphic );
-}
-
-void SvxContourDlg::SetGraphicLinked( sal_Bool bGraphicLinked )
-{
-    pSuperClass->SetGraphicLinked( bGraphicLinked );
-}
-
 const Graphic& SvxContourDlg::GetGraphic() const
 {
     return pSuperClass->GetGraphic();
@@ -263,21 +190,11 @@ sal_Bool SvxContourDlg::IsGraphicChanged() const
     return pSuperClass->IsGraphicChanged();
 }
 
-void SvxContourDlg::SetPolyPolygon( const PolyPolygon& rPolyPoly )
-{
-    pSuperClass->SetPolyPolygon( rPolyPoly );
-}
-
 PolyPolygon SvxContourDlg::GetPolyPolygon()
 {
     return pSuperClass->GetPolyPolygon( sal_True );
 }
 
-void SvxContourDlg::SetEditingObject( void* pObj )
-{
-    pSuperClass->SetEditingObject( pObj );
-}
-
 const void* SvxContourDlg::GetEditingObject() const
 {
     return pSuperClass->GetEditingObject();
@@ -333,8 +250,8 @@ SvxSuperContourDlg::SvxSuperContourDlg( SfxBindings *_pBindings, SfxChildWindow
     SetMinOutputSizePixel( aLastSize = GetOutputSizePixel() );
 
     aStbStatus.InsertItem( 1, 130, SIB_LEFT | SIB_IN | SIB_AUTOSIZE );
-    aStbStatus.InsertItem( 2, 10 + GetTextWidth( String::CreateFromAscii( " 9999,99 cm / 9999,99 cm " ) ), SIB_CENTER | SIB_IN );
-    aStbStatus.InsertItem( 3, 10 + GetTextWidth( String::CreateFromAscii( " 9999,99 cm x 9999,99 cm " ) ), SIB_CENTER | SIB_IN );
+    aStbStatus.InsertItem( 2, 10 + GetTextWidth( rtl::OUString(" 9999,99 cm / 9999,99 cm ") ), SIB_CENTER | SIB_IN );
+    aStbStatus.InsertItem( 3, 10 + GetTextWidth( rtl::OUString(" 9999,99 cm x 9999,99 cm ") ), SIB_CENTER | SIB_IN );
     aStbStatus.InsertItem( 4, 20, SIB_CENTER | SIB_IN );
 
     Resize();
@@ -501,50 +418,6 @@ sal_Bool SvxSuperContourDlg::IsRedoPossible() const
     return aRedoGraphic.GetType() != GRAPHIC_NONE;
 }
 
-void SvxSuperContourDlg::DoAutoCreate()
-{
-    aCreateTimer.Start();
-}
-
-void SvxSuperContourDlg::ReducePoints( const long nTol )
-{
-    PolyPolygon aPolyPoly( GetPolyPolygon( sal_False ) );
-
-    if ( aPolyPoly.Count() )
-    {
-        const MapMode   aMapMode( MAP_100TH_MM );
-        const long      nTol2 = nTol * nTol;
-        Polygon&        rPoly = aPolyPoly[ 0 ];
-        OutputDevice*   pOutDev = Application::GetDefaultDevice();
-        Point           aPtPix;
-        const sal_uInt16    nSize = rPoly.GetSize();
-        sal_uInt16          nCounter = 0;
-
-        if ( nSize )
-            aPtPix = pOutDev->LogicToPixel( rPoly[ 0 ], aMapMode );
-
-        for( sal_uInt16 i = 1; i < nSize; i++ )
-        {
-            const Point&    rNewPt = rPoly[ i ];
-            const Point     aNewPtPix( pOutDev->LogicToPixel( rNewPt, aMapMode ) );
-
-            const long nDistX = aNewPtPix.X() - aPtPix.X();
-            const long nDistY = aNewPtPix.Y() - aPtPix.Y();
-
-            if( ( nDistX * nDistX + nDistY * nDistY ) >= nTol2 )
-            {
-                rPoly[ ++nCounter ] = rNewPt;
-                aPtPix = aNewPtPix;
-            }
-        }
-
-        rPoly.SetSize( nCounter );
-        aContourWnd.SetPolyPolygon( aPolyPoly );
-        aContourWnd.GetSdrModel()->SetChanged( sal_True );
-    }
-}
-
-
 // Click handler for ToolBox
 
 IMPL_LINK( SvxSuperContourDlg, Tbx1ClickHdl, ToolBox*, pTbx )
@@ -686,11 +559,11 @@ IMPL_LINK( SvxSuperContourDlg, MousePosHdl, ContourWindow*, pWnd )
     String aStr;
     const FieldUnit eFieldUnit = GetBindings().GetDispatcher()->GetModule()->GetFieldUnit();
     const Point& rMousePos = pWnd->GetMousePos();
-    LocaleDataWrapper aLocaleWrapper( ::comphelper::getProcessServiceFactory(), Application::GetSettings().GetLocale() );
-    const sal_Unicode cSep = aLocaleWrapper.getNumDecimalSep().GetChar(0);
+    const LocaleDataWrapper& rLocaleWrapper( Application::GetSettings().GetLocaleDataWrapper() );
+    const sal_Unicode cSep = rLocaleWrapper.getNumDecimalSep()[0];
 
     aStr.Assign( GetUnitString( rMousePos.X(), eFieldUnit, cSep ) );
-    aStr.Append( String::CreateFromAscii( " / " ) );
+    aStr.Append( rtl::OUString(" / ") );
     aStr.Append( GetUnitString( rMousePos.Y(), eFieldUnit, cSep ) );
 
     aStbStatus.SetItemText( 2, aStr );
@@ -703,11 +576,11 @@ IMPL_LINK( SvxSuperContourDlg, GraphSizeHdl, ContourWindow*, pWnd )
     String aStr;
     const FieldUnit eFieldUnit = GetBindings().GetDispatcher()->GetModule()->GetFieldUnit();
     const Size& rSize = pWnd->GetGraphicSize();
-    LocaleDataWrapper aLocaleWrapper( ::comphelper::getProcessServiceFactory(), Application::GetSettings().GetLocale() );
-    const sal_Unicode cSep = aLocaleWrapper.getNumDecimalSep().GetChar(0);
+    const LocaleDataWrapper& rLocaleWrapper( Application::GetSettings().GetLocaleDataWrapper() );
+    const sal_Unicode cSep = rLocaleWrapper.getNumDecimalSep()[0];
 
     aStr.Assign( GetUnitString( rSize.Width(), eFieldUnit, cSep ) );
-    aStr.Append( String::CreateFromAscii( " x " ) );
+    aStr.Append( rtl::OUString(" x ") );
     aStr.Append( GetUnitString( rSize.Height(), eFieldUnit, cSep ) );
 
     aStbStatus.SetItemText( 3, aStr );
@@ -715,7 +588,7 @@ IMPL_LINK( SvxSuperContourDlg, GraphSizeHdl, ContourWindow*, pWnd )
     return 0L;
 }
 
-IMPL_LINK( SvxSuperContourDlg, UpdateHdl, Timer*, EMPTYARG )
+IMPL_LINK_NOARG(SvxSuperContourDlg, UpdateHdl)
 {
     aUpdateTimer.Stop();
 
@@ -741,7 +614,7 @@ IMPL_LINK( SvxSuperContourDlg, UpdateHdl, Timer*, EMPTYARG )
     return 0L;
 }
 
-IMPL_LINK( SvxSuperContourDlg, CreateHdl, Timer*, EMPTYARG )
+IMPL_LINK_NOARG(SvxSuperContourDlg, CreateHdl)
 {
     aCreateTimer.Stop();
 
@@ -909,7 +782,7 @@ void SvxSuperContourDlg::DataChanged( const DataChangedEvent& rDCEvt )
             ApplyImageList();
 }
 
-IMPL_LINK( SvxSuperContourDlg, MiscHdl, void*, EMPTYARG )
+IMPL_LINK_NOARG(SvxSuperContourDlg, MiscHdl)
 {
        SvtMiscOptions aMiscOptions;
     aTbx1.SetOutStyle( aMiscOptions.GetToolboxStyle() );
