@@ -1,45 +1,34 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
-
-#define _ANIMATION
 #include <unotools/streamwrap.hxx>
 
 #include <sfx2/lnkbase.hxx>
 #include <math.h>
-#include <vcl/salbtype.hxx>
+#include <tools/helpers.hxx>
 #include <sot/formats.hxx>
 #include <sot/storage.hxx>
 #include <comphelper/storagehelper.hxx>
 #include <unotools/ucbstreamhelper.hxx>
 #include <unotools/localfilehelper.hxx>
 #include <svl/style.hxx>
-#include <svtools/filter.hxx>
+#include <vcl/graphicfilter.hxx>
 #include <svl/urihelper.hxx>
 #include <svtools/grfmgr.hxx>
 #include <vcl/svapp.hxx>
@@ -56,7 +45,7 @@
 #include <svx/svdpagv.hxx>
 #include "svx/svdviter.hxx"
 #include <svx/svdview.hxx>
-#include "svtools/filter.hxx"
+#include <vcl/graphicfilter.hxx>
 #include <svx/svdograf.hxx>
 #include <svx/svdogrp.hxx>
 #include <svx/xbitmap.hxx>
@@ -80,7 +69,6 @@ using namespace ::com::sun::star::io;
 // - Defines -
 // -----------
 
-#define GRAFSTREAMPOS_INVALID   0xffffffff
 #define SWAPGRAPHIC_TIMEOUT     5000
 
 
@@ -93,7 +81,7 @@ const Graphic ImpLoadLinkedGraphic( const String aFileName, const String aFilter
 {
     Graphic aGraphic;
 
-    SfxMedium xMed( aFileName, STREAM_STD_READ, sal_True );
+    SfxMedium xMed( aFileName, STREAM_STD_READ );
     xMed.DownLoad();
 
     SvStream* pInStrm = xMed.GetInStream();
@@ -114,7 +102,7 @@ const Graphic ImpLoadLinkedGraphic( const String aFileName, const String aFilter
         // But this link is required by some filters to access the native graphic (PDF export/MS export),
         // there we should create a new service to provide this data if needed
         aFilterData[ 0 ].Name = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "CreateNativeLink" ) );
-        aFilterData[ 0 ].Value = Any( sal_True );
+        aFilterData[ 0 ].Value = Any( true );
         rGF.ImportGraphic( aGraphic, aEmptyStr, *pInStrm, nFilter, NULL, 0, &aFilterData );
     }
     return aGraphic;
@@ -176,7 +164,7 @@ SdrGraphicUpdater::SdrGraphicUpdater( const String& rFileName, const String& rFi
 : maFileName( rFileName )
 , maFilterName( rFilterName )
 , mrGraphicLink( rGraphicLink )
-, mbIsTerminated( sal_False )
+, mbIsTerminated( false )
 {
     create();
 }
@@ -187,7 +175,7 @@ SdrGraphicUpdater::~SdrGraphicUpdater( void )
 
 void SdrGraphicUpdater::Terminate()
 {
-    mbIsTerminated = sal_True;
+    mbIsTerminated = true;
 }
 
 void SAL_CALL SdrGraphicUpdater::onTerminated(void)
@@ -213,7 +201,7 @@ SdrGraphicLink::SdrGraphicLink(SdrGrafObj* pObj)
 , pGrafObj( pObj )
 , pGraphicUpdater( NULL )
 {
-    SetSynchron( sal_False );
+    SetSynchron( false );
 }
 
 // -----------------------------------------------------------------------------
@@ -324,21 +312,24 @@ TYPEINIT1(SdrGrafObj,SdrRectObj);
 SdrGrafObj::SdrGrafObj()
 :   SdrRectObj(),
     pGraphicLink    ( NULL ),
-    bMirrored       ( sal_False )
+    bMirrored       ( false )
 {
     pGraphic = new GraphicObject;
+    mpReplacementGraphic = 0;
     pGraphic->SetSwapStreamHdl( LINK( this, SdrGrafObj, ImpSwapHdl ), SWAPGRAPHIC_TIMEOUT );
-    bNoShear = sal_True;
 
-    mbGrafAnimationAllowed = sal_True;
+    // #i118485# Shear allowed and possible now
+    bNoShear = false;
+
+    mbGrafAnimationAllowed = true;
 
     // #i25616#
-    mbLineIsOutsideGeometry = sal_True;
-    mbInsidePaint = sal_False;
-    mbIsPreview = sal_False;
+    mbLineIsOutsideGeometry = true;
+    mbInsidePaint = false;
+    mbIsPreview = false;
 
     // #i25616#
-    mbSupportTextIndentingOnLineWidthChange = sal_False;
+    mbSupportTextIndentingOnLineWidthChange = false;
 }
 
 // -----------------------------------------------------------------------------
@@ -346,21 +337,24 @@ SdrGrafObj::SdrGrafObj()
 SdrGrafObj::SdrGrafObj(const Graphic& rGrf, const Rectangle& rRect)
 :   SdrRectObj      ( rRect ),
     pGraphicLink    ( NULL ),
-    bMirrored       ( sal_False )
+    bMirrored       ( false )
 {
     pGraphic = new GraphicObject( rGrf );
+    mpReplacementGraphic = 0;
     pGraphic->SetSwapStreamHdl( LINK( this, SdrGrafObj, ImpSwapHdl ), SWAPGRAPHIC_TIMEOUT );
-    bNoShear = sal_True;
 
-    mbGrafAnimationAllowed = sal_True;
+    // #i118485# Shear allowed and possible now
+    bNoShear = false;
+
+    mbGrafAnimationAllowed = true;
 
     // #i25616#
-    mbLineIsOutsideGeometry = sal_True;
-    mbInsidePaint = sal_False;
-    mbIsPreview = sal_False;
+    mbLineIsOutsideGeometry = true;
+    mbInsidePaint = false;
+    mbIsPreview = false;
 
     // #i25616#
-    mbSupportTextIndentingOnLineWidthChange = sal_False;
+    mbSupportTextIndentingOnLineWidthChange = false;
 }
 
 // -----------------------------------------------------------------------------
@@ -368,21 +362,24 @@ SdrGrafObj::SdrGrafObj(const Graphic& rGrf, const Rectangle& rRect)
 SdrGrafObj::SdrGrafObj( const Graphic& rGrf )
 :   SdrRectObj(),
     pGraphicLink    ( NULL ),
-    bMirrored       ( sal_False )
+    bMirrored       ( false )
 {
     pGraphic = new GraphicObject( rGrf );
+    mpReplacementGraphic = 0;
     pGraphic->SetSwapStreamHdl( LINK( this, SdrGrafObj, ImpSwapHdl ), SWAPGRAPHIC_TIMEOUT );
-    bNoShear = sal_True;
 
-    mbGrafAnimationAllowed = sal_True;
+    // #i118485# Shear allowed and possible now
+    bNoShear = false;
+
+    mbGrafAnimationAllowed = true;
 
     // #i25616#
-    mbLineIsOutsideGeometry = sal_True;
-    mbInsidePaint = sal_False;
-    mbIsPreview = sal_False;
+    mbLineIsOutsideGeometry = true;
+    mbInsidePaint = false;
+    mbIsPreview = false;
 
     // #i25616#
-    mbSupportTextIndentingOnLineWidthChange = sal_False;
+    mbSupportTextIndentingOnLineWidthChange = false;
 }
 
 // -----------------------------------------------------------------------------
@@ -390,6 +387,7 @@ SdrGrafObj::SdrGrafObj( const Graphic& rGrf )
 SdrGrafObj::~SdrGrafObj()
 {
     delete pGraphic;
+    delete mpReplacementGraphic;
     ImpLinkAbmeldung();
 }
 
@@ -398,9 +396,11 @@ SdrGrafObj::~SdrGrafObj()
 void SdrGrafObj::SetGraphicObject( const GraphicObject& rGrfObj )
 {
     *pGraphic = rGrfObj;
+    delete mpReplacementGraphic;
+    mpReplacementGraphic = 0;
     pGraphic->SetSwapStreamHdl( LINK( this, SdrGrafObj, ImpSwapHdl ), SWAPGRAPHIC_TIMEOUT );
     pGraphic->SetUserData();
-    mbIsPreview = sal_False;
+    mbIsPreview = false;
     SetChanged();
     BroadcastObjectChange();
 }
@@ -417,13 +417,30 @@ const GraphicObject& SdrGrafObj::GetGraphicObject(bool bForceSwapIn) const
     return *pGraphic;
 }
 
+const GraphicObject* SdrGrafObj::GetReplacementGraphicObject() const
+{
+    if(!mpReplacementGraphic && pGraphic)
+    {
+        const SvgDataPtr& rSvgDataPtr = pGraphic->GetGraphic().getSvgData();
+
+        if(rSvgDataPtr.get())
+        {
+            const_cast< SdrGrafObj* >(this)->mpReplacementGraphic = new GraphicObject(rSvgDataPtr->getReplacement());
+        }
+    }
+
+    return mpReplacementGraphic;
+}
+
 // -----------------------------------------------------------------------------
 
 void SdrGrafObj::NbcSetGraphic( const Graphic& rGrf )
 {
     pGraphic->SetGraphic( rGrf );
+    delete mpReplacementGraphic;
+    mpReplacementGraphic = 0;
     pGraphic->SetUserData();
-    mbIsPreview = sal_False;
+    mbIsPreview = false;
 }
 
 void SdrGrafObj::SetGraphic( const Graphic& rGrf )
@@ -462,8 +479,8 @@ Graphic SdrGrafObj::GetTransformedGraphic( sal_uIntPtr nTransformFlags ) const
     if( SDRGRAFOBJ_TRANSFORMATTR_NONE != nTransformFlags &&
         GRAPHIC_NONE != eType )
     {
-        // actually transform the graphic only in this case. On the
-        // other hand, cropping will always happen
+        // Actually transform the graphic only in this case.
+        // Cropping always happens, though.
         aActAttr = aGrafInfo;
 
         if( bMirror )
@@ -490,29 +507,19 @@ GraphicType SdrGrafObj::GetGraphicType() const
     return pGraphic->GetType();
 }
 
-sal_Bool SdrGrafObj::IsAnimated() const
+bool SdrGrafObj::IsAnimated() const
 {
     return pGraphic->IsAnimated();
 }
 
-sal_Bool SdrGrafObj::IsEPS() const
+bool SdrGrafObj::IsEPS() const
 {
     return pGraphic->IsEPS();
 }
 
-sal_Bool SdrGrafObj::IsRenderGraphic() const
+bool SdrGrafObj::IsSwappedOut() const
 {
-    return pGraphic->IsRenderGraphic();
-}
-
-sal_Bool SdrGrafObj::HasRenderGraphic() const
-{
-    return pGraphic->HasRenderGraphic();
-}
-
-sal_Bool SdrGrafObj::IsSwappedOut() const
-{
-    return mbIsPreview ? sal_True : pGraphic->IsSwappedOut();
+    return mbIsPreview ? true : pGraphic->IsSwappedOut();
 }
 
 const MapMode& SdrGrafObj::GetGrafPrefMapMode() const
@@ -529,7 +536,7 @@ const Size& SdrGrafObj::GetGrafPrefSize() const
 
 void SdrGrafObj::SetGrafStreamURL( const String& rGraphicStreamURL )
 {
-    mbIsPreview = sal_False;
+    mbIsPreview = false;
     if( !rGraphicStreamURL.Len() )
     {
         pGraphic->SetUserData();
@@ -565,10 +572,10 @@ void SdrGrafObj::ForceSwapIn() const
         pGraphic->SetUserData( aUserData );
         pGraphic->SetSwapState();
 
-        const_cast< SdrGrafObj* >( this )->mbIsPreview = sal_False;
+        const_cast< SdrGrafObj* >( this )->mbIsPreview = false;
     }
     if ( pGraphicLink && pGraphic->IsSwappedOut() )
-        ImpUpdateGraphicLink( sal_False );
+        ImpUpdateGraphicLink( false );
     else
         pGraphic->FireSwapInRequest();
 
@@ -597,10 +604,11 @@ void SdrGrafObj::ImpLinkAnmeldung()
 
     if( pLinkManager != NULL && pGraphicLink == NULL )
     {
-        if( aFileName.Len() )
+        if (!aFileName.isEmpty())
         {
             pGraphicLink = new SdrGraphicLink( this );
-            pLinkManager->InsertFileLink( *pGraphicLink, OBJECT_CLIENT_GRF, aFileName, ( aFilterName.Len() ? &aFilterName : NULL ), NULL );
+            pLinkManager->InsertFileLink(
+                *pGraphicLink, OBJECT_CLIENT_GRF, aFileName, (aFilterName.isEmpty() ? NULL : &aFilterName), NULL);
             pGraphicLink->Connect();
         }
     }
@@ -622,7 +630,7 @@ void SdrGrafObj::ImpLinkAbmeldung()
 
 // -----------------------------------------------------------------------------
 
-void SdrGrafObj::SetGraphicLink( const String& rFileName, const String& rFilterName )
+void SdrGrafObj::SetGraphicLink(const rtl::OUString& rFileName, const String& rFilterName)
 {
     ImpLinkAbmeldung();
     aFileName = rFileName;
@@ -639,8 +647,23 @@ void SdrGrafObj::SetGraphicLink( const String& rFileName, const String& rFilterN
 void SdrGrafObj::ReleaseGraphicLink()
 {
     ImpLinkAbmeldung();
-    aFileName = String();
-    aFilterName = String();
+    aFileName = rtl::OUString();
+    aFilterName = rtl::OUString();
+}
+
+bool SdrGrafObj::IsLinkedGraphic() const
+{
+    return !aFileName.isEmpty();
+}
+
+const rtl::OUString& SdrGrafObj::GetFileName() const
+{
+    return aFileName;
+}
+
+const rtl::OUString& SdrGrafObj::GetFilterName() const
+{
+    return aFilterName;
 }
 
 // -----------------------------------------------------------------------------
@@ -648,27 +671,29 @@ void SdrGrafObj::ReleaseGraphicLink()
 void SdrGrafObj::TakeObjInfo(SdrObjTransformInfoRec& rInfo) const
 {
     bool bAnim = pGraphic->IsAnimated();
-    bool bRenderGraphic = pGraphic->HasRenderGraphic();
     bool bNoPresGrf = ( pGraphic->GetType() != GRAPHIC_NONE ) && !bEmptyPresObj;
 
     rInfo.bResizeFreeAllowed = aGeo.nDrehWink % 9000 == 0 ||
                                aGeo.nDrehWink % 18000 == 0 ||
                                aGeo.nDrehWink % 27000 == 0;
 
-    rInfo.bResizePropAllowed = sal_True;
-    rInfo.bRotateFreeAllowed = bNoPresGrf && !bAnim && !bRenderGraphic;
-    rInfo.bRotate90Allowed = bNoPresGrf && !bAnim && !bRenderGraphic;
-    rInfo.bMirrorFreeAllowed = bNoPresGrf && !bAnim && !bRenderGraphic;
-    rInfo.bMirror45Allowed = bNoPresGrf && !bAnim && !bRenderGraphic;
-    rInfo.bMirror90Allowed = !bEmptyPresObj && !bRenderGraphic;
-    rInfo.bTransparenceAllowed = sal_False;
-    rInfo.bGradientAllowed = sal_False;
-    rInfo.bShearAllowed = sal_False;
-    rInfo.bEdgeRadiusAllowed=sal_False;
-    rInfo.bCanConvToPath = sal_False;
-    rInfo.bCanConvToPathLineToArea = sal_False;
-    rInfo.bCanConvToPolyLineToArea = sal_False;
-    rInfo.bCanConvToPoly = !IsEPS() && !bRenderGraphic;
+    rInfo.bResizePropAllowed = true;
+    rInfo.bRotateFreeAllowed = bNoPresGrf && !bAnim;
+    rInfo.bRotate90Allowed = bNoPresGrf && !bAnim;
+    rInfo.bMirrorFreeAllowed = bNoPresGrf && !bAnim;
+    rInfo.bMirror45Allowed = bNoPresGrf && !bAnim;
+    rInfo.bMirror90Allowed = !bEmptyPresObj;
+    rInfo.bTransparenceAllowed = false;
+    rInfo.bGradientAllowed = false;
+
+    // #i118485# Shear allowed and possible now
+    rInfo.bShearAllowed = true;
+
+    rInfo.bEdgeRadiusAllowed=false;
+    rInfo.bCanConvToPath = !IsEPS();
+    rInfo.bCanConvToPathLineToArea = false;
+    rInfo.bCanConvToPolyLineToArea = false;
+    rInfo.bCanConvToPoly = !IsEPS();
     rInfo.bCanConvToContour = (rInfo.bCanConvToPoly || LineGeometryUsageIsNecessary());
 }
 
@@ -684,16 +709,16 @@ sal_uInt16 SdrGrafObj::GetObjIdentifier() const
 /* The graphic of the GraphicLink will be loaded. If it is called with
    bAsynchron = true then the graphic will be set later via DataChanged
 */
-sal_Bool SdrGrafObj::ImpUpdateGraphicLink( sal_Bool bAsynchron ) const
+bool SdrGrafObj::ImpUpdateGraphicLink( bool bAsynchron ) const
 {
-    sal_Bool bRet = sal_False;
+    bool bRet = false;
     if( pGraphicLink )
     {
         if ( bAsynchron )
             pGraphicLink->UpdateAsynchron();
         else
             pGraphicLink->DataChanged( ImpLoadLinkedGraphic( aFileName, aFilterName ) );
-        bRet = sal_True;
+        bRet = true;
     }
     return bRet;
 }
@@ -713,38 +738,50 @@ void SdrGrafObj::ImpSetLinkedGraphic( const Graphic& rGraphic )
 
 void SdrGrafObj::TakeObjNameSingul(XubString& rName) const
 {
-    switch( pGraphic->GetType() )
+    if(pGraphic)
     {
-        case GRAPHIC_BITMAP:
+        const SvgDataPtr& rSvgDataPtr = pGraphic->GetGraphic().getSvgData();
+
+        if(rSvgDataPtr.get())
         {
-            const sal_uInt16 nId = ( ( pGraphic->IsTransparent() || ( (const SdrGrafTransparenceItem&) GetObjectItem( SDRATTR_GRAFTRANSPARENCE ) ).GetValue() ) ?
-                                 ( IsLinkedGraphic() ? STR_ObjNameSingulGRAFBMPTRANSLNK : STR_ObjNameSingulGRAFBMPTRANS ) :
-                                 ( IsLinkedGraphic() ? STR_ObjNameSingulGRAFBMPLNK : STR_ObjNameSingulGRAFBMP ) );
-
-            rName=ImpGetResStr( nId );
+            rName = ImpGetResStr(STR_ObjNameSingulGRAFSVG);
         }
-        break;
+        else
+        {
+            switch( pGraphic->GetType() )
+            {
+                case GRAPHIC_BITMAP:
+                {
+                    const sal_uInt16 nId = ( ( pGraphic->IsTransparent() || ( (const SdrGrafTransparenceItem&) GetObjectItem( SDRATTR_GRAFTRANSPARENCE ) ).GetValue() ) ?
+                                         ( IsLinkedGraphic() ? STR_ObjNameSingulGRAFBMPTRANSLNK : STR_ObjNameSingulGRAFBMPTRANS ) :
+                                         ( IsLinkedGraphic() ? STR_ObjNameSingulGRAFBMPLNK : STR_ObjNameSingulGRAFBMP ) );
 
-        case GRAPHIC_GDIMETAFILE:
-            rName=ImpGetResStr( IsLinkedGraphic() ? STR_ObjNameSingulGRAFMTFLNK : STR_ObjNameSingulGRAFMTF );
-        break;
+                    rName=ImpGetResStr( nId );
+                }
+                break;
 
-        case GRAPHIC_NONE:
-            rName=ImpGetResStr( IsLinkedGraphic() ? STR_ObjNameSingulGRAFNONELNK : STR_ObjNameSingulGRAFNONE );
-        break;
+                case GRAPHIC_GDIMETAFILE:
+                    rName=ImpGetResStr( IsLinkedGraphic() ? STR_ObjNameSingulGRAFMTFLNK : STR_ObjNameSingulGRAFMTF );
+                break;
 
-        default:
-            rName=ImpGetResStr(  IsLinkedGraphic() ? STR_ObjNameSingulGRAFLNK : STR_ObjNameSingulGRAF );
-        break;
-    }
+                case GRAPHIC_NONE:
+                    rName=ImpGetResStr( IsLinkedGraphic() ? STR_ObjNameSingulGRAFNONELNK : STR_ObjNameSingulGRAFNONE );
+                break;
 
-    const String aName(GetName());
+                default:
+                    rName=ImpGetResStr(  IsLinkedGraphic() ? STR_ObjNameSingulGRAFLNK : STR_ObjNameSingulGRAF );
+                break;
+            }
+        }
 
-    if( aName.Len() )
-    {
-        rName.AppendAscii( " '" );
-        rName += aName;
-        rName += sal_Unicode( '\'' );
+        const String aName(GetName());
+
+        if( aName.Len() )
+        {
+            rName.AppendAscii( " '" );
+            rName += aName;
+            rName += sal_Unicode( '\'' );
+        }
     }
 }
 
@@ -752,38 +789,50 @@ void SdrGrafObj::TakeObjNameSingul(XubString& rName) const
 
 void SdrGrafObj::TakeObjNamePlural( XubString& rName ) const
 {
-    switch( pGraphic->GetType() )
+    if(pGraphic)
     {
-        case GRAPHIC_BITMAP:
+        const SvgDataPtr& rSvgDataPtr = pGraphic->GetGraphic().getSvgData();
+
+        if(rSvgDataPtr.get())
         {
-            const sal_uInt16 nId = ( ( pGraphic->IsTransparent() || ( (const SdrGrafTransparenceItem&) GetObjectItem( SDRATTR_GRAFTRANSPARENCE ) ).GetValue() ) ?
-                                 ( IsLinkedGraphic() ? STR_ObjNamePluralGRAFBMPTRANSLNK : STR_ObjNamePluralGRAFBMPTRANS ) :
-                                 ( IsLinkedGraphic() ? STR_ObjNamePluralGRAFBMPLNK : STR_ObjNamePluralGRAFBMP ) );
-
-            rName=ImpGetResStr( nId );
+            rName = ImpGetResStr(STR_ObjNamePluralGRAFSVG);
         }
-        break;
+        else
+        {
+            switch( pGraphic->GetType() )
+            {
+                case GRAPHIC_BITMAP:
+                {
+                    const sal_uInt16 nId = ( ( pGraphic->IsTransparent() || ( (const SdrGrafTransparenceItem&) GetObjectItem( SDRATTR_GRAFTRANSPARENCE ) ).GetValue() ) ?
+                                         ( IsLinkedGraphic() ? STR_ObjNamePluralGRAFBMPTRANSLNK : STR_ObjNamePluralGRAFBMPTRANS ) :
+                                         ( IsLinkedGraphic() ? STR_ObjNamePluralGRAFBMPLNK : STR_ObjNamePluralGRAFBMP ) );
 
-        case GRAPHIC_GDIMETAFILE:
-            rName=ImpGetResStr( IsLinkedGraphic() ? STR_ObjNamePluralGRAFMTFLNK : STR_ObjNamePluralGRAFMTF );
-        break;
+                    rName=ImpGetResStr( nId );
+                }
+                break;
 
-        case GRAPHIC_NONE:
-            rName=ImpGetResStr( IsLinkedGraphic() ? STR_ObjNamePluralGRAFNONELNK : STR_ObjNamePluralGRAFNONE );
-        break;
+                case GRAPHIC_GDIMETAFILE:
+                    rName=ImpGetResStr( IsLinkedGraphic() ? STR_ObjNamePluralGRAFMTFLNK : STR_ObjNamePluralGRAFMTF );
+                break;
 
-        default:
-            rName=ImpGetResStr(  IsLinkedGraphic() ? STR_ObjNamePluralGRAFLNK : STR_ObjNamePluralGRAF );
-        break;
-    }
+                case GRAPHIC_NONE:
+                    rName=ImpGetResStr( IsLinkedGraphic() ? STR_ObjNamePluralGRAFNONELNK : STR_ObjNamePluralGRAFNONE );
+                break;
 
-    const String aName(GetName());
+                default:
+                    rName=ImpGetResStr(  IsLinkedGraphic() ? STR_ObjNamePluralGRAFLNK : STR_ObjNamePluralGRAF );
+                break;
+            }
+        }
 
-    if( aName.Len() )
-    {
-        rName.AppendAscii( " '" );
-        rName += aName;
-        rName += sal_Unicode( '\'' );
+        const String aName(GetName());
+
+        if( aName.Len() )
+        {
+            rName.AppendAscii( " '" );
+            rName += aName;
+            rName += sal_Unicode( '\'' );
+        }
     }
 }
 
@@ -818,7 +867,6 @@ SdrGrafObj& SdrGrafObj::operator=( const SdrGrafObj& rObj )
     SdrRectObj::operator=( rObj );
 
     pGraphic->SetGraphic( rObj.GetGraphic(), &rObj.GetGraphicObject() );
-    aCropRect = rObj.aCropRect;
     aFileName = rObj.aFileName;
     aFilterName = rObj.aFilterName;
     bMirrored = rObj.bMirrored;
@@ -907,7 +955,8 @@ void SdrGrafObj::NbcMirror(const Point& rRef1, const Point& rRef2)
 
 void SdrGrafObj::NbcShear(const Point& rRef, long nWink, double tn, bool bVShear)
 {
-    SdrRectObj::NbcRotate( rRef, nWink, tn, bVShear );
+    // #i118485# Call Shear now, old version redirected to rotate
+    SdrRectObj::NbcShear(rRef, nWink, tn, bVShear);
 }
 
 // -----------------------------------------------------------------------------
@@ -944,8 +993,6 @@ void SdrGrafObj::SaveGeoData(SdrObjGeoData& rGeo) const
 
 void SdrGrafObj::RestGeoData(const SdrObjGeoData& rGeo)
 {
-    Size        aSizMerk( aRect.GetSize() );
-
     SdrRectObj::RestGeoData(rGeo);
     SdrGrafObjGeoData& rGGeo=(SdrGrafObjGeoData&)rGeo;
     bMirrored=rGGeo.bMirrored;
@@ -970,7 +1017,7 @@ void SdrGrafObj::SetPage( SdrPage* pNewPage )
 
     SdrRectObj::SetPage( pNewPage );
 
-    if(aFileName.Len() && bInsert)
+    if (!aFileName.isEmpty() && bInsert)
         ImpLinkAnmeldung();
 }
 
@@ -995,7 +1042,7 @@ void SdrGrafObj::SetModel( SdrModel* pNewModel )
     // realize model
     SdrRectObj::SetModel(pNewModel);
 
-    if( bChg && aFileName.Len() )
+    if (bChg && !aFileName.isEmpty())
         ImpLinkAnmeldung();
 }
 
@@ -1003,7 +1050,7 @@ void SdrGrafObj::SetModel( SdrModel* pNewModel )
 
 void SdrGrafObj::StartAnimation( OutputDevice* /*pOutDev*/, const Point& /*rPoint*/, const Size& /*rSize*/, long /*nExtraData*/)
 {
-    SetGrafAnimationAllowed(sal_True);
+    SetGrafAnimationAllowed(true);
 }
 
 // -----------------------------------------------------------------------------
@@ -1015,36 +1062,102 @@ bool SdrGrafObj::HasGDIMetaFile() const
 
 // -----------------------------------------------------------------------------
 
-SdrObject* SdrGrafObj::DoConvertToPolyObj(sal_Bool bBezier) const
+bool SdrGrafObj::isEmbeddedSvg() const
+{
+    return GRAPHIC_BITMAP == GetGraphicType() && GetGraphic().getSvgData().get();
+}
+
+GDIMetaFile SdrGrafObj::getMetafileFromEmbeddedSvg() const
+{
+    GDIMetaFile aRetval;
+
+    if(isEmbeddedSvg() && GetModel())
+    {
+        VirtualDevice aOut;
+        const Rectangle aBoundRect(GetCurrentBoundRect());
+        const MapMode aMap(GetModel()->GetScaleUnit(), Point(), GetModel()->GetScaleFraction(), GetModel()->GetScaleFraction());
+
+        aOut.EnableOutput(false);
+        aOut.SetMapMode(aMap);
+        aRetval.Record(&aOut);
+        SingleObjectPainter(aOut);
+        aRetval.Stop();
+        aRetval.WindStart();
+        aRetval.Move(-aBoundRect.Left(), -aBoundRect.Top());
+        aRetval.SetPrefMapMode(aMap);
+        aRetval.SetPrefSize(aBoundRect.GetSize());
+    }
+
+    return aRetval;
+}
+
+SdrObject* SdrGrafObj::DoConvertToPolyObj(sal_Bool bBezier, bool bAddText ) const
 {
     SdrObject* pRetval = NULL;
+    GraphicType aGraphicType(GetGraphicType());
+    GDIMetaFile aMtf;
 
-    switch( GetGraphicType() )
+    if(isEmbeddedSvg())
+    {
+        // Embedded Svg
+        // There is currently no helper to create SdrObjects from primitives (even if I'm thinking
+        // about writing one for some time). To get the roundtrip to SdrObjects it is necessary to
+        // use the old converter path over the MetaFile mechanism. Create Metafile from Svg
+        // primitives here pretty directly
+        aMtf = getMetafileFromEmbeddedSvg();
+        aGraphicType = GRAPHIC_GDIMETAFILE;
+    }
+    else if(GRAPHIC_GDIMETAFILE == aGraphicType)
+    {
+        aMtf = GetTransformedGraphic(SDRGRAFOBJ_TRANSFORMATTR_COLOR|SDRGRAFOBJ_TRANSFORMATTR_MIRROR).GetGDIMetaFile();
+    }
+
+    switch(aGraphicType)
     {
         case GRAPHIC_GDIMETAFILE:
         {
             // Sort into group and return ONLY those objects that can be created from the MetaFile.
-            SdrObjGroup*            pGrp = new SdrObjGroup();
             ImpSdrGDIMetaFileImport aFilter(*GetModel());
-            Point                   aOutPos( aRect.TopLeft() );
-            const Size              aOutSiz( aRect.GetSize() );
 
-            aFilter.SetScaleRect(GetSnapRect());
+            aFilter.SetScaleRect(aRect);
             aFilter.SetLayer(GetLayer());
 
-            sal_uInt32 nInsAnz = aFilter.DoImport(GetTransformedGraphic().GetGDIMetaFile(), *pGrp->GetSubList(), 0);
+            SdrObjGroup* pGrp = new SdrObjGroup();
+            sal_uInt32 nInsAnz = aFilter.DoImport(aMtf, *pGrp->GetSubList(), 0);
+
             if(nInsAnz)
             {
+                {
+                        // copy transformation
+                    GeoStat aGeoStat(GetGeoStat());
+
+                    if(aGeoStat.nShearWink)
+                    {
+                        aGeoStat.RecalcTan();
+                        pGrp->NbcShear(aRect.TopLeft(), aGeoStat.nShearWink, aGeoStat.nTan, false);
+                    }
+
+                    if(aGeoStat.nDrehWink)
+                    {
+                        aGeoStat.RecalcSinCos();
+                        pGrp->NbcRotate(aRect.TopLeft(), aGeoStat.nDrehWink, aGeoStat.nSin, aGeoStat.nCos);
+                    }
+                }
+
                 pRetval = pGrp;
                 pGrp->NbcSetLayer(GetLayer());
                 pGrp->SetModel(GetModel());
-                pRetval = ImpConvertAddText(pRetval, bBezier);
+
+                if(bAddText)
+                {
+                    pRetval = ImpConvertAddText(pRetval, bBezier);
+                }
 
                 // convert all children
                 if( pRetval )
                 {
                     SdrObject* pHalfDone = pRetval;
-                    pRetval = pHalfDone->DoConvertToPolyObj(bBezier);
+                    pRetval = pHalfDone->DoConvertToPolyObj(bBezier, bAddText);
                     SdrObject::Free( pHalfDone ); // resulting object is newly created
 
                     if( pRetval )
@@ -1060,13 +1173,42 @@ SdrObject* SdrGrafObj::DoConvertToPolyObj(sal_Bool bBezier) const
                 }
             }
             else
+            {
                 delete pGrp;
+            }
+
+            // #i118485# convert line and fill
+            SdrObject* pLineFill = SdrRectObj::DoConvertToPolyObj(bBezier, false);
+
+            if(pLineFill)
+            {
+                if(pRetval)
+                {
+                    pGrp = dynamic_cast< SdrObjGroup* >(pRetval);
+
+                    if(!pGrp)
+                    {
+                        pGrp = new SdrObjGroup();
+
+                        pGrp->NbcSetLayer(GetLayer());
+                        pGrp->SetModel(GetModel());
+                        pGrp->GetSubList()->NbcInsertObject(pRetval);
+                    }
+
+                    pGrp->GetSubList()->NbcInsertObject(pLineFill, 0);
+                }
+                else
+                {
+                    pRetval = pLineFill;
+                }
+            }
+
             break;
         }
         case GRAPHIC_BITMAP:
         {
             // create basic object and add fill
-            pRetval = SdrRectObj::DoConvertToPolyObj(bBezier);
+            pRetval = SdrRectObj::DoConvertToPolyObj(bBezier, bAddText);
 
             // save bitmap as an attribute
             if(pRetval)
@@ -1078,7 +1220,7 @@ SdrObject* SdrGrafObj::DoConvertToPolyObj(sal_Bool bBezier) const
                 Bitmap aBitmap( GetTransformedGraphic().GetBitmap() );
                 XOBitmap aXBmp(aBitmap, XBITMAP_STRETCH);
                 aSet.Put(XFillBitmapItem(String(), aXBmp));
-                aSet.Put(XFillBmpTileItem(sal_False));
+                aSet.Put(XFillBmpTileItem(false));
 
                 pRetval->SetMergedItemSet(aSet);
             }
@@ -1087,7 +1229,7 @@ SdrObject* SdrGrafObj::DoConvertToPolyObj(sal_Bool bBezier) const
         case GRAPHIC_NONE:
         case GRAPHIC_DEFAULT:
         {
-            pRetval = SdrRectObj::DoConvertToPolyObj(bBezier);
+            pRetval = SdrRectObj::DoConvertToPolyObj(bBezier, bAddText);
             break;
         }
     }
@@ -1104,6 +1246,16 @@ void SdrGrafObj::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
     ImpSetAttrToGrafInfo();
 }
 
+bool SdrGrafObj::IsMirrored() const
+{
+    return bMirrored;
+}
+
+void SdrGrafObj::SetMirrored( bool _bMirrored )
+{
+    bMirrored = _bMirrored;
+}
+
 void SdrGrafObj::ImpSetAttrToGrafInfo()
 {
     const SfxItemSet& rSet = GetObjectItemSet();
@@ -1222,8 +1374,9 @@ IMPL_LINK( SdrGrafObj, ImpSwapHdl, GraphicObject*, pO )
             if( pGraphic->HasUserData() )
             {
                 ::comphelper::LifecycleProxy proxy;
+                OUString aUserData = pGraphic->GetUserData();
                 uno::Reference<io::XInputStream> const xStream(
-                    pModel->GetDocumentStream(pGraphic->GetUserData(), proxy));
+                    pModel->GetDocumentStream(aUserData, proxy));
 
                 ::boost::scoped_ptr<SvStream> const pStream( (xStream.is())
                         ? ::utl::UcbStreamHelper::CreateStream(xStream)
@@ -1240,8 +1393,8 @@ IMPL_LINK( SdrGrafObj, ImpSwapHdl, GraphicObject*, pO )
                         pFilterData = new com::sun::star::uno::Sequence< com::sun::star::beans::PropertyValue >( 3 );
 
                         com::sun::star::awt::Size aPreviewSizeHint( 64, 64 );
-                        sal_Bool bAllowPartialStreamRead = sal_True;
-                        sal_Bool bCreateNativeLink = sal_False;
+                        sal_Bool bAllowPartialStreamRead = true;
+                        sal_Bool bCreateNativeLink = false;
                         (*pFilterData)[ 0 ].Name = String( RTL_CONSTASCII_USTRINGPARAM( "PreviewSizeHint" ) );
                         (*pFilterData)[ 0 ].Value <<= aPreviewSizeHint;
                         (*pFilterData)[ 1 ].Name = String( RTL_CONSTASCII_USTRINGPARAM( "AllowPartialStreamRead" ) );
@@ -1249,19 +1402,17 @@ IMPL_LINK( SdrGrafObj, ImpSwapHdl, GraphicObject*, pO )
                         (*pFilterData)[ 2 ].Name = String( RTL_CONSTASCII_USTRINGPARAM( "CreateNativeLink" ) );
                         (*pFilterData)[ 2 ].Value <<= bCreateNativeLink;
 
-                        mbIsPreview = sal_True;
+                        mbIsPreview = true;
                     }
 
-                    if( !GraphicFilter::GetGraphicFilter().ImportGraphic( aGraphic,
-                                                                          pGraphic->GetUserData(),
-                                                                          *pStream,
-                                                                          GRFILTER_FORMAT_DONTKNOW,
-                                                                          NULL, 0, pFilterData ) )
+                    if(!GraphicFilter::GetGraphicFilter().ImportGraphic(
+                        aGraphic, aUserData, *pStream,
+                        GRFILTER_FORMAT_DONTKNOW, NULL, 0, pFilterData))
                     {
-                        const String aUserData( pGraphic->GetUserData() );
+                        const String aNewUserData( pGraphic->GetUserData() );
 
                         pGraphic->SetGraphic( aGraphic );
-                        pGraphic->SetUserData( aUserData );
+                        pGraphic->SetUserData( aNewUserData );
 
                         // Graphic successfully swapped in.
                         pRet = GRFMGR_AUTOSWAPSTREAM_LOADED;
@@ -1271,7 +1422,7 @@ IMPL_LINK( SdrGrafObj, ImpSwapHdl, GraphicObject*, pO )
                     pStream->ResetError();
                 }
             }
-            else if( !ImpUpdateGraphicLink( sal_False ) )
+            else if( !ImpUpdateGraphicLink( false ) )
             {
                 pRet = GRFMGR_AUTOSWAPSTREAM_TEMP;
             }
@@ -1289,7 +1440,7 @@ IMPL_LINK( SdrGrafObj, ImpSwapHdl, GraphicObject*, pO )
 
 // -----------------------------------------------------------------------------
 
-void SdrGrafObj::SetGrafAnimationAllowed(sal_Bool bNew)
+void SdrGrafObj::SetGrafAnimationAllowed(bool bNew)
 {
     if(mbGrafAnimationAllowed != bNew)
     {
@@ -1333,13 +1484,13 @@ Reference< XInputStream > SdrGrafObj::getInputStream()
                     memcpy( pBuffer, pSourceData, nSize );
 
                     SvMemoryStream* pStream = new SvMemoryStream( (void*)pBuffer, (sal_Size)nSize, STREAM_READ );
-                    pStream->ObjectOwnsMemory( sal_True );
-                    xStream.set( new utl::OInputStreamWrapper( pStream, sal_True ) );
+                    pStream->ObjectOwnsMemory( true );
+                    xStream.set( new utl::OInputStreamWrapper( pStream, true ) );
                 }
             }
         }
 
-        if( !xStream.is() && aFileName.Len() )
+        if (!xStream.is() && !aFileName.isEmpty())
         {
             SvFileStream* pStream = new SvFileStream( aFileName, STREAM_READ );
             if( pStream )
