@@ -1,32 +1,21 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
-
-
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 #include <comphelper/string.hxx>
 #include <tools/urlobj.hxx>
@@ -87,7 +76,8 @@ public:
 
 typedef const SwDoc* SwDocPtr;
 typedef std::vector<SwDocPtr> SwDocPtrVector;
-class SwAutoCompleteString : public String
+class SwAutoCompleteString
+    : public editeng::IAutoCompleteString
 {
 #if OSL_DEBUG_LEVEL > 0
     static sal_uLong nSwAutoCompleteStringCount;
@@ -99,7 +89,7 @@ class SwAutoCompleteString : public String
         ~SwAutoCompleteString();
         void        AddDocument(const SwDoc& rDoc);
         //returns true if last document reference has been removed
-        sal_Bool     RemoveDocument(const SwDoc& rDoc);
+        bool        RemoveDocument(const SwDoc& rDoc);
 #if OSL_DEBUG_LEVEL > 0
     static sal_uLong GetElementCount() {return nSwAutoCompleteStringCount;}
 #endif
@@ -186,8 +176,9 @@ void SwAutoCompleteWord_Impl::RemoveDocument(const SwDoc& rDoc)
     }
 }
 
-SwAutoCompleteString::SwAutoCompleteString(const String& rStr, xub_StrLen nPos, xub_StrLen nLen) :
-            String( rStr, nPos, nLen )
+SwAutoCompleteString::SwAutoCompleteString(
+            const String& rStr, xub_StrLen const nPos, xub_StrLen const nLen)
+    : editeng::IAutoCompleteString(String(rStr, nPos, nLen))
 {
 #if OSL_DEBUG_LEVEL > 0
     ++nSwAutoCompleteStringCount;
@@ -203,47 +194,40 @@ SwAutoCompleteString::~SwAutoCompleteString()
 
 void SwAutoCompleteString::AddDocument(const SwDoc& rDoc)
 {
-    SwDocPtrVector::iterator aIt;
-    for(aIt = aSourceDocs.begin(); aIt != aSourceDocs.end(); ++aIt)
+    for(SwDocPtrVector::iterator aIt = aSourceDocs.begin(); aIt != aSourceDocs.end(); ++aIt)
     {
-        if(*aIt == &rDoc)
+        if( *aIt == &rDoc )
             return;
     }
-    SwDocPtr pNew = &rDoc;
-    aSourceDocs.push_back(pNew);
+    aSourceDocs.push_back(&rDoc);
 }
 
-sal_Bool SwAutoCompleteString::RemoveDocument(const SwDoc& rDoc)
+bool SwAutoCompleteString::RemoveDocument(const SwDoc& rDoc)
 {
-    SwDocPtrVector::iterator aIt;
-    for(aIt = aSourceDocs.begin(); aIt != aSourceDocs.end(); ++aIt)
+    for(SwDocPtrVector::iterator aIt = aSourceDocs.begin(); aIt != aSourceDocs.end(); ++aIt)
     {
-        if(*aIt == &rDoc)
+        if( *aIt == &rDoc )
         {
             aSourceDocs.erase(aIt);
-            return !aSourceDocs.size();
+            return aSourceDocs.empty();
         }
     }
-    return sal_False;
+    return false;
 }
 
-SwAutoCompleteWord::SwAutoCompleteWord( sal_uInt16 nWords, sal_uInt16 nMWrdLen )
-    : aWordLst( 0, 255 ), aLRULst( 0, 255 ),
+SwAutoCompleteWord::SwAutoCompleteWord( sal_uInt16 nWords, sal_uInt16 nMWrdLen ) :
     pImpl(new SwAutoCompleteWord_Impl(*this)),
     nMaxCount( nWords ),
     nMinWrdLen( nMWrdLen ),
     bLockWordLst( sal_False )
 {
+    m_LookupTree = new LatinLookupTree(OUString("default"));
 }
 
 SwAutoCompleteWord::~SwAutoCompleteWord()
 {
-    for(sal_uInt16 nPos = aWordLst.Count(); nPos; nPos--)
-    {
-        SwAutoCompleteString* pCurrent = (SwAutoCompleteString*)aWordLst[ nPos - 1 ];
-        aWordLst.Remove( nPos - 1 );
-        delete pCurrent;
-    }
+    m_WordList.DeleteAndDestroyAll(); // so the assertion below works
+    delete m_LookupTree;
     delete pImpl;
 #if OSL_DEBUG_LEVEL > 0
     sal_uLong nStrings = SwAutoCompleteString::GetElementCount();
@@ -252,7 +236,7 @@ SwAutoCompleteWord::~SwAutoCompleteWord()
 #endif
 }
 
-sal_Bool SwAutoCompleteWord::InsertWord( const String& rWord, SwDoc& rDoc )
+bool SwAutoCompleteWord::InsertWord( const String& rWord, SwDoc& rDoc )
 {
     SwDocShell* pDocShell = rDoc.GetDocShell();
     SfxMedium* pMedium = pDocShell ? pDocShell->GetMedium() : 0;
@@ -269,53 +253,50 @@ sal_Bool SwAutoCompleteWord::InsertWord( const String& rWord, SwDoc& rDoc )
     aNewWord = comphelper::string::remove(aNewWord, CH_TXTATR_BREAKWORD);
 
     pImpl->AddDocument(rDoc);
-    sal_Bool bRet = sal_False;
+    bool bRet = false;
     xub_StrLen nWrdLen = aNewWord.Len();
     while( nWrdLen && '.' == aNewWord.GetChar( nWrdLen-1 ))
         --nWrdLen;
 
     if( !bLockWordLst && nWrdLen >= nMinWrdLen )
     {
-        SwAutoCompleteString* pAutoString;
-        StringPtr pNew = pAutoString = new SwAutoCompleteString( aNewWord, 0, nWrdLen );
-        pAutoString->AddDocument(rDoc);
-        sal_uInt16 nInsPos;
-        if( aWordLst.Insert( pNew, nInsPos ) )
+        SwAutoCompleteString* pNew = new SwAutoCompleteString( aNewWord, 0, nWrdLen );
+        pNew->AddDocument(rDoc);
+        std::pair<editeng::SortedAutoCompleteStrings::const_iterator, bool>
+            aInsPair = m_WordList.insert(pNew);
+
+        m_LookupTree->insert( OUString(aNewWord) );
+
+        if (aInsPair.second)
         {
-            bRet = sal_True;
-            if( aLRULst.Count() < nMaxCount )
-                aLRULst.Insert( pNew, 0 );
-            else
+            bRet = true;
+            if (aLRULst.size() >= nMaxCount)
             {
                 // the last one needs to be removed
                 // so that there is space for the first one
-                String* pDel = (String*)aLRULst[ nMaxCount - 1 ];
-
-                void** ppData = (void**)aLRULst.GetData();
-                memmove( ppData+1, ppData, (nMaxCount - 1) * sizeof( void* ));
-                *ppData = pNew;
-
-                aWordLst.Remove( pDel );
-                delete (SwAutoCompleteString*)pDel;
+                SwAutoCompleteString* pDel = aLRULst.back();
+                aLRULst.pop_back();
+                m_WordList.erase(pDel);
+                delete pDel;
             }
+            aLRULst.push_front(pNew);
         }
         else
         {
-            delete (SwAutoCompleteString*)pNew;
+            delete pNew;
             // then move "up"
-            pNew = aWordLst[ nInsPos ];
+            pNew = (SwAutoCompleteString*)(*aInsPair.first);
 
             // add the document to the already inserted string
-            SwAutoCompleteString* pCurrent = (SwAutoCompleteString*)pNew;
-            pCurrent->AddDocument(rDoc);
+            pNew->AddDocument(rDoc);
 
-            nInsPos = aLRULst.GetPos( (void*)pNew );
-            OSL_ENSURE( USHRT_MAX != nInsPos, "String not found" );
-            if( nInsPos )
+            // move pNew to the front of the LRU list
+            SwAutoCompleteStringPtrDeque::iterator it = std::find( aLRULst.begin(), aLRULst.end(), pNew );
+            OSL_ENSURE( aLRULst.end() != it, "String not found" );
+            if ( aLRULst.begin() != it && aLRULst.end() != it )
             {
-                void** ppData = (void**)aLRULst.GetData();
-                memmove( ppData+1, ppData, nInsPos * sizeof( void* ) );
-                *ppData = pNew;
+                aLRULst.erase( it );
+                aLRULst.push_front( pNew );
             }
         }
     }
@@ -324,19 +305,20 @@ sal_Bool SwAutoCompleteWord::InsertWord( const String& rWord, SwDoc& rDoc )
 
 void SwAutoCompleteWord::SetMaxCount( sal_uInt16 nNewMax )
 {
-    if( nNewMax < nMaxCount && aLRULst.Count() > nNewMax )
+    if( nNewMax < nMaxCount && aLRULst.size() > nNewMax )
     {
         // remove the trailing ones
         sal_uInt16 nLRUIndex = nNewMax-1;
-        while( nNewMax < aWordLst.Count() && nLRUIndex < aLRULst.Count())
+        while (nNewMax < m_WordList.size() && nLRUIndex < aLRULst.size())
         {
-            sal_uInt16 nPos = aWordLst.GetPos( (String*)aLRULst[ nLRUIndex++ ] );
-            OSL_ENSURE( USHRT_MAX != nPos, "String not found" );
-            void * pDel = aWordLst[nPos];
-            aWordLst.Remove(nPos);
-            delete (SwAutoCompleteString*)pDel;
+            editeng::SortedAutoCompleteStrings::const_iterator it =
+                m_WordList.find(aLRULst[ nLRUIndex++ ]);
+            OSL_ENSURE( m_WordList.end() != it, "String not found" );
+            editeng::IAutoCompleteString *const pDel = *it;
+            m_WordList.erase(it - m_WordList.begin());
+            delete pDel;
         }
-        aLRULst.Remove( nNewMax-1, aLRULst.Count() - nNewMax );
+        aLRULst.erase( aLRULst.begin() + nNewMax - 1, aLRULst.end() );
     }
     nMaxCount = nNewMax;
 }
@@ -346,54 +328,91 @@ void SwAutoCompleteWord::SetMinWordLen( sal_uInt16 n )
     // Do you really want to remove all words that are less than the minWrdLen?
     if( n < nMinWrdLen )
     {
-        for( sal_uInt16 nPos = 0; nPos < aWordLst.Count(); ++nPos  )
-            if( aWordLst[ nPos ]->Len() < n )
+        for (size_t nPos = 0; nPos < m_WordList.size(); ++nPos)
+            if (m_WordList[ nPos ]->GetAutoCompleteString().Len() < n)
             {
-                void* pDel = aWordLst[ nPos ];
-                aWordLst.Remove(nPos);
+                SwAutoCompleteString *const pDel =
+                    dynamic_cast<SwAutoCompleteString*>(m_WordList[nPos]);
+                m_WordList.erase(nPos);
 
-                sal_uInt16 nDelPos = aLRULst.GetPos( pDel );
-                OSL_ENSURE( USHRT_MAX != nDelPos, "String not found" );
-                aLRULst.Remove( nDelPos );
+                SwAutoCompleteStringPtrDeque::iterator it = std::find( aLRULst.begin(), aLRULst.end(), pDel );
+                OSL_ENSURE( aLRULst.end() != it, "String not found" );
+                aLRULst.erase( it );
                 --nPos;
-                delete (SwAutoCompleteString*)pDel;
+                delete pDel;
             }
     }
 
     nMinWrdLen = n;
 }
 
-sal_Bool SwAutoCompleteWord::GetRange( const String& rWord, sal_uInt16& rStt,
-                                    sal_uInt16& rEnd ) const
+// Resets the current position within the tree to its root node.
+void SwAutoCompleteWord::returnToRoot()
 {
-    const StringPtr pStr = (StringPtr)&rWord;
-    aWordLst.Seek_Entry( pStr, &rStt );
-    rEnd = rStt;
-
-    const ::utl::TransliterationWrapper& rSCmp = GetAppCmpStrIgnore();
-    while( rEnd < aWordLst.Count() && rSCmp.isMatch( rWord, *aWordLst[ rEnd ]))
-        ++rEnd;
-
-    return rStt < rEnd;
+    m_LookupTree->returnToRoot();
 }
 
-void SwAutoCompleteWord::CheckChangedList( const SvStringsISortDtor& rNewLst )
+// Advances to a given node within the AutoComplete tree.
+void SwAutoCompleteWord::gotoNode(OUString sNode)
 {
-    sal_uInt16 nMyLen = aWordLst.Count(), nNewLen = rNewLst.Count();
-    sal_uInt16 nMyPos = 0, nNewPos = 0;
+    m_LookupTree->gotoNode( sNode );
+}
+
+// Advances from the current position towards the node keyed with cKey.
+void SwAutoCompleteWord::advance(const sal_Unicode cKey)
+{
+    m_LookupTree->advance( cKey );
+}
+
+// Goes back one char within the tree, except if the current node is already the root node.
+void SwAutoCompleteWord::goBack()
+{
+    m_LookupTree->goBack();
+}
+
+// Returns all words matching a given prefix aMatch. If bIgnoreCurrentPos is set, the current
+// position within the tree is ignored and replaced by aMatch.
+bool SwAutoCompleteWord::GetWordsMatching(String aMatch, std::vector<String>& aWords, bool bIgnoreCurrentPos) const
+{
+    OUString aStringRoot = OUString( aMatch );
+
+    // The lookup tree already contains the information about the root keyword in most cases. Only if we don't trust that
+    // information (e.g. if we need some autocompletion for a place other than the main writing area), the location within
+    // the tree needs to be refreshed.
+    if (bIgnoreCurrentPos)
+    {
+        m_LookupTree->gotoNode( aStringRoot );
+    }
+
+    OUString aAutocompleteWord = m_LookupTree->suggestAutoCompletion();
+    if (aAutocompleteWord.isEmpty())
+    {
+        return false;
+    }
+
+    OUString aCompleteWord = aStringRoot + aAutocompleteWord;
+    aWords.push_back( String(aCompleteWord) );
+    return true;
+}
+
+void SwAutoCompleteWord::CheckChangedList(
+        const editeng::SortedAutoCompleteStrings& rNewLst)
+{
+    size_t nMyLen = m_WordList.size(), nNewLen = rNewLst.size();
+    size_t nMyPos = 0, nNewPos = 0;
 
     for( ; nMyPos < nMyLen && nNewPos < nNewLen; ++nMyPos, ++nNewPos )
     {
-        const StringPtr pStr = rNewLst[ nNewPos ];
-        while( aWordLst[ nMyPos ] != pStr )
+        const editeng::IAutoCompleteString * pStr = rNewLst[ nNewPos ];
+        while (m_WordList[nMyPos] != pStr)
         {
-            void* pDel = aWordLst[ nMyPos ];
-            aWordLst.Remove(nMyPos);
-
-            sal_uInt16 nPos = aLRULst.GetPos( pDel );
-            OSL_ENSURE( USHRT_MAX != nPos, "String not found" );
-            aLRULst.Remove( nPos );
-            delete (SwAutoCompleteString*)pDel;
+            SwAutoCompleteString *const pDel =
+                dynamic_cast<SwAutoCompleteString*>(m_WordList[nMyPos]);
+            m_WordList.erase(nMyPos);
+            SwAutoCompleteStringPtrDeque::iterator it = std::find( aLRULst.begin(), aLRULst.end(), pDel );
+            OSL_ENSURE( aLRULst.end() != it, "String not found" );
+            aLRULst.erase( it );
+            delete pDel;
             if( nMyPos >= --nMyLen )
                 break;
         }
@@ -404,14 +423,16 @@ void SwAutoCompleteWord::CheckChangedList( const SvStringsISortDtor& rNewLst )
         // clear LRU array first then delete the string object
         for( ; nNewPos < nMyLen; ++nNewPos )
         {
-            void* pDel = aWordLst[ nNewPos ];
-            sal_uInt16 nPos = aLRULst.GetPos( pDel );
-            OSL_ENSURE( USHRT_MAX != nPos, "String not found" );
-            aLRULst.Remove( nPos );
-            delete (SwAutoCompleteString*)pDel;
+            SwAutoCompleteString *const pDel =
+                dynamic_cast<SwAutoCompleteString*>(m_WordList[nNewPos]);
+            SwAutoCompleteStringPtrDeque::iterator it = std::find( aLRULst.begin(), aLRULst.end(), pDel );
+            OSL_ENSURE( aLRULst.end() != it, "String not found" );
+            aLRULst.erase( it );
+            delete pDel;
         }
         // remove from array
-        aWordLst.Remove( nMyPos, nMyLen - nMyPos );
+        m_WordList.erase(m_WordList.begin() + nMyPos,
+                         m_WordList.begin() + nMyLen);
     }
 }
 
@@ -421,15 +442,16 @@ void SwAutoCompleteWord::DocumentDying(const SwDoc& rDoc)
 
     SvxAutoCorrect* pACorr = SvxAutoCorrCfg::Get().GetAutoCorrect();
     const sal_Bool bDelete = !pACorr->GetSwFlags().bAutoCmpltKeepList;
-    for(sal_uInt16 nPos = aWordLst.Count(); nPos; nPos--)
+    for (size_t nPos = m_WordList.size(); nPos; nPos--)
     {
-        SwAutoCompleteString* pCurrent = (SwAutoCompleteString*)aWordLst[ nPos - 1 ];
+        SwAutoCompleteString *const pCurrent =
+            dynamic_cast<SwAutoCompleteString*>(m_WordList[nPos - 1]);
         if(pCurrent->RemoveDocument(rDoc) && bDelete)
         {
-            aWordLst.Remove( nPos - 1 );
-            sal_uInt16 nLRUPos = aLRULst.GetPos( (void*)pCurrent );
-            OSL_ENSURE(nLRUPos < USHRT_MAX, "word not found in LRU list" );
-            aLRULst.Remove( nLRUPos );
+            m_WordList.erase(nPos - 1);
+            SwAutoCompleteStringPtrDeque::iterator it = std::find( aLRULst.begin(), aLRULst.end(), pCurrent );
+            OSL_ENSURE( aLRULst.end() != it, "word not found in LRU list" );
+            aLRULst.erase( it );
             delete pCurrent;
         }
     }
