@@ -1,32 +1,21 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
-
-
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 #include <hintids.hxx>
 #include <tools/urlobj.hxx>
@@ -51,6 +40,7 @@
 #include <fesh.hxx>
 #include <doc.hxx>
 #include <flyfrm.hxx>
+#include <flyfrms.hxx>
 #include <frmtool.hxx>
 #include <viewopt.hxx>
 #include <viewimp.hxx>
@@ -76,28 +66,31 @@
 #include <com/sun/star/embed/EmbedStates.hpp>
 
 #include <svtools/embedhlp.hxx>
-#include <svtools/chartprettypainter.hxx>
+#include <svx/charthelper.hxx>
 #include <dview.hxx> // #i99665#
 
-using namespace com::sun::star;
+#include <basegfx/matrix/b2dhommatrix.hxx>
+#include <drawinglayer/processor2d/processorfromoutputdevice.hxx>
+#include <drawinglayer/processor2d/baseprocessor2d.hxx>
+#include <basegfx/matrix/b2dhommatrixtools.hxx>
 
-#define DEFTEXTSIZE  12
+using namespace com::sun::star;
 
 extern void ClrContourCache( const SdrObject *pObj ); // TxtFly.Cxx
 
 
-inline sal_Bool GetRealURL( const SwGrfNode& rNd, String& rTxt )
+inline bool GetRealURL( const SwGrfNode& rNd, String& rTxt )
 {
-    sal_Bool bRet = rNd.GetFileFilterNms( &rTxt, 0 );
+    bool bRet = rNd.GetFileFilterNms( &rTxt, 0 );
     if( bRet )
         rTxt = URIHelper::removePassword( rTxt, INetURLObject::WAS_ENCODED,
                                            INetURLObject::DECODE_UNAMBIGUOUS);
     return bRet;
 }
 
-void lcl_PaintReplacement( const SwRect &rRect, const String &rText,
+static void lcl_PaintReplacement( const SwRect &rRect, const String &rText,
                            const ViewShell &rSh, const SwNoTxtFrm *pFrm,
-                           sal_Bool bDefect )
+                           bool bDefect )
 {
     static Font *pFont = 0;
     if ( !pFont )
@@ -105,8 +98,7 @@ void lcl_PaintReplacement( const SwRect &rRect, const String &rText,
         pFont = new Font();
         pFont->SetWeight( WEIGHT_BOLD );
         pFont->SetStyleName( aEmptyStr );
-        pFont->SetName( String::CreateFromAscii(
-                            RTL_CONSTASCII_STRINGPARAM( "Arial Unicode" )));
+        pFont->SetName(rtl::OUString("Arial Unicode"));
         pFont->SetFamily( FAMILY_SWISS );
         pFont->SetTransparent( sal_True );
     }
@@ -116,7 +108,7 @@ void lcl_PaintReplacement( const SwRect &rRect, const String &rText,
     const SwFmtURL &rURL = pFrm->FindFlyFrm()->GetFmt()->GetURL();
     if( rURL.GetURL().Len() || rURL.GetMap() )
     {
-        sal_Bool bVisited = sal_False;
+        bool bVisited = false;
         if ( rURL.GetMap() )
         {
             ImageMap *pMap = (ImageMap*)rURL.GetMap();
@@ -125,7 +117,7 @@ void lcl_PaintReplacement( const SwRect &rRect, const String &rText,
                 IMapObject *pObj = pMap->GetIMapObject( i );
                 if( rSh.GetDoc()->IsVisitedURL( pObj->GetURL() ) )
                 {
-                    bVisited = sal_True;
+                    bVisited = true;
                     break;
                 }
             }
@@ -142,7 +134,7 @@ void lcl_PaintReplacement( const SwRect &rRect, const String &rText,
     pFont->SetUnderline( eUnderline );
     pFont->SetColor( aCol );
 
-    const BitmapEx& rBmp = ViewShell::GetReplacementBitmap( bDefect != sal_False );
+    const BitmapEx& rBmp = ViewShell::GetReplacementBitmap( bDefect );
     Graphic::DrawEx( rSh.GetOut(), rText, *pFont, rBmp, rRect.Pos(), rRect.SSize() );
 }
 
@@ -159,16 +151,15 @@ SwNoTxtFrm::SwNoTxtFrm(SwNoTxtNode * const pNode, SwFrm* pSib )
     InitCtor();
 }
 
-// Initialisierung: z.Zt. Eintragen des Frames im Cache
+// Initialization: Currently add the Frame to the Cache
 
 
 void SwNoTxtFrm::InitCtor()
 {
     nType = FRMC_NOTXT;
-    // Das Gewicht der Grafik ist 0, wenn sie noch nicht
-    // gelesen ist, < 0, wenn ein Lesefehler auftrat und
-    // Ersatzdarstellung angewendet werden musste und >0,
-    // wenn sie zur Verfuegung steht.
+    // The graphic's weight is 0 if it has not been read,
+    // < 0 if we had a read error and we needed to use the replacement and
+    // > 0 if it is available
     nWeight = 0;
 }
 
@@ -209,25 +200,25 @@ void SetOutDev( ViewShell *pSh, OutputDevice *pOut )
 
 
 
-void lcl_ClearArea( const SwFrm &rFrm,
+static void lcl_ClearArea( const SwFrm &rFrm,
                     OutputDevice &rOut, const SwRect& rPtArea,
                     const SwRect &rGrfArea )
 {
-    SwRegionRects aRegion( rPtArea, 4, 4 );
+    SwRegionRects aRegion( rPtArea, 4 );
     aRegion -= rGrfArea;
 
-    if ( aRegion.Count() )
+    if ( !aRegion.empty() )
     {
         const SvxBrushItem *pItem; const Color *pCol; SwRect aOrigRect;
         if ( rFrm.GetBackgroundBrush( pItem, pCol, aOrigRect, sal_False ) )
-            for( sal_uInt16 i = 0; i < aRegion.Count(); ++i )
+            for( sal_uInt16 i = 0; i < aRegion.size(); ++i )
                 ::DrawGraphic( pItem, &rOut, aOrigRect, aRegion[i] );
         else
         {
             rOut.Push( PUSH_FILLCOLOR|PUSH_LINECOLOR );
             rOut.SetFillColor( rFrm.getRootFrm()->GetCurrShell()->Imp()->GetRetoucheColor());
             rOut.SetLineColor();
-            for( sal_uInt16 i = 0; i < aRegion.Count(); ++i )
+            for( sal_uInt16 i = 0; i < aRegion.size(); ++i )
                 rOut.DrawRect( aRegion[i].SVRect() );
             rOut.Pop();
         }
@@ -258,7 +249,7 @@ void SwNoTxtFrm::Paint(SwRect const& rRect, SwPrintData const*const) const
                 GetRealURL( *(SwGrfNode*)pNd, aTxt );
             if( !aTxt.Len() )
                 aTxt = FindFlyFrm()->GetFmt()->GetName();
-            lcl_PaintReplacement( Frm(), aTxt, *pSh, this, sal_False );
+            lcl_PaintReplacement( Frm(), aTxt, *pSh, this, false );
         }
         return;
     }
@@ -268,11 +259,11 @@ void SwNoTxtFrm::Paint(SwRect const& rRect, SwPrintData const*const) const
        !pSh->GetWin() )
         StopAnimation();
 
-    SfxProgress::EnterLock(); //Keine Progress-Reschedules im Paint (SwapIn)
+    SfxProgress::EnterLock(); // No progress reschedules in paint (SwapIn)
 
     OutputDevice *pOut = pSh->GetOut();
     pOut->Push();
-    sal_Bool bClip = sal_True;
+    bool bClip = true;
     PolyPolygon aPoly;
 
     SwNoTxtNode& rNoTNd = *(SwNoTxtNode*)GetNode();
@@ -289,7 +280,7 @@ void SwNoTxtFrm::Paint(SwRect const& rRect, SwPrintData const*const) const
        )
     {
         pOut->SetClipRegion( aPoly );
-        bClip = sal_False;
+        bClip = false;
     }
 
     SwRect aOrigPaint( rRect );
@@ -300,19 +291,28 @@ void SwNoTxtFrm::Paint(SwRect const& rRect, SwPrintData const*const) const
 
     SwRect aGrfArea( Frm() );
     SwRect aPaintArea( aGrfArea );
+
+    // In case the picture fly frm was clipped, render it with the origin
+    // size instead of scaling it
+    if ( rNoTNd.getIDocumentSettingAccess()->get( IDocumentSettingAccess::CLIPPED_PICTURES ) )
+    {
+        const SwFlyFreeFrm *pFly = dynamic_cast< const SwFlyFreeFrm* >( FindFlyFrm() );
+        if( pFly )
+            aGrfArea = SwRect( Frm().Pos( ), pFly->GetUnclippedFrm( ).SSize( ) );
+    }
+
     aPaintArea._Intersection( aOrigPaint );
 
     SwRect aNormal( Frm().Pos() + Prt().Pos(), Prt().SSize() );
-    aNormal.Justify(); //Normalisiertes Rechteck fuer die Vergleiche
+    aNormal.Justify(); // Normalized rectangle for the comparisons
 
     if( aPaintArea.IsOver( aNormal ) )
     {
-        // berechne die 4 zu loeschenden Rechtecke
+        // Calculate the four to-be-deleted rectangles
         if( pSh->GetWin() )
             ::lcl_ClearArea( *this, *pSh->GetOut(), aPaintArea, aNormal );
 
-        // in der Schnittmenge vom PaintBereich und der Bitmap liegt
-        // der absolut sichtbare Bereich vom Frame
+        // The intersection of the PaintArea and the Bitmap contains the absolutely visible area of the Frame
         aPaintArea._Intersection( aNormal );
 
         if ( bClip )
@@ -321,7 +321,7 @@ void SwNoTxtFrm::Paint(SwRect const& rRect, SwPrintData const*const) const
         PaintPicture( pOut, aGrfArea );
     }
     else
-        // wenn nicht sichtbar, loesche einfach den angegebenen Bereich
+        // If it's not visible, simply delete the given Area
         lcl_ClearArea( *this, *pSh->GetOut(), aPaintArea, SwRect() );
     if( pGrfNd )
         pGrfNd->SetFrameInPaint( sal_False );
@@ -335,17 +335,17 @@ void SwNoTxtFrm::Paint(SwRect const& rRect, SwPrintData const*const) const
 |*    void lcl_CalcRect( Point & aPt, Size & aDim,
 |*                   sal_uInt16 nMirror )
 |*
-|*    Beschreibung      Errechne die Position und die Groesse der Grafik im
-|*                      Frame, entsprechen der aktuellen Grafik-Attribute
+|*    Calculate the position and the size of the graphic in the Frame,
+|*    corresponding to the current graphic attributes
 |*
-|*    Parameter         Point&  die Position im Frame  ( auch Return-Wert )
-|*                      Size&   die Groesse der Grafik ( auch Return-Wert )
-|*                      MirrorGrf   akt. Spiegelungs-Attribut
+|*    Point&  the position in the Frame (also returned)
+|*    Size&   the graphic's size (also returned)
+|*    nMirror the current mirror attribute
 |*
 *************************************************************************/
 
 
-void lcl_CalcRect( Point& rPt, Size& rDim, sal_uInt16 nMirror )
+static void lcl_CalcRect( Point& rPt, Size& rDim, sal_uInt16 nMirror )
 {
     if( nMirror == RES_MIRROR_GRAPH_VERT || nMirror == RES_MIRROR_GRAPH_BOTH )
     {
@@ -364,19 +364,18 @@ void lcl_CalcRect( Point& rPt, Size& rDim, sal_uInt16 nMirror )
 |*
 |*    void SwNoTxtFrm::GetGrfArea()
 |*
-|*    Beschreibung      Errechne die Position und die Groesse der Bitmap
-|*                      innerhalb des uebergebenem Rechtecks.
+|*    Calculate the Bitmap's position and the size within the passed rectangle
 |*
 *************************************************************************/
 
 void SwNoTxtFrm::GetGrfArea( SwRect &rRect, SwRect* pOrigRect,
-                             sal_Bool ) const
+                             bool ) const
 {
-    //currently only used for scaling, cropping and mirroring the contour of graphics!
-    //all other is handled by the GraphicObject
+    // Currently only used for scaling, cropping and mirroring the contour of graphics!
+    // Everything else is handled by GraphicObject
 
-    //In rRect wird das sichbare Rechteck der Grafik gesteckt.
-    //In pOrigRect werden Pos+Size der Gesamtgrafik gesteck.
+    // We put the graphic's visible rectangle into rRect.
+    // pOrigRect contains position and size of the whole graphic.
 
     const SwAttrSet& rAttrSet = GetNode()->GetSwAttrSet();
     const SwCropGrf& rCrop = rAttrSet.GetCropGrf();
@@ -396,7 +395,8 @@ void SwNoTxtFrm::GetGrfArea( SwRect &rRect, SwRect* pOrigRect,
         }
     }
 
-    //Grafik wird vom Node eingelesen falls notwendig. Kann aber schiefgehen.
+    // We read graphic from the Node, if needed.
+    // It may fail, however.
     long nLeftCrop, nRightCrop, nTopCrop, nBottomCrop;
     Size aOrigSz( ((SwNoTxtNode*)GetNode())->GetTwipSize() );
     if ( !aOrigSz.Width() )
@@ -449,7 +449,7 @@ void SwNoTxtFrm::GetGrfArea( SwRect &rRect, SwRect* pOrigRect,
     Point aVisPt( Frm().Pos() + Prt().Pos() );
     Point aGrfPt( aVisPt );
 
-    //Erst das 'sichtbare' Rect einstellen.
+    // Set the "visible" rectangle first
     if ( nLeftCrop > 0 )
     {
         aVisPt.X()  += nLeftCrop;
@@ -468,7 +468,7 @@ void SwNoTxtFrm::GetGrfArea( SwRect &rRect, SwRect* pOrigRect,
     rRect.Pos  ( aVisPt );
     rRect.SSize( aVisSz );
 
-    //Ggf. Die Gesamtgrafik berechnen
+    // Calculate the whole graphic if needed
     if ( pOrigRect )
     {
         Size aTmpSz( aGrfSz );
@@ -489,15 +489,14 @@ void SwNoTxtFrm::GetGrfArea( SwRect &rRect, SwRect* pOrigRect,
 |*
 |*    Size SwNoTxtFrm::GetSize()
 |*
-|*    Beschreibung      Gebe die Groesse des umgebenen FLys und
-|*                      damit die der Grafik zurueck.
+|*    By returning the surrounding Fly's size which equals the graphic's size
 |*
 *************************************************************************/
 
 
 const Size& SwNoTxtFrm::GetSize() const
 {
-    // gebe die Groesse des Frames zurueck
+    // Return the Frame's size
     const SwFrm *pFly = FindFlyFrm();
     if( !pFly )
         pFly = this;
@@ -537,7 +536,7 @@ void SwNoTxtFrm::MakeAll()
 |*
 |*    SwNoTxtFrm::Format()
 |*
-|*    Beschreibung      Errechne die Groesse der Bitmap, wenn noetig
+|*    Calculate the Bitmap's site, if needed
 |*
 *************************************************************************/
 
@@ -546,7 +545,7 @@ void SwNoTxtFrm::Format( const SwBorderAttrs * )
 {
     const Size aNewSize( GetSize() );
 
-    // hat sich die Hoehe geaendert?
+    // Did the height change?
     SwTwips nChgHght = IsVertical() ?
         (SwTwips)(aNewSize.Width() - Prt().Width()) :
         (SwTwips)(aNewSize.Height() - Prt().Height());
@@ -577,10 +576,10 @@ sal_Bool SwNoTxtFrm::GetCharRect( SwRect &rRect, const SwPosition& rPos,
 
     rRect.Justify();
 
-    // liegt die Bitmap ueberhaupt im sichtbaren Berich ?
+    // Is the Bitmap in the visible area at all?
     if( !aFrameRect.IsOver( rRect ) )
     {
-        // wenn nicht dann steht der Cursor auf dem Frame
+        // If not, then the Cursor is on the Frame
         rRect = aFrameRect;
         rRect.Width( 1 );
     }
@@ -601,7 +600,7 @@ sal_Bool SwNoTxtFrm::GetCharRect( SwRect &rRect, const SwPosition& rPos,
 
 
 sal_Bool SwNoTxtFrm::GetCrsrOfst(SwPosition* pPos, Point& ,
-                             SwCrsrMoveState* ) const
+                             SwCrsrMoveState*, bool ) const
 {
     SwCntntNode* pCNd = (SwCntntNode*)GetNode();
     pPos->nNode = *pCNd;
@@ -633,7 +632,7 @@ void SwNoTxtFrm::Modify( const SfxPoolItem* pOld, const SfxPoolItem* pNew )
         SwCntntFrm::Modify( pOld, pNew );
     }
 
-    sal_Bool bComplete = sal_True;
+    bool bComplete = true;
 
     switch( nWhich )
     {
@@ -643,7 +642,7 @@ void SwNoTxtFrm::Modify( const SfxPoolItem* pOld, const SfxPoolItem* pNew )
     case RES_GRF_REREAD_AND_INCACHE:
         if( ND_GRFNODE == GetNode()->GetNodeType() )
         {
-            bComplete = sal_False;
+            bComplete = false;
             SwGrfNode* pNd = (SwGrfNode*) GetNode();
 
             ViewShell *pVSh = 0;
@@ -698,7 +697,7 @@ void SwNoTxtFrm::Modify( const SfxPoolItem* pOld, const SfxPoolItem* pNew )
     case RES_LINKED_GRAPHIC_STREAM_ARRIVED:
         if ( GetNode()->GetNodeType() == ND_GRFNODE )
         {
-            bComplete = sal_False;
+            bComplete = false;
             SwGrfNode* pNd = (SwGrfNode*) GetNode();
 
             CLEARCACHE( pNd )
@@ -721,7 +720,7 @@ void SwNoTxtFrm::Modify( const SfxPoolItem* pOld, const SfxPoolItem* pNew )
                 else if ( pSh->VisArea().IsOver( aRect ) &&
                    OUTDEV_WINDOW == pSh->GetOut()->GetOutDevType() )
                 {
-                    //invalidate instead of painting
+                    // invalidate instead of painting
                     pSh->GetWin()->Invalidate( aRect.SVRect() );
                 }
 
@@ -742,7 +741,7 @@ void SwNoTxtFrm::Modify( const SfxPoolItem* pOld, const SfxPoolItem* pNew )
     }
 }
 
-void lcl_correctlyAlignRect( SwRect& rAlignedGrfArea, const SwRect& rInArea, OutputDevice* pOut )
+static void lcl_correctlyAlignRect( SwRect& rAlignedGrfArea, const SwRect& rInArea, OutputDevice* pOut )
 {
 
     if(!pOut)
@@ -771,12 +770,98 @@ void lcl_correctlyAlignRect( SwRect& rAlignedGrfArea, const SwRect& rInArea, Out
     }
 }
 
-// Ausgabe der Grafik. Hier wird entweder eine QuickDraw-Bmp oder
-// eine Grafik vorausgesetzt. Ist nichts davon vorhanden, wird
-// eine Ersatzdarstellung ausgegeben.
-/// delete unused 3rd parameter.
-/// use aligned rectangle for drawing graphic.
-/// pixel-align coordinations for drawing graphic.
+bool paintUsingPrimitivesHelper(
+    OutputDevice& rOutputDevice,
+    const drawinglayer::primitive2d::Primitive2DSequence& rSequence,
+    const basegfx::B2DRange& rSourceRange,
+    const basegfx::B2DRange& rTargetRange,
+    const sal_Int32 nLeftCrop = 0,
+    const sal_Int32 nTopCrop = 0,
+    const sal_Int32 nRightCrop = 0,
+    const sal_Int32 nBottomCrop = 0,
+    const bool bMirrorX = false,
+    const bool bMirrorY = false)
+{
+    const double fSourceWidth(rSourceRange.getWidth());
+    const double fSourceHeight(rSourceRange.getHeight());
+
+    if(rSequence.hasElements() && !basegfx::fTools::equalZero(fSourceWidth) && !basegfx::fTools::equalZero(fSourceHeight))
+    {
+        // copy target range and apply evtl. cropping
+        basegfx::B2DRange aTargetRange(rTargetRange);
+
+        if(nLeftCrop || nTopCrop || nRightCrop || nBottomCrop)
+        {
+            // calculate original TargetRange
+            const double fFactor100thmmToTwips(72.0 / 127.0);
+
+            aTargetRange = basegfx::B2DRange(
+                aTargetRange.getMinX() - (nLeftCrop * fFactor100thmmToTwips),
+                aTargetRange.getMinY() - (nTopCrop * fFactor100thmmToTwips),
+                aTargetRange.getMaxX() + (nRightCrop * fFactor100thmmToTwips),
+                aTargetRange.getMaxY() + (nBottomCrop * fFactor100thmmToTwips));
+        }
+
+        const double fTargetWidth(aTargetRange.getWidth());
+        const double fTargetHeight(aTargetRange.getHeight());
+
+        if(!basegfx::fTools::equalZero(fTargetWidth) && !basegfx::fTools::equalZero(fTargetHeight))
+        {
+            // map graphic range to target range. This will automatically include
+            // tme mapping from Svg 1/100th mm content to twips since the target
+            // range is twips already
+            basegfx::B2DHomMatrix aMappingTransform(
+                basegfx::tools::createTranslateB2DHomMatrix(
+                    -rSourceRange.getMinX(),
+                    -rSourceRange.getMinY()));
+
+            aMappingTransform.scale(fTargetWidth / fSourceWidth, fTargetHeight / fSourceHeight);
+            aMappingTransform.translate(aTargetRange.getMinX(), aTargetRange.getMinY());
+
+            // apply mirrorings
+            if(bMirrorX || bMirrorY)
+            {
+                aMappingTransform.translate(-aTargetRange.getCenterX(), -aTargetRange.getCenterY());
+                aMappingTransform.scale(bMirrorX ? -1.0 : 1.0, bMirrorY ? -1.0 : 1.0); // #119176# small typo with X/Y
+                aMappingTransform.translate(aTargetRange.getCenterX(), aTargetRange.getCenterY());
+            }
+
+            // Fill ViewInformation. Use MappingTransform here, so there is no need to
+            // embed the primitives to it. Use original TargetRange here so there is also
+            // no need to embed the primitives to a MaskPrimitive for cropping. This works
+            // only in this case where the graphic object cannot be rotated, though.
+            const drawinglayer::geometry::ViewInformation2D aViewInformation2D(
+                aMappingTransform,
+                rOutputDevice.GetViewTransformation(),
+                aTargetRange,
+                0,
+                0.0,
+                uno::Sequence< beans::PropertyValue >());
+
+            // get a primitive processor for rendering
+            drawinglayer::processor2d::BaseProcessor2D* pProcessor2D =
+                drawinglayer::processor2d::createBaseProcessor2DFromOutputDevice(
+                                                rOutputDevice, aViewInformation2D);
+
+            if(pProcessor2D)
+            {
+                // render and cleanup
+                pProcessor2D->process(rSequence);
+                delete pProcessor2D;
+                return true;
+            }
+        }
+    }
+
+    return false;
+}
+
+// Paint the graphic.
+// We require either a QuickDraw-Bitmap or a graphic here. If we do not have
+// either, we return a replacement.
+// delete unused 3rd parameter.
+// use aligned rectangle for drawing graphic.
+// pixel-align coordinations for drawing graphic.
 void SwNoTxtFrm::PaintPicture( OutputDevice* pOut, const SwRect &rGrfArea ) const
 {
     ViewShell* pShell = getRootFrm()->GetCurrShell();
@@ -788,27 +873,27 @@ void SwNoTxtFrm::PaintPicture( OutputDevice* pOut, const SwRect &rGrfArea ) cons
     const sal_Bool bPrn = pOut == rNoTNd.getIDocumentDeviceAccess()->getPrinter( false ) ||
                           pOut->GetConnectMetaFile();
 
-    const bool bIsChart = pOLENd && ChartPrettyPainter::IsChart( pOLENd->GetOLEObj().GetObject() );
+    const bool bIsChart = pOLENd && ChartHelper::IsChart( pOLENd->GetOLEObj().GetObject() );
 
-    /// calculate aligned rectangle from parameter <rGrfArea>.
-    ///     Use aligned rectangle <aAlignedGrfArea> instead of <rGrfArea> in
-    ///     the following code.
+    // calculate aligned rectangle from parameter <rGrfArea>.
+    //     Use aligned rectangle <aAlignedGrfArea> instead of <rGrfArea> in
+    //     the following code.
     SwRect aAlignedGrfArea = rGrfArea;
     ::SwAlignRect( aAlignedGrfArea,  pShell );
 
     if( !bIsChart )
     {
-        /// Because for drawing a graphic left-top-corner and size coordinations are
-        /// used, these coordinations have to be determined on pixel level.
+        // Because for drawing a graphic left-top-corner and size coordinations are
+        // used, these coordinations have to be determined on pixel level.
         ::SwAlignGrfRect( &aAlignedGrfArea, *pOut );
     }
     else //if( bIsChart )
     {
-        //#i78025# charts own borders are not completely visible
-        //the above pixel correction is not correct - at least not for charts
-        //so a different pixel correction is choosen here
-        //this might be a good idea for all other OLE objects also,
-        //but as I cannot oversee the consequences I fix it only for charts for now
+        // #i78025# charts own borders are not completely visible
+        // the above pixel correction is not correct - at least not for charts
+        // so a different pixel correction is chosen here
+        // this might be a good idea for all other OLE objects also,
+        // but as I cannot oversee the consequences I fix it only for charts for now
         lcl_correctlyAlignRect( aAlignedGrfArea, rGrfArea, pOut );
     }
 
@@ -821,7 +906,7 @@ void SwNoTxtFrm::PaintPicture( OutputDevice* pOut, const SwRect &rGrfArea ) cons
             pOut->SetAntialiasing( nFormerAntialiasingAtOutput | ANTIALIASING_ENABLE_B2DDRAW );
         }
 
-        sal_Bool bForceSwap = sal_False, bContinue = sal_True;
+        bool bForceSwap = false, bContinue = true;
         GraphicObject& rGrfObj = pGrfNd->GetGrfObj();
 
         GraphicAttr aGrfAttr;
@@ -836,7 +921,6 @@ void SwNoTxtFrm::PaintPicture( OutputDevice* pOut, const SwRect &rGrfArea ) cons
             }
             // #i85717#, #i90395# - check, if asynchronous retrieval
             // if input stream for the graphic is possible
-//            else if( GRAPHIC_DEFAULT == rGrfObj.GetType() &&
             else if ( ( rGrfObj.GetType() == GRAPHIC_DEFAULT ||
                         rGrfObj.GetType() == GRAPHIC_NONE ) &&
                       pGrfNd->IsLinkedFile() &&
@@ -854,8 +938,8 @@ void SwNoTxtFrm::PaintPicture( OutputDevice* pOut, const SwRect &rGrfArea ) cons
                 String aTxt( pGrfNd->GetTitle() );
                 if ( !aTxt.Len() )
                     GetRealURL( *pGrfNd, aTxt );
-                ::lcl_PaintReplacement( aAlignedGrfArea, aTxt, *pShell, this, sal_False );
-                bContinue = sal_False;
+                ::lcl_PaintReplacement( aAlignedGrfArea, aTxt, *pShell, this, false );
+                bContinue = false;
             }
             else if( rGrfObj.IsCached( pOut, aAlignedGrfArea.Pos(),
                                     aAlignedGrfArea.SSize(), &aGrfAttr ))
@@ -863,17 +947,17 @@ void SwNoTxtFrm::PaintPicture( OutputDevice* pOut, const SwRect &rGrfArea ) cons
                 rGrfObj.DrawWithPDFHandling( *pOut,
                                              aAlignedGrfArea.Pos(), aAlignedGrfArea.SSize(),
                                              &aGrfAttr );
-                bContinue = sal_False;
+                bContinue = false;
             }
         }
 
         if( bContinue )
         {
             const sal_Bool bSwapped = rGrfObj.IsSwappedOut();
-            const sal_Bool bSwappedIn = 0 != pGrfNd->SwapIn( bPrn );
+            const bool bSwappedIn = 0 != pGrfNd->SwapIn( bPrn );
             if( bSwappedIn && rGrfObj.GetGraphic().IsSupportedGraphic())
             {
-                const sal_Bool bAnimate = rGrfObj.IsAnimated() &&
+                const bool bAnimate = rGrfObj.IsAnimated() &&
                                          !pShell->IsPreView() &&
                                          !pShell->GetAccessibilityOptions()->IsStopAnimatedGraphics() &&
                 // #i9684# Stop animation during printing/pdf export
@@ -893,16 +977,44 @@ void SwNoTxtFrm::PaintPicture( OutputDevice* pOut, const SwRect &rGrfArea ) cons
 
                     OSL_ENSURE( OUTDEV_VIRDEV != pOut->GetOutDevType() ||
                             pShell->GetViewOptions()->IsPDFExport(),
-                            "pOut sollte kein virtuelles Device sein" );
+                            "pOut should not be a virtual device" );
 
                     rGrfObj.StartAnimation( pOut, aAlignedGrfArea.Pos(),
                                         aAlignedGrfArea.SSize(), long(this),
                                         0, GRFMGR_DRAW_STANDARD, pVout );
                 }
                 else
-                    rGrfObj.DrawWithPDFHandling( *pOut,
-                                                 aAlignedGrfArea.Pos(), aAlignedGrfArea.SSize(),
-                                                 &aGrfAttr );
+                {
+                    const SvgDataPtr& rSvgDataPtr = rGrfObj.GetGraphic().getSvgData();
+                    bool bDone(false);
+
+                    if(rSvgDataPtr.get())
+                    {
+                        // Graphic is Svg and can be painted as primitives (vector graphic)
+                        const basegfx::B2DRange aTargetRange(
+                            aAlignedGrfArea.Left(), aAlignedGrfArea.Top(),
+                            aAlignedGrfArea.Right(), aAlignedGrfArea.Bottom());
+                        const bool bCropped(aGrfAttr.IsCropped());
+
+                        bDone = paintUsingPrimitivesHelper(
+                            *pOut,
+                            rSvgDataPtr->getPrimitive2DSequence(),
+                            rSvgDataPtr->getRange(),
+                            aTargetRange,
+                            bCropped ? aGrfAttr.GetLeftCrop() : 0,
+                            bCropped ? aGrfAttr.GetTopCrop() : 0,
+                            bCropped ? aGrfAttr.GetRightCrop() : 0,
+                            bCropped ? aGrfAttr.GetBottomCrop() : 0,
+                            aGrfAttr.GetMirrorFlags() & BMP_MIRROR_HORZ,
+                            aGrfAttr.GetMirrorFlags() & BMP_MIRROR_VERT);
+                    }
+
+                    if(!bDone)
+                    {
+                        // fallback paint, uses replacement image
+                        rGrfObj.DrawWithPDFHandling(*pOut, aAlignedGrfArea.Pos(), aAlignedGrfArea.SSize(), &aGrfAttr);
+                    }
+                }
             }
             else
             {
@@ -925,12 +1037,12 @@ void SwNoTxtFrm::PaintPicture( OutputDevice* pOut, const SwRect &rGrfArea ) cons
                 if ( nResId )
                     aText = SW_RESSTR( nResId );
 
-                ::lcl_PaintReplacement( aAlignedGrfArea, aText, *pShell, this, sal_True );
+                ::lcl_PaintReplacement( aAlignedGrfArea, aText, *pShell, this, true );
             }
 
-            //Beim Drucken duerfen wir nicht die Grafiken sammeln...
+            // When printing, we must not collect the graphics
             if( bSwapped && bPrn )
-                bForceSwap = sal_True;
+                bForceSwap = true;
         }
 
         if( bForceSwap )
@@ -939,16 +1051,7 @@ void SwNoTxtFrm::PaintPicture( OutputDevice* pOut, const SwRect &rGrfArea ) cons
         if ( pShell->Imp()->GetDrawView()->IsAntiAliasing() )
             pOut->SetAntialiasing( nFormerAntialiasingAtOutput );
     }
-    else if( bIsChart
-        //charts must be painted resolution dependent!! #i82893#, #i75867#
-        && ChartPrettyPainter::ShouldPrettyPaintChartOnThisDevice( pOut )
-        && svt::EmbeddedObjectRef::TryRunningState( pOLENd->GetOLEObj().GetOleRef() )
-        && ChartPrettyPainter::DoPrettyPaintChart( uno::Reference< frame::XModel >(
-            pOLENd->GetOLEObj().GetOleRef()->getComponent(), uno::UNO_QUERY), pOut, aAlignedGrfArea.SVRect() ) )
-    {
-        (void)(0);//all was done in if statement
-    }
-    else if( pOLENd )
+    else // bIsChart || pOLENd
     {
         // Fix for bug fdo#33781
         const sal_uInt16 nFormerAntialiasingAtOutput( pOut->GetAntialiasing() );
@@ -964,50 +1067,87 @@ void SwNoTxtFrm::PaintPicture( OutputDevice* pOut, const SwRect &rGrfArea ) cons
             pOut->SetAntialiasing( nNewAntialiasingAtOutput );
         }
 
-        Point aPosition(aAlignedGrfArea.Pos());
-        Size aSize(aAlignedGrfArea.SSize());
+        bool bDone(false);
 
-        // Im BrowseModus gibt es nicht unbedingt einen Drucker und
-        // damit kein JobSetup, also legen wir eines an ...
-        const JobSetup* pJobSetup = pOLENd->getIDocumentDeviceAccess()->getJobsetup();
-        sal_Bool bDummyJobSetup = 0 == pJobSetup;
-        if( bDummyJobSetup )
-            pJobSetup = new JobSetup();
-
-        // #i42323#
-        //TODO/LATER: is it a problem that the JopSetup isn't used?
-        //xRef->DoDraw( pOut, aAlignedGrfArea.Pos(), aAlignedGrfArea.SSize(), *pJobSetup );
-
-        Graphic* pGraphic = pOLENd->GetGraphic();
-
-        if ( pGraphic && pGraphic->GetType() != GRAPHIC_NONE )
+        if(bIsChart)
         {
-            pGraphic->Draw( pOut, aPosition, aSize );
+            const uno::Reference< frame::XModel > aXModel(pOLENd->GetOLEObj().GetOleRef()->getComponent(), uno::UNO_QUERY);
 
-            // shade the representation if the object is activated outplace
-            uno::Reference < embed::XEmbeddedObject > xObj = pOLENd->GetOLEObj().GetOleRef();
-            if ( xObj.is() && xObj->getCurrentState() == embed::EmbedStates::ACTIVE )
+            if(aXModel.is())
             {
-                ::svt::EmbeddedObjectRef::DrawShading( Rectangle( aPosition, aSize ), pOut );
+                basegfx::B2DRange aSourceRange;
+
+                const drawinglayer::primitive2d::Primitive2DSequence aSequence(
+                    ChartHelper::tryToGetChartContentAsPrimitive2DSequence(
+                        aXModel,
+                        aSourceRange));
+
+                if(aSequence.hasElements() && !aSourceRange.isEmpty())
+                {
+                    const basegfx::B2DRange aTargetRange(
+                        aAlignedGrfArea.Left(), aAlignedGrfArea.Top(),
+                        aAlignedGrfArea.Right(), aAlignedGrfArea.Bottom());
+
+                    bDone = paintUsingPrimitivesHelper(
+                        *pOut,
+                        aSequence,
+                        aSourceRange,
+                        aTargetRange);
+                }
             }
         }
-        else
-            ::svt::EmbeddedObjectRef::DrawPaintReplacement( Rectangle( aPosition, aSize ), pOLENd->GetOLEObj().GetCurrentPersistName(), pOut );
 
-        if( bDummyJobSetup )
-            delete pJobSetup;  // ... und raeumen wieder auf.
-
-        sal_Int64 nMiscStatus = pOLENd->GetOLEObj().GetOleRef()->getStatus( pOLENd->GetAspect() );
-        if ( !bPrn && pShell->ISA( SwCrsrShell ) &&
-                nMiscStatus & embed::EmbedMisc::MS_EMBED_ACTIVATEWHENVISIBLE )
+        if(!bDone && pOLENd)
         {
-            const SwFlyFrm *pFly = FindFlyFrm();
-            OSL_ENSURE( pFly, "OLE not in FlyFrm" );
-            ((SwFEShell*)pShell)->ConnectObj( pOLENd->GetOLEObj().GetObject(), pFly->Prt(), pFly->Frm());
+            Point aPosition(aAlignedGrfArea.Pos());
+            Size aSize(aAlignedGrfArea.SSize());
+
+            // Im BrowseModus gibt es nicht unbedingt einen Drucker und
+            // damit kein JobSetup, also legen wir eines an ...
+            const JobSetup* pJobSetup = pOLENd->getIDocumentDeviceAccess()->getJobsetup();
+            sal_Bool bDummyJobSetup = 0 == pJobSetup;
+            if( bDummyJobSetup )
+                pJobSetup = new JobSetup();
+
+            // #i42323#
+            // The reason for #114233# is gone, so i remove it again
+            //TODO/LATER: is it a problem that the JobSetup isn't used?
+            //xRef->DoDraw( pOut, aAlignedGrfArea.Pos(), aAlignedGrfArea.SSize(), *pJobSetup );
+
+            Graphic* pGraphic = pOLENd->GetGraphic();
+            if ( pGraphic && pGraphic->GetType() != GRAPHIC_NONE )
+            {
+                pGraphic->Draw( pOut, aPosition, aSize );
+
+                // shade the representation if the object is activated outplace
+                uno::Reference < embed::XEmbeddedObject > xObj = pOLENd->GetOLEObj().GetOleRef();
+                if ( xObj.is() && xObj->getCurrentState() == embed::EmbedStates::ACTIVE )
+                {
+                    ::svt::EmbeddedObjectRef::DrawShading( Rectangle( aPosition, aSize ), pOut );
+                }
+            }
+            else
+                ::svt::EmbeddedObjectRef::DrawPaintReplacement( Rectangle( aPosition, aSize ), pOLENd->GetOLEObj().GetCurrentPersistName(), pOut );
+
+            if( bDummyJobSetup )
+                delete pJobSetup;
+
+            sal_Int64 nMiscStatus = pOLENd->GetOLEObj().GetOleRef()->getStatus( pOLENd->GetAspect() );
+            if ( !bPrn && pShell->ISA( SwCrsrShell ) &&
+                    nMiscStatus & embed::EmbedMisc::MS_EMBED_ACTIVATEWHENVISIBLE )
+            {
+                const SwFlyFrm *pFly = FindFlyFrm();
+                assert( pFly != NULL );
+                ((SwFEShell*)pShell)->ConnectObj( pOLENd->GetOLEObj().GetObject(), pFly->Prt(), pFly->Frm());
+            }
         }
 
-        if ( pShell->Imp()->GetDrawView()->IsAntiAliasing() )
+        // see #i99665#
+        if ( pOLENd->IsChart() &&
+                pShell->Imp()->GetDrawView()->IsAntiAliasing() )
+        {
             pOut->SetAntialiasing( nFormerAntialiasingAtOutput );
+        }
     }
 }
 
@@ -1022,14 +1162,14 @@ sal_Bool SwNoTxtFrm::IsTransparent() const
     if( 0 != (pNd = GetNode()->GetGrfNode()) )
         return pNd->IsTransparent();
 
-    //#29381# OLE sind immer Transparent.
+    //#29381# OLE are always transparent
     return sal_True;
 }
 
 
 void SwNoTxtFrm::StopAnimation( OutputDevice* pOut ) const
 {
-    //animierte Grafiken anhalten
+    // Stop animated graphics
     SwGrfNode* pGrfNd = (SwGrfNode*)GetNode()->GetGrfNode();
     if( pGrfNd && pGrfNd->IsAnimated() )
         pGrfNd->GetGrfObj().StopAnimation( pOut, long(this) );
