@@ -1,32 +1,21 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
-
-
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 #include <hintids.hxx>
 
@@ -296,8 +285,8 @@ void SwNumFmt::SetCharFmt( SwCharFmt* pChFmt)
 
 void SwNumFmt::Modify( const SfxPoolItem* pOld, const SfxPoolItem* pNew )
 {
-    // dann suche mal in dem Doc nach dem NumRules-Object, in dem dieses
-    // NumFormat gesetzt ist. Das Format muss es nicht geben!
+    // Look for the NumRules object in the Doc where this NumFormat is set.
+    // The format does not need to exist!
     const SwCharFmt* pFmt = 0;
     sal_uInt16 nWhich = pOld ? pOld->Which() : pNew ? pNew->Which() : 0;
     switch( nWhich )
@@ -355,9 +344,9 @@ sal_Int16   SwNumFmt::GetVertOrient() const
 void SwNumFmt::UpdateNumNodes( SwDoc* pDoc )
 {
     sal_Bool bDocIsModified = pDoc->IsModified();
-    sal_Bool bFnd = sal_False;
+    bool bFnd = false;
     const SwNumRule* pRule;
-    for( sal_uInt16 n = pDoc->GetNumRuleTbl().Count(); !bFnd && n; )
+    for( sal_uInt16 n = pDoc->GetNumRuleTbl().size(); !bFnd && n; )
     {
         pRule = pDoc->GetNumRuleTbl()[ --n ];
         for( sal_uInt8 i = 0; i < MAXLEVEL; ++i )
@@ -370,7 +359,7 @@ void SwNumFmt::UpdateNumNodes( SwDoc* pDoc )
                 {
                     lcl_SetRuleChgd( *(*aIter), i );
                 }
-                bFnd = sal_True;
+                bFnd = true;
                 break;
             }
     }
@@ -409,11 +398,12 @@ SwNumRule::SwNumRule( const String& rNm,
     bInvalidRuleFlag( sal_True ),
     bContinusNum( sal_False ),
     bAbsSpaces( sal_False ),
+    bHidden( sal_False ),
     mbCountPhantoms( true ),
     meDefaultNumberFormatPositionAndSpaceMode( eDefaultNumberFormatPositionAndSpaceMode ),
     msDefaultListId()
 {
-    if( !nRefCount++ )          // zum erstmal, also initialisiern
+    if( !nRefCount++ )          // for the first time, initialize
     {
         SwNumFmt* pFmt;
         sal_uInt8 n;
@@ -491,7 +481,7 @@ SwNumRule::SwNumRule( const String& rNm,
         }
     }
     memset( aFmts, 0, sizeof( aFmts ));
-    OSL_ENSURE( sName.Len(), "NumRule ohne Namen!" );
+    OSL_ENSURE( sName.Len(), "NumRule without a name!" );
 }
 
 SwNumRule::SwNumRule( const SwNumRule& rNumRule )
@@ -507,6 +497,7 @@ SwNumRule::SwNumRule( const SwNumRule& rNumRule )
       bInvalidRuleFlag( sal_True ),
       bContinusNum( rNumRule.bContinusNum ),
       bAbsSpaces( rNumRule.bAbsSpaces ),
+      bHidden( rNumRule.bHidden ),
       mbCountPhantoms( true ),
       meDefaultNumberFormatPositionAndSpaceMode( rNumRule.meDefaultNumberFormatPositionAndSpaceMode ),
       msDefaultListId( rNumRule.msDefaultListId )
@@ -528,16 +519,16 @@ SwNumRule::~SwNumRule()
         pNumRuleMap->erase(GetName());
     }
 
-    if( !--nRefCount )          // der letzte macht die Tuer zu
+    if( !--nRefCount )          // the last one closes the door (?)
     {
-            // Nummerierung:
+            // Numbering:
             SwNumFmt** ppFmts = (SwNumFmt**)SwNumRule::aBaseFmts;
             int n;
 
             for( n = 0; n < MAXLEVEL; ++n, ++ppFmts )
                 delete *ppFmts, *ppFmts = 0;
 
-            // Gliederung:
+            // Outline:
             for( n = 0; n < MAXLEVEL; ++n, ++ppFmts )
                 delete *ppFmts, *ppFmts = 0;
 
@@ -559,7 +550,7 @@ void SwNumRule::CheckCharFmts( SwDoc* pDoc )
         if( aFmts[ n ] && 0 != ( pFmt = aFmts[ n ]->GetCharFmt() ) &&
             pFmt->GetDoc() != pDoc )
         {
-            // dann kopieren!
+            // copy
             SwNumFmt* pNew = new SwNumFmt( *aFmts[ n ] );
             pNew->SetCharFmt( pDoc->CopyCharFmt( *pFmt ) );
             delete aFmts[ n ];
@@ -580,6 +571,7 @@ SwNumRule& SwNumRule::operator=( const SwNumRule& rNumRule )
         bInvalidRuleFlag = sal_True;
         bContinusNum = rNumRule.bContinusNum;
         bAbsSpaces = rNumRule.bAbsSpaces;
+        bHidden = rNumRule.bHidden;
         nPoolFmtId = rNumRule.GetPoolFmtId();
         nPoolHelpId = rNumRule.GetPoolHelpId();
         nPoolHlpFileId = rNumRule.GetPoolHlpFileId();
@@ -683,7 +675,7 @@ String SwNumRule::MakeNumString( const SwNumberTree::tNumberVector & rNumVector,
             if( !IsContinusNum() &&
                 // - do not include upper levels, if level isn't numbered.
                 rMyNFmt.GetNumberingType() != SVX_NUM_NUMBER_NONE &&
-                rMyNFmt.GetIncludeUpperLevels() )  // nur der eigene Level ?
+                rMyNFmt.GetIncludeUpperLevels() )  // Just the own level?
             {
                 sal_uInt8 n = rMyNFmt.GetIncludeUpperLevels();
                 if( 1 < n )
@@ -700,7 +692,7 @@ String SwNumRule::MakeNumString( const SwNumberTree::tNumberVector & rNumVector,
                 const SwNumFmt& rNFmt = Get( i );
                 if( SVX_NUM_NUMBER_NONE == rNFmt.GetNumberingType() )
                 {
-                    // Soll aus 1.1.1 --> 2. NoNum --> 1..1 oder 1.1 ??
+                    // Should 1.1.1 --> 2. NoNum --> 1..1 or 1.1 ??
                     //                 if( i != rNum.nMyLevel )
                     //                    aStr += aDotStr;
                     continue;
@@ -714,13 +706,13 @@ String SwNumRule::MakeNumString( const SwNumberTree::tNumberVector & rNumVector,
                         aStr += rNFmt.GetNumStr( rNumVector[ i ] );
                 }
                 else
-                    aStr += '0';        // alle 0-Level sind eine 0
+                    aStr += '0';        // all 0 level are a 0
                 if( i != nLevel && aStr.Len() )
                     aStr += aDotStr;
             }
 
-            //JP 14.12.99: the type dont have any number, so dont append
-            //              the Post-/Prefix String
+            // The type doesn't have any number, so don't append
+            // the post-/prefix string
             if( bInclStrings && !bOnlyArabic &&
                 SVX_NUM_CHAR_SPECIAL != rMyNFmt.GetNumberingType() &&
                 SVX_NUM_BITMAP != rMyNFmt.GetNumberingType() )
@@ -751,7 +743,9 @@ String SwNumRule::MakeRefNumString( const SwNodeNum& rNodeNum,
 
     if ( rNodeNum.GetLevelInListTree() >= 0 )
     {
-        sal_Bool bOldHadPrefix = sal_True;
+        bool bOldHadPrefix = true;
+        bool bFirstIteration = true;
+        ::rtl::OUString sOldPrefix;
 
         const SwNodeNum* pWorkingNodeNum( &rNodeNum );
         do
@@ -773,7 +767,6 @@ String SwNumRule::MakeRefNumString( const SwNodeNum& rNodeNum,
                 String aPrevStr = MakeNumString( pWorkingNodeNum->GetNumberVector(),
                                                  sal_True, sal_False, MAXLEVEL,
                                                  &aExtremities);
-                int        nLen = aPrevStr.Len();
                 int        nStrip = 0;
                 sal_Unicode        c;
 
@@ -787,26 +780,43 @@ String SwNumRule::MakeRefNumString( const SwNodeNum& rNodeNum,
 
                 if (nStrip)
                 {
-                        aPrevStr.Erase( 0, nStrip );
-                        aExtremities.nPrefixChars -= nStrip;
-                        nLen -= nStrip;
+                    aPrevStr.Erase( 0, nStrip );
+                    aExtremities.nPrefixChars -= nStrip;
                 }
 
-                if ( bOldHadPrefix &&
+                if ((bFirstIteration || bOldHadPrefix) &&
                      aExtremities.nSuffixChars &&
                      !aExtremities.nPrefixChars
                    )
                 {
-                        aPrevStr.Erase( nLen - aExtremities.nSuffixChars, aExtremities.nSuffixChars );
+                    int nStrip2 = aPrevStr.Len();
+                    while (aPrevStr.Len() - nStrip2 < aExtremities.nSuffixChars)
+                    {
+                        char const cur = aPrevStr.GetChar(nStrip2);
+                        if  (!bFirstIteration && '\t' != cur && ' ' != cur)
+                        {
+                            break;
+                        }
+                        --nStrip2;
+                    }
+                    if (nStrip2 < aPrevStr.Len())
+                    {
+                        aPrevStr.Erase(nStrip2, aPrevStr.Len() - nStrip2);
+                    }
                 }
+                else if (sOldPrefix.getLength())
+                {
+                    aRefNumStr.Insert(sOldPrefix, 0);
+                }
+                sOldPrefix = ::rtl::OUString();
+
                 bOldHadPrefix = ( aExtremities.nPrefixChars >  0);
 
                 aRefNumStr.Insert( aPrevStr, 0 );
-
             }
             else if ( aRefNumStr.Len() > 0 )
             {
-                aRefNumStr.Insert( String::CreateFromAscii(" "), 0 );
+                sOldPrefix += " ";
                 bOldHadPrefix = true;
             }
 
@@ -825,6 +835,7 @@ String SwNumRule::MakeRefNumString( const SwNodeNum& rNodeNum,
             {
                 break;
             }
+            bFirstIteration = false;
         } while ( pWorkingNodeNum &&
                   pWorkingNodeNum->GetLevelInListTree() >= 0 &&
                   static_cast<sal_uInt8>(pWorkingNodeNum->GetLevelInListTree()) >= nRestrictInclToThisLevel );
@@ -833,21 +844,20 @@ String SwNumRule::MakeRefNumString( const SwNodeNum& rNodeNum,
     return aRefNumStr;
 }
 
-//  ----- Copy-Methode vom SwNumRule ------
+//  ----- Copy method of SwNumRule ------
 
-    // eine Art Copy-Constructor, damit die Num-Formate auch an den
-    // richtigen CharFormaten eines Dokumentes haengen !!
-    // (Kopiert die NumFormate und returnt sich selbst)
+    // A kind of copy constructor, so that the num formats are attached
+    // to the right CharFormats of a Document.
+    // Copies the NumFormats and returns itself.
 SwNumRule& SwNumRule::CopyNumRule( SwDoc* pDoc, const SwNumRule& rNumRule )
 {
     for( sal_uInt16 n = 0; n < MAXLEVEL; ++n )
     {
         Set( n, rNumRule.aFmts[ n ] );
         if( aFmts[ n ] && aFmts[ n ]->GetCharFmt() &&
-            USHRT_MAX == pDoc->GetCharFmts()->GetPos( aFmts[n]->GetCharFmt() ))
-            // ueber unterschiedliche Dokumente kopieren, dann
-            // kopiere das entsprechende Char-Format ins neue
-            // Dokument.
+            !pDoc->GetCharFmts()->Contains( aFmts[n]->GetCharFmt() ))
+            // If we copy across different Documents, then copy the
+            // corresponding CharFormat into the new Document.
             aFmts[n]->SetCharFmt( pDoc->CopyCharFmt( *aFmts[n]->
                                         GetCharFmt() ) );
     }
@@ -1177,7 +1187,7 @@ namespace numfunc
     SwDefBulletConfig::SwDefBulletConfig()
         : ConfigItem( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Office.Writer/Numbering/DefaultBulletList")) ),
           // default bullet font is now OpenSymbol
-          msFontname( String::CreateFromAscii("OpenSymbol") ),
+          msFontname( rtl::OUString("OpenSymbol") ),
           mbUserDefinedFontname( false ),
           meFontWeight( WEIGHT_DONTKNOW ),
           meFontItalic( ITALIC_NONE ),
@@ -1198,7 +1208,7 @@ namespace numfunc
 
     void SwDefBulletConfig::SetToDefault()
     {
-        msFontname = String::CreateFromAscii("OpenSymbol");
+        msFontname = rtl::OUString("OpenSymbol");
         mbUserDefinedFontname = false;
         meFontWeight = WEIGHT_DONTKNOW;
         meFontItalic = ITALIC_NONE;
