@@ -1,39 +1,24 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
-
-
-#define _SVSTDARR_STRINGSDTOR
-#define _SVSTDARR_USHORTS
-#define _SVSTDARR_ULONGS
 #include <hintids.hxx>
-
-#include <svl/svstdarr.hxx>
+#include <comphelper/string.hxx>
 #include <editeng/unolingu.hxx>
 #include <editeng/langitem.hxx>
 #include <swtypes.hxx>
@@ -61,15 +46,6 @@ using namespace ::com::sun::star::lang;
 using rtl::OUString;
 
 
-typedef SwAuthEntry* SwAuthEntryPtr;
-SV_DECL_PTRARR_DEL( SwAuthDataArr, SwAuthEntryPtr, 5, 5 )
-SV_IMPL_PTRARR( SwAuthDataArr, SwAuthEntryPtr )
-
-
-typedef SwTOXSortKey* TOXSortKeyPtr;
-SV_DECL_PTRARR_DEL( SortKeyArr, TOXSortKeyPtr, 5, 5 )
-SV_IMPL_PTRARR( SortKeyArr, TOXSortKeyPtr )
-
 SwAuthEntry::SwAuthEntry(const SwAuthEntry& rCopy)
     : nRefCount(0)
 {
@@ -88,37 +64,18 @@ sal_Bool    SwAuthEntry::operator==(const SwAuthEntry& rComp)
 SwAuthorityFieldType::SwAuthorityFieldType(SwDoc* pDoc)
     : SwFieldType( RES_AUTHORITY ),
     m_pDoc(pDoc),
-    m_pDataArr(new SwAuthDataArr ),
-    m_pSortKeyArr(new SortKeyArr(3, 3)),
+    m_DataArr(),
+    m_SortKeyArr(3),
     m_cPrefix('['),
     m_cSuffix(']'),
     m_bIsSequence(sal_False),
     m_bSortByDocument(sal_True),
-    m_eLanguage((LanguageType)::GetAppLanguage())
+    m_eLanguage(::GetAppLanguage())
 {
 }
 
-SwAuthorityFieldType::SwAuthorityFieldType( const SwAuthorityFieldType& rFType)
-    : SwFieldType( RES_AUTHORITY ),
-    m_pDataArr(new SwAuthDataArr ),
-    m_pSortKeyArr(new SortKeyArr(3, 3)),
-    m_cPrefix(rFType.m_cPrefix),
-    m_cSuffix(rFType.m_cSuffix),
-    m_bIsSequence(rFType.m_bIsSequence),
-    m_bSortByDocument(rFType.m_bSortByDocument),
-    m_eLanguage(rFType.m_eLanguage),
-    m_sSortAlgorithm(rFType.m_sSortAlgorithm)
-{
-    for(sal_uInt16 i = 0; i < rFType.m_pSortKeyArr->Count(); i++)
-        m_pSortKeyArr->Insert((*rFType.m_pSortKeyArr)[i], i);
-}
-
 SwAuthorityFieldType::~SwAuthorityFieldType()
 {
-    m_pSortKeyArr->DeleteAndDestroy(0, m_pSortKeyArr->Count());
-    delete m_pSortKeyArr;
-    m_SequArr.clear();
-    delete m_pDataArr;
 }
 
 SwFieldType*    SwAuthorityFieldType::Copy()  const
@@ -129,21 +86,21 @@ SwFieldType*    SwAuthorityFieldType::Copy()  const
 void    SwAuthorityFieldType::RemoveField(long nHandle)
 {
 #if OSL_DEBUG_LEVEL > 0
-    sal_Bool bRemoved = sal_False;
+    bool bRemoved = false;
 #endif
-    for(sal_uInt16 j = 0; j < m_pDataArr->Count(); j++)
+    for(sal_uInt16 j = 0; j < m_DataArr.size(); j++)
     {
-        SwAuthEntry* pTemp = m_pDataArr->GetObject(j);
+        SwAuthEntry* pTemp = &m_DataArr[j];
         long nRet = (long)(void*)pTemp;
         if(nRet == nHandle)
         {
 #if OSL_DEBUG_LEVEL > 0
-            bRemoved = sal_True;
+            bRemoved = true;
 #endif
             pTemp->RemoveRef();
             if(!pTemp->GetRefCount())
             {
-                m_pDataArr->DeleteAndDestroy(j, 1);
+                m_DataArr.erase(m_DataArr.begin() + j);
                 //re-generate positions of the fields
                 DelSequenceArray();
             }
@@ -163,9 +120,9 @@ long    SwAuthorityFieldType::AddField(const String& rFieldContents)
         pEntry->SetAuthorField( (ToxAuthorityField)i,
                         rFieldContents.GetToken( i, TOX_STYLE_DELIMITER ));
 
-    for(sal_uInt16 j = 0; j < m_pDataArr->Count() && pEntry; j++)
+    for(sal_uInt16 j = 0; j < m_DataArr.size() && pEntry; j++)
     {
-        SwAuthEntry* pTemp = m_pDataArr->GetObject(j);
+        SwAuthEntry* pTemp = &m_DataArr[j];
         if(*pTemp == *pEntry)
         {
             DELETEZ(pEntry);
@@ -178,7 +135,7 @@ long    SwAuthorityFieldType::AddField(const String& rFieldContents)
     {
         nRet = (long)(void*)pEntry;
         pEntry->AddRef();
-        m_pDataArr->Insert(pEntry, m_pDataArr->Count());
+        m_DataArr.push_back(pEntry);
         //re-generate positions of the fields
         DelSequenceArray();
     }
@@ -188,9 +145,9 @@ long    SwAuthorityFieldType::AddField(const String& rFieldContents)
 sal_Bool SwAuthorityFieldType::AddField(long nHandle)
 {
     sal_Bool bRet = sal_False;
-    for( sal_uInt16 j = 0; j < m_pDataArr->Count(); j++ )
+    for( sal_uInt16 j = 0; j < m_DataArr.size(); j++ )
     {
-        SwAuthEntry* pTemp = m_pDataArr->GetObject(j);
+        SwAuthEntry* pTemp = &m_DataArr[j];
         long nTmp = (long)(void*)pTemp;
         if( nTmp == nHandle )
         {
@@ -208,9 +165,9 @@ sal_Bool SwAuthorityFieldType::AddField(long nHandle)
 const SwAuthEntry*  SwAuthorityFieldType::GetEntryByHandle(long nHandle) const
 {
     const SwAuthEntry* pRet = 0;
-    for(sal_uInt16 j = 0; j < m_pDataArr->Count(); j++)
+    for(sal_uInt16 j = 0; j < m_DataArr.size(); j++)
     {
-        const SwAuthEntry* pTemp = m_pDataArr->GetObject(j);
+        const SwAuthEntry* pTemp = &m_DataArr[j];
         long nTmp = (long)(void*)pTemp;
         if( nTmp == nHandle )
         {
@@ -223,13 +180,12 @@ const SwAuthEntry*  SwAuthorityFieldType::GetEntryByHandle(long nHandle) const
 }
 
 void SwAuthorityFieldType::GetAllEntryIdentifiers(
-                SvStringsDtor& rToFill )const
+    std::vector<String>& rToFill )const
 {
-    for(sal_uInt16 j = 0; j < m_pDataArr->Count(); j++)
+    for(sal_uInt16 j = 0; j < m_DataArr.size(); j++)
     {
-        SwAuthEntry* pTemp = m_pDataArr->GetObject(j);
-        rToFill.Insert( new String( pTemp->GetAuthorField(
-                    AUTH_FIELD_IDENTIFIER )), rToFill.Count() );
+        const SwAuthEntry* pTemp = &m_DataArr[j];
+        rToFill.push_back(pTemp->GetAuthorField(AUTH_FIELD_IDENTIFIER));
     }
 }
 
@@ -237,9 +193,9 @@ const SwAuthEntry*  SwAuthorityFieldType::GetEntryByIdentifier(
                                 const String& rIdentifier)const
 {
     const SwAuthEntry* pRet = 0;
-    for( sal_uInt16 j = 0; j < m_pDataArr->Count(); ++j )
+    for( sal_uInt16 j = 0; j < m_DataArr.size(); ++j )
     {
-        const SwAuthEntry* pTemp = m_pDataArr->GetObject(j);
+        const SwAuthEntry* pTemp = &m_DataArr[j];
         if( rIdentifier == pTemp->GetAuthorField( AUTH_FIELD_IDENTIFIER ))
         {
             pRet = pTemp;
@@ -252,9 +208,9 @@ const SwAuthEntry*  SwAuthorityFieldType::GetEntryByIdentifier(
 bool SwAuthorityFieldType::ChangeEntryContent(const SwAuthEntry* pNewEntry)
 {
     bool bChanged = false;
-    for( sal_uInt16 j = 0; j < m_pDataArr->Count(); ++j )
+    for( sal_uInt16 j = 0; j < m_DataArr.size(); ++j )
     {
-        SwAuthEntry* pTemp = m_pDataArr->GetObject(j);
+        SwAuthEntry* pTemp = &m_DataArr[j];
         if(pTemp->GetAuthorField(AUTH_FIELD_IDENTIFIER) ==
                     pNewEntry->GetAuthorField(AUTH_FIELD_IDENTIFIER))
         {
@@ -274,9 +230,9 @@ bool SwAuthorityFieldType::ChangeEntryContent(const SwAuthEntry* pNewEntry)
 sal_uInt16  SwAuthorityFieldType::AppendField( const SwAuthEntry& rInsert )
 {
     sal_uInt16 nRet = 0;
-    for( nRet = 0; nRet < m_pDataArr->Count(); ++nRet )
+    for( nRet = 0; nRet < m_DataArr.size(); ++nRet )
     {
-        SwAuthEntry* pTemp = m_pDataArr->GetObject( nRet );
+        SwAuthEntry* pTemp = &m_DataArr[ nRet ];
         if( *pTemp == rInsert )
         {
             break;
@@ -285,8 +241,8 @@ sal_uInt16  SwAuthorityFieldType::AppendField( const SwAuthEntry& rInsert )
     }
 
     //if it is a new Entry - insert
-    if( nRet == m_pDataArr->Count() )
-        m_pDataArr->Insert( new SwAuthEntry( rInsert ), nRet );
+    if( nRet == m_DataArr.size() )
+        m_DataArr.push_back( new SwAuthEntry( rInsert ) );
 
     return nRet;
 }
@@ -294,9 +250,9 @@ sal_uInt16  SwAuthorityFieldType::AppendField( const SwAuthEntry& rInsert )
 long    SwAuthorityFieldType::GetHandle(sal_uInt16 nPos)
 {
     long nRet = 0;
-    if( nPos < m_pDataArr->Count() )
+    if( nPos < m_DataArr.size() )
     {
-        SwAuthEntry* pTemp = m_pDataArr->GetObject(nPos);
+        SwAuthEntry* pTemp = &m_DataArr[nPos];
         nRet = (long)(void*)pTemp;
     }
     return nRet;
@@ -306,9 +262,9 @@ sal_uInt16  SwAuthorityFieldType::GetSequencePos(long nHandle)
 {
     //find the field in a sorted array of handles,
 #if OSL_DEBUG_LEVEL > 0
-    sal_Bool bCurrentFieldWithoutTextNode = sal_False;
+    bool bCurrentFieldWithoutTextNode = false;
 #endif
-    if(!m_SequArr.empty() && m_SequArr.size() != m_pDataArr->Count())
+    if(!m_SequArr.empty() && m_SequArr.size() != m_DataArr.size())
         DelSequenceArray();
     if(m_SequArr.empty())
     {
@@ -324,7 +280,7 @@ sal_uInt16  SwAuthorityFieldType::GetSequencePos(long nHandle)
             {
 #if OSL_DEBUG_LEVEL > 0
                 if(nHandle == ((SwAuthorityField*)pFmtFld->GetFld())->GetHandle())
-                    bCurrentFieldWithoutTextNode = sal_True;
+                    bCurrentFieldWithoutTextNode = true;
 #endif
                 continue;
             }
@@ -345,7 +301,7 @@ sal_uInt16  SwAuthorityFieldType::GetSequencePos(long nHandle)
                 SwTOXAuthority* pNew = new SwTOXAuthority( *pTxtNode,
                                                             *pFmtFld, aIntl );
 
-                for(short i = 0; i < aSortArr.Count(); ++i)
+                for(short i = 0; i < (short)aSortArr.size(); ++i)
                 {
                     SwTOXSortTabBase* pOld = aSortArr[i];
                     if(*pOld == *pNew)
@@ -355,7 +311,10 @@ sal_uInt16  SwAuthorityFieldType::GetSequencePos(long nHandle)
                         if(*pOld < *pNew)
                             DELETEZ(pNew);
                         else // remove the old content
-                            aSortArr.DeleteAndDestroy( i, 1 );
+                        {
+                            aSortArr.erase(aSortArr.begin() + i);
+                            delete pOld;
+                        }
                         break;
                     }
                 }
@@ -364,25 +323,27 @@ sal_uInt16  SwAuthorityFieldType::GetSequencePos(long nHandle)
                 {
                     short j;
 
-                    for( j = 0; j < aSortArr.Count(); ++j)
+                    for( j = 0; j < (short)aSortArr.size(); ++j)
                     {
                         SwTOXSortTabBase* pOld = aSortArr[j];
                         if(*pNew < *pOld)
                             break;
                     }
-                    aSortArr.Insert(pNew, j );
+                    aSortArr.insert(aSortArr.begin() + j, pNew);
                 }
             }
         }
 
-        for(sal_uInt16 i = 0; i < aSortArr.Count(); i++)
+        for(sal_uInt16 i = 0; i < aSortArr.size(); i++)
         {
             const SwTOXSortTabBase& rBase = *aSortArr[i];
             SwFmtFld& rFmtFld = ((SwTOXAuthority&)rBase).GetFldFmt();
             SwAuthorityField* pAFld = (SwAuthorityField*)rFmtFld.GetFld();
             m_SequArr.push_back(pAFld->GetHandle());
         }
-        aSortArr.DeleteAndDestroy(0, aSortArr.Count());
+        for (SwTOXSortTabBases::const_iterator it = aSortArr.begin(); it != aSortArr.end(); ++it)
+            delete *it;
+        aSortArr.clear();
     }
     //find nHandle
     sal_uInt16 nRet = 0;
@@ -427,18 +388,18 @@ bool SwAuthorityFieldType::QueryValue( Any& rVal, sal_uInt16 nWhichId ) const
         break;
 
     case FIELD_PROP_LOCALE:
-        rVal <<= SvxCreateLocale(GetLanguage());
+        rVal <<= LanguageTag(GetLanguage()).getLocale();
         break;
 
     case FIELD_PROP_PROP_SEQ:
         {
-            Sequence<PropertyValues> aRet(m_pSortKeyArr->Count());
+            Sequence<PropertyValues> aRet(m_SortKeyArr.size());
             PropertyValues* pValues = aRet.getArray();
             OUString sProp1( rtl::OUString::createFromAscii(SW_PROP_NAME_STR(UNO_NAME_SORT_KEY)) ),
                      sProp2( rtl::OUString::createFromAscii(SW_PROP_NAME_STR(UNO_NAME_IS_SORT_ASCENDING)));
-            for(sal_uInt16 i = 0; i < m_pSortKeyArr->Count(); i++)
+            for(sal_uInt16 i = 0; i < m_SortKeyArr.size(); i++)
             {
-                const SwTOXSortKey* pKey = (*m_pSortKeyArr)[i];
+                const SwTOXSortKey* pKey = &m_SortKeyArr[i];
                 pValues[i].realloc(2);
                 PropertyValue* pValue = pValues[i].getArray();
                 pValue[0].Name = sProp1;
@@ -487,7 +448,7 @@ bool    SwAuthorityFieldType::PutValue( const Any& rAny, sal_uInt16 nWhichId )
         {
             com::sun::star::lang::Locale aLocale;
             if( 0 != (bRet = rAny >>= aLocale ))
-                SetLanguage( SvxLocaleToLanguage( aLocale ));
+                SetLanguage( LanguageTag( aLocale ).getLanguageType());
         }
         break;
 
@@ -496,7 +457,7 @@ bool    SwAuthorityFieldType::PutValue( const Any& rAny, sal_uInt16 nWhichId )
             Sequence<PropertyValues> aSeq;
             if( 0 != (bRet = rAny >>= aSeq) )
             {
-                m_pSortKeyArr->DeleteAndDestroy(0, m_pSortKeyArr->Count());
+                m_SortKeyArr.clear();
                 const PropertyValues* pValues = aSeq.getConstArray();
                 for(sal_Int32 i = 0; i < aSeq.getLength() && i < USHRT_MAX / 4; i++)
                 {
@@ -517,7 +478,7 @@ bool    SwAuthorityFieldType::PutValue( const Any& rAny, sal_uInt16 nWhichId )
                             pSortKey->bSortAscending = *(sal_Bool*)pValue[j].Value.getValue();
                         }
                     }
-                    m_pSortKeyArr->Insert(pSortKey, m_pSortKeyArr->Count());
+                    m_SortKeyArr.push_back(pSortKey);
                 }
             }
         }
@@ -537,25 +498,24 @@ void SwAuthorityFieldType::Modify( const SfxPoolItem* pOld, const SfxPoolItem *p
 
 sal_uInt16 SwAuthorityFieldType::GetSortKeyCount() const
 {
-    return m_pSortKeyArr->Count();
+    return m_SortKeyArr.size();
 }
 
 const SwTOXSortKey*  SwAuthorityFieldType::GetSortKey(sal_uInt16 nIdx) const
 {
-    SwTOXSortKey* pRet = 0;
-    if(m_pSortKeyArr->Count() > nIdx)
-        pRet = (*m_pSortKeyArr)[nIdx];
+    const SwTOXSortKey* pRet = 0;
+    if(m_SortKeyArr.size() > nIdx)
+        pRet = &m_SortKeyArr[nIdx];
     OSL_ENSURE(pRet, "Sort key not found");
     return pRet;
 }
 
 void SwAuthorityFieldType::SetSortKeys(sal_uInt16 nKeyCount, SwTOXSortKey aKeys[])
 {
-    m_pSortKeyArr->DeleteAndDestroy(0, m_pSortKeyArr->Count());
-    sal_uInt16 nArrIdx = 0;
+    m_SortKeyArr.clear();
     for(sal_uInt16 i = 0; i < nKeyCount; i++)
         if(aKeys[i].eField < AUTH_FIELD_END)
-            m_pSortKeyArr->Insert(new SwTOXSortKey(aKeys[i]), nArrIdx++);
+            m_SortKeyArr.push_back(new SwTOXSortKey(aKeys[i]));
 }
 
 SwAuthorityField::SwAuthorityField( SwAuthorityFieldType* pInitType,
@@ -619,7 +579,7 @@ const String&   SwAuthorityField::GetFieldText(ToxAuthorityField eField) const
     return pEntry->GetAuthorField( eField );
 }
 
-void    SwAuthorityField::SetPar1(const String& rStr)
+void    SwAuthorityField::SetPar1(const rtl::OUString& rStr)
 {
     SwAuthorityFieldType* pInitType = (SwAuthorityFieldType* )GetTyp();
     pInitType->RemoveField(m_nHandle);
@@ -689,7 +649,7 @@ bool    SwAuthorityField::QueryValue( Any& rAny, sal_uInt16 /*nWhichId*/ ) const
     return false;
 }
 
-sal_Int16 lcl_Find(const OUString& rFieldName)
+static sal_Int16 lcl_Find(const OUString& rFieldName)
 {
     for(sal_Int16 i = 0; i < AUTH_FIELD_END; i++)
         if(!rFieldName.compareToAscii(aFieldNames[i]))
@@ -706,8 +666,9 @@ bool    SwAuthorityField::PutValue( const Any& rAny, sal_uInt16 /*nWhichId*/ )
     if(!(rAny >>= aParam))
         return false;
 
-    String sToSet;
-    sToSet.Fill(AUTH_FIELD_ISBN, TOX_STYLE_DELIMITER);
+    rtl::OUStringBuffer sBuf;
+    comphelper::string::padToLength(sBuf, AUTH_FIELD_ISBN, TOX_STYLE_DELIMITER);
+    String sToSet(sBuf.makeStringAndClear());
     const PropertyValue* pParam = aParam.getConstArray();
     for(sal_Int32 i = 0; i < aParam.getLength(); i++)
     {
