@@ -1,32 +1,21 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
-
-
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 #include <com/sun/star/uno/Sequence.h>
 #include <unotools/linguprops.hxx>
@@ -41,6 +30,7 @@
 #include <editeng/splwrap.hxx>
 #include <editeng/pgrditem.hxx>
 #include <editeng/tstpitem.hxx>
+#include <xmloff/odffields.hxx>
 
 #include <SwSmartTagMgr.hxx>
 #include <linguistic/lngprops.hxx>
@@ -49,6 +39,9 @@
 #include <editeng/forbiddenruleitem.hxx>
 #include <txatbase.hxx>
 #include <fmtinfmt.hxx>
+#include <fmtfld.hxx>
+#include <fldbas.hxx>
+#include <PostItMgr.hxx>
 #include <swmodule.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/wrkwin.hxx>
@@ -63,7 +56,7 @@
 #include <blink.hxx>    // SwBlink
 #include <noteurl.hxx>  // SwNoteURL
 #include <porftn.hxx>   // SwFtnPortion
-#include <porrst.hxx>       // SwHangingPortion
+#include <porrst.hxx>   // SwHangingPortion
 #include <itratr.hxx>
 #include <accessibilityoptions.hxx>
 #include <wrong.hxx>
@@ -97,7 +90,6 @@ using namespace ::com::sun::star::beans;
 #define DRAW_SPECIAL_OPTIONS_CENTER 1
 #define DRAW_SPECIAL_OPTIONS_ROTATE 2
 
-//
 // variable moved to class <numfunc:GetDefBulletConfig>
 //extern const sal_Char sBulletFntName[];
 namespace numfunc
@@ -107,29 +99,9 @@ namespace numfunc
 }
 
 #ifdef DBG_UTIL
-// Test2: WYSIWYG++
-// Test4: WYSIWYG debug
-static bool g_bDbgLow = false;
-#endif
-
-#ifdef DBG_UTIL
-sal_Bool SwTxtSizeInfo::IsOptCalm() const { return !GetOpt().IsTest3(); }
-sal_Bool SwTxtSizeInfo::IsOptLow() const { return g_bDbgLow; }
 sal_Bool SwTxtSizeInfo::IsOptDbg() const { return GetOpt().IsTest4(); }
-sal_Bool SwTxtSizeInfo::IsOptTest1() const { return GetOpt().IsTest1(); }
-sal_Bool SwTxtSizeInfo::IsOptTest2() const { return GetOpt().IsTest2(); }
-sal_Bool SwTxtSizeInfo::IsOptTest3() const { return GetOpt().IsTest3(); }
-sal_Bool SwTxtSizeInfo::IsOptTest4() const { return GetOpt().IsTest4(); }
-sal_Bool SwTxtSizeInfo::IsOptTest5() const { return GetOpt().IsTest5(); }
-sal_Bool SwTxtSizeInfo::IsOptTest6() const { return GetOpt().IsTest6(); }
-sal_Bool SwTxtSizeInfo::IsOptTest7() const { return GetOpt().IsTest7(); }
-sal_Bool SwTxtSizeInfo::IsOptTest8() const { return GetOpt().IsTest8(); }
 #endif
 
-/*************************************************************************
- *                      SwLineInfo::SwLineInfo()
- *************************************************************************/
-
 SwLineInfo::SwLineInfo()
     : pRuler( 0 ),
       pSpace( 0 ),
@@ -189,10 +161,6 @@ void SwLineInfo::CtorInitLineInfo( const SwAttrSet& rAttrSet,
     nDefTabStop = MSHRT_MAX;
 }
 
-/*************************************************************************
- *                      SwTxtInfo::CtorInitTxtInfo()
- *************************************************************************/
-
 void SwTxtInfo::CtorInitTxtInfo( SwTxtFrm *pFrm )
 {
     pPara = pFrm->GetPara();
@@ -212,9 +180,6 @@ SwTxtInfo::SwTxtInfo( const SwTxtInfo &rInf )
 
 
 #if OSL_DEBUG_LEVEL > 0
-/*************************************************************************
- *                      ChkOutDev()
- *************************************************************************/
 
 void ChkOutDev( const SwTxtSizeInfo &rInf )
 {
@@ -225,7 +190,7 @@ void ChkOutDev( const SwTxtSizeInfo &rInf )
     const OutputDevice* pRef = rInf.GetRefDev();
     OSL_ENSURE( pOut && pRef, "ChkOutDev: invalid output devices" );
 }
-#endif  // PRODUCT
+#endif
 
 
 inline xub_StrLen GetMinLen( const SwTxtSizeInfo &rInf )
@@ -288,11 +253,10 @@ void SwTxtSizeInfo::CtorInitTxtSizeInfo( SwTxtFrm *pFrame, SwFont *pNewFnt,
     }
     else
     {
-        //Zugriff ueber StarONE, es muss keine Shell existieren oder aktiv sein.
+        // Access via StarONE. We do not need a Shell or an active one.
         if ( pNd->getIDocumentSettingAccess()->get(IDocumentSettingAccess::HTML_MODE) )
         {
-            //in Ermangelung eines Besseren kann hier ja wohl nur noch das
-            //AppWin genommen werden?
+            // We can only pick the AppWin here? (there's nothing better to pick?)
             pOut = GetpApp()->GetDefaultDevice();
         }
         else
@@ -324,10 +288,10 @@ void SwTxtSizeInfo::CtorInitTxtSizeInfo( SwTxtFrm *pFrame, SwFont *pNewFnt,
     //
     pOpt = pVsh ?
            pVsh->GetViewOptions() :
-           SW_MOD()->GetViewOption( pNd->getIDocumentSettingAccess()->get(IDocumentSettingAccess::HTML_MODE) ); //Options vom Module wg. StarONE
+           SW_MOD()->GetViewOption( pNd->getIDocumentSettingAccess()->get(IDocumentSettingAccess::HTML_MODE) ); // Options from Module, due to StarONE
 
-    // bURLNotify wird gesetzt, wenn MakeGraphic dies vorbereitet
-    // TODO: Aufdr?seln
+    // bURLNotify is set if MakeGraphic prepares it
+    // TODO: Unwind
     bURLNotify = pNoteURL && !bOnWin;
 
     SetSnapToGrid( pNd->GetSwAttrSet().GetParaGrid().GetValue() &&
@@ -383,24 +347,15 @@ SwTxtSizeInfo::SwTxtSizeInfo( const SwTxtSizeInfo &rNew, const XubString &rTxt,
     SetLen( GetMinLen( *this ) );
 }
 
-/*************************************************************************
- *                      SwTxtSizeInfo::SelectFont()
- *************************************************************************/
-
 void SwTxtSizeInfo::SelectFont()
 {
-    // 8731: Der Weg muss ueber ChgPhysFnt gehen, sonst geraet
-    // der FontMetricCache durcheinander. In diesem Fall steht pLastMet
-    // auf dem alten Wert.
-    // Falsch: GetOut()->SetFont( GetFont()->GetFnt() );
+     // The path needs to go via ChgPhysFnt or the FontMetricCache gets confused.
+     // In this case pLastMet has it's old value.
+     // Wrong: GetOut()->SetFont( GetFont()->GetFnt() );
     GetFont()->Invalidate();
     GetFont()->ChgPhysFnt( pVsh, *GetOut() );
 }
 
-/*************************************************************************
- *                      SwTxtSizeInfo::NoteAnimation()
- *************************************************************************/
-
 void SwTxtSizeInfo::NoteAnimation() const
 {
     if( OnWin() )
@@ -410,10 +365,6 @@ void SwTxtSizeInfo::NoteAnimation() const
             "SwTxtSizeInfo::NoteAnimation() changed pOut" );
 }
 
-/*************************************************************************
- *                      SwTxtSizeInfo::GetTxtSize()
- *************************************************************************/
-
 SwPosSize SwTxtSizeInfo::GetTxtSize( OutputDevice* pOutDev,
                                      const SwScriptInfo* pSI,
                                      const XubString& rTxt,
@@ -430,16 +381,12 @@ SwPosSize SwTxtSizeInfo::GetTxtSize( OutputDevice* pOutDev,
     return aSize;
 }
 
-/*************************************************************************
- *                      SwTxtSizeInfo::GetTxtSize()
- *************************************************************************/
-
 SwPosSize SwTxtSizeInfo::GetTxtSize() const
 {
     const SwScriptInfo& rSI =
                      ( (SwParaPortion*)GetParaPortion() )->GetScriptInfo();
 
-    // in some cases, compression is not allowed or surpressed for
+    // in some cases, compression is not allowed or suppressed for
     // performance reasons
     sal_uInt16 nComp =( SW_CJK == GetFont()->GetActual() &&
                     rSI.CountCompChg() &&
@@ -455,10 +402,6 @@ SwPosSize SwTxtSizeInfo::GetTxtSize() const
     return pFnt->_GetTxtSize( aDrawInf );
 }
 
-/*************************************************************************
- *                      SwTxtSizeInfo::GetTxtSize()
- *************************************************************************/
-
 void SwTxtSizeInfo::GetTxtSize( const SwScriptInfo* pSI, const xub_StrLen nIndex,
                                 const xub_StrLen nLength, const sal_uInt16 nComp,
                                 sal_uInt16& nMinSize, sal_uInt16& nMaxSizeDiff ) const
@@ -473,10 +416,6 @@ void SwTxtSizeInfo::GetTxtSize( const SwScriptInfo* pSI, const xub_StrLen nIndex
     nMinSize = aSize.Width();
 }
 
-/*************************************************************************
- *                      SwTxtSizeInfo::GetTxtBreak()
- *************************************************************************/
-
 xub_StrLen SwTxtSizeInfo::GetTxtBreak( const long nLineWidth,
                                        const xub_StrLen nMaxLen,
                                        const sal_uInt16 nComp ) const
@@ -496,10 +435,6 @@ xub_StrLen SwTxtSizeInfo::GetTxtBreak( const long nLineWidth,
     return pFnt->GetTxtBreak( aDrawInf, nLineWidth );
 }
 
-/*************************************************************************
- *                      SwTxtSizeInfo::GetTxtBreak()
- *************************************************************************/
-
 xub_StrLen SwTxtSizeInfo::GetTxtBreak( const long nLineWidth,
                                        const xub_StrLen nMaxLen,
                                        const sal_uInt16 nComp,
@@ -520,10 +455,6 @@ xub_StrLen SwTxtSizeInfo::GetTxtBreak( const long nLineWidth,
     return pFnt->GetTxtBreak( aDrawInf, nLineWidth );
 }
 
-/*************************************************************************
- *                     SwTxtPaintInfo::CtorInitTxtPaintInfo()
- *************************************************************************/
-
 void SwTxtPaintInfo::CtorInitTxtPaintInfo( SwTxtFrm *pFrame, const SwRect &rPaint )
 {
     CtorInitTxtSizeInfo( pFrame );
@@ -571,12 +502,12 @@ SwTxtPaintInfo::SwTxtPaintInfo( const SwTxtPaintInfo &rInf )
 extern Color aGlobalRetoucheColor;
 
 /*************************************************************************
- *                          lcl_IsDarkBackground
+ * lcl_IsDarkBackground
  *
  * Returns if the current background color is dark.
  *************************************************************************/
 
-sal_Bool lcl_IsDarkBackground( const SwTxtPaintInfo& rInf )
+static sal_Bool lcl_IsDarkBackground( const SwTxtPaintInfo& rInf )
 {
     const Color* pCol = rInf.GetFont()->GetBackColor();
     if( ! pCol || COL_TRANSPARENT == pCol->GetColor() )
@@ -584,19 +515,16 @@ sal_Bool lcl_IsDarkBackground( const SwTxtPaintInfo& rInf )
         const SvxBrushItem* pItem;
         SwRect aOrigBackRect;
 
-        /// OD 21.08.2002
-        ///     consider, that [GetBackgroundBrush(...)] can set <pCol>
-        ///     - see implementation in /core/layout/paintfrm.cxx
-        /// OD 21.08.2002 #99657#
-        ///     There is a background color, if there is a background brush and
-        ///     its color is *not* "no fill"/"auto fill".
+        // Consider, that [GetBackgroundBrush(...)] can set <pCol>
+        // See implementation in /core/layout/paintfrm.cxx
+        // There is a background color, if there is a background brush and
+        // its color is *not* "no fill"/"auto fill".
         if( rInf.GetTxtFrm()->GetBackgroundBrush( pItem, pCol, aOrigBackRect, sal_False ) )
         {
             if ( !pCol )
                 pCol = &pItem->GetColor();
 
-            /// OD 30.08.2002 #99657#
-            /// determined color <pCol> can be <COL_TRANSPARENT>. Thus, check it.
+            // Determined color <pCol> can be <COL_TRANSPARENT>. Thus, check it.
             if ( pCol->GetColor() == COL_TRANSPARENT)
                 pCol = NULL;
         }
@@ -612,7 +540,7 @@ sal_Bool lcl_IsDarkBackground( const SwTxtPaintInfo& rInf )
 }
 
 /*************************************************************************
- *                     SwTxtPaintInfo::_DrawText()
+ * SwTxtPaintInfo::_DrawText()
  *************************************************************************/
 
 void SwTxtPaintInfo::_DrawText( const XubString &rText, const SwLinePortion &rPor,
@@ -662,14 +590,14 @@ void SwTxtPaintInfo::_DrawText( const XubString &rText, const SwLinePortion &rPo
     if ( ! rPor.InFldGrp() )
         pSI = &GetParaPortion()->GetScriptInfo();
 
-    // in some cases, kana compression is not allowed or surpressed for
+    // in some cases, kana compression is not allowed or suppressed for
     // performance reasons
     sal_uInt16 nComp = 0;
     if ( ! IsMulti() )
         nComp = GetKanaComp();
 
     sal_Bool bCfgIsAutoGrammar = sal_False;
-    SvtLinguConfig().GetProperty( C2U( UPN_IS_GRAMMAR_AUTO ) ) >>= bCfgIsAutoGrammar;
+    SvtLinguConfig().GetProperty( UPN_IS_GRAMMAR_AUTO ) >>= bCfgIsAutoGrammar;
     const sal_Bool bBullet = OnWin() && GetOpt().IsBlank() && IsNoSymbol();
     const sal_Bool bTmpWrong = bWrong && OnWin() && GetOpt().IsOnlineSpell();
     const sal_Bool bTmpGrammarCheck = bGrammarCheck && OnWin() && bCfgIsAutoGrammar && GetOpt().IsOnlineSpell();
@@ -688,7 +616,7 @@ void SwTxtPaintInfo::_DrawText( const XubString &rText, const SwLinePortion &rPo
     if ( nSpaceAdd )
     {
         xub_StrLen nCharCnt;
-        // #i41860# Thai justified alignemt needs some
+        // #i41860# Thai justified alignment needs some
         // additional information:
         aDrawInf.SetNumberOfBlanks( rPor.InTxtGrp() ?
                                     static_cast<const SwTxtPortion&>(rPor).GetSpaceCnt( *this, nCharCnt ) :
@@ -712,8 +640,8 @@ void SwTxtPaintInfo::_DrawText( const XubString &rText, const SwLinePortion &rPo
 
     if( GetTxtFly()->IsOn() )
     {
-        // aPos muss als TopLeft vorliegen, weil die ClipRects sonst
-        // nicht berechnet werden koennen.
+        // aPos needs to be the TopLeft, because we cannot calculate the
+        // ClipRects otherwise
         const Point aPoint( aPos.X(), aPos.Y() - rPor.GetAscent() );
         const Size aSize( rPor.Width(), rPor.Height() );
         aDrawInf.SetPos( aPoint );
@@ -740,10 +668,6 @@ void SwTxtPaintInfo::_DrawText( const XubString &rText, const SwLinePortion &rPo
     }
 }
 
-/*************************************************************************
- *                          SwTxtPaintInfo::CalcRect()
- *************************************************************************/
-
 void SwTxtPaintInfo::CalcRect( const SwLinePortion& rPor,
                                SwRect* pRect, SwRect* pIntersect ) const
 {
@@ -820,11 +744,11 @@ void SwTxtPaintInfo::CalcRect( const SwLinePortion& rPor,
 }
 
 /*************************************************************************
- *                          lcl_DrawSpecial
+ * lcl_DrawSpecial
  *
  * Draws a special portion, e.g., line break portion, tab portion.
- * rPor - The portion
- * rRect - The rectangle surrounding the character
+ * rPor     - The portion
+ * rRect    - The rectangle surrounding the character
  * pCol     - Specify a color for the character
  * bCenter  - Draw the character centered, otherwise left aligned
  * bRotate  - Rotate the character if character rotation is set
@@ -890,7 +814,7 @@ static void lcl_DrawSpecial( const SwTxtPaintInfo& rInf, const SwLinePortion& rP
     }
 
     // check if char fits into rectangle
-    const XubString aTmp( cChar );
+    const OUString aTmp( cChar );
     aFontSize = rInf.GetTxtSize( aTmp ).SvLSize();
     while ( aFontSize.Width() > nMaxWidth )
     {
@@ -947,10 +871,6 @@ static void lcl_DrawSpecial( const SwTxtPaintInfo& rInf, const SwLinePortion& rP
     ((SwTxtPaintInfo&)rInf).SetPos( aOldPos );
 }
 
-/*************************************************************************
- *                     SwTxtPaintInfo::DrawRect()
- *************************************************************************/
-
 void SwTxtPaintInfo::DrawRect( const SwRect &rRect, sal_Bool bNoGraphic,
                                sal_Bool bRetouche ) const
 {
@@ -969,10 +889,6 @@ void SwTxtPaintInfo::DrawRect( const SwRect &rRect, sal_Bool bNoGraphic,
     }
 }
 
-/*************************************************************************
- *                     SwTxtPaintInfo::DrawTab()
- *************************************************************************/
-
 void SwTxtPaintInfo::DrawTab( const SwLinePortion &rPor ) const
 {
     if( OnWin() )
@@ -991,10 +907,6 @@ void SwTxtPaintInfo::DrawTab( const SwLinePortion &rPor ) const
     }
 }
 
-/*************************************************************************
- *                     SwTxtPaintInfo::DrawLineBreak()
- *************************************************************************/
-
 void SwTxtPaintInfo::DrawLineBreak( const SwLinePortion &rPor ) const
 {
     if( OnWin() )
@@ -1017,11 +929,6 @@ void SwTxtPaintInfo::DrawLineBreak( const SwLinePortion &rPor ) const
     }
 }
 
-
-/*************************************************************************
- *                     SwTxtPaintInfo::DrawRedArrow()
- *************************************************************************/
-
 void SwTxtPaintInfo::DrawRedArrow( const SwLinePortion &rPor ) const
 {
     Size aSize( SPECIAL_FONT_HEIGHT, SPECIAL_FONT_HEIGHT );
@@ -1056,11 +963,6 @@ void SwTxtPaintInfo::DrawRedArrow( const SwLinePortion &rPor ) const
     }
 }
 
-
-/*************************************************************************
- *                     SwTxtPaintInfo::DrawPostIts()
- *************************************************************************/
-
 void SwTxtPaintInfo::DrawPostIts( const SwLinePortion&, sal_Bool bScript ) const
 {
     if( OnWin() && pOpt->IsPostIts() )
@@ -1137,12 +1039,10 @@ void SwTxtPaintInfo::DrawCheckBox( const SwFieldFormPortion &rPor, bool checked)
         pOut->Pop();
     }
 }
-/*************************************************************************
- *                     SwTxtPaintInfo::DrawBackGround()
- *************************************************************************/
+
 void SwTxtPaintInfo::DrawBackground( const SwLinePortion &rPor ) const
 {
-    OSL_ENSURE( OnWin(), "SwTxtPaintInfo::DrawBackground: printer polution ?" );
+    OSL_ENSURE( OnWin(), "SwTxtPaintInfo::DrawBackground: printer pollution ?" );
 
     SwRect aIntersect;
     CalcRect( rPor, 0, &aIntersect );
@@ -1176,7 +1076,7 @@ void SwTxtPaintInfo::_DrawBackBrush( const SwLinePortion &rPor ) const
         if(aIntersect.HasArea())
         {
             SwTxtNode *pNd = pFrm->GetTxtNode();
-            const ::sw::mark::IMark* pFieldmark = NULL;
+            const ::sw::mark::IFieldmark* pFieldmark = NULL;
             if(pNd)
             {
                 const SwDoc *doc=pNd->GetDoc();
@@ -1191,7 +1091,7 @@ void SwTxtPaintInfo::_DrawBackBrush( const SwLinePortion &rPor ) const
             if(pFieldmark) {
                 OSL_TRACE("Found Fieldmark");
 #if OSL_DEBUG_LEVEL > 1
-                rtl::OUString str = pFieldmark->ToString( );
+                OUString str = pFieldmark->ToString( );
                 fprintf( stderr, "%s\n", rtl::OUStringToOString( str, RTL_TEXTENCODING_UTF8 ).getStr( ) );
 #endif
             }
@@ -1202,8 +1102,30 @@ void SwTxtPaintInfo::_DrawBackBrush( const SwLinePortion &rPor ) const
             {
                 OutputDevice* pOutDev = (OutputDevice*)GetOut();
                 pOutDev->Push( PUSH_LINECOLOR | PUSH_FILLCOLOR );
-                pOutDev->SetFillColor( SwViewOption::GetFieldShadingsColor() );
-                pOutDev->SetLineColor( );
+                bool bFilled = false;
+                // If this is a comment range, need to look up the color of the comment author.
+                if (pFieldmark->GetFieldname() == ODF_COMMENTRANGE)
+                {
+                    // Search for the position of the postit field
+                    const sal_Unicode fld[] = { CH_TXTATR_INWORD, 0 };
+                    xub_StrLen nEndIdx = GetTxt().SearchChar(fld, GetIdx());
+                    if (nEndIdx != STRING_NOTFOUND)
+                    {
+                        SwTxtAttr* pTxtAttr = pNd->GetTxtAttrForCharAt(nEndIdx, RES_TXTATR_FIELD);
+                        const SwFmtFld& rPostItField = pTxtAttr->GetFld();
+                        // Look up the author name
+                        const OUString& rAuthor = rPostItField.GetFld()->GetPar1();
+                        sal_uInt16 nIndex = pNd->GetDoc()->InsertRedlineAuthor(rAuthor);
+                        pOutDev->SetFillColor( SwPostItMgr::GetColorLight(nIndex) );
+                        pOutDev->SetLineColor( SwPostItMgr::GetColorAnchor(nIndex) );
+                        bFilled = true;
+                    }
+                }
+                if (!bFilled)
+                {
+                    pOutDev->SetFillColor( SwViewOption::GetFieldShadingsColor() );
+                    pOutDev->SetLineColor( );
+                }
                 pOutDev->DrawRect( aIntersect.SVRect() );
                 pOutDev->Pop();
             }
@@ -1234,10 +1156,6 @@ void SwTxtPaintInfo::_DrawBackBrush( const SwLinePortion &rPor ) const
     }
 }
 
-/*************************************************************************
- *                     SwTxtPaintInfo::DrawViewOpt()
- *************************************************************************/
-
 void SwTxtPaintInfo::DrawViewOpt( const SwLinePortion &rPor,
                                   const MSHORT nWhich ) const
 {
@@ -1277,10 +1195,6 @@ void SwTxtPaintInfo::DrawViewOpt( const SwLinePortion &rPor,
     }
 }
 
-/*************************************************************************
- *                     SwTxtPaintInfo::_NotifyURL()
- *************************************************************************/
-
 void SwTxtPaintInfo::_NotifyURL( const SwLinePortion &rPor ) const
 {
     OSL_ENSURE( pNoteURL, "NotifyURL: pNoteURL gone with the wind!" );
@@ -1302,10 +1216,6 @@ void SwTxtPaintInfo::_NotifyURL( const SwLinePortion &rPor ) const
     }
 }
 
-/*************************************************************************
- *                  lcl_InitHyphValues()
- *************************************************************************/
-
 static void lcl_InitHyphValues( PropertyValues &rVals,
             sal_Int16 nMinLeading, sal_Int16 nMinTrailing )
 {
@@ -1316,11 +1226,11 @@ static void lcl_InitHyphValues( PropertyValues &rVals,
         rVals.realloc( 2 );
         PropertyValue *pVal = rVals.getArray();
 
-        pVal[0].Name    = C2U( UPN_HYPH_MIN_LEADING );
+        pVal[0].Name    = UPN_HYPH_MIN_LEADING;
         pVal[0].Handle  = UPH_HYPH_MIN_LEADING;
         pVal[0].Value   <<= nMinLeading;
 
-        pVal[1].Name    = C2U( UPN_HYPH_MIN_TRAILING );
+        pVal[1].Name    = UPN_HYPH_MIN_TRAILING;
         pVal[1].Handle  = UPH_HYPH_MIN_TRAILING;
         pVal[1].Value   <<= nMinTrailing;
     }
@@ -1331,14 +1241,10 @@ static void lcl_InitHyphValues( PropertyValues &rVals,
         pVal[1].Value <<= nMinTrailing;
     }
     else {
-        OSL_FAIL( "unxpected size of sequence" );
+        OSL_FAIL( "unexpected size of sequence" );
     }
 }
 
-/*************************************************************************
- *                  SwTxtFormatInfo::GetHyphValues()
- *************************************************************************/
-
 const PropertyValues & SwTxtFormatInfo::GetHyphValues() const
 {
     OSL_ENSURE( 2 == aHyphVals.getLength(),
@@ -1346,10 +1252,6 @@ const PropertyValues & SwTxtFormatInfo::GetHyphValues() const
     return aHyphVals;
 }
 
-/*************************************************************************
- *                  SwTxtFormatInfo::InitHyph()
- *************************************************************************/
-
 sal_Bool SwTxtFormatInfo::InitHyph( const sal_Bool bAutoHyphen )
 {
     const SwAttrSet& rAttrSet = GetTxtFrm()->GetTxtNode()->GetSwAttrSet();
@@ -1371,10 +1273,6 @@ sal_Bool SwTxtFormatInfo::InitHyph( const sal_Bool bAutoHyphen )
     return bAuto;
 }
 
-/*************************************************************************
- *                  SwTxtFormatInfo::CtorInitTxtFormatInfo()
- *************************************************************************/
-
 void SwTxtFormatInfo::CtorInitTxtFormatInfo( SwTxtFrm *pNewFrm, const sal_Bool bNewInterHyph,
                                 const sal_Bool bNewQuick, const sal_Bool bTst )
 {
@@ -1407,15 +1305,13 @@ void SwTxtFormatInfo::CtorInitTxtFormatInfo( SwTxtFrm *pNewFrm, const sal_Bool b
 }
 
 /*************************************************************************
- *                  SwTxtFormatInfo::IsHyphenate()
+ * SwTxtFormatInfo::IsHyphenate()
+ * If the Hyphenator returns ERROR or the language is set to NOLANGUAGE
+ * we do not hyphenate.
+ * Else, we always hyphenate if we do interactive hyphenation.
+ * If we do not do interactive hyphenation, we only hyphenate if ParaFmt is
+ * set to automatic hyphenation.
  *************************************************************************/
-// Trennen oder nicht trennen, das ist hier die Frage:
-// - in keinem Fall trennen, wenn der Hyphenator ERROR zurueckliefert,
-//   oder wenn als Sprache NOLANGUAGE eingestellt ist.
-// - ansonsten immer trennen, wenn interaktive Trennung vorliegt
-// - wenn keine interakt. Trennung, dann nur trennen, wenn im ParaFmt
-//   automatische Trennung eingestellt ist.
-
 sal_Bool SwTxtFormatInfo::IsHyphenate() const
 {
     if( !bInterHyph && !bAutoHyph )
@@ -1435,10 +1331,10 @@ sal_Bool SwTxtFormatInfo::IsHyphenate() const
 }
 
 /*************************************************************************
- *                  SwTxtFormatInfo::GetDropFmt()
- *************************************************************************/
+ * SwTxtFormatInfo::GetDropFmt()
+ * Dropcaps called by the SwTxtFormatter::CTOR
+*************************************************************************/
 
-// Dropcaps vom SwTxtFormatter::CTOR gerufen.
 const SwFmtDrop *SwTxtFormatInfo::GetDropFmt() const
 {
     const SwFmtDrop *pDrop = &GetTxtFrm()->GetTxtNode()->GetSwAttrSet().GetDrop();
@@ -1448,13 +1344,9 @@ const SwFmtDrop *SwTxtFormatInfo::GetDropFmt() const
     return pDrop;
 }
 
-/*************************************************************************
- *                      SwTxtFormatInfo::Init()
- *************************************************************************/
-
 void SwTxtFormatInfo::Init()
 {
-    // Nicht initialisieren: pRest, nLeft, nRight, nFirst, nRealWidth
+    // Not initialized: pRest, nLeft, nRight, nFirst, nRealWidth
     X(0);
     bArrowDone = bFull = bFtnDone = bErgoDone = bNumDone = bNoEndHyph =
         bNoMidHyph = bStop = bNewLine = bUnderFlow = bTabOverflow = sal_False;
@@ -1553,11 +1445,6 @@ SwTxtFormatInfo::SwTxtFormatInfo( const SwTxtFormatInfo& rInf,
     SetMulti( sal_True );
     SetFirstMulti( rInf.IsFirstMulti() );
 }
-
-/*************************************************************************
- *                 SwTxtFormatInfo::_CheckFtnPortion()
- *************************************************************************/
-
 sal_Bool SwTxtFormatInfo::_CheckFtnPortion( SwLineLayout* pCurr )
 {
     KSHORT nHeight = pCurr->GetRealHeight();
@@ -1577,12 +1464,6 @@ sal_Bool SwTxtFormatInfo::_CheckFtnPortion( SwLineLayout* pCurr )
     return bRet;
 }
 
-
-
-
-/*************************************************************************
- *                 SwTxtFormatInfo::ScanPortionEnd()
- *************************************************************************/
 xub_StrLen SwTxtFormatInfo::ScanPortionEnd( const xub_StrLen nStart,
                                             const xub_StrLen nEnd )
 {
@@ -1592,17 +1473,17 @@ xub_StrLen SwTxtFormatInfo::ScanPortionEnd( const xub_StrLen nStart,
     //
     // Used for decimal tab handling:
     //
-    const xub_Unicode cTabDec = GetLastTab() ? (sal_Unicode)GetTabDecimal() : 0;
-    const xub_Unicode cThousandSep  = ',' == cTabDec ? '.' : ',';
+    const sal_Unicode cTabDec = GetLastTab() ? (sal_Unicode)GetTabDecimal() : 0;
+    const sal_Unicode cThousandSep  = ',' == cTabDec ? '.' : ',';
     // #i45951# German (Switzerland) uses ' as thousand separator
-    const xub_Unicode cThousandSep2 = ',' == cTabDec ? '.' : '\'';
+    const sal_Unicode cThousandSep2 = ',' == cTabDec ? '.' : '\'';
 
     bool bNumFound = false;
     const bool bTabCompat = GetTxtFrm()->GetTxtNode()->getIDocumentSettingAccess()->get(IDocumentSettingAccess::TAB_COMPAT);
 
     for( ; i < nEnd; ++i )
     {
-        const xub_Unicode cPos = GetChar( i );
+        const sal_Unicode cPos = GetChar( i );
         switch( cPos )
         {
         case CH_TXTATR_BREAKWORD:
@@ -1664,11 +1545,11 @@ xub_StrLen SwTxtFormatInfo::ScanPortionEnd( const xub_StrLen nStart,
         }
     }
 
-    // #130210# Check if character *behind* the portion has
+    // Check if character *behind* the portion has
     // to become the hook:
     if ( i == nEnd && i < GetTxt().Len() && bNumFound )
     {
-        const xub_Unicode cPos = GetChar( i );
+        const sal_Unicode cPos = GetChar( i );
         if ( cPos != cTabDec && cPos != cThousandSep && cPos !=cThousandSep2 && ( 0x2F >= cPos || cPos >= 0x3A ) )
         {
             cHookChar = GetChar( i );
@@ -1707,10 +1588,6 @@ sal_Bool SwTxtFormatInfo::LastKernPortion()
     return sal_False;
 }
 
-/*************************************************************************
- *                      class SwTxtSlot
- *************************************************************************/
-
 SwTxtSlot::SwTxtSlot( const SwTxtSizeInfo *pNew, const SwLinePortion *pPor,
                       bool bTxtLen, bool bExgLists, const sal_Char *pCh )
     : pOldTxt( 0 ),
@@ -1726,7 +1603,7 @@ SwTxtSlot::SwTxtSlot( const SwTxtSizeInfo *pNew, const SwLinePortion *pPor,
     else
         bOn = pPor->GetExpTxt( *pNew, aTxt );
 
-    // Der Text wird ausgetauscht...
+    // Teh text is replaced ...
     if( bOn )
     {
         pInf = (SwTxtSizeInfo*)pNew;
@@ -1750,7 +1627,7 @@ SwTxtSlot::SwTxtSlot( const SwTxtSizeInfo *pNew, const SwLinePortion *pPor,
                 else if( !pTempList && nPos < pOldSmartTagList->Count() && nListPos < nIdx && aTxt.Len() )
                 {
                     pTempList = new SwWrongList( WRONGLIST_SMARTTAG );
-                    pTempList->Insert( rtl::OUString(), 0, 0, aTxt.Len(), 0 );
+                    pTempList->Insert( OUString(), 0, 0, aTxt.Len(), 0 );
                     ((SwTxtPaintInfo*)pInf)->SetSmartTags( pTempList );
                 }
                 else
@@ -1766,7 +1643,7 @@ SwTxtSlot::SwTxtSlot( const SwTxtSizeInfo *pNew, const SwLinePortion *pPor,
                 else if( !pTempList && nPos < pOldGrammarCheckList->Count() && nListPos < nIdx && aTxt.Len() )
                 {
                     pTempList = new SwWrongList( WRONGLIST_GRAMMAR );
-                    pTempList->Insert( rtl::OUString(), 0, 0, aTxt.Len(), 0 );
+                    pTempList->Insert( OUString(), 0, 0, aTxt.Len(), 0 );
                     ((SwTxtPaintInfo*)pInf)->SetGrammarCheckList( pTempList );
                 }
                 else
@@ -1776,10 +1653,6 @@ SwTxtSlot::SwTxtSlot( const SwTxtSizeInfo *pNew, const SwLinePortion *pPor,
     }
 }
 
-/*************************************************************************
- *                       SwTxtSlot::~SwTxtSlot()
- *************************************************************************/
-
 SwTxtSlot::~SwTxtSlot()
 {
     if( bOn )
@@ -1798,10 +1671,6 @@ SwTxtSlot::~SwTxtSlot()
     }
 }
 
-/*************************************************************************
- *                     SwFontSave::SwFontSave()
- *************************************************************************/
-
 SwFontSave::SwFontSave( const SwTxtSizeInfo &rInf, SwFont *pNew,
         SwAttrIter* pItr )
         : pFnt( pNew ? ((SwTxtSizeInfo&)rInf).GetFont() : 0 )
@@ -1838,15 +1707,11 @@ SwFontSave::SwFontSave( const SwTxtSizeInfo &rInf, SwFont *pNew,
     }
 }
 
-/*************************************************************************
- *                     SwFontSave::~SwFontSave()
- *************************************************************************/
-
 SwFontSave::~SwFontSave()
 {
     if( pFnt )
     {
-        // SwFont zurueckstellen
+        // Reset SwFont
         pFnt->Invalidate();
         pInf->SetFont( pFnt );
         if( pIter )
@@ -1857,10 +1722,6 @@ SwFontSave::~SwFontSave()
     }
 }
 
-/*************************************************************************
- *                     SwDefFontSave::SwDefFontSave()
- *************************************************************************/
-
 SwDefFontSave::SwDefFontSave( const SwTxtSizeInfo &rInf )
         : pFnt( ((SwTxtSizeInfo&)rInf).GetFont()  )
 {
@@ -1900,25 +1761,17 @@ SwDefFontSave::SwDefFontSave( const SwTxtSizeInfo &rInf )
     }
 }
 
-/*************************************************************************
- *                     SwDefFontSave::~SwDefFontSave()
- *************************************************************************/
-
 SwDefFontSave::~SwDefFontSave()
 {
     if( pFnt )
     {
         delete pNewFnt;
-        // SwFont zurueckstellen
+        // Reset SwFont
         pFnt->Invalidate();
         pInf->SetFont( pFnt );
     }
 }
 
-/*************************************************************************
- *                  SwTxtFormatInfo::ChgHyph()
- *************************************************************************/
-
 sal_Bool SwTxtFormatInfo::ChgHyph( const sal_Bool bNew )
 {
     const sal_Bool bOld = bAutoHyph;
@@ -1926,7 +1779,7 @@ sal_Bool SwTxtFormatInfo::ChgHyph( const sal_Bool bNew )
     {
         bAutoHyph = bNew;
         InitHyph( bNew );
-        // 5744: Sprache am Hyphenator einstellen.
+        // Set language in the Hyphenator
         if( pFnt )
             pFnt->ChgPhysFnt( pVsh, *pOut );
     }
