@@ -1,52 +1,37 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
-
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 #include <UndoOverwrite.hxx>
-
 #include <tools/resid.hxx>
-
 #include <unotools/charclass.hxx>
 #include <unotools/transliterationwrapper.hxx>
-
 #include <comphelper/processfactory.hxx>
-
 #include <doc.hxx>
 #include <IDocumentUndoRedo.hxx>
 #include <IShellCursorSupplier.hxx>
-#include <swundo.hxx>           // fuer die UndoIds
+#include <swundo.hxx>
 #include <pam.hxx>
 #include <ndtxt.hxx>
 #include <UndoCore.hxx>
 #include <rolbck.hxx>
 #include <acorrect.hxx>
 #include <docary.hxx>
-
 #include <comcore.hrc> // #111827#
 #include <undo.hrc>
 
@@ -54,18 +39,12 @@ using namespace ::com::sun::star;
 using namespace ::com::sun::star::i18n;
 using namespace ::com::sun::star::uno;
 
-
-//------------------------------------------------------------
-
-// OVERWRITE
-
-
 SwUndoOverwrite::SwUndoOverwrite( SwDoc* pDoc, SwPosition& rPos,
                                     sal_Unicode cIns )
     : SwUndo(UNDO_OVERWRITE),
       pRedlSaveData( 0 ), bGroup( sal_False )
 {
-    if( !pDoc->IsIgnoreRedline() && pDoc->GetRedlineTbl().Count() )
+    if( !pDoc->IsIgnoreRedline() && !pDoc->GetRedlineTbl().empty() )
     {
         SwPaM aPam( rPos.nNode, rPos.nContent.GetIndex(),
                     rPos.nNode, rPos.nContent.GetIndex()+1 );
@@ -78,11 +57,11 @@ SwUndoOverwrite::SwUndoOverwrite( SwDoc* pDoc, SwPosition& rPos,
     nSttCntnt = rPos.nContent.GetIndex();
 
     SwTxtNode* pTxtNd = rPos.nNode.GetNode().GetTxtNode();
-    OSL_ENSURE( pTxtNd, "Overwrite nicht im TextNode?" );
+    OSL_ENSURE( pTxtNd, "Overwrite not in a TextNode?" );
 
     bInsChar = sal_True;
     xub_StrLen nTxtNdLen = pTxtNd->GetTxt().Len();
-    if( nSttCntnt < nTxtNdLen )     // kein reines Einfuegen ?
+    if( nSttCntnt < nTxtNdLen )     // no pure insert?
     {
         aDelStr.Insert( pTxtNd->GetTxt().GetChar( nSttCntnt ) );
         if( !pHistory )
@@ -94,10 +73,10 @@ SwUndoOverwrite::SwUndoOverwrite( SwDoc* pDoc, SwPosition& rPos,
         bInsChar = sal_False;
     }
 
-    sal_Bool bOldExpFlg = pTxtNd->IsIgnoreDontExpand();
-    pTxtNd->SetIgnoreDontExpand( sal_True );
+    bool bOldExpFlg = pTxtNd->IsIgnoreDontExpand();
+    pTxtNd->SetIgnoreDontExpand( true );
 
-    pTxtNd->InsertText( cIns, rPos.nContent,
+    pTxtNd->InsertText( rtl::OUString(cIns), rPos.nContent,
             IDocumentContentOperations::INS_EMPTYEXPAND );
     aInsStr.Insert( cIns );
 
@@ -119,14 +98,14 @@ SwUndoOverwrite::~SwUndoOverwrite()
 sal_Bool SwUndoOverwrite::CanGrouping( SwDoc* pDoc, SwPosition& rPos,
                                     sal_Unicode cIns )
 {
-///  ?? was ist mit nur eingefuegten Charaktern ???
+// What is with only inserted characters?
 
-    // es kann nur das Loeschen von einzelnen char's zusammengefasst werden
+    // Only deletion of single chars can be combined.
     if( rPos.nNode != nSttNode || !aInsStr.Len()  ||
         ( !bGroup && aInsStr.Len() != 1 ))
         return sal_False;
 
-    // ist der Node ueberhaupt ein TextNode?
+    // Is the node a TextNode at all?
     SwTxtNode * pDelTxtNd = rPos.nNode.GetNode().GetTxtNode();
     if( !pDelTxtNd ||
         ( pDelTxtNd->GetTxt().Len() != rPos.nContent.GetIndex() &&
@@ -135,9 +114,9 @@ sal_Bool SwUndoOverwrite::CanGrouping( SwDoc* pDoc, SwPosition& rPos,
 
     CharClass& rCC = GetAppCharClass();
 
-    // befrage das einzufuegende Charakter
+    // ask the char that should be inserted
     if (( CH_TXTATR_BREAKWORD == cIns || CH_TXTATR_INWORD == cIns ) ||
-        rCC.isLetterNumeric( String( cIns ), 0 ) !=
+        rCC.isLetterNumeric( rtl::OUString( cIns ), 0 ) !=
         rCC.isLetterNumeric( aInsStr, aInsStr.Len()-1 ) )
         return sal_False;
 
@@ -160,8 +139,7 @@ sal_Bool SwUndoOverwrite::CanGrouping( SwDoc* pDoc, SwPosition& rPos,
         pDoc->DeleteRedline( aPam, false, USHRT_MAX );
     }
 
-    // Ok, die beiden 'Overwrites' koennen zusammen gefasst werden, also
-    // 'verschiebe' das enstprechende Zeichen
+    // both 'overwrites' can be combined so 'move' the corresponding character
     if( !bInsChar )
     {
         if( rPos.nContent.GetIndex() < pDelTxtNd->GetTxt().Len() )
@@ -173,10 +151,10 @@ sal_Bool SwUndoOverwrite::CanGrouping( SwDoc* pDoc, SwPosition& rPos,
             bInsChar = sal_True;
     }
 
-    sal_Bool bOldExpFlg = pDelTxtNd->IsIgnoreDontExpand();
-    pDelTxtNd->SetIgnoreDontExpand( sal_True );
+    bool bOldExpFlg = pDelTxtNd->IsIgnoreDontExpand();
+    pDelTxtNd->SetIgnoreDontExpand( true );
 
-    pDelTxtNd->InsertText( cIns, rPos.nContent,
+    pDelTxtNd->InsertText( rtl::OUString(cIns), rPos.nContent,
             IDocumentContentOperations::INS_EMPTYEXPAND );
     aInsStr.Insert( cIns );
 
@@ -191,10 +169,6 @@ sal_Bool SwUndoOverwrite::CanGrouping( SwDoc* pDoc, SwPosition& rPos,
     return sal_True;
 }
 
-
-
-
-
 void SwUndoOverwrite::UndoImpl(::sw::UndoRedoContext & rContext)
 {
     SwDoc *const pDoc = & rContext.GetDoc();
@@ -203,7 +177,7 @@ void SwUndoOverwrite::UndoImpl(::sw::UndoRedoContext & rContext)
     pAktPam->DeleteMark();
     pAktPam->GetPoint()->nNode = nSttNode;
     SwTxtNode* pTxtNd = pAktPam->GetNode()->GetTxtNode();
-    OSL_ENSURE( pTxtNd, "Overwrite nicht im TextNode?" );
+    OSL_ENSURE( pTxtNd, "Overwrite not in a TextNode?" );
     SwIndex& rIdx = pAktPam->GetPoint()->nContent;
     rIdx.Assign( pTxtNd, nSttCntnt );
 
@@ -215,8 +189,7 @@ void SwUndoOverwrite::UndoImpl(::sw::UndoRedoContext & rContext)
         pDoc->SetAutoCorrExceptWord( 0 );
     }
 
-    // wurde nicht nur ueberschieben sondern auch geinsertet, so loesche
-    // den Ueberhang
+    // If there was not only a overwrite but also an insert, delete the surplus
     if( aInsStr.Len() > aDelStr.Len() )
     {
         rIdx += aDelStr.Len();
@@ -226,16 +199,16 @@ void SwUndoOverwrite::UndoImpl(::sw::UndoRedoContext & rContext)
 
     if( aDelStr.Len() )
     {
-        String aTmpStr( '1' );
+        String aTmpStr = rtl::OUString('1');
         sal_Unicode* pTmpStr = aTmpStr.GetBufferAccess();
 
-        sal_Bool bOldExpFlg = pTxtNd->IsIgnoreDontExpand();
-        pTxtNd->SetIgnoreDontExpand( sal_True );
+        bool bOldExpFlg = pTxtNd->IsIgnoreDontExpand();
+        pTxtNd->SetIgnoreDontExpand( true );
 
-        rIdx++;
+        ++rIdx;
         for( xub_StrLen n = 0; n < aDelStr.Len(); n++  )
         {
-            // einzeln, damit die Attribute stehen bleiben !!!
+            // do it individually, to keep the attributes!
             *pTmpStr = aDelStr.GetChar( n );
             pTxtNd->InsertText( aTmpStr, rIdx /*???, SETATTR_NOTXTATRCHR*/ );
             rIdx -= 2;
@@ -245,6 +218,7 @@ void SwUndoOverwrite::UndoImpl(::sw::UndoRedoContext & rContext)
         pTxtNd->SetIgnoreDontExpand( bOldExpFlg );
         rIdx--;
     }
+
     if( pHistory )
     {
         if( pTxtNd->GetpSwpHints() )
@@ -272,10 +246,10 @@ void SwUndoOverwrite::RepeatImpl(::sw::RepeatContext & rContext)
 
     {
         ::sw::GroupUndoGuard const undoGuard(rDoc.GetIDocumentUndoRedo());
-        rDoc.Overwrite(*pAktPam, aInsStr.GetChar(0));
+        rDoc.Overwrite(*pAktPam, rtl::OUString(aInsStr.GetChar(0)));
     }
     for( xub_StrLen n = 1; n < aInsStr.Len(); ++n )
-        rDoc.Overwrite( *pAktPam, aInsStr.GetChar( n ) );
+        rDoc.Overwrite( *pAktPam, rtl::OUString(aInsStr.GetChar(n)) );
 }
 
 void SwUndoOverwrite::RedoImpl(::sw::UndoRedoContext & rContext)
@@ -286,7 +260,7 @@ void SwUndoOverwrite::RedoImpl(::sw::UndoRedoContext & rContext)
     pAktPam->DeleteMark();
     pAktPam->GetPoint()->nNode = nSttNode;
     SwTxtNode* pTxtNd = pAktPam->GetNode()->GetTxtNode();
-    OSL_ENSURE( pTxtNd, "Overwrite nicht im TextNode?" );
+    OSL_ENSURE( pTxtNd, "Overwrite not in TextNode?" );
     SwIndex& rIdx = pAktPam->GetPoint()->nContent;
 
     if( pRedlSaveData )
@@ -299,13 +273,13 @@ void SwUndoOverwrite::RedoImpl(::sw::UndoRedoContext & rContext)
     }
     rIdx.Assign( pTxtNd, aDelStr.Len() ? nSttCntnt+1 : nSttCntnt );
 
-    sal_Bool bOldExpFlg = pTxtNd->IsIgnoreDontExpand();
-    pTxtNd->SetIgnoreDontExpand( sal_True );
+    bool bOldExpFlg = pTxtNd->IsIgnoreDontExpand();
+    pTxtNd->SetIgnoreDontExpand( true );
 
     for( xub_StrLen n = 0; n < aInsStr.Len(); n++  )
     {
-        // einzeln, damit die Attribute stehen bleiben !!!
-        pTxtNd->InsertText( aInsStr.GetChar( n ), rIdx,
+        // do it individually, to keep the attributes!
+        pTxtNd->InsertText( rtl::OUString(aInsStr.GetChar(n)), rIdx,
                 IDocumentContentOperations::INS_EMPTYEXPAND );
         if( n < aDelStr.Len() )
         {
@@ -316,7 +290,7 @@ void SwUndoOverwrite::RedoImpl(::sw::UndoRedoContext & rContext)
     }
     pTxtNd->SetIgnoreDontExpand( bOldExpFlg );
 
-    // alte Anfangs-Position vom UndoNodes-Array zurueckholen
+    // get back old start position from UndoNodes array
     if( pHistory )
         pHistory->SetTmpEnd( pHistory->Count() );
     if( pAktPam->GetMark()->nContent.GetIndex() != nSttCntnt )
@@ -337,13 +311,11 @@ SwRewriter SwUndoOverwrite::GetRewriter() const
                              String(SW_RES(STR_LDOTS)));
     aString += String(SW_RES(STR_END_QUOTE));
 
-    aResult.AddRule(UNDO_ARG1, aString);
+    aResult.AddRule(UndoArg1, aString);
 
     return aResult;
 }
 
-//------------------------------------------------------------
-
 struct _UndoTransliterate_Data
 {
     String          sText;
@@ -401,7 +373,7 @@ void SwUndoTransliterate::RepeatImpl(::sw::RepeatContext & rContext)
 
 void SwUndoTransliterate::DoTransliterate(SwDoc & rDoc, SwPaM & rPam)
 {
-    utl::TransliterationWrapper aTrans( ::comphelper::getProcessServiceFactory(), nType );
+    utl::TransliterationWrapper aTrans( ::comphelper::getProcessComponentContext(), nType );
     rDoc.TransliterateText( rPam, aTrans );
 }
 
@@ -498,5 +470,4 @@ void _UndoTransliterate_Data::SetChangeAtNode( SwDoc& rDoc )
     }
 }
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
