@@ -1,40 +1,29 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
-#ifdef SW_DLLIMPLEMENTATION
-#undef SW_DLLIMPLEMENTATION
-#endif
 #include <swtypes.hxx>
 #include <mmlayoutpage.hxx>
 #include <mailmergewizard.hxx>
 #include <mmconfigitem.hxx>
 #include <mailmergehelper.hxx>
 #include <unotools.hxx>
+#include <comphelper/string.hxx>
 #include <unotools/tempfile.hxx>
 #include <uitool.hxx>
 #include <svx/dlgutil.hxx>
@@ -119,15 +108,14 @@ SwMailMergeLayoutPage::SwMailMergeLayoutPage( SwMailMergeWizard* _pParent) :
 
 
     const SfxFilter *pSfxFlt = SwIoSystem::GetFilterOfFormat(
-            String::CreateFromAscii( FILTER_XML ),
+            rtl::OUString( FILTER_XML ),
             SwDocShell::Factory().GetFilterContainer() );
     //save the current document into a temporary file
     {
         //temp file needs it's own block
         //creating with extension is not supported by a static method :-(
         String sLeading;
-        String sExt(pSfxFlt->GetDefaultExtension());
-        sExt.EraseLeadingChars('*');
+        String sExt(comphelper::string::stripStart(pSfxFlt->GetDefaultExtension(), '*'));
         utl::TempFile aTempFile( sLeading, &sExt );
         m_sExampleURL = aTempFile.GetURL();
         aTempFile.EnableKillingFile();
@@ -151,9 +139,9 @@ SwMailMergeLayoutPage::SwMailMergeLayoutPage( SwMailMergeWizard* _pParent) :
     m_aLeftMF.SetValue(m_aLeftMF.Normalize(DEFAULT_LEFT_DISTANCE), FUNIT_TWIP);
     m_aTopMF.SetValue(m_aTopMF.Normalize(DEFAULT_TOP_DISTANCE), FUNIT_TWIP);
 
-    m_aZoomLB.InsertEntry(String::CreateFromAscii("50 %"), 1);
-    m_aZoomLB.InsertEntry(String::CreateFromAscii("75 %"), 2);
-    m_aZoomLB.InsertEntry(String::CreateFromAscii("100 %"), 3);
+    m_aZoomLB.InsertEntry(rtl::OUString("50 %"), 1);
+    m_aZoomLB.InsertEntry(rtl::OUString("75 %"), 2);
+    m_aZoomLB.InsertEntry(rtl::OUString("100 %"), 3);
     m_aZoomLB.SelectEntryPos(0); //page size
     m_aZoomLB.SetSelectHdl(LINK(this, SwMailMergeLayoutPage, ZoomHdl_Impl));
 
@@ -348,14 +336,14 @@ SwFrmFmt* SwMailMergeLayoutPage::InsertAddressFrame(
         sal_Bool bIncludeCountry = rConfigItem.IsIncludeCountry();
         sal_Bool bHideEmptyParagraphs = rConfigItem.IsHideEmptyParagraphs();
         const ::rtl::OUString rExcludeCountry = rConfigItem.GetExcludeCountry();
-        bool bSpecialReplacementForCountry = (!bIncludeCountry || rExcludeCountry.getLength());
+        bool bSpecialReplacementForCountry = (!bIncludeCountry || !rExcludeCountry.isEmpty());
 
         const ResStringArray& rHeaders = rConfigItem.GetDefaultAddressHeaders();
         String sCountryColumn = rHeaders.GetString(MM_PART_COUNTRY);
         Sequence< ::rtl::OUString> aAssignment =
                         rConfigItem.GetColumnAssignment( rConfigItem.GetCurrentDBData() );
         const ::rtl::OUString* pAssignment = aAssignment.getConstArray();
-        if(aAssignment.getLength() > MM_PART_COUNTRY && aAssignment[MM_PART_COUNTRY].getLength())
+        if(aAssignment.getLength() > MM_PART_COUNTRY && !aAssignment[MM_PART_COUNTRY].isEmpty())
             sCountryColumn = aAssignment[MM_PART_COUNTRY];
         //
         String sHideParagraphsExpression;
@@ -370,8 +358,8 @@ SwFrmFmt* SwMailMergeLayoutPage::InsertAddressFrame(
                         nColumn < rHeaders.Count() && nColumn < aAssignment.getLength();
                                                                                     ++nColumn)
                 {
-                    if(rHeaders.GetString(nColumn) == aItem.sText &&
-                        pAssignment[nColumn].getLength())
+                    if (rHeaders.GetString(nColumn).equals(aItem.sText) &&
+                        !pAssignment[nColumn].isEmpty())
                     {
                         sConvertedColumn = pAssignment[nColumn];
                         break;
@@ -392,7 +380,7 @@ SwFrmFmt* SwMailMergeLayoutPage::InsertAddressFrame(
                 {
                     // now insert a hidden paragraph field
                     String sExpression;
-                    if( rExcludeCountry.getLength() )
+                    if( !rExcludeCountry.isEmpty() )
                     {
                         sExpression = sDatabaseConditionPrefix;
                         sExpression.Insert('[', 0);
@@ -490,7 +478,7 @@ void SwMailMergeLayoutPage::InsertGreeting(SwWrtShell& rShell, SwMailMergeConfig
         else
             while(nMoves)
             {
-                sal_Bool bMoved = rShell.MoveParagraph( 1 );
+                bool bMoved = rShell.MoveParagraph( 1 );
                 if(!bMoved)
                 {
                     //insert a new paragraph before the greeting line
@@ -560,7 +548,7 @@ void SwMailMergeLayoutPage::InsertGreeting(SwWrtShell& rShell, SwMailMergeConfig
 //          Female:  [database.sGenderColumn] != "rFemaleGenderValue" && [database.NameColumn]
 //          Male:    [database.sGenderColumn] == "rFemaleGenderValue" && [database.rGenderColumn]
 //          Neutral: [database.sNameColumn]
-            OSL_ENSURE(sGenderColumn.Len() && rFemaleGenderValue.getLength(),
+            OSL_ENSURE(sGenderColumn.Len() && !rFemaleGenderValue.isEmpty(),
                     "gender settings not available - how to form the condition?");
             //column used as lastname
             for(sal_Int8 eGender = SwMailMergeConfigItem::FEMALE;
@@ -627,8 +615,8 @@ void SwMailMergeLayoutPage::InsertGreeting(SwWrtShell& rShell, SwMailMergeConfig
                                     nColumn < rHeaders.Count() && nColumn < aAssignment.getLength();
                                                                                                 ++nColumn)
                             {
-                                if(rHeaders.GetString(nColumn) == aItem.sText &&
-                                    pAssignment[nColumn].getLength())
+                                if (rHeaders.GetString(nColumn).equals(aItem.sText) &&
+                                    !pAssignment[nColumn].isEmpty())
                                 {
                                     sConvertedColumn = pAssignment[nColumn];
                                     break;
@@ -672,7 +660,7 @@ void SwMailMergeLayoutPage::InsertGreeting(SwWrtShell& rShell, SwMailMergeConfig
     OSL_ENSURE(0 == rShell.GetTableFmt(), "What to do with a table here?");
 }
 
-IMPL_LINK(SwMailMergeLayoutPage, PreviewLoadedHdl_Impl, void*, EMPTYARG)
+IMPL_LINK_NOARG(SwMailMergeLayoutPage, PreviewLoadedHdl_Impl)
 {
     m_aExampleWIN.Show( sal_True );
     m_aExampleContainerWIN.Show(sal_False);
@@ -737,7 +725,7 @@ IMPL_LINK(SwMailMergeLayoutPage, ZoomHdl_Impl, ListBox*, pBox)
     return 0;
 }
 
-IMPL_LINK(SwMailMergeLayoutPage, ChangeAddressHdl_Impl, MetricField*, EMPTYARG)
+IMPL_LINK_NOARG(SwMailMergeLayoutPage, ChangeAddressHdl_Impl)
 {
     if(m_pExampleWrtShell && m_pAddressBlockFormat)
     {
@@ -761,7 +749,7 @@ IMPL_LINK(SwMailMergeLayoutPage, ChangeAddressHdl_Impl, MetricField*, EMPTYARG)
 IMPL_LINK(SwMailMergeLayoutPage, GreetingsHdl_Impl, PushButton*, pButton)
 {
     bool bDown = pButton == &m_aDownPB;
-    sal_Bool bMoved = m_pExampleWrtShell->MoveParagraph( bDown ? 1 : -1 );
+    bool bMoved = m_pExampleWrtShell->MoveParagraph( bDown ? 1 : -1 );
     if (bMoved || bDown)
         m_pWizard->GetConfigItem().MoveGreeting(bDown ? 1 : -1 );
     if(!bMoved && bDown)
