@@ -1,30 +1,21 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 
 #include <toolkit/controls/controlmodelcontainerbase.hxx>
@@ -38,14 +29,14 @@
 #include <toolkit/controls/unocontrols.hxx>
 #include "toolkit/controls/formattedcontrol.hxx"
 #include "toolkit/controls/roadmapcontrol.hxx"
-#ifndef TOOLKIT_INC_TOOLKIT_CONTROLS_TKSCROLLBAR_HXX
 #include "toolkit/controls/tkscrollbar.hxx"
-#endif
+#include "toolkit/controls/tabpagemodel.hxx"
 #include <toolkit/controls/stdtabcontroller.hxx>
 #include <com/sun/star/awt/PosSize.hpp>
 #include <com/sun/star/awt/WindowAttribute.hpp>
 #include <com/sun/star/resource/XStringResourceResolver.hpp>
 #include <com/sun/star/graphic/XGraphicProvider.hpp>
+#include <com/sun/star/lang/XInitialization.hpp>
 #include <cppuhelper/typeprovider.hxx>
 #include <tools/debug.hxx>
 #include <tools/diagnose_ex.h>
@@ -392,6 +383,8 @@ Reference< XInterface > ControlModelContainerBase::createInstance( const ::rtl::
         pNewModel = new OGeometryControlModel< UnoControlTabPageContainerModel >( xFactory );
     else if ( aServiceSpecifier.compareToAscii( szServiceName_UnoMultiPageModel ) == 0 )
         pNewModel = new OGeometryControlModel< UnoMultiPageModel >( xFactory );
+    else if ( aServiceSpecifier.compareToAscii( szServiceName_UnoControlTabPageModel ) == 0 )
+        pNewModel = new OGeometryControlModel< UnoControlTabPageModel >( xFactory );
     else if ( aServiceSpecifier.compareToAscii( szServiceName_UnoPageModel ) == 0 )
         pNewModel = new OGeometryControlModel< UnoPageModel >( xFactory );
     else if ( aServiceSpecifier.compareToAscii( szServiceName_UnoFrameModel ) == 0 )
@@ -424,9 +417,13 @@ Reference< XInterface > ControlModelContainerBase::createInstance( const ::rtl::
     return xNewModel;
 }
 
-Reference< XInterface > ControlModelContainerBase::createInstanceWithArguments( const ::rtl::OUString& ServiceSpecifier, const Sequence< Any >& /* Arguments */ ) throw(Exception, RuntimeException)
+Reference< XInterface > ControlModelContainerBase::createInstanceWithArguments( const ::rtl::OUString& ServiceSpecifier, const Sequence< Any >& i_arguments ) throw(Exception, RuntimeException)
 {
-    return createInstance( ServiceSpecifier );
+    const Reference< XInterface > xInstance( createInstance( ServiceSpecifier ) );
+    const Reference< XInitialization > xInstanceInit( xInstance, UNO_QUERY );
+    ENSURE_OR_RETURN( xInstanceInit.is(), "ControlModelContainerBase::createInstanceWithArguments: can't pass the arguments!", xInstance );
+    xInstanceInit->initialize( i_arguments );
+    return xInstance;
 }
 
 Sequence< ::rtl::OUString > ControlModelContainerBase::getAvailableServiceNames() throw(RuntimeException)
@@ -595,7 +592,7 @@ void ControlModelContainerBase::insertByName( const ::rtl::OUString& aName, cons
 
 
 
-    if ( !aName.getLength() || !xM.is() )
+    if ( aName.isEmpty() || !xM.is() )
         lcl_throwIllegalArgumentException();
 
     UnoControlModelHolderList::iterator aElementPos = ImplFindElement( aName );
@@ -826,11 +823,11 @@ void SAL_CALL ControlModelContainerBase::setImageURL( const ::rtl::OUString& _im
 {
     m_sImageURL = _imageurl;
 }
-::rtl::OUString SAL_CALL ControlModelContainerBase::getTooltip() throw (::com::sun::star::uno::RuntimeException)
+::rtl::OUString SAL_CALL ControlModelContainerBase::getToolTip() throw (::com::sun::star::uno::RuntimeException)
 {
     return m_sTooltip;
 }
-void SAL_CALL ControlModelContainerBase::setTooltip( const ::rtl::OUString& _tooltip ) throw (::com::sun::star::uno::RuntimeException)
+void SAL_CALL ControlModelContainerBase::setToolTip( const ::rtl::OUString& _tooltip ) throw (::com::sun::star::uno::RuntimeException)
 {
     m_sTooltip = _tooltip;
 }
@@ -1391,7 +1388,7 @@ void ControlContainerBase::ImplInsertControl( Reference< XControlModel >& rxMode
     Reference < XControl > xCtrl;
     maContext.createComponent( aDefCtrl, xCtrl );
 
-    DBG_ASSERT( xCtrl.is(), "UnoDialogControl::ImplInsertControl: could not create the control!" );
+    DBG_ASSERT( xCtrl.is(), "ControlContainerBase::ImplInsertControl: could not create the control!" );
     if ( xCtrl.is() )
     {
         xCtrl->setModel( rxModel );
@@ -1454,7 +1451,7 @@ void ControlContainerBase::ImplSetPosSize( Reference< XControl >& rxCtrl )
         FontDescriptor aFD;
         Any aVal = ImplGetPropertyValue( GetPropertyName( BASEPROPERTY_FONTDESCRIPTOR ) );
         aVal >>= aFD;
-        if ( aFD.StyleName.getLength() )
+        if ( !aFD.StyleName.isEmpty() )
         {
             Reference< XFont > xFont = xD->getFont( aFD );
             aFM = xFont->getFontMetric();
@@ -1607,7 +1604,7 @@ void ControlContainerBase::elementInserted( const ContainerEvent& Event ) throw(
 
     Event.Accessor >>= aName;
     Event.Element >>= xModel;
-    ENSURE_OR_RETURN_VOID( xModel.is(), "UnoDialogControl::elementInserted: illegal element!" );
+    ENSURE_OR_RETURN_VOID( xModel.is(), "ControlContainerBase::elementInserted: illegal element!" );
     try
     {
         ImplInsertControl( xModel, aName );
@@ -1628,7 +1625,7 @@ void ControlContainerBase::elementRemoved( const ContainerEvent& Event ) throw(R
 
     Reference< XControlModel > xModel;
     Event.Element >>= xModel;
-    ENSURE_OR_RETURN_VOID( xModel.is(), "UnoDialogControl::elementRemoved: illegal element!" );
+    ENSURE_OR_RETURN_VOID( xModel.is(), "ControlContainerBase::elementRemoved: illegal element!" );
     try
     {
         ImplRemoveControl( xModel );
@@ -1651,7 +1648,7 @@ void ControlContainerBase::elementReplaced( const ContainerEvent& Event ) throw(
     Event.ReplacedElement >>= xModel;
     try
     {
-        OSL_ENSURE( xModel.is(), "UnoDialogControl::elementReplaced: invalid ReplacedElement!" );
+        OSL_ENSURE( xModel.is(), "ControlContainerBase::elementReplaced: invalid ReplacedElement!" );
         if ( xModel.is() )
             ImplRemoveControl( xModel );
     }
@@ -1667,7 +1664,7 @@ void ControlContainerBase::elementReplaced( const ContainerEvent& Event ) throw(
     ::rtl::OUString aName;
     Event.Accessor >>= aName;
     Event.Element >>= xModel;
-    ENSURE_OR_RETURN_VOID( xModel.is(), "UnoDialogControl::elementReplaced: invalid new element!" );
+    ENSURE_OR_RETURN_VOID( xModel.is(), "ControlContainerBase::elementReplaced: invalid new element!" );
     try
     {
         ImplInsertControl( xModel, aName );
@@ -1772,7 +1769,7 @@ void SAL_CALL ControlContainerBase::changesOccurred( const ChangesEvent& ) throw
     if ( mxTabController.is() && !mbDesignMode )
         mxTabController->activateTabOrder();
 }
-void lcl_ApplyResolverToNestedContainees(  const Reference< resource::XStringResourceResolver >& xStringResourceResolver, const Reference< XControlContainer >& xContainer )
+static void lcl_ApplyResolverToNestedContainees(  const Reference< resource::XStringResourceResolver >& xStringResourceResolver, const Reference< XControlContainer >& xContainer )
 {
     rtl::OUString aPropName( PROPERTY_RESOURCERESOLVER );
 
@@ -1870,7 +1867,7 @@ void ControlContainerBase::ImplUpdateResourceResolver()
     rUrl  >>= url;
 
     ::rtl::OUString absoluteURL( url );
-    if ( url.getLength() > 0 )
+    if ( !url.isEmpty() )
     {
         INetURLObject urlObj(baseLocation);
         urlObj.removeSegment();
