@@ -1,30 +1,21 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 
 /**************************************************************************
@@ -82,17 +73,17 @@ struct DataSupplier_Impl
     osl::Mutex                                   m_aMutex;
     ResultList                                   m_aResults;
     rtl::Reference< Content >                    m_xContent;
-    uno::Reference< lang::XMultiServiceFactory > m_xSMgr;
+    uno::Reference< uno::XComponentContext >     m_xContext;
     uno::Sequence< rtl::OUString > *             m_pNamesOfChildren;
     sal_Int32                                    m_nOpenMode;
     bool                                         m_bCountFinal;
     bool                                         m_bThrowException;
 
     DataSupplier_Impl(
-            const uno::Reference< lang::XMultiServiceFactory >& rxSMgr,
+            const uno::Reference< uno::XComponentContext >& rxContext,
             const rtl::Reference< Content >& rContent,
             sal_Int32 nOpenMode )
-    : m_xContent( rContent ), m_xSMgr( rxSMgr ),
+    : m_xContent( rContent ), m_xContext( rxContext ),
       m_pNamesOfChildren( 0 ), m_nOpenMode( nOpenMode ),
       m_bCountFinal( false ), m_bThrowException( false )
     {}
@@ -125,10 +116,10 @@ DataSupplier_Impl::~DataSupplier_Impl()
 //=========================================================================
 
 ResultSetDataSupplier::ResultSetDataSupplier(
-                const uno::Reference< lang::XMultiServiceFactory >& rxSMgr,
+                const uno::Reference< uno::XComponentContext >& rxContext,
                 const rtl::Reference< Content >& rContent,
                 sal_Int32 nOpenMode )
-: m_pImpl( new DataSupplier_Impl( rxSMgr, rContent, nOpenMode ) )
+: m_pImpl( new DataSupplier_Impl( rxContext, rContent, nOpenMode ) )
 {
 }
 
@@ -149,7 +140,7 @@ ResultSetDataSupplier::queryContentIdentifierString( sal_uInt32 nIndex )
     if ( nIndex < m_pImpl->m_aResults.size() )
     {
         rtl::OUString aId = m_pImpl->m_aResults[ nIndex ]->aURL;
-        if ( aId.getLength() )
+        if ( !aId.isEmpty() )
         {
             // Already cached.
             return aId;
@@ -183,7 +174,7 @@ ResultSetDataSupplier::queryContentIdentifier( sal_uInt32 nIndex )
     }
 
     rtl::OUString aId = queryContentIdentifierString( nIndex );
-    if ( aId.getLength() )
+    if ( !aId.isEmpty() )
     {
         uno::Reference< ucb::XContentIdentifier > xId
             = new ::ucbhelper::ContentIdentifier( aId );
@@ -262,7 +253,7 @@ sal_Bool ResultSetDataSupplier::getResult( sal_uInt32 nIndex )
             const rtl::OUString & rName
                 = m_pImpl->m_pNamesOfChildren->getConstArray()[ n ];
 
-            if ( !rName.getLength() )
+            if ( rName.isEmpty() )
             {
                 OSL_FAIL( "ResultDataSupplier::getResult - Empty name!" );
                 break;
@@ -322,7 +313,7 @@ sal_uInt32 ResultSetDataSupplier::totalCount()
             const rtl::OUString & rName
                 = m_pImpl->m_pNamesOfChildren->getConstArray()[ n ];
 
-            if ( !rName.getLength() )
+            if ( rName.isEmpty() )
             {
                 OSL_FAIL( "ResultDataSupplier::getResult - Empty name!" );
                 break;
@@ -386,7 +377,7 @@ ResultSetDataSupplier::queryPropertyValues( sal_uInt32 nIndex  )
     if ( getResult( nIndex ) )
     {
         uno::Reference< sdbc::XRow > xRow = Content::getPropertyValues(
-                        m_pImpl->m_xSMgr,
+                        m_pImpl->m_xContext,
                         getResultSet()->getProperties(),
                         m_pImpl->m_xContent->getContentProvider().get(),
                         queryContentIdentifierString( nIndex ) );
@@ -458,7 +449,7 @@ ResultSetDataSupplier::assembleChildURL( const ::rtl::OUString& aName )
 
     sal_Int32 nUrlEnd = aURL.lastIndexOf( '/' );
     if ( nUrlEnd != aURL.getLength() - 1 )
-        aURL += rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("/"));
+        aURL += rtl::OUString("/");
 
     aURL += aName;
     return aURL;
