@@ -1,43 +1,35 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
+#include <i18npool/mslangid.hxx>
 #include <unotools/fontcfg.hxx>
 #include <unotools/fontdefs.hxx>
 #include <comphelper/processfactory.hxx>
 #include <com/sun/star/uno/Any.hxx>
 #include <com/sun/star/uno/Sequence.hxx>
 #include <com/sun/star/beans/PropertyValue.hpp>
-#include <unotools/configpathes.hxx>
+#include <com/sun/star/configuration/theDefaultProvider.hpp>
+#include <unotools/configpaths.hxx>
 #include <unotools/syslocale.hxx>
 #include <rtl/ustrbuf.hxx>
 #include <rtl/instance.hxx>
 #include <sal/macros.h>
-#include <tools/debug.hxx>
 
 #if OSL_DEBUG_LEVEL > 1
 #include <stdio.h>
@@ -47,14 +39,12 @@
 #include <list>
 #include <algorithm>
 
-#define DEFAULTFONT_CONFIGNODE "VCL/DefaultFonts"
-#define SUBSTFONT_CONFIGNODE "VCL/FontSubstitutions"
-
 using namespace utl;
 using namespace com::sun::star::uno;
 using namespace com::sun::star::lang;
 using namespace com::sun::star::beans;
 using namespace com::sun::star::container;
+using namespace com::sun::star::configuration;
 
 using ::rtl::OUString;
 
@@ -114,61 +104,51 @@ DefaultFontConfiguration::DefaultFontConfiguration()
     try
     {
         // get service provider
-        Reference< XMultiServiceFactory > xSMgr( comphelper::getProcessServiceFactory() );
+        Reference< XComponentContext > xContext( comphelper::getProcessComponentContext() );
         // create configuration hierachical access name
-        if( xSMgr.is() )
+        try
         {
-            try
+            m_xConfigProvider = theDefaultProvider::get( xContext );
+            Sequence< Any > aArgs(1);
+            PropertyValue aVal;
+            aVal.Name = OUString( RTL_CONSTASCII_USTRINGPARAM( "nodepath" ) );
+            aVal.Value <<= OUString( RTL_CONSTASCII_USTRINGPARAM( "/org.openoffice.VCL/DefaultFonts" ) );
+            aArgs.getArray()[0] <<= aVal;
+            m_xConfigAccess =
+                Reference< XNameAccess >(
+                    m_xConfigProvider->createInstanceWithArguments( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(
+                                        "com.sun.star.configuration.ConfigurationAccess" )),
+                                                                    aArgs ),
+                    UNO_QUERY );
+            if( m_xConfigAccess.is() )
             {
-                m_xConfigProvider =
-                    Reference< XMultiServiceFactory >(
-                        xSMgr->createInstance( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(
-                                        "com.sun.star.configuration.ConfigurationProvider" ))),
-                        UNO_QUERY );
-                if( m_xConfigProvider.is() )
+                Sequence< OUString > aLocales = m_xConfigAccess->getElementNames();
+                // fill config hash with empty interfaces
+                int nLocales = aLocales.getLength();
+                const OUString* pLocaleStrings = aLocales.getConstArray();
+                Locale aLoc;
+                for( int i = 0; i < nLocales; i++ )
                 {
-                    Sequence< Any > aArgs(1);
-                    PropertyValue aVal;
-                    aVal.Name = OUString( RTL_CONSTASCII_USTRINGPARAM( "nodepath" ) );
-                    aVal.Value <<= OUString( RTL_CONSTASCII_USTRINGPARAM( "/org.openoffice.VCL/DefaultFonts" ) );
-                    aArgs.getArray()[0] <<= aVal;
-                    m_xConfigAccess =
-                        Reference< XNameAccess >(
-                            m_xConfigProvider->createInstanceWithArguments( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(
-                                                "com.sun.star.configuration.ConfigurationAccess" )),
-                                                                            aArgs ),
-                            UNO_QUERY );
-                    if( m_xConfigAccess.is() )
-                    {
-                        Sequence< OUString > aLocales = m_xConfigAccess->getElementNames();
-                        // fill config hash with empty interfaces
-                        int nLocales = aLocales.getLength();
-                        const OUString* pLocaleStrings = aLocales.getConstArray();
-                        Locale aLoc;
-                        for( int i = 0; i < nLocales; i++ )
-                        {
-                            sal_Int32 nIndex = 0;
-                            aLoc.Language = pLocaleStrings[i].getToken( 0, sal_Unicode('-'), nIndex ).toAsciiLowerCase();
-                            if( nIndex != -1 )
-                                aLoc.Country = pLocaleStrings[i].getToken( 0, sal_Unicode('-'), nIndex ).toAsciiUpperCase();
-                            else
-                                aLoc.Country = OUString();
-                            if( nIndex != -1 )
-                                aLoc.Variant = pLocaleStrings[i].getToken( 0, sal_Unicode('-'), nIndex ).toAsciiUpperCase();
-                            else
-                                aLoc.Variant = OUString();
-                            m_aConfig[ aLoc ] = LocaleAccess();
-                            m_aConfig[ aLoc ].aConfigLocaleString = pLocaleStrings[i];
-                        }
-                    }
+                    sal_Int32 nIndex = 0;
+                    aLoc.Language = pLocaleStrings[i].getToken( 0, sal_Unicode('-'), nIndex ).toAsciiLowerCase();
+                    if( nIndex != -1 )
+                        aLoc.Country = pLocaleStrings[i].getToken( 0, sal_Unicode('-'), nIndex ).toAsciiUpperCase();
+                    else
+                        aLoc.Country = OUString();
+                    if( nIndex != -1 )
+                        aLoc.Variant = pLocaleStrings[i].getToken( 0, sal_Unicode('-'), nIndex ).toAsciiUpperCase();
+                    else
+                        aLoc.Variant = OUString();
+                    m_aConfig[ aLoc ] = LocaleAccess();
+                    m_aConfig[ aLoc ].aConfigLocaleString = pLocaleStrings[i];
                 }
             }
-            catch (const Exception&)
-            {
-                // configuration is awry
-                m_xConfigProvider.clear();
-                m_xConfigAccess.clear();
-            }
+        }
+        catch (const Exception&)
+        {
+            // configuration is awry
+            m_xConfigProvider.clear();
+            m_xConfigAccess.clear();
         }
     }
     catch (const WrappedTargetException&)
@@ -250,17 +230,17 @@ OUString DefaultFontConfiguration::getDefaultFont( const Locale& rLocale, int nT
 
     OUString aType = OUString::createFromAscii( getKeyType( nType ) );
     OUString aRet = tryLocale( aLocale, aType );
-    if( ! aRet.getLength() && aLocale.Variant.getLength() )
+    if( aRet.isEmpty() && !aLocale.Variant.isEmpty() )
     {
         aLocale.Variant = OUString();
         aRet = tryLocale( aLocale, aType );
     }
-    if( ! aRet.getLength() && aLocale.Country.getLength() )
+    if( aRet.isEmpty() && !aLocale.Country.isEmpty() )
     {
         aLocale.Country = OUString();
         aRet = tryLocale( aLocale, aType );
     }
-    if( ! aRet.getLength() )
+    if( aRet.isEmpty() )
     {
         aLocale.Language = OUString( RTL_CONSTASCII_USTRINGPARAM( "en" ) );
         aRet = tryLocale( aLocale, aType );
@@ -271,12 +251,12 @@ OUString DefaultFontConfiguration::getDefaultFont( const Locale& rLocale, int nT
 OUString DefaultFontConfiguration::getUserInterfaceFont( const Locale& rLocale ) const
 {
     Locale aLocale = rLocale;
-    if( ! aLocale.Language.getLength() )
-        aLocale = SvtSysLocale().GetUILocale();
+    if( aLocale.Language.isEmpty() )
+        aLocale = SvtSysLocale().GetUILanguageTag().getLocale();
 
     OUString aUIFont = getDefaultFont( aLocale, DEFAULTFONT_UI_SANS );
 
-    if( aUIFont.getLength() )
+    if( !aUIFont.isEmpty() )
         return aUIFont;
 
     // fallback mechanism (either no configuration or no entry in configuration
@@ -291,58 +271,31 @@ OUString DefaultFontConfiguration::getUserInterfaceFont( const Locale& rLocale )
     #define FALLBACKFONT_UI_SANS_CHINSIM "Andale Sans UI;Arial Unicode MS;ZYSong18030;AR PL SungtiL GB;AR PL KaitiM GB;SimSun;Lucida Sans Unicode;Fangsong;Hei;Song;Kai;Ming;gnu-unifont;Interface User;"
     #define FALLBACKFONT_UI_SANS_CHINTRD "Andale Sans UI;Arial Unicode MS;AR PL Mingti2L Big5;AR PL KaitiM Big5;Kai;PMingLiU;MingLiU;Ming;Lucida Sans Unicode;gnu-unifont;Interface User;"
 
-    // we need localized names for japanese fonts
-    static sal_Unicode const aMSGothic[] = { 0xFF2D, 0xFF33, ' ', 0x30B4, 0x30B7, 0x30C3, 0x30AF, 0, 0 };
-    static sal_Unicode const aMSPGothic[] = { 0xFF2D, 0xFF33, ' ', 0xFF30, 0x30B4, 0x30B7, 0x30C3, 0x30AF, 0, 0 };
-    static sal_Unicode const aTLPGothic[] = { 0x0054, 0x004C, 0x0050, 0x30B4, 0x30B7, 0x30C3, 0x30AF, 0, 0 };
-    static sal_Unicode const aLXGothic[] = { 0x004C, 0x0058, 0x30B4, 0x30B7, 0x30C3, 0x30AF, 0, 0 };
-    static sal_Unicode const aKochiGothic[] = { 0x6771, 0x98A8, 0x30B4, 0x30B7, 0x30C3, 0x30AF, 0, 0 };
-
-    String aFallBackJapaneseLocalized( RTL_CONSTASCII_USTRINGPARAM( "MS UI Gothic;" ) );
-    aFallBackJapaneseLocalized += String( RTL_CONSTASCII_USTRINGPARAM( FALLBACKFONT_UI_SANS_JAPANESE1 ) );
-    aFallBackJapaneseLocalized += String( aMSPGothic );
-    aFallBackJapaneseLocalized += String(RTL_CONSTASCII_USTRINGPARAM( ";" ) );
-    aFallBackJapaneseLocalized += String( aMSGothic );
-    aFallBackJapaneseLocalized += String(RTL_CONSTASCII_USTRINGPARAM( ";" ) );
-    aFallBackJapaneseLocalized += String( aTLPGothic );
-    aFallBackJapaneseLocalized += String(RTL_CONSTASCII_USTRINGPARAM( ";" ) );
-    aFallBackJapaneseLocalized += String( aLXGothic );
-    aFallBackJapaneseLocalized += String(RTL_CONSTASCII_USTRINGPARAM( ";" ) );
-    aFallBackJapaneseLocalized += String( aKochiGothic );
-    aFallBackJapaneseLocalized += String(RTL_CONSTASCII_USTRINGPARAM( ";" ) );
-    aFallBackJapaneseLocalized += String(RTL_CONSTASCII_USTRINGPARAM( FALLBACKFONT_UI_SANS_JAPANESE2 ) );
-    static const OUString aFallBackJapanese( aFallBackJapaneseLocalized );
-    static const OUString aFallback (RTL_CONSTASCII_USTRINGPARAM(FALLBACKFONT_UI_SANS));
-    static const OUString aFallbackLatin2 (RTL_CONSTASCII_USTRINGPARAM(FALLBACKFONT_UI_SANS_LATIN2));
-    static const OUString aFallBackArabic (RTL_CONSTASCII_USTRINGPARAM( FALLBACKFONT_UI_SANS_ARABIC ) );
-    static const OUString aFallBackThai (RTL_CONSTASCII_USTRINGPARAM( FALLBACKFONT_UI_SANS_THAI ) );
-    static const OUString aFallBackChineseSIM (RTL_CONSTASCII_USTRINGPARAM( FALLBACKFONT_UI_SANS_CHINSIM ) );
-    static const OUString aFallBackChineseTRD (RTL_CONSTASCII_USTRINGPARAM( FALLBACKFONT_UI_SANS_CHINTRD ) );
-
-    // we need localized names for korean fonts
-    static sal_Unicode const aSunGulim[] = { 0xC36C, 0xAD74, 0xB9BC, 0 };
-    static sal_Unicode const aBaekmukGulim[] = { 0xBC31, 0xBC35, 0xAD74, 0xB9BC, 0 };
-    String aFallBackKoreanLocalized( aSunGulim );
-    aFallBackKoreanLocalized += String(RTL_CONSTASCII_USTRINGPARAM( ";" ) );
-    aFallBackKoreanLocalized += String( aBaekmukGulim );
-    aFallBackKoreanLocalized += String(RTL_CONSTASCII_USTRINGPARAM( ";" ) );
-    aFallBackKoreanLocalized += String(RTL_CONSTASCII_USTRINGPARAM( FALLBACKFONT_UI_SANS_KOREAN ) );
-    static const OUString aFallBackKorean( aFallBackKoreanLocalized );
-
     // optimize font list for some locales, as long as Andale Sans UI does not support them
     if( aLocale.Language.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "ar" ) ) ||
         aLocale.Language.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "he" ) ) ||
         aLocale.Language.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "iw" ) ) )
     {
-        return aFallBackArabic;
+        return rtl::OUString(FALLBACKFONT_UI_SANS_ARABIC);
     }
-    else if( aLocale.Language.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "th" ) ) )
+    else if ( aLocale.Language == "th" )
     {
-        return aFallBackThai;
+        return rtl::OUString(FALLBACKFONT_UI_SANS_THAI);
     }
-    else if( aLocale.Language.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "ko" ) ) )
+    else if ( aLocale.Language == "ko" )
     {
-        return aFallBackKorean;
+        // we need localized names for korean fonts
+        const sal_Unicode aSunGulim[] = { 0xC36C, 0xAD74, 0xB9BC, 0 };
+        const sal_Unicode aBaekmukGulim[] = { 0xBC31, 0xBC35, 0xAD74, 0xB9BC, 0 };
+
+        rtl::OUStringBuffer aFallBackKoreanLocalized;
+        aFallBackKoreanLocalized.append(aSunGulim);
+        aFallBackKoreanLocalized.append(';');
+        aFallBackKoreanLocalized.append(aBaekmukGulim);
+        aFallBackKoreanLocalized.append(";");
+        aFallBackKoreanLocalized.append(FALLBACKFONT_UI_SANS_KOREAN);
+
+        return aFallBackKoreanLocalized.makeStringAndClear();
     }
     else if( aLocale.Language.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "cs" ) ) ||
              aLocale.Language.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "hu" ) ) ||
@@ -354,21 +307,40 @@ OUString DefaultFontConfiguration::getUserInterfaceFont( const Locale& rLocale )
              aLocale.Language.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "sl" ) ) ||
              aLocale.Language.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "sb" ) ) )
     {
-        return aFallbackLatin2;
+        return rtl::OUString(FALLBACKFONT_UI_SANS_LATIN2);
     }
-    else if( aLocale.Language.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "zh" ) ) )
+    else if (MsLangId::isTraditionalChinese(aLocale))
+        return rtl::OUString(FALLBACKFONT_UI_SANS_CHINTRD);
+    else if (MsLangId::isSimplifiedChinese(aLocale))
+        return rtl::OUString(FALLBACKFONT_UI_SANS_CHINSIM);
+    else if ( aLocale.Language == "ja" )
     {
-        if( ! aLocale.Country.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "cn" ) ) )
-            return aFallBackChineseTRD;
-        else
-            return aFallBackChineseSIM;
-    }
-    else if( aLocale.Language.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "ja" ) ) )
-    {
-        return aFallBackJapanese;
+        // we need localized names for japanese fonts
+        const sal_Unicode aMSGothic[] = { 0xFF2D, 0xFF33, ' ', 0x30B4, 0x30B7, 0x30C3, 0x30AF, 0 };
+        const sal_Unicode aMSPGothic[] = { 0xFF2D, 0xFF33, ' ', 0xFF30, 0x30B4, 0x30B7, 0x30C3, 0x30AF, 0 };
+        const sal_Unicode aTLPGothic[] = { 0x0054, 0x004C, 0x0050, 0x30B4, 0x30B7, 0x30C3, 0x30AF, 0 };
+        const sal_Unicode aLXGothic[] = { 0x004C, 0x0058, 0x30B4, 0x30B7, 0x30C3, 0x30AF, 0 };
+        const sal_Unicode aKochiGothic[] = { 0x6771, 0x98A8, 0x30B4, 0x30B7, 0x30C3, 0x30AF, 0 };
+
+        rtl::OUStringBuffer aFallBackJapaneseLocalized;
+        aFallBackJapaneseLocalized.append("MS UI Gothic;");
+        aFallBackJapaneseLocalized.append(FALLBACKFONT_UI_SANS_JAPANESE1);
+        aFallBackJapaneseLocalized.append(aMSPGothic);
+        aFallBackJapaneseLocalized.append(';');
+        aFallBackJapaneseLocalized.append(aMSGothic);
+        aFallBackJapaneseLocalized.append(';');
+        aFallBackJapaneseLocalized.append(aTLPGothic);
+        aFallBackJapaneseLocalized.append(';');
+        aFallBackJapaneseLocalized.append(aLXGothic);
+        aFallBackJapaneseLocalized.append(';');
+        aFallBackJapaneseLocalized.append(aKochiGothic);
+        aFallBackJapaneseLocalized.append(';');
+        aFallBackJapaneseLocalized.append(FALLBACKFONT_UI_SANS_JAPANESE2);
+
+        return aFallBackJapaneseLocalized.makeStringAndClear();
     }
 
-   return aFallback;
+    return rtl::OUString(FALLBACKFONT_UI_SANS);
 }
 
 // ------------------------------------------------------------------------------------
@@ -400,61 +372,51 @@ FontSubstConfiguration::FontSubstConfiguration() :
     try
     {
         // get service provider
-        Reference< XMultiServiceFactory > xSMgr( comphelper::getProcessServiceFactory() );
+        Reference< XComponentContext > xContext( comphelper::getProcessComponentContext() );
         // create configuration hierachical access name
-        if( xSMgr.is() )
+        try
         {
-            try
+            m_xConfigProvider = theDefaultProvider::get( xContext );
+            Sequence< Any > aArgs(1);
+            PropertyValue aVal;
+            aVal.Name = OUString( RTL_CONSTASCII_USTRINGPARAM( "nodepath" ) );
+            aVal.Value <<= OUString( RTL_CONSTASCII_USTRINGPARAM( "/org.openoffice.VCL/FontSubstitutions" ) );
+            aArgs.getArray()[0] <<= aVal;
+            m_xConfigAccess =
+                Reference< XNameAccess >(
+                    m_xConfigProvider->createInstanceWithArguments( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(
+                                        "com.sun.star.configuration.ConfigurationAccess" )),
+                                                                    aArgs ),
+                    UNO_QUERY );
+            if( m_xConfigAccess.is() )
             {
-                m_xConfigProvider =
-                    Reference< XMultiServiceFactory >(
-                        xSMgr->createInstance( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(
-                                        "com.sun.star.configuration.ConfigurationProvider" ))),
-                        UNO_QUERY );
-                if( m_xConfigProvider.is() )
+                Sequence< OUString > aLocales = m_xConfigAccess->getElementNames();
+                // fill config hash with empty interfaces
+                int nLocales = aLocales.getLength();
+                const OUString* pLocaleStrings = aLocales.getConstArray();
+                Locale aLoc;
+                for( int i = 0; i < nLocales; i++ )
                 {
-                    Sequence< Any > aArgs(1);
-                    PropertyValue aVal;
-                    aVal.Name = OUString( RTL_CONSTASCII_USTRINGPARAM( "nodepath" ) );
-                    aVal.Value <<= OUString( RTL_CONSTASCII_USTRINGPARAM( "/org.openoffice.VCL/FontSubstitutions" ) );
-                    aArgs.getArray()[0] <<= aVal;
-                    m_xConfigAccess =
-                        Reference< XNameAccess >(
-                            m_xConfigProvider->createInstanceWithArguments( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(
-                                                "com.sun.star.configuration.ConfigurationAccess" )),
-                                                                            aArgs ),
-                            UNO_QUERY );
-                    if( m_xConfigAccess.is() )
-                    {
-                        Sequence< OUString > aLocales = m_xConfigAccess->getElementNames();
-                        // fill config hash with empty interfaces
-                        int nLocales = aLocales.getLength();
-                        const OUString* pLocaleStrings = aLocales.getConstArray();
-                        Locale aLoc;
-                        for( int i = 0; i < nLocales; i++ )
-                        {
-                            sal_Int32 nIndex = 0;
-                            aLoc.Language = pLocaleStrings[i].getToken( 0, sal_Unicode('-'), nIndex ).toAsciiLowerCase();
-                            if( nIndex != -1 )
-                                aLoc.Country = pLocaleStrings[i].getToken( 0, sal_Unicode('-'), nIndex ).toAsciiUpperCase();
-                            else
-                                aLoc.Country = OUString();
-                            if( nIndex != -1 )
-                                aLoc.Variant = pLocaleStrings[i].getToken( 0, sal_Unicode('-'), nIndex ).toAsciiUpperCase();
-                            else
-                                aLoc.Variant = OUString();
-                            m_aSubst[ aLoc ] = LocaleSubst();
-                            m_aSubst[ aLoc ].aConfigLocaleString = pLocaleStrings[i];
-                        }
-                    }
+                    sal_Int32 nIndex = 0;
+                    aLoc.Language = pLocaleStrings[i].getToken( 0, sal_Unicode('-'), nIndex ).toAsciiLowerCase();
+                    if( nIndex != -1 )
+                        aLoc.Country = pLocaleStrings[i].getToken( 0, sal_Unicode('-'), nIndex ).toAsciiUpperCase();
+                    else
+                        aLoc.Country = OUString();
+                    if( nIndex != -1 )
+                        aLoc.Variant = pLocaleStrings[i].getToken( 0, sal_Unicode('-'), nIndex ).toAsciiUpperCase();
+                    else
+                        aLoc.Variant = OUString();
+                    m_aSubst[ aLoc ] = LocaleSubst();
+                    m_aSubst[ aLoc ].aConfigLocaleString = pLocaleStrings[i];
                 }
             }
-            catch (const Exception&)
-            {
-                // configuration is awry
-                m_xConfigProvider.clear();
-                m_xConfigAccess.clear();
-            }
+        }
+        catch (const Exception&)
+        {
+            // configuration is awry
+            m_xConfigProvider.clear();
+            m_xConfigAccess.clear();
         }
     }
     catch (const WrappedTargetException&)
@@ -697,8 +659,8 @@ static bool ImplKillLeading( String& rName, const char* const* ppStr )
     for(; *ppStr; ++ppStr )
     {
         const char*         pStr = *ppStr;
-        const xub_Unicode*  pNameStr = rName.GetBuffer();
-        while ( (*pNameStr == (xub_Unicode)(unsigned char)*pStr) && *pStr )
+        const sal_Unicode*  pNameStr = rName.GetBuffer();
+        while ( (*pNameStr == (sal_Unicode)(unsigned char)*pStr) && *pStr )
         {
             pNameStr++;
             pStr++;
@@ -713,7 +675,7 @@ static bool ImplKillLeading( String& rName, const char* const* ppStr )
 
     // special case for Baekmuk
     // TODO: allow non-ASCII KillLeading list
-    const xub_Unicode* pNameStr = rName.GetBuffer();
+    const sal_Unicode* pNameStr = rName.GetBuffer();
     if( (pNameStr[0]==0xBC31) && (pNameStr[1]==0xBC35) )
     {
         xub_StrLen nLen = (pNameStr[2]==0x0020) ? 3 : 2;
@@ -732,7 +694,7 @@ static xub_StrLen ImplIsTrailing( const String& rName, const char* pStr )
     if( nStrLen >= rName.Len() )
         return 0;
 
-    const xub_Unicode* pEndName = rName.GetBuffer() + rName.Len();
+    const sal_Unicode* pEndName = rName.GetBuffer() + rName.Len();
     const sal_Unicode* pNameStr = pEndName - nStrLen;
     do if( *(pNameStr++) != *(pStr++) )
         return 0;
@@ -979,7 +941,7 @@ void FontSubstConfiguration::fillSubstVector( const com::sun::star::uno::Referen
                 while( nIndex != -1 )
                 {
                     OUString aSubst( pLine->getToken( 0, ';', nIndex ) );
-                    if( aSubst.getLength() )
+                    if( !aSubst.isEmpty() )
                     {
                         UniqueSubstHash::iterator aEntry = maSubstHash.find( aSubst );
                         if (aEntry != maSubstHash.end())
@@ -1010,7 +972,7 @@ FontWeight FontSubstConfiguration::getSubstWeight( const com::sun::star::uno::Re
         if( aAny.getValueTypeClass() == TypeClass_STRING )
         {
             const OUString* pLine = (const OUString*)aAny.getValue();
-            if( pLine->getLength() )
+            if( !pLine->isEmpty() )
             {
                 for( weight=SAL_N_ELEMENTS(pWeightNames)-1; weight >= 0; weight-- )
                     if( pLine->equalsIgnoreAsciiCaseAscii( pWeightNames[weight].pName ) )
@@ -1042,7 +1004,7 @@ FontWidth FontSubstConfiguration::getSubstWidth( const com::sun::star::uno::Refe
         if( aAny.getValueTypeClass() == TypeClass_STRING )
         {
             const OUString* pLine = (const OUString*)aAny.getValue();
-            if( pLine->getLength() )
+            if( !pLine->isEmpty() )
             {
                 for( width=SAL_N_ELEMENTS(pWidthNames)-1; width >= 0; width-- )
                     if( pLine->equalsIgnoreAsciiCaseAscii( pWidthNames[width].pName ) )
@@ -1074,7 +1036,7 @@ unsigned long FontSubstConfiguration::getSubstType( const com::sun::star::uno::R
         if( aAny.getValueTypeClass() == TypeClass_STRING )
         {
             const OUString* pLine = (const OUString*)aAny.getValue();
-            if( pLine->getLength() )
+            if( !pLine->isEmpty() )
             {
                 sal_Int32 nIndex = 0;
                 while( nIndex != -1 )
@@ -1197,10 +1159,10 @@ const FontNameAttr* FontSubstConfiguration::getSubstInfo( const String& rFontNam
     aLocale.Country = rLocale.Country.toAsciiUpperCase();
     aLocale.Variant = rLocale.Variant.toAsciiUpperCase();
 
-    if( ! aLocale.Language.getLength() )
-        aLocale = SvtSysLocale().GetUILocale();
+    if( aLocale.Language.isEmpty() )
+        aLocale = SvtSysLocale().GetUILanguageTag().getLocale();
 
-    while( aLocale.Language.getLength() )
+    while( !aLocale.Language.isEmpty() )
     {
         boost::unordered_map< Locale, LocaleSubst, LocaleHash >::const_iterator lang = m_aSubst.find( aLocale );
         if( lang != m_aSubst.end() )
@@ -1221,11 +1183,11 @@ const FontNameAttr* FontSubstConfiguration::getSubstInfo( const String& rFontNam
             }
         }
         // gradually become more unspecific
-        if( aLocale.Variant.getLength() )
+        if( !aLocale.Variant.isEmpty() )
             aLocale.Variant = OUString();
-        else if( aLocale.Country.getLength() )
+        else if( !aLocale.Country.isEmpty() )
             aLocale.Country = OUString();
-        else if( ! aLocale.Language.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "en" ) ) )
+        else if( aLocale.Language != "en" )
             aLocale.Language = OUString( RTL_CONSTASCII_USTRINGPARAM( "en" ) );
         else
             aLocale.Language = OUString();
