@@ -1,30 +1,21 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 #include <com/sun/star/lang/XServiceInfo.hpp>
 #include <com/sun/star/frame/XDesktop.hpp>
 #include <com/sun/star/container/XNameAccess.hpp>
@@ -48,7 +39,7 @@ class CommandBarEnumeration : public CommandBarEnumeration_BASE
     uno::Reference< XHelperInterface > m_xParent;
     uno::Reference< uno::XComponentContext > m_xContext;
     VbaCommandBarHelperRef m_pCBarHelper;
-    uno::Sequence< rtl::OUString > m_sNames;
+    uno::Sequence< OUString > m_sNames;
     sal_Int32 m_nCurrentPosition;
 public:
     CommandBarEnumeration( const uno::Reference< XHelperInterface >& xParent, const uno::Reference< uno::XComponentContext >& xContext, VbaCommandBarHelperRef pHelper) throw ( uno::RuntimeException ) : m_xParent( xParent ), m_xContext( xContext ), m_pCBarHelper( pHelper ) , m_nCurrentPosition( 0 )
@@ -67,11 +58,11 @@ public:
         // FIXME: should be add menubar
         if( hasMoreElements() )
         {
-            rtl::OUString sResourceUrl( m_sNames[ m_nCurrentPosition++ ] );
-            if( sResourceUrl.indexOf( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("private:resource/toolbar/")) ) != -1 )
+            OUString sResourceUrl( m_sNames[ m_nCurrentPosition++ ] );
+            if( sResourceUrl.indexOf( "private:resource/toolbar/" ) != -1 )
             {
                 uno::Reference< container::XIndexAccess > xCBarSetting = m_pCBarHelper->getSettings( sResourceUrl );
-                uno::Reference< XCommandBar > xCommandBar( new ScVbaCommandBar( m_xParent, m_xContext, m_pCBarHelper, xCBarSetting, sResourceUrl, sal_False, sal_False ) );
+                uno::Reference< XCommandBar > xCommandBar( new ScVbaCommandBar( m_xParent, m_xContext, m_pCBarHelper, xCBarSetting, sResourceUrl, sal_False ) );
              }
              else
                 return nextElement();
@@ -109,21 +100,21 @@ uno::Any
 ScVbaCommandBars::createCollectionObject( const uno::Any& aSource )
 {
     // aSource should be a name at this time, because of the class is API wrapper.
-    rtl::OUString sResourceUrl;
+    OUString sResourceUrl;
     uno::Reference< container::XIndexAccess > xBarSettings;
-    rtl::OUString sBarName;
+    OUString sBarName;
     sal_Bool bMenu = sal_False;
     uno::Any aRet;
 
     if( aSource >>= sBarName )
     {
         // some built-in command bars
-        if( m_pCBarHelper->getModuleId().equalsAsciiL( RTL_CONSTASCII_STRINGPARAM("com.sun.star.sheet.SpreadsheetDocument") ) )
+        if( m_pCBarHelper->getModuleId() == "com.sun.star.sheet.SpreadsheetDocument" )
         {
             if( sBarName.equalsIgnoreAsciiCaseAsciiL( RTL_CONSTASCII_STRINGPARAM("Worksheet Menu Bar") ) )
             {
                 // spreadsheet menu bar
-                sResourceUrl = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( ITEM_MENUBAR_URL ));
+                sResourceUrl = ITEM_MENUBAR_URL;
                 bMenu = sal_True;
             }
             else if( sBarName.equalsIgnoreAsciiCaseAsciiL( RTL_CONSTASCII_STRINGPARAM("Cell") ) )
@@ -132,66 +123,62 @@ ScVbaCommandBars::createCollectionObject( const uno::Any& aSource )
                 aRet <<= uno::Reference< XCommandBar >( new VbaDummyCommandBar( this, mxContext, sBarName, office::MsoBarType::msoBarTypePopup ) );
             }
         }
-        else if( m_pCBarHelper->getModuleId().equalsAsciiL( RTL_CONSTASCII_STRINGPARAM("com.sun.star.text.TextDocument") ) )
+        else if( m_pCBarHelper->getModuleId() == "com.sun.star.text.TextDocument" )
         {
             if( sBarName.equalsIgnoreAsciiCaseAsciiL( RTL_CONSTASCII_STRINGPARAM("Menu Bar") ) )
             {
                 // text processor menu bar
-                sResourceUrl = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( ITEM_MENUBAR_URL ));
+                sResourceUrl = ITEM_MENUBAR_URL;
                 bMenu = sal_True;
             }
         }
 
         // nothing found - try to resolve from name
-        if( !aRet.hasValue() && (sResourceUrl.getLength() == 0) )
+        if( !aRet.hasValue() && sResourceUrl.isEmpty() )
         {
             sResourceUrl = m_pCBarHelper->findToolbarByName( m_xNameAccess, sBarName );
             bMenu = sal_False;
         }
     }
 
-    if( sResourceUrl.getLength() )
+    if( !sResourceUrl.isEmpty() )
     {
         xBarSettings = m_pCBarHelper->getSettings( sResourceUrl );
-        aRet <<= uno::Reference< XCommandBar >( new ScVbaCommandBar( this, mxContext, m_pCBarHelper, xBarSettings, sResourceUrl, bMenu, sal_False ) );
+        aRet <<= uno::Reference< XCommandBar >( new ScVbaCommandBar( this, mxContext, m_pCBarHelper, xBarSettings, sResourceUrl, bMenu ) );
     }
 
     if( !aRet.hasValue() )
-        throw uno::RuntimeException( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("Toolbar do not exist") ), uno::Reference< uno::XInterface >() );
+        throw uno::RuntimeException( "Toolbar do not exist" , uno::Reference< uno::XInterface >() );
 
     return aRet;
 }
 
 // XCommandBars
 uno::Reference< XCommandBar > SAL_CALL
-ScVbaCommandBars::Add( const css::uno::Any& Name, const css::uno::Any& /*Position*/, const css::uno::Any& /*MenuBar*/, const css::uno::Any& Temporary ) throw (css::script::BasicErrorException, css::uno::RuntimeException)
+ScVbaCommandBars::Add( const css::uno::Any& Name, const css::uno::Any& /*Position*/, const css::uno::Any& /*MenuBar*/, const css::uno::Any& /*Temporary*/ ) throw (css::script::BasicErrorException, css::uno::RuntimeException)
 {
     // FIXME: only support to add Toolbar
     // Position - MsoBar MenuBar - sal_Bool
     // Currently only the Name is supported.
-    rtl::OUString sName;
+    OUString sName;
     if( Name.hasValue() )
         Name >>= sName;
 
-    rtl::OUString sResourceUrl;
-    if( sName.getLength() )
+    OUString sResourceUrl;
+    if( !sName.isEmpty() )
     {
         sResourceUrl = m_pCBarHelper->findToolbarByName( m_xNameAccess, sName );
-        if( sResourceUrl.getLength() )
-            throw uno::RuntimeException( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("Toolbar exists") ), uno::Reference< uno::XInterface >() );
+        if( !sResourceUrl.isEmpty() )
+            throw uno::RuntimeException( "Toolbar exists" , uno::Reference< uno::XInterface >() );
     }
     else
     {
-        sName = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("Custom1") );
+        sName = "Custom1";
     }
 
-    sal_Bool bTemporary = sal_False;
-    if( Temporary.hasValue() )
-        Temporary >>= bTemporary;
-
     sResourceUrl = VbaCommandBarHelper::generateCustomURL();
     uno::Reference< container::XIndexAccess > xBarSettings( m_pCBarHelper->getSettings( sResourceUrl ), uno::UNO_QUERY_THROW );
-    uno::Reference< XCommandBar > xCBar( new ScVbaCommandBar( this, mxContext, m_pCBarHelper, xBarSettings, sResourceUrl, sal_False, bTemporary ) );
+    uno::Reference< XCommandBar > xCBar( new ScVbaCommandBar( this, mxContext, m_pCBarHelper, xBarSettings, sResourceUrl, sal_False ) );
     xCBar->setName( sName );
     return xCBar;
 }
@@ -200,10 +187,10 @@ ScVbaCommandBars::getCount() throw(css::uno::RuntimeException)
 {
     // Filter out all toolbars from the window collection
     sal_Int32 nCount = 1; // there is a Menubar in OOo
-    uno::Sequence< ::rtl::OUString > allNames = m_xNameAccess->getElementNames();
+    uno::Sequence< ::OUString > allNames = m_xNameAccess->getElementNames();
     for( sal_Int32 i = 0; i < allNames.getLength(); i++ )
     {
-        if(allNames[i].indexOf( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("private:resource/toolbar/")) ) != -1 )
+        if(allNames[i].indexOf( "private:resource/toolbar/" ) != -1 )
         {
             nCount++;
         }
@@ -226,10 +213,10 @@ ScVbaCommandBars::Item( const uno::Any& aIndex, const uno::Any& /*aIndex2*/ ) th
     if( nIndex == 1 )
     {
         uno::Any aSource;
-        if( m_pCBarHelper->getModuleId().equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "com.sun.star.sheet.SpreadsheetDocument" ) ) )
-            aSource <<= rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Worksheet Menu Bar"));
-        else if( m_pCBarHelper->getModuleId().equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("com.sun.star.text.TextDocument")) )
-            aSource <<= rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Menu Bar"));
+        if( m_pCBarHelper->getModuleId() == "com.sun.star.sheet.SpreadsheetDocument" )
+            aSource <<= OUString("Worksheet Menu Bar");
+        else if( m_pCBarHelper->getModuleId() == "com.sun.star.text.TextDocument" )
+            aSource <<= OUString("Menu Bar");
         if( aSource.hasValue() )
             return createCollectionObject( aSource );
     }
@@ -237,20 +224,20 @@ ScVbaCommandBars::Item( const uno::Any& aIndex, const uno::Any& /*aIndex2*/ ) th
 }
 
 // XHelperInterface
-rtl::OUString&
+OUString
 ScVbaCommandBars::getServiceImplName()
 {
-    static rtl::OUString sImplName( RTL_CONSTASCII_USTRINGPARAM("ScVbaCommandBars") );
-    return sImplName;
+    return OUString("ScVbaCommandBars");
 }
-uno::Sequence<rtl::OUString>
+
+uno::Sequence<OUString>
 ScVbaCommandBars::getServiceNames()
 {
-    static uno::Sequence< rtl::OUString > aServiceNames;
+    static uno::Sequence< OUString > aServiceNames;
     if ( aServiceNames.getLength() == 0 )
     {
         aServiceNames.realloc( 1 );
-        aServiceNames[ 0 ] = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("ooo.vba.CommandBars" ) );
+        aServiceNames[ 0 ] = "ooo.vba.CommandBars";
     }
     return aServiceNames;
 }
