@@ -1,31 +1,21 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
-
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 #include <functional>
 #include <algorithm>
@@ -41,11 +31,9 @@
 #include <vcl/virdev.hxx>
 #include <vcl/metaact.hxx>
 #include <vcl/gdimtf.hxx>
-#include <vcl/salbtype.hxx>
 #include <vcl/print.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/bmpacc.hxx>
-#include <vcl/rendergraphicrasterizer.hxx>
 
 #include <print.h>
 
@@ -114,9 +102,6 @@ static bool ImplIsActionSpecial( const MetaAction& rAct )
         case META_BMPEXSCALEPART_ACTION:
             return static_cast<const MetaBmpExScalePartAction&>(rAct).GetBitmapEx().IsTransparent();
 
-        case META_RENDERGRAPHIC_ACTION:
-            return true;
-
         default:
             return false;
     }
@@ -204,16 +189,6 @@ static void ImplConvertTransparentAction( GDIMetaFile&        o_rMtf,
                 aBmpEx = static_cast<const MetaBmpExScaleAction&>(rAct).GetBitmapEx();
                 break;
 
-            case META_RENDERGRAPHIC_ACTION:
-            {
-                const ::vcl::RenderGraphicRasterizer aRasterizer( static_cast<const MetaRenderGraphicAction&>(rAct).
-                                                                      GetRenderGraphic() );
-
-                aBmpEx = aRasterizer.Rasterize( rStateOutDev.LogicToPixel(
-                             static_cast<const MetaRenderGraphicAction&>(rAct).GetSize() ) );
-                break;
-            }
-
             case META_TRANSPARENT_ACTION:
 
             default:
@@ -281,11 +256,6 @@ static void ImplConvertTransparentAction( GDIMetaFile&        o_rMtf,
                                        static_cast<const MetaBmpExScalePartAction&>(rAct).GetSrcSize(),
                                        aBmp ));
                 break;
-            case META_RENDERGRAPHIC_ACTION:
-                o_rMtf.AddAction( new MetaBmpScaleAction(
-                                       static_cast<const MetaRenderGraphicAction&>(rAct).GetPoint(),
-                                       static_cast<const MetaRenderGraphicAction&>(rAct).GetSize(),
-                                       aBmp ));
             default:
                 OSL_FAIL("Unexpected case");
                 break;
@@ -398,7 +368,6 @@ static bool ImplIsNotTransparent( const MetaAction& rAct, const OutputDevice& rO
         case META_TEXTRECT_ACTION:
         case META_STRETCHTEXT_ACTION:
         case META_TEXTLINE_ACTION:
-        case META_RENDERGRAPHIC_ACTION:
             // all other actions: generate non-transparent output
             bRet = true;
             break;
@@ -653,13 +622,6 @@ static Rectangle ImplCalcActionBounds( const MetaAction& rAct, const OutputDevic
             OSL_FAIL("META_TEXTLINE_ACTION not supported");
         break;
 
-        case( META_RENDERGRAPHIC_ACTION ):
-        {
-            const MetaRenderGraphicAction& rRenderAct = static_cast<const MetaRenderGraphicAction&>(rAct);
-            aActionBounds = Rectangle( rRenderAct.GetPoint(), rRenderAct.GetSize() );
-        }
-        break;
-
         default:
             break;
     }
@@ -685,7 +647,6 @@ static bool ImplIsActionHandlingTransparency( const MetaAction& rAct )
         case META_BMPEX_ACTION:
         case META_BMPEXSCALE_ACTION:
         case META_BMPEXSCALEPART_ACTION:
-        case META_RENDERGRAPHIC_ACTION:
             return true;
 
         default:
