@@ -1,30 +1,22 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
+#include <boost/optional.hpp>
 #include <DomainMapperTableManager.hxx>
 #include <resourcemodel/WW8ResourceModel.hxx>
 #include <BorderHandler.hxx>
@@ -32,6 +24,7 @@
 #include <CellMarginHandler.hxx>
 #include <ConversionHelper.hxx>
 #include <MeasureHandler.hxx>
+#include <TablePositionHandler.hxx>
 #include <TDefTableHandler.hxx>
 #include <com/sun/star/text/HoriOrientation.hpp>
 #include <com/sun/star/text/SizeType.hpp>
@@ -50,13 +43,16 @@ using namespace ::std;
 
 DomainMapperTableManager::DomainMapperTableManager(bool bOOXML, bool bImplicitMerges) :
     m_nRow(0),
-    m_nCell(0),
+    m_nCell(),
     m_nGridSpan(1),
+    m_nGridBefore(0),
+    m_nGridAfter(0),
     m_nCellBorderIndex(0),
     m_nHeaderRepeat(0),
     m_nTableWidth(0),
     m_bOOXML( bOOXML ),
     m_bImplicitMerges(bImplicitMerges),
+    m_bPushCurrentWidth(false),
     m_pTablePropsHandler( new TablePropertiesHandler( bOOXML ) )
 {
     m_pTablePropsHandler->SetTableManager( this );
@@ -150,7 +146,7 @@ bool DomainMapperTableManager::sprm(Sprm & rSprm)
                     pProperties->resolve( *pTDefTableHandler );
 
                     TablePropertyMapPtr pRowPropMap( new TablePropertyMap );
-                    pRowPropMap->insert( pTDefTableHandler->getRowProperties() );
+                    pRowPropMap->InsertProps(pTDefTableHandler->getRowProperties());
                     insertRowProps( pRowPropMap );
                     if( !m_nTableWidth )
                     {
@@ -179,7 +175,7 @@ bool DomainMapperTableManager::sprm(Sprm & rSprm)
                     BorderHandlerPtr pBorderHandler( new BorderHandler(m_bOOXML) );
                     pProperties->resolve(*pBorderHandler);
                     TablePropertyMapPtr pCellPropMap( new TablePropertyMap() );
-                    pCellPropMap->insert( pBorderHandler->getProperties() );
+                    pCellPropMap->InsertProps(pBorderHandler->getProperties());
                     cellPropsByCell( m_nCellBorderIndex, pCellPropMap );
                     ++m_nCellBorderIndex;
                 }
@@ -262,13 +258,13 @@ bool DomainMapperTableManager::sprm(Sprm & rSprm)
                     // Binary filter takes BiDirection into account ( but I have no idea about that here )
                     // or even what it is. But... here's where to handle it if it becomes an issue
                         pPropMap->Insert( PROP_FRM_DIRECTION, false, uno::makeAny( VERT_TOP_RIGHT ));
-                        OSL_TRACE("Have inserted textDirection %d", nIntValue );
+                        SAL_INFO( "writerfilter", "Have inserted textDirection " << nIntValue );
                         break;
                     case 3:  // btLr
                         // We have to fake this text direction
                          pPropMap->Insert( PROP_FRM_DIRECTION, false, uno::makeAny( HORI_LEFT_TOP ));
                          pPropMap->Insert( PROP_CHAR_ROTATION, false, uno::makeAny( sal_Int16( 900 ) ));
-                        OSL_TRACE("Have inserted textDirection %d", nIntValue );
+                        SAL_INFO( "writerfilter", "Have inserted textDirection " << nIntValue );
                         break;
                     case 4: // lrTbV
                         pPropMap->Insert( PROP_FRM_DIRECTION, false, uno::makeAny( HORI_LEFT_TOP ));
@@ -288,7 +284,21 @@ bool DomainMapperTableManager::sprm(Sprm & rSprm)
                 break;
             }
             case NS_ooxml::LN_CT_TcPrBase_tcW:
-                break; //fixed column width is not supported
+                {
+                    // Contains unit and value, but unit is not interesting for
+                    // us, later we'll just distribute these values in a
+                    // 0..10000 scale.
+                    writerfilter::Reference<Properties>::Pointer_t pProperties = rSprm.getProps();
+                    if( pProperties.get())
+                    {
+                        MeasureHandlerPtr pMeasureHandler(new MeasureHandler());
+                        pProperties->resolve(*pMeasureHandler);
+                        getCurrentCellWidths()->push_back(pMeasureHandler->getMeasureValue());
+                        if (getTableDepthDifference() > 0)
+                            m_bPushCurrentWidth = true;
+                    }
+                }
+                break;
             case NS_ooxml::LN_CT_TrPrBase_cnfStyle:
                 {
                     TablePropertyMapPtr pProps( new TablePropertyMap );
@@ -306,6 +316,23 @@ bool DomainMapperTableManager::sprm(Sprm & rSprm)
                     cellProps( pProps );
                 }
                 break;
+            case NS_ooxml::LN_CT_TblPrBase_tblpPr:
+                {
+                    writerfilter::Reference<Properties>::Pointer_t pProperties = rSprm.getProps();
+                    if (pProperties.get())
+                    {
+                        TablePositionHandlerPtr pHandler( new TablePositionHandler );
+                        pProperties->resolve(*pHandler);
+                        m_sTableVertAnchor = pHandler->getVertAnchor();
+                    }
+                }
+                break;
+            case NS_ooxml::LN_CT_TrPrBase_gridBefore:
+                m_nGridBefore = nIntValue;
+                break;
+            case NS_ooxml::LN_CT_TrPrBase_gridAfter:
+                m_nGridAfter = nIntValue;
+                break;
             default:
                 bRet = false;
 
@@ -327,21 +354,48 @@ boost::shared_ptr< vector< sal_Int32 > > DomainMapperTableManager::getCurrentSpa
     return m_aGridSpans.back( );
 }
 
+boost::shared_ptr< vector< sal_Int32 > > DomainMapperTableManager::getCurrentCellWidths( )
+{
+    return m_aCellWidths.back( );
+}
+
+const OUString& DomainMapperTableManager::getTableVertAnchor() const
+{
+    return m_sTableVertAnchor;
+}
+
 void DomainMapperTableManager::startLevel( )
 {
     DomainMapperTableManager_Base_t::startLevel( );
 
+    // If requested, pop the value that was pushed too early.
+    boost::optional<sal_Int32> oCurrentWidth;
+    if (m_bPushCurrentWidth && !m_aCellWidths.empty() && !m_aCellWidths.back()->empty())
+    {
+        oCurrentWidth.reset(m_aCellWidths.back()->back());
+        m_aCellWidths.back()->pop_back();
+    }
+
     IntVectorPtr pNewGrid( new vector<sal_Int32> );
     IntVectorPtr pNewSpans( new vector<sal_Int32> );
+    IntVectorPtr pNewCellWidths( new vector<sal_Int32> );
     m_aTableGrid.push_back( pNewGrid );
     m_aGridSpans.push_back( pNewSpans );
+    m_aCellWidths.push_back( pNewCellWidths );
+    m_nCell.push_back( 0 );
     m_nTableWidth = 0;
+
+    // And push it back to the right level.
+    if (oCurrentWidth)
+        m_aCellWidths.back()->push_back(*oCurrentWidth);
 }
 
 void DomainMapperTableManager::endLevel( )
 {
     m_aTableGrid.pop_back( );
     m_aGridSpans.pop_back( );
+    m_aCellWidths.pop_back( );
+    m_nCell.pop_back( );
     m_nTableWidth = 0;
 
     DomainMapperTableManager_Base_t::endLevel( );
@@ -365,7 +419,7 @@ void DomainMapperTableManager::endOfCellAction()
 
     getCurrentSpans()->push_back(m_nGridSpan);
     m_nGridSpan = 1;
-    ++m_nCell;
+    ++m_nCell.back( );
 }
 
 
@@ -376,6 +430,7 @@ void DomainMapperTableManager::endOfRowAction()
 #endif
 
     IntVectorPtr pTableGrid = getCurrentGrid( );
+    IntVectorPtr pCellWidths = getCurrentCellWidths( );
     if(!m_nTableWidth && pTableGrid->size())
     {
         ::std::vector<sal_Int32>::const_iterator aCellIter = pTableGrid->begin();
@@ -408,10 +463,10 @@ void DomainMapperTableManager::endOfRowAction()
     }
 
     IntVectorPtr pCurrentSpans = getCurrentSpans( );
-    if( pCurrentSpans->size() < m_nCell)
+    if( pCurrentSpans->size() < m_nCell.back( ) )
     {
         //fill missing elements with '1'
-        pCurrentSpans->insert( pCurrentSpans->end( ), m_nCell - pCurrentSpans->size(), 1 );
+        pCurrentSpans->insert( pCurrentSpans->end( ), m_nCell.back( ) - pCurrentSpans->size(), 1 );
     }
 
 #ifdef DEBUG_DOMAINMAPPER
@@ -442,15 +497,15 @@ void DomainMapperTableManager::endOfRowAction()
     double nFullWidth = m_nTableWidth;
     //the positions have to be distibuted in a range of 10000
     const double nFullWidthRelative = 10000.;
-    if( pTableGrid->size() == nGrids && m_nCell > 0 )
+    if( pTableGrid->size() == ( m_nGridBefore + nGrids + m_nGridAfter ) && m_nCell.back( ) > 0 )
     {
-        uno::Sequence< text::TableColumnSeparator > aSeparators( m_nCell - 1 );
+        uno::Sequence< text::TableColumnSeparator > aSeparators( m_nCell.back( ) - 1 );
         text::TableColumnSeparator* pSeparators = aSeparators.getArray();
         sal_Int16 nLastRelPos = 0;
-        sal_uInt32 nBorderGridIndex = 0;
+        sal_uInt32 nBorderGridIndex = m_nGridBefore;
 
         ::std::vector< sal_Int32 >::const_iterator aSpansIter = pCurrentSpans->begin( );
-        for( sal_uInt32 nBorder = 0; nBorder < m_nCell - 1; ++nBorder )
+        for( sal_uInt32 nBorder = 0; nBorder < m_nCell.back( ) - 1; ++nBorder )
         {
             sal_Int32 nGridCount = *aSpansIter;
             double fGridWidth = 0.;
@@ -460,7 +515,7 @@ void DomainMapperTableManager::endOfRowAction()
             }while( --nGridCount );
 
             sal_Int16 nRelPos =
-                sal::static_int_cast< sal_Int16 >(fGridWidth * nFullWidthRelative / nFullWidth );
+                sal::static_int_cast< sal_Int16 >( floor( fGridWidth * nFullWidthRelative / nFullWidth  + 0.5 ) );
 
             pSeparators[nBorder].Position =  nRelPos + nLastRelPos;
             pSeparators[nBorder].IsVisible = sal_True;
@@ -481,14 +536,14 @@ void DomainMapperTableManager::endOfRowAction()
     {
         // More grid than cells definitions? Then take the last ones.
         // This feature is used by the RTF implicit horizontal cell merges.
-        uno::Sequence< text::TableColumnSeparator > aSeparators(m_nCell - 1);
+        uno::Sequence< text::TableColumnSeparator > aSeparators(m_nCell.back( ) - 1);
         text::TableColumnSeparator* pSeparators = aSeparators.getArray();
 
         sal_Int16 nSum = 0;
         sal_uInt32 nPos = 0;
         sal_uInt32 nSizeTableGrid = pTableGrid->size();
         // Ignoring the i=0 case means we assume that the width of the last cell matches the table width
-        for (sal_uInt32 i = m_nCell; i > 1 && nSizeTableGrid >= i; i--)
+        for (sal_uInt32 i = m_nCell.back( ); i > 1 && nSizeTableGrid >= i; i--)
         {
             nSum += (*pTableGrid.get())[pTableGrid->size() - i]; // Size of the current cell
             pSeparators[nPos].Position = nSum * nFullWidthRelative / nFullWidth; // Relative position
@@ -505,11 +560,42 @@ void DomainMapperTableManager::endOfRowAction()
 #endif
         insertRowProps(pPropMap);
     }
+    else if (pCellWidths->size() > 0)
+    {
+        // If we're here, then the number of cells does not equal to the amount
+        // defined by the grid, even after taking care of
+        // gridSpan/gridBefore/gridAfter. Handle this by ignoring the grid and
+        // providing the separators based on the provided cell widths.
+        uno::Sequence< text::TableColumnSeparator > aSeparators(pCellWidths->size() - 1);
+        text::TableColumnSeparator* pSeparators = aSeparators.getArray();
+        sal_Int16 nSum = 0;
+        sal_uInt32 nPos = 0;
+
+        for (sal_uInt32 i = 0; i < pCellWidths->size() - 1; ++i)
+        {
+            nSum += (*pCellWidths.get())[i];
+            pSeparators[nPos].Position = nSum * nFullWidthRelative / nFullWidth;
+            pSeparators[nPos].IsVisible = sal_True;
+            nPos++;
+        }
+
+        TablePropertyMapPtr pPropMap( new TablePropertyMap );
+        pPropMap->Insert( PROP_TABLE_COLUMN_SEPARATORS, false, uno::makeAny( aSeparators ) );
+#ifdef DEBUG_DOMAINMAPPER
+        dmapper_logger->startElement("rowProperties");
+        pPropMap->dumpXml( dmapper_logger );
+        dmapper_logger->endElement();
+#endif
+        insertRowProps(pPropMap);
+    }
 
     ++m_nRow;
-    m_nCell = 0;
+    m_nCell.back( ) = 0;
     m_nCellBorderIndex = 0;
     pCurrentSpans->clear();
+    pCellWidths->clear();
+
+    m_nGridBefore = m_nGridAfter = 0;
 
 #ifdef DEBUG_DOMAINMAPPER
     dmapper_logger->endElement();
@@ -519,8 +605,9 @@ void DomainMapperTableManager::endOfRowAction()
 
 void DomainMapperTableManager::clearData()
 {
-    m_nRow = m_nCell = m_nCellBorderIndex = m_nHeaderRepeat = m_nTableWidth = 0;
-    m_sTableStyleName = ::rtl::OUString();
+    m_nRow = m_nCellBorderIndex = m_nHeaderRepeat = m_nTableWidth = 0;
+    m_sTableStyleName = OUString();
+    m_sTableVertAnchor = OUString();
     m_pTableStyleTextProperies.reset();
 }
 
@@ -531,7 +618,7 @@ void lcl_CopyTextProperties(PropertyMapPtr pToFill,
     if( !pStyleSheetEntry )
         return;
     //fill base style properties first, recursively
-    if( pStyleSheetEntry->sBaseStyleIdentifier.getLength())
+    if( !pStyleSheetEntry->sBaseStyleIdentifier.isEmpty())
     {
         const StyleSheetEntryPtr pParentStyleSheet =
             pStyleSheetTable->FindStyleSheetByISTD(pStyleSheetEntry->sBaseStyleIdentifier);
@@ -558,7 +645,7 @@ void DomainMapperTableManager::CopyTextProperties(PropertyMapPtr pContext, Style
         OSL_ENSURE( pStyleSheetEntry, "table style not found" );
         lcl_CopyTextProperties(m_pTableStyleTextProperies, pStyleSheetEntry.get( ), pStyleSheetTable);
     }
-    pContext->insert( m_pTableStyleTextProperies );
+    pContext->InsertProps(m_pTableStyleTextProperies);
 }
 
 
