@@ -1,4 +1,21 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/*
+ * This file is part of the LibreOffice project.
+ *
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * This file incorporates work covered by the following license notice:
+ *
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 #include "ConversionHelper.hxx"
 #include "GraphicHelpers.hxx"
 
@@ -117,7 +134,7 @@ void PositionHandler::lcl_sprm( Sprm& )
 {
 }
 
-void PositionHandler::setPositionOffset(const ::rtl::OUString & sText, bool vertical)
+void PositionHandler::setPositionOffset(const OUString & sText, bool vertical)
 {
     if( vertical )
         savedPositionOffsetV = ConversionHelper::convertEMUToMM100( sText.toInt32());
@@ -125,31 +142,31 @@ void PositionHandler::setPositionOffset(const ::rtl::OUString & sText, bool vert
         savedPositionOffsetH = ConversionHelper::convertEMUToMM100( sText.toInt32());
 }
 
-void PositionHandler::setAlignH(const ::rtl::OUString & sText)
+void PositionHandler::setAlignH(const OUString & sText)
 {
-    if( sText == rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "left" )))
+    if( sText == "left")
         savedAlignH = text::HoriOrientation::LEFT;
-    else if( sText == rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "right" )))
+    else if( sText == "right" )
         savedAlignH = text::HoriOrientation::RIGHT;
-    else if( sText == rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "center" )))
+    else if( sText == "center" )
         savedAlignH = text::HoriOrientation::CENTER;
-    else if( sText == rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "inside" )))
+    else if( sText == "inside" )
         savedAlignH = text::HoriOrientation::INSIDE;
-    else if( sText == rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "outside" )))
+    else if( sText == "outside" )
         savedAlignH = text::HoriOrientation::OUTSIDE;
 }
 
-void PositionHandler::setAlignV(const ::rtl::OUString & sText)
+void PositionHandler::setAlignV(const OUString & sText)
 {
-    if( sText == rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "top" )))
+    if( sText == "top" )
         savedAlignV = text::VertOrientation::TOP;
-    else if( sText == rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "bottom" )))
+    else if( sText == "bottom" )
         savedAlignV = text::VertOrientation::BOTTOM;
-    else if( sText == rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "center" )))
+    else if( sText == "center" )
         savedAlignV = text::VertOrientation::CENTER;
-    else if( sText == rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "inside" )))
+    else if( sText == "inside" )
         savedAlignV = text::VertOrientation::NONE;
-    else if( sText == rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "outside" )))
+    else if( sText == "outside" )
         savedAlignV = text::VertOrientation::NONE;
 }
 
@@ -208,7 +225,6 @@ sal_Int32 WrapHandler::getWrapMode( )
                 }
             }
             break;
-            break;
         case NS_ooxml::LN_Value_vml_wordprocessingDrawing_ST_WrapType_topAndBottom:
             nMode = com::sun::star::text::WrapTextMode_NONE;
             break;
