@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
  * Version: MPL 1.1 / GPLv3+ / LGPLv3+
  *
@@ -43,7 +44,7 @@ RTFSkipDestination::~RTFSkipDestination()
     {
         if (!m_bParsed)
         {
-            OSL_TRACE("%s: skipping destination", OSL_THIS_FUNC);
+            SAL_INFO("writerfilter", OSL_THIS_FUNC << ": skipping destination");
             m_rImport.getState().nDestinationState = DESTINATION_SKIP;
         }
         m_rImport.setSkipUnknown(false);
