@@ -1,35 +1,27 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
+ * This file is part of the LibreOffice project.
  *
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * Copyright 2000, 2010 Oracle and/or its affiliates.
+ * This file incorporates work covered by the following license notice:
  *
- * OpenOffice.org - a multi-platform office productivity suite
- *
- * This file is part of OpenOffice.org.
- *
- * OpenOffice.org is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3
- * only, as published by the Free Software Foundation.
- *
- * OpenOffice.org is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License version 3 for more details
- * (a copy is included in the LICENSE file that accompanied this code).
- *
- * You should have received a copy of the GNU Lesser General Public License
- * version 3 along with OpenOffice.org.  If not, see
- * <http://www.openoffice.org/license.html>
- * for a copy of the LGPLv3 License.
- *
- ************************************************************************/
+ *   Licensed to the Apache Software Foundation (ASF) under one or more
+ *   contributor license agreements. See the NOTICE file distributed
+ *   with this work for additional information regarding copyright
+ *   ownership. The ASF licenses this file to you under the Apache
+ *   License, Version 2.0 (the "License"); you may not use this file
+ *   except in compliance with the License. You may obtain a copy of
+ *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
+ */
 
 #include <com/sun/star/container/XNameContainer.hpp>
 #include <com/sun/star/xml/AttributeData.hpp>
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/beans/XPropertyState.hpp>
+#include <com/sun/star/lang/XTypeProvider.hpp>
 #include <com/sun/star/beans/XMultiPropertySet.hpp>
 #include <com/sun/star/beans/XTolerantMultiPropertySet.hpp>
 #include <com/sun/star/beans/TolerantPropertySetResultType.hpp>
@@ -228,7 +220,7 @@ public:
 
 typedef boost::unordered_map
 <
-    Reference< XPropertySetInfo >,
+    PropertySetInfoKey,
     FilterPropertiesInfo_Impl *,
     PropertySetInfoHash,
     PropertySetInfoHash
@@ -628,12 +620,24 @@ vector< XMLPropertyState > SvXMLExportPropertyMapper::_Filter(
 
     FilterPropertiesInfo_Impl *pFilterInfo = 0;
 
-    if( pCache )
+    Reference < XTypeProvider > xTypeProv( xPropSet, UNO_QUERY );
+    Sequence< sal_Int8 > aImplId;
+    if( xTypeProv.is() )
     {
-        FilterPropertiesInfos_Impl::iterator aIter =
-            pCache->find( xInfo );
-        if( aIter != pCache->end() )
-            pFilterInfo = (*aIter).second;
+        aImplId = xTypeProv->getImplementationId();
+        if( aImplId.getLength() == 16 )
+        {
+            if( pCache )
+            {
+                // The key must not be created outside this block, because it
+                // keeps a reference to the property set info.
+                PropertySetInfoKey aKey( xInfo, aImplId );
+                FilterPropertiesInfos_Impl::iterator aIter =
+                    pCache->find( aKey );
+                if( aIter != pCache->end() )
+                    pFilterInfo = (*aIter).second;
+            }
+        }
     }
 
     sal_Bool bDelInfo = sal_False;
@@ -660,22 +664,31 @@ vector< XMLPropertyState > SvXMLExportPropertyMapper::_Filter(
             }
         }
 
-        // Check whether the property set info is destroyed if it is
-        // assigned to a weak reference only. If it is destroyed, then
-        // every instance of getPropertySetInfo returns a new object.
-        // Such property set infos must not be cached.
-        WeakReference < XPropertySetInfo > xWeakInfo( xInfo );
-        xInfo = 0;
-        xInfo = xWeakInfo;
-        if( xInfo.is() )
+        if( xTypeProv.is() && aImplId.getLength() == 16 )
         {
-            if( !pCache )
-                ((SvXMLExportPropertyMapper *)this)->pCache =
-                    new FilterPropertiesInfos_Impl;
-            (*pCache)[xInfo] = pFilterInfo;
+            // Check whether the property set info is destroyed if it is
+            // assigned to a weak reference only. If it is destroyed, then
+            // every instance of getPropertySetInfo returns a new object.
+            // Such property set infos must not be cached.
+            WeakReference < XPropertySetInfo > xWeakInfo( xInfo );
+            xInfo = 0;
+            xInfo = xWeakInfo;
+            if( xInfo.is() )
+            {
+                if( !pCache )
+                    ((SvXMLExportPropertyMapper *)this)->pCache =
+                        new FilterPropertiesInfos_Impl;
+                PropertySetInfoKey aKey( xInfo, aImplId );
+                (*pCache)[aKey] = pFilterInfo;
+            }
+            else
+                bDelInfo = sal_True;
         }
         else
+        {
+            OSL_FAIL("here is no TypeProvider or the ImplId is wrong");
             bDelInfo = sal_True;
+        }
     }
 
     if( pFilterInfo->GetPropertyCount() )
@@ -790,19 +803,6 @@ void SvXMLExportPropertyMapper::exportXML( SvXMLAttributeList& rAttrList,
 }
 */
 
-
-void SvXMLExportPropertyMapper::exportXML( SvXMLAttributeList& rAttrList,
-        const XMLPropertyState& rProperty,
-        const SvXMLUnitConverter& rUnitConverter,
-        const SvXMLNamespaceMap& rNamespaceMap,
-        sal_uInt16 nFlags ) const
-{
-    if( ( maPropMapper->GetEntryFlags( rProperty.mnIndex ) &
-                MID_FLAG_ELEMENT_ITEM_EXPORT ) == 0 )
-        _exportXML( rAttrList, rProperty, rUnitConverter, rNamespaceMap,
-                    nFlags );
-}
-
 void SvXMLExportPropertyMapper::exportXML(
         SvXMLExport& rExport,
         const ::std::vector< XMLPropertyState >& rProperties,
@@ -946,8 +946,6 @@ void SvXMLExportPropertyMapper::_exportXML(
         const ::std::vector< XMLPropertyState > *pProperties,
         sal_uInt32 nIdx ) const
 {
-    OUString sCDATA( GetXMLToken(XML_CDATA) );
-
     if ( ( maPropMapper->GetEntryFlags( rProperty.mnIndex ) &
                 MID_FLAG_SPECIAL_ITEM_EXPORT ) != 0 )
     {
@@ -976,7 +974,7 @@ void SvXMLExportPropertyMapper::_exportXML(
                 if( nColonPos != -1 )
                     sPrefix = pAttribName->copy( 0, nColonPos );
 
-                if( sPrefix.getLength() )
+                if( !sPrefix.isEmpty() )
                 {
                     OUString sNamespace( aData.Namespace );
 
@@ -1044,9 +1042,9 @@ void SvXMLExportPropertyMapper::_exportXML(
                     }
                 }
                 OUString sOldValue( rAttrList.getValueByName( sAttribName ) );
-                OSL_ENSURE( sOldValue.getLength() == 0, "alien attribute exists already" );
+                OSL_ENSURE( sOldValue.isEmpty(), "alien attribute exists already" );
                 OSL_ENSURE(aData.Type == GetXMLToken(XML_CDATA), "different type to our default type which should be written out");
-                if( !sOldValue.getLength() )
+                if( sOldValue.isEmpty() )
                     rAttrList.AddAttribute( sAttribName, aData.Value );
             }
 
@@ -1092,7 +1090,6 @@ void SvXMLExportPropertyMapper::exportElementItems(
     const sal_uInt16 nCount = rIndexArray.size();
 
     sal_Bool bItemsExported = sal_False;
-    OUString sWS( GetXMLToken(XML_WS) );
     for( sal_uInt16 nIndex = 0; nIndex < nCount; nIndex++ )
     {
         const sal_uInt16 nElement = rIndexArray[nIndex];
